@@ -38,9 +38,9 @@ using namespace ::com::sun::star::accessibility;
 
 namespace
 {
-    // =========================================================================
+
     // = OToolBoxWindowItemContext
-    // =========================================================================
+
     /** XAccessibleContext implementation for a toolbox item which is represented by a VCL Window
     */
     class OToolBoxWindowItemContext : public OAccessibleContextWrapper
@@ -60,19 +60,19 @@ namespace
             ,m_nIndexInParent(_nIndexInParent)
         {
         }
-        virtual sal_Int32 SAL_CALL getAccessibleIndexInParent(  ) throw (::com::sun::star::uno::RuntimeException);
+        virtual sal_Int32 SAL_CALL getAccessibleIndexInParent(  ) throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
     };
 
-    // -------------------------------------------------------------------------
-    sal_Int32 SAL_CALL OToolBoxWindowItemContext::getAccessibleIndexInParent(  ) throw (::com::sun::star::uno::RuntimeException)
+
+    sal_Int32 SAL_CALL OToolBoxWindowItemContext::getAccessibleIndexInParent(  ) throw (::com::sun::star::uno::RuntimeException, std::exception)
     {
         ::osl::MutexGuard aGuard( m_aMutex );
         return m_nIndexInParent;
     }
 
-    // =========================================================================
+
     // = OToolBoxWindowItem
-    // =========================================================================
+
     typedef ::cppu::ImplHelper1 <   XUnoTunnel
                                 >   OToolBoxWindowItem_Base;
 
@@ -89,7 +89,7 @@ namespace
         inline sal_Int32    getIndexInParent() const                    { return m_nIndexInParent; }
         inline void         setIndexInParent( sal_Int32 _nNewIndex )    { m_nIndexInParent = _nNewIndex; }
 
-        static  sal_Bool    isWindowItem( const Reference< XAccessible >& _rxAcc, OToolBoxWindowItem** /* [out] */ _ppImplementation = NULL );
+        static  bool    isWindowItem( const Reference< XAccessible >& _rxAcc, OToolBoxWindowItem** /* [out] */ _ppImplementation = NULL );
 
     public:
         OToolBoxWindowItem(sal_Int32 _nIndexInParent,
@@ -112,26 +112,23 @@ namespace
         // OAccessibleWrapper
         virtual OAccessibleContextWrapper* createAccessibleContext(
                 const ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessibleContext >& _rxInnerContext
-            );
+            ) SAL_OVERRIDE;
 
         // XUnoTunnel
-        virtual sal_Int64 SAL_CALL getSomething( const Sequence< sal_Int8 >& aIdentifier ) throw (RuntimeException);
+        virtual sal_Int64 SAL_CALL getSomething( const Sequence< sal_Int8 >& aIdentifier ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
         static Sequence< sal_Int8 > getUnoTunnelImplementationId();
     };
 
-    // -------------------------------------------------------------------------
     IMPLEMENT_FORWARD_XINTERFACE2( OToolBoxWindowItem, OAccessibleWrapper, OToolBoxWindowItem_Base )
     IMPLEMENT_FORWARD_XTYPEPROVIDER2( OToolBoxWindowItem, OAccessibleWrapper, OToolBoxWindowItem_Base )
 
-    // -------------------------------------------------------------------------
     OAccessibleContextWrapper* OToolBoxWindowItem::createAccessibleContext(
             const Reference< XAccessibleContext >& _rxInnerContext )
     {
         return new OToolBoxWindowItemContext( m_nIndexInParent, getComponentContext(), _rxInnerContext, this, getParent() );
     }
 
-    //--------------------------------------------------------------------
-    sal_Bool OToolBoxWindowItem::isWindowItem( const Reference< XAccessible >& _rxAcc, OToolBoxWindowItem** /* [out] */ _ppImplementation )
+    bool OToolBoxWindowItem::isWindowItem( const Reference< XAccessible >& _rxAcc, OToolBoxWindowItem** /* [out] */ _ppImplementation )
     {
         OToolBoxWindowItem* pImplementation = NULL;
 
@@ -145,7 +142,6 @@ namespace
         return NULL != pImplementation;
     }
 
-    //--------------------------------------------------------------------
     Sequence< sal_Int8 > OToolBoxWindowItem::getUnoTunnelImplementationId()
     {
         static ::cppu::OImplementationId * pId = 0;
@@ -161,8 +157,7 @@ namespace
         return pId->getImplementationId();
     }
 
-    //--------------------------------------------------------------------
-    sal_Int64 SAL_CALL OToolBoxWindowItem::getSomething( const Sequence< sal_Int8 >& _rId ) throw (RuntimeException)
+    sal_Int64 SAL_CALL OToolBoxWindowItem::getSomething( const Sequence< sal_Int8 >& _rId ) throw (RuntimeException, std::exception)
     {
         if  (   ( 16 == _rId.getLength() )
             &&  ( 0 == memcmp( getUnoTunnelImplementationId().getConstArray(),  _rId.getConstArray(), 16 ) )
@@ -173,53 +168,51 @@ namespace
     }
 }
 
-// -----------------------------------------------------------------------------
 // VCLXAccessibleToolBox
-// -----------------------------------------------------------------------------
+
 VCLXAccessibleToolBox::VCLXAccessibleToolBox( VCLXWindow* pVCLXWindow ) :
 
     VCLXAccessibleComponent( pVCLXWindow )
 
 {
 }
-// -----------------------------------------------------------------------------
+
 VCLXAccessibleToolBox::~VCLXAccessibleToolBox()
 {
 }
-// -----------------------------------------------------------------------------
+
 VCLXAccessibleToolBoxItem* VCLXAccessibleToolBox::GetItem_Impl( sal_Int32 _nPos, bool _bMustHaveFocus )
 {
     VCLXAccessibleToolBoxItem* pItem = NULL;
-    ToolBox* pToolBox = static_cast< ToolBox* >( GetWindow() );
+    VclPtr< ToolBox > pToolBox = GetAs< ToolBox >();
     if ( pToolBox && ( !_bMustHaveFocus || pToolBox->HasFocus() ) )
     {
         ToolBoxItemsMap::iterator aIter = m_aAccessibleChildren.find( _nPos );
         // returns only toolbox buttons, not windows
-        if ( aIter != m_aAccessibleChildren.end()  && !aIter->second.is())
+        if ( aIter != m_aAccessibleChildren.end()  && aIter->second.is())
             pItem = static_cast< VCLXAccessibleToolBoxItem* >( aIter->second.get() );
     }
 
     return pItem;
 }
-// -----------------------------------------------------------------------------
 
 void VCLXAccessibleToolBox::UpdateFocus_Impl()
 {
-    ToolBox* pToolBox = static_cast< ToolBox* >( GetWindow() );
+    VclPtr< ToolBox > pToolBox = GetAs< ToolBox >();
     if( !pToolBox )
         return;
 
     // submit events only if toolbox has the focus to avoid sending events due to mouse move
-    sal_Bool bHasFocus = sal_False;
+    bool bHasFocus = false;
     if ( pToolBox->HasFocus() )
-        bHasFocus = sal_True;
+        bHasFocus = true;
     else
     {
         // check for subtoolbar, i.e. check if our parent is a toolbar
         ToolBox* pToolBoxParent = dynamic_cast< ToolBox* >( pToolBox->GetParent() );
         // subtoolbars never get the focus as key input is just forwarded, so check if the parent toolbar has it
         if ( pToolBoxParent && pToolBoxParent->HasFocus() )
-            bHasFocus = sal_True;
+            bHasFocus = true;
     }
 
     if ( bHasFocus )
@@ -238,13 +231,13 @@ void VCLXAccessibleToolBox::UpdateFocus_Impl()
                 if ( pItem->HasFocus() && nItemId != nHighlightItemId )
                 {
                     // reset the old focused item
-                    pItem->SetFocus( sal_False );
+                    pItem->SetFocus( false );
                     nFocusCount++;
                 }
                 if ( nItemId == nHighlightItemId )
                 {
                     // set the new focused item
-                    pItem->SetFocus( sal_True );
+                    pItem->SetFocus( true );
                     nFocusCount++;
                 }
             }
@@ -254,10 +247,10 @@ void VCLXAccessibleToolBox::UpdateFocus_Impl()
         }
     }
 }
-// -----------------------------------------------------------------------------
+
 void VCLXAccessibleToolBox::ReleaseFocus_Impl( sal_Int32 _nPos )
 {
-    ToolBox* pToolBox = static_cast< ToolBox* >( GetWindow() );
+    VclPtr< ToolBox > pToolBox = GetAs< ToolBox >();
     if ( pToolBox ) // #107124#, do not check for focus because this message is also handled in losefocus
     {
         ToolBoxItemsMap::iterator aIter = m_aAccessibleChildren.find( _nPos );
@@ -266,16 +259,19 @@ void VCLXAccessibleToolBox::ReleaseFocus_Impl( sal_Int32 _nPos )
             VCLXAccessibleToolBoxItem* pItem =
                 static_cast< VCLXAccessibleToolBoxItem* >( aIter->second.get() );
             if ( pItem->HasFocus() )
-                pItem->SetFocus( sal_False );
+                pItem->SetFocus( false );
         }
     }
 }
-// -----------------------------------------------------------------------------
-void VCLXAccessibleToolBox::UpdateChecked_Impl( sal_Int32  )
+
+void VCLXAccessibleToolBox::UpdateChecked_Impl( sal_Int32 _nPos )
 {
-    ToolBox* pToolBox = static_cast< ToolBox* >( GetWindow() );
+    VclPtr< ToolBox > pToolBox = GetAs< ToolBox >();
     if ( pToolBox )
     {
+        sal_uInt16 nFocusId = pToolBox->GetItemId( (sal_uInt16)_nPos );
+        VCLXAccessibleToolBoxItem* pFocusItem = NULL;
+
         for ( ToolBoxItemsMap::iterator aIter = m_aAccessibleChildren.begin();
               aIter != m_aAccessibleChildren.end(); ++aIter )
         {
@@ -284,13 +280,18 @@ void VCLXAccessibleToolBox::UpdateChecked_Impl( sal_Int32  )
                 VCLXAccessibleToolBoxItem* pItem =
                     static_cast< VCLXAccessibleToolBoxItem* >( aIter->second.get() );
                 pItem->SetChecked( pToolBox->IsItemChecked( nItemId ) );
+                if ( nItemId == nFocusId )
+                    pFocusItem = pItem;
         }
+        //Solution:If the position is not a child item,the focus should not be called
+        if ( pFocusItem && (sal_uInt16)_nPos != TOOLBOX_ITEM_NOTFOUND )
+            pFocusItem->SetFocus( true );
     }
 }
-// -----------------------------------------------------------------------------
+
 void VCLXAccessibleToolBox::UpdateIndeterminate_Impl( sal_Int32 _nPos )
 {
-    ToolBox* pToolBox = static_cast< ToolBox* >( GetWindow() );
+    VclPtr< ToolBox > pToolBox = GetAs< ToolBox >();
     if ( pToolBox )
     {
         sal_uInt16 nItemId = pToolBox->GetItemId( (sal_uInt16)_nPos );
@@ -301,11 +302,11 @@ void VCLXAccessibleToolBox::UpdateIndeterminate_Impl( sal_Int32 _nPos )
             VCLXAccessibleToolBoxItem* pItem =
                 static_cast< VCLXAccessibleToolBoxItem* >( aIter->second.get() );
             if ( pItem )
-                pItem->SetIndeterminate( pToolBox->GetItemState( nItemId ) == STATE_DONTKNOW );
+                pItem->SetIndeterminate( pToolBox->GetItemState( nItemId ) == TRISTATE_INDET );
         }
     }
 }
-// -----------------------------------------------------------------------------
+
 void VCLXAccessibleToolBox::implReleaseToolboxItem( ToolBoxItemsMap::iterator& _rMapPos,
         bool _bNotifyRemoval, bool _bDispose )
 {
@@ -338,8 +339,7 @@ void VCLXAccessibleToolBox::implReleaseToolboxItem( ToolBoxItemsMap::iterator& _
     }
 }
 
-// -----------------------------------------------------------------------------
-void VCLXAccessibleToolBox::UpdateItem_Impl( sal_Int32 _nPos, sal_Bool _bItemAdded )
+void VCLXAccessibleToolBox::UpdateItem_Impl( sal_Int32 _nPos, bool _bItemAdded )
 {
     if ( _nPos < sal_Int32( m_aAccessibleChildren.size() ) )
     {
@@ -347,7 +347,7 @@ void VCLXAccessibleToolBox::UpdateItem_Impl( sal_Int32 _nPos, sal_Bool _bItemAdd
         return;
     }
 
-    ToolBox* pToolBox = static_cast< ToolBox* >( GetWindow() );
+    VclPtr< ToolBox > pToolBox = GetAs< ToolBox >();
     if ( pToolBox )
     {
         if ( !_bItemAdded )
@@ -400,10 +400,10 @@ void VCLXAccessibleToolBox::UpdateItem_Impl( sal_Int32 _nPos, sal_Bool _bItemAdd
         }
     }
 }
-// -----------------------------------------------------------------------------
+
 void VCLXAccessibleToolBox::UpdateAllItems_Impl()
 {
-    ToolBox* pToolBox = static_cast< ToolBox* >( GetWindow() );
+    VclPtr< ToolBox > pToolBox = GetAs< ToolBox >();
     if ( pToolBox )
     {
         // deregister the old items
@@ -425,17 +425,21 @@ void VCLXAccessibleToolBox::UpdateAllItems_Impl()
     }
 }
 
-// -----------------------------------------------------------------------------
-
-void VCLXAccessibleToolBox::UpdateCustomPopupItemp_Impl( Window* pWindow, bool bOpen )
+void VCLXAccessibleToolBox::UpdateCustomPopupItemp_Impl( vcl::Window* pWindow, bool bOpen )
 {
-    ToolBox* pToolBox = static_cast< ToolBox* >( GetWindow() );
+    VclPtr< ToolBox > pToolBox = GetAs< ToolBox >();
     if( pWindow && pToolBox )
     {
+        const sal_uInt16 nDownItem = pToolBox->GetDownItemId();
+        if ( !nDownItem )
+            // Items with ItemId == 0 are not allowed in ToolBox, which means that currently no item is in down state.
+            // Moreover, running GetItemPos with 0 could find a separator item if there is any.
+            return;
+
         Reference< XAccessible > xChild( pWindow->GetAccessible() );
         if( xChild.is() )
         {
-            Reference< XAccessible > xChildItem( getAccessibleChild( static_cast< sal_Int32 >( pToolBox->GetItemPos( pToolBox->GetDownItemId() ) ) ) );
+            Reference< XAccessible > xChildItem( getAccessibleChild( static_cast< sal_Int32 >( pToolBox->GetItemPos( nDownItem ) ) ) );
             VCLXAccessibleToolBoxItem* pItem = static_cast< VCLXAccessibleToolBoxItem* >( xChildItem.get() );
 
             pItem->SetChild( xChild );
@@ -444,25 +448,24 @@ void VCLXAccessibleToolBox::UpdateCustomPopupItemp_Impl( Window* pWindow, bool b
     }
 }
 
-// -----------------------------------------------------------------------------
 void VCLXAccessibleToolBox::UpdateItemName_Impl( sal_Int32 _nPos )
 {
     VCLXAccessibleToolBoxItem* pItem = GetItem_Impl( _nPos, false );
     if ( pItem )
         pItem->NameChanged();
 }
-// -----------------------------------------------------------------------------
+
 void VCLXAccessibleToolBox::UpdateItemEnabled_Impl( sal_Int32 _nPos )
 {
     VCLXAccessibleToolBoxItem* pItem = GetItem_Impl( _nPos, false );
     if ( pItem )
         pItem->ToggleEnableState();
 }
-// -----------------------------------------------------------------------------
+
 void VCLXAccessibleToolBox::HandleSubToolBarEvent( const VclWindowEvent& rVclWindowEvent, bool _bShow )
 {
-    Window* pChildWindow = (Window *) rVclWindowEvent.GetData();
-    ToolBox* pToolBox = static_cast< ToolBox* >( GetWindow() );
+    vcl::Window* pChildWindow = static_cast<vcl::Window *>(rVclWindowEvent.GetData());
+    VclPtr< ToolBox > pToolBox = GetAs< ToolBox >();
     if ( pChildWindow
         && pToolBox
         && pToolBox == pChildWindow->GetParent()
@@ -480,10 +483,10 @@ void VCLXAccessibleToolBox::HandleSubToolBarEvent( const VclWindowEvent& rVclWin
         }
     }
 }
-// -----------------------------------------------------------------------------
+
 void VCLXAccessibleToolBox::ReleaseSubToolBox( ToolBox* _pSubToolBox )
 {
-    ToolBox* pToolBox = static_cast< ToolBox* >( GetWindow() );
+    VclPtr< ToolBox > pToolBox = GetAs< ToolBox >();
     if ( !pToolBox )
         return;
 
@@ -504,12 +507,12 @@ void VCLXAccessibleToolBox::ReleaseSubToolBox( ToolBox* _pSubToolBox )
         pItem->NotifyChildEvent( xChild, false );
     }
 }
-// -----------------------------------------------------------------------------
+
 void VCLXAccessibleToolBox::FillAccessibleStateSet( utl::AccessibleStateSetHelper& rStateSet )
 {
     VCLXAccessibleComponent::FillAccessibleStateSet( rStateSet );
 
-    ToolBox* pToolBox = static_cast< ToolBox* >( GetWindow() );
+    VclPtr< ToolBox > pToolBox = GetAs< ToolBox >();
     if ( pToolBox )
     {
         rStateSet.AddState( AccessibleStateType::FOCUSABLE );
@@ -519,7 +522,7 @@ void VCLXAccessibleToolBox::FillAccessibleStateSet( utl::AccessibleStateSetHelpe
             rStateSet.AddState( AccessibleStateType::VERTICAL );
     }
 }
-// -----------------------------------------------------------------------------
+
 void VCLXAccessibleToolBox::ProcessWindowEvent( const VclWindowEvent& rVclWindowEvent )
 {
     // to prevent an early release of the toolbox (VCLEVENT_OBJECT_DYING)
@@ -528,31 +531,47 @@ void VCLXAccessibleToolBox::ProcessWindowEvent( const VclWindowEvent& rVclWindow
     switch ( rVclWindowEvent.GetId() )
     {
         case VCLEVENT_TOOLBOX_CLICK:
+        case VCLEVENT_TOOLBOX_SELECT:
         {
+            VclPtr< ToolBox > pToolBox = GetAs< ToolBox >();
             if ( rVclWindowEvent.GetData() )
             {
-                UpdateChecked_Impl( (sal_Int32)(sal_IntPtr)rVclWindowEvent.GetData() );
-                UpdateIndeterminate_Impl( (sal_Int32)(sal_IntPtr)rVclWindowEvent.GetData() );
+                UpdateChecked_Impl( (sal_Int32)reinterpret_cast<sal_IntPtr>(rVclWindowEvent.GetData()) );
+                UpdateIndeterminate_Impl( (sal_Int32)reinterpret_cast<sal_IntPtr>(rVclWindowEvent.GetData()) );
+            }
+            else if( pToolBox->GetItemPos(pToolBox->GetCurItemId()) != TOOLBOX_ITEM_NOTFOUND )
+            {
+                UpdateChecked_Impl( pToolBox->GetItemPos(pToolBox->GetCurItemId()) );
+                        UpdateIndeterminate_Impl( pToolBox->GetItemPos(pToolBox->GetCurItemId()) );
             }
             break;
         }
         case VCLEVENT_TOOLBOX_DOUBLECLICK:
         case VCLEVENT_TOOLBOX_ACTIVATE:
         case VCLEVENT_TOOLBOX_DEACTIVATE:
-        case VCLEVENT_TOOLBOX_SELECT:
+        //case VCLEVENT_TOOLBOX_SELECT:
             break;
 
+        case VCLEVENT_TOOLBOX_ITEMUPDATED:
+        {
+            if ( rVclWindowEvent.GetData() )
+            {
+                UpdateChecked_Impl( TOOLBOX_ITEM_NOTFOUND );
+                UpdateIndeterminate_Impl( (sal_Int32)reinterpret_cast<sal_IntPtr>(rVclWindowEvent.GetData()) );
+            }
+        break;
+        }
+
         case VCLEVENT_TOOLBOX_HIGHLIGHT:
             UpdateFocus_Impl();
             break;
 
         case VCLEVENT_TOOLBOX_HIGHLIGHTOFF:
-            ReleaseFocus_Impl( (sal_Int32)(sal_IntPtr)rVclWindowEvent.GetData() );
+            ReleaseFocus_Impl( (sal_Int32)reinterpret_cast<sal_IntPtr>(rVclWindowEvent.GetData()) );
             break;
 
         case VCLEVENT_TOOLBOX_ITEMADDED :
-//            UpdateItem_Impl( (sal_Int32)(sal_IntPtr)rVclWindowEvent.GetData(), VCLEVENT_TOOLBOX_ITEMADDED == rVclWindowEvent.GetId() );
-            UpdateItem_Impl( (sal_Int32)(sal_IntPtr)rVclWindowEvent.GetData(), sal_True );
+            UpdateItem_Impl( (sal_Int32)reinterpret_cast<sal_IntPtr>(rVclWindowEvent.GetData()), true );
             break;
 
         case VCLEVENT_TOOLBOX_ITEMREMOVED :
@@ -564,7 +583,7 @@ void VCLXAccessibleToolBox::ProcessWindowEvent( const VclWindowEvent& rVclWindow
 
         case VCLEVENT_TOOLBOX_ITEMWINDOWCHANGED:
         {
-            sal_Int32 nPos = (sal_Int32)(sal_IntPtr)rVclWindowEvent.GetData();
+            sal_Int32 nPos = (sal_Int32)reinterpret_cast<sal_IntPtr>(rVclWindowEvent.GetData());
             ToolBoxItemsMap::iterator aAccessiblePos( m_aAccessibleChildren.find( nPos ) );
             if ( m_aAccessibleChildren.end() != aAccessiblePos )
             {
@@ -578,34 +597,34 @@ void VCLXAccessibleToolBox::ProcessWindowEvent( const VclWindowEvent& rVclWindow
             break;
         }
         case VCLEVENT_TOOLBOX_ITEMTEXTCHANGED :
-            UpdateItemName_Impl( (sal_Int32)(sal_IntPtr)rVclWindowEvent.GetData() );
+            UpdateItemName_Impl( (sal_Int32)reinterpret_cast<sal_IntPtr>(rVclWindowEvent.GetData()) );
             break;
 
         case VCLEVENT_TOOLBOX_ITEMENABLED :
         case VCLEVENT_TOOLBOX_ITEMDISABLED :
         {
-            UpdateItemEnabled_Impl( (sal_Int32)(sal_IntPtr)rVclWindowEvent.GetData() );
+            UpdateItemEnabled_Impl( (sal_Int32)reinterpret_cast<sal_IntPtr>(rVclWindowEvent.GetData()) );
             break;
         }
 
         case VCLEVENT_DROPDOWN_OPEN:
         case VCLEVENT_DROPDOWN_CLOSE:
         {
-            UpdateCustomPopupItemp_Impl( static_cast< Window* >( rVclWindowEvent.GetData() ), rVclWindowEvent.GetId() == VCLEVENT_DROPDOWN_OPEN );
+            UpdateCustomPopupItemp_Impl( static_cast< vcl::Window* >( rVclWindowEvent.GetData() ), rVclWindowEvent.GetId() == VCLEVENT_DROPDOWN_OPEN );
             break;
         }
 
         case VCLEVENT_OBJECT_DYING :
         {
             // if this toolbox is a subtoolbox, we have to relese it from its parent
-            ToolBox* pToolBox = static_cast< ToolBox* >( GetWindow() );
-            if ( pToolBox && pToolBox->GetParent() &&
-                 pToolBox->GetParent()->GetType() == WINDOW_TOOLBOX )
+            VclPtr< vcl::Window > pWin = GetAs< vcl::Window >();
+            if ( pWin && pWin->GetParent() &&
+                 pWin->GetParent()->GetType() == WINDOW_TOOLBOX )
             {
                 VCLXAccessibleToolBox* pParent = static_cast< VCLXAccessibleToolBox* >(
-                    pToolBox->GetParent()->GetAccessible()->getAccessibleContext().get() );
+                    pWin->GetParent()->GetAccessible()->getAccessibleContext().get() );
                 if ( pParent )
-                    pParent->ReleaseSubToolBox( pToolBox );
+                    pParent->ReleaseSubToolBox(static_cast<ToolBox *>(pWin.get()));
             }
 
             // dispose all items
@@ -623,7 +642,7 @@ void VCLXAccessibleToolBox::ProcessWindowEvent( const VclWindowEvent& rVclWindow
             VCLXAccessibleComponent::ProcessWindowEvent( rVclWindowEvent );
     }
 }
-// -----------------------------------------------------------------------------
+
 void VCLXAccessibleToolBox::ProcessWindowChildEvent( const VclWindowEvent& rVclWindowEvent )
 {
     switch ( rVclWindowEvent.GetId() )
@@ -643,17 +662,14 @@ void VCLXAccessibleToolBox::ProcessWindowChildEvent( const VclWindowEvent& rVclW
 
     }
 }
-// -----------------------------------------------------------------------------
+
 // XInterface
-// -----------------------------------------------------------------------------
 IMPLEMENT_FORWARD_XINTERFACE2( VCLXAccessibleToolBox, VCLXAccessibleComponent, VCLXAccessibleToolBox_BASE )
-// -----------------------------------------------------------------------------
+
 // XTypeProvider
-// -----------------------------------------------------------------------------
 IMPLEMENT_FORWARD_XTYPEPROVIDER2( VCLXAccessibleToolBox, VCLXAccessibleComponent, VCLXAccessibleToolBox_BASE )
-// -----------------------------------------------------------------------------
+
 // XComponent
-// -----------------------------------------------------------------------------
 void SAL_CALL VCLXAccessibleToolBox::disposing()
 {
     VCLXAccessibleComponent::disposing();
@@ -666,15 +682,14 @@ void SAL_CALL VCLXAccessibleToolBox::disposing()
     }
     m_aAccessibleChildren.clear();
 }
-// -----------------------------------------------------------------------------
+
 // XServiceInfo
-// -----------------------------------------------------------------------------
-OUString VCLXAccessibleToolBox::getImplementationName() throw (RuntimeException)
+OUString VCLXAccessibleToolBox::getImplementationName() throw (RuntimeException, std::exception)
 {
     return OUString( "com.sun.star.comp.toolkit.AccessibleToolBox" );
 }
-// -----------------------------------------------------------------------------
-Sequence< OUString > VCLXAccessibleToolBox::getSupportedServiceNames() throw (RuntimeException)
+
+Sequence< OUString > VCLXAccessibleToolBox::getSupportedServiceNames() throw (RuntimeException, std::exception)
 {
     Sequence< OUString > aNames = VCLXAccessibleComponent::getSupportedServiceNames();
     sal_Int32 nLength = aNames.getLength();
@@ -682,29 +697,28 @@ Sequence< OUString > VCLXAccessibleToolBox::getSupportedServiceNames() throw (Ru
     aNames[nLength] = "com.sun.star.accessibility.AccessibleToolBox";
     return aNames;
 }
-// -----------------------------------------------------------------------------
+
 // XAccessibleContext
-// -----------------------------------------------------------------------------
-sal_Int32 SAL_CALL VCLXAccessibleToolBox::getAccessibleChildCount(  ) throw (RuntimeException)
+sal_Int32 SAL_CALL VCLXAccessibleToolBox::getAccessibleChildCount(  ) throw (RuntimeException, std::exception)
 {
     comphelper::OExternalLockGuard aGuard( this );
 
     sal_Int32 nCount = 0;
-    ToolBox* pToolBox = static_cast< ToolBox* >( GetWindow() );
+    VclPtr< ToolBox > pToolBox = GetAs< ToolBox >();
     if ( pToolBox )
         nCount = pToolBox->GetItemCount();
 
     return nCount;
 }
-// -----------------------------------------------------------------------------
-Reference< XAccessible > SAL_CALL VCLXAccessibleToolBox::getAccessibleChild( sal_Int32 i ) throw (IndexOutOfBoundsException, RuntimeException)
+
+Reference< XAccessible > SAL_CALL VCLXAccessibleToolBox::getAccessibleChild( sal_Int32 i ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
 {
     if ( i < 0 || i >= getAccessibleChildCount() )
         throw IndexOutOfBoundsException();
 
     comphelper::OExternalLockGuard aGuard( this );
 
-    ToolBox* pToolBox = static_cast< ToolBox* >( GetWindow() );
+    VclPtr< ToolBox > pToolBox = GetAs< ToolBox >();
     if ( pToolBox )
     {
         Reference< XAccessible > xChild;
@@ -714,7 +728,7 @@ Reference< XAccessible > SAL_CALL VCLXAccessibleToolBox::getAccessibleChild( sal
         {
             sal_uInt16 nItemId = pToolBox->GetItemId( (sal_uInt16)i );
             sal_uInt16 nHighlightItemId = pToolBox->GetHighlightItemId();
-            Window* pItemWindow = pToolBox->GetItemWindow( nItemId );
+            vcl::Window* pItemWindow = pToolBox->GetItemWindow( nItemId );
             // not found -> create a new child
             VCLXAccessibleToolBoxItem* pChild = new VCLXAccessibleToolBoxItem( pToolBox, i );
             Reference< XAccessible> xParent = pChild;
@@ -726,10 +740,10 @@ Reference< XAccessible > SAL_CALL VCLXAccessibleToolBox::getAccessibleChild( sal
             }
             xChild = pChild;
             if ( nHighlightItemId > 0 && nItemId == nHighlightItemId )
-                pChild->SetFocus( sal_True );
+                pChild->SetFocus( true );
             if ( pToolBox->IsItemChecked( nItemId ) )
-                pChild->SetChecked( sal_True );
-            if ( pToolBox->GetItemState( nItemId ) == STATE_DONTKNOW )
+                pChild->SetChecked( true );
+            if ( pToolBox->GetItemState( nItemId ) == TRISTATE_INDET )
                 pChild->SetIndeterminate( true );
             m_aAccessibleChildren.insert( ToolBoxItemsMap::value_type( i, xChild ) );
         }
@@ -743,13 +757,13 @@ Reference< XAccessible > SAL_CALL VCLXAccessibleToolBox::getAccessibleChild( sal
 
     return NULL;
 }
-// -----------------------------------------------------------------------------
-Reference< XAccessible > SAL_CALL VCLXAccessibleToolBox::getAccessibleAtPoint( const awt::Point& _rPoint ) throw (RuntimeException)
+
+Reference< XAccessible > SAL_CALL VCLXAccessibleToolBox::getAccessibleAtPoint( const awt::Point& _rPoint ) throw (RuntimeException, std::exception)
 {
     comphelper::OExternalLockGuard aGuard( this );
 
     Reference< XAccessible > xAccessible;
-    ToolBox* pToolBox = static_cast< ToolBox* >( GetWindow() );
+    VclPtr< ToolBox > pToolBox = GetAs< ToolBox >();
     if ( pToolBox )
     {
         sal_uInt16 nItemPos = pToolBox->GetItemPos( VCLPoint( _rPoint ) );
@@ -759,26 +773,26 @@ Reference< XAccessible > SAL_CALL VCLXAccessibleToolBox::getAccessibleAtPoint( c
 
     return xAccessible;
 }
-// -----------------------------------------------------------------------------
+
 Reference< XAccessible > VCLXAccessibleToolBox::GetItemWindowAccessible( const VclWindowEvent& rVclWindowEvent )
 {
     Reference< XAccessible > xReturn;
-    Window* pChildWindow = (Window *) rVclWindowEvent.GetData();
-    ToolBox* pToolBox = static_cast< ToolBox* >( GetWindow() );
+    vcl::Window* pChildWindow = static_cast<vcl::Window *>(rVclWindowEvent.GetData());
+    VclPtr< ToolBox > pToolBox = GetAs< ToolBox >();
     if ( pChildWindow && pToolBox )
     {
         sal_uInt16 nCount = pToolBox->GetItemCount();
         for (sal_uInt16 i = 0 ; i < nCount && !xReturn.is() ; ++i)
         {
             sal_uInt16 nItemId = pToolBox->GetItemId( i );
-            Window* pItemWindow = pToolBox->GetItemWindow( nItemId );
+            vcl::Window* pItemWindow = pToolBox->GetItemWindow( nItemId );
             if ( pItemWindow == pChildWindow )
                 xReturn = getAccessibleChild(i);
         }
     }
     return xReturn;
 }
-// -----------------------------------------------------------------------------
+
 Reference< XAccessible > VCLXAccessibleToolBox::GetChildAccessible( const VclWindowEvent& rVclWindowEvent )
 {
     Reference< XAccessible > xReturn = GetItemWindowAccessible(rVclWindowEvent);
@@ -787,46 +801,45 @@ Reference< XAccessible > VCLXAccessibleToolBox::GetChildAccessible( const VclWin
         xReturn = VCLXAccessibleComponent::GetChildAccessible(rVclWindowEvent);
     return xReturn;
 }
-// -----------------------------------------------------------------------------
+
 // XAccessibleSelection
-// -----------------------------------------------------------------------------
-void VCLXAccessibleToolBox::selectAccessibleChild( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+void VCLXAccessibleToolBox::selectAccessibleChild( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
     if ( nChildIndex < 0 || nChildIndex >= getAccessibleChildCount() )
         throw IndexOutOfBoundsException();
-    ToolBox * pToolBox = static_cast < ToolBox * > ( GetWindow() );
+    VclPtr< ToolBox > pToolBox = GetAs< ToolBox >();
     sal_uInt16 nPos = static_cast < sal_uInt16 > (nChildIndex);
     pToolBox->ChangeHighlight( nPos );
 }
-// -----------------------------------------------------------------------------
-sal_Bool VCLXAccessibleToolBox::isAccessibleChildSelected( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+
+sal_Bool VCLXAccessibleToolBox::isAccessibleChildSelected( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
     if ( nChildIndex < 0 || nChildIndex >= getAccessibleChildCount() )
         throw IndexOutOfBoundsException();
-    ToolBox * pToolBox = static_cast < ToolBox * > ( GetWindow() );
+    VclPtr< ToolBox > pToolBox = GetAs< ToolBox >();
     sal_uInt16 nPos = static_cast < sal_uInt16 > (nChildIndex);
-    if ( pToolBox != NULL && pToolBox->GetHighlightItemId() == pToolBox->GetItemId( nPos ) )
-        return sal_True;
+    if ( pToolBox && pToolBox->GetHighlightItemId() == pToolBox->GetItemId( nPos ) )
+        return true;
     else
-        return sal_False;
+        return false;
 }
-// -----------------------------------------------------------------------------
-void VCLXAccessibleToolBox::clearAccessibleSelection(  ) throw (RuntimeException)
+
+void VCLXAccessibleToolBox::clearAccessibleSelection(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
-    ToolBox * pToolBox = static_cast < ToolBox * > ( GetWindow() );
+    VclPtr< ToolBox > pToolBox = GetAs< ToolBox >();
     pToolBox -> LoseFocus();
 }
-// -----------------------------------------------------------------------------
-void VCLXAccessibleToolBox::selectAllAccessibleChildren(  ) throw (RuntimeException)
+
+void VCLXAccessibleToolBox::selectAllAccessibleChildren(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
     // intentionally empty. makes no sense for a toolbox
 }
-// -----------------------------------------------------------------------------
-sal_Int32 VCLXAccessibleToolBox::getSelectedAccessibleChildCount(  ) throw (RuntimeException)
+
+sal_Int32 VCLXAccessibleToolBox::getSelectedAccessibleChildCount(  ) throw (RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
     sal_Int32 nRet = 0;
@@ -840,8 +853,8 @@ sal_Int32 VCLXAccessibleToolBox::getSelectedAccessibleChildCount(  ) throw (Runt
     }
     return nRet;
 }
-// -----------------------------------------------------------------------------
-Reference< XAccessible > VCLXAccessibleToolBox::getSelectedAccessibleChild( sal_Int32 nSelectedChildIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+
+Reference< XAccessible > VCLXAccessibleToolBox::getSelectedAccessibleChild( sal_Int32 nSelectedChildIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
     if ( nSelectedChildIndex < 0 || nSelectedChildIndex >= getSelectedAccessibleChildCount() )
@@ -857,14 +870,13 @@ Reference< XAccessible > VCLXAccessibleToolBox::getSelectedAccessibleChild( sal_
     }
     return xChild;
 }
-// -----------------------------------------------------------------------------
-void VCLXAccessibleToolBox::deselectAccessibleChild( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+
+void VCLXAccessibleToolBox::deselectAccessibleChild( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
 {
     OExternalLockGuard aGuard( this );
     if ( nChildIndex < 0 || nChildIndex >= getAccessibleChildCount() )
         throw IndexOutOfBoundsException();
     clearAccessibleSelection(); // a toolbox can only have (n)one selected child
 }
-// -----------------------------------------------------------------------------
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
