@@ -52,6 +52,7 @@
 #include "intconversion.hxx"
 
 #include <rtl/alloc.h>
+#include <sal/log.hxx>
 #include <osl/diagnose.h>
 
 #include <basegfx/tools/tools.hxx>
@@ -107,6 +108,7 @@ static const sal_uInt8 bitsPerPixel[] =
     16, // SIXTEEN_BIT_LSB_TC_MASK
     16, // SIXTEEN_BIT_MSB_TC_MASK
     24, // TWENTYFOUR_BIT_TC_MASK
+    32, // TWENTYFOUR_BIT_TC_MASK_BGRX
     32, // THIRTYTWO_BIT_TC_MASK_BGRA
     32, // THIRTYTWO_BIT_TC_MASK_ARGB
     32, // THIRTYTWO_BIT_TC_MASK_ABGR
@@ -358,7 +360,7 @@ namespace
 
         void damagedPixel( const basegfx::B2IPoint& rDamagePoint ) const
         {
-            if( !mpDamage )
+            if (!mpDamage)
                 return;
 
             sal_Int32 nX(rDamagePoint.getX());
@@ -372,7 +374,7 @@ namespace
             damaged( basegfx::B2IBox( rDamagePoint, aEnd ) );
         }
 
-        boost::shared_ptr<BitmapRenderer> getCompatibleBitmap( const BitmapDeviceSharedPtr& bmp ) const
+        static boost::shared_ptr<BitmapRenderer> getCompatibleBitmap( const BitmapDeviceSharedPtr& bmp )
         {
             return boost::dynamic_pointer_cast< BitmapRenderer >( bmp );
         }
@@ -404,7 +406,7 @@ namespace
             return boost::dynamic_pointer_cast<mask_bitmap_type>( bmp ).get() != NULL;
         }
 
-        boost::shared_ptr<alphamask_bitmap_type> getCompatibleAlphaMask( const BitmapDeviceSharedPtr& bmp ) const
+        static boost::shared_ptr<alphamask_bitmap_type> getCompatibleAlphaMask( const BitmapDeviceSharedPtr& bmp )
         {
             return boost::dynamic_pointer_cast<alphamask_bitmap_type>( bmp );
         }
@@ -498,9 +500,25 @@ namespace
                                col,
                                begin,
                                rawAcc );
+
+            if (!mpDamage)
+                return;
+
             // TODO(P2): perhaps this needs pushing up the stack a bit
             // to make more complex polygons more efficient ...
-            damaged( basegfx::B2IBox( rPt1, rPt2 ) );
+            basegfx::B2IBox aBounds(rPt1, rPt2 );
+
+            const basegfx::B2IPoint& rEnd = aBounds.getMaximum();
+
+            sal_Int32 nX(rEnd.getX());
+            sal_Int32 nY(rEnd.getY());
+            if (nX < SAL_MAX_INT32)
+                ++nX;
+            if (nY < SAL_MAX_INT32)
+                ++nY;
+
+            basegfx::B2IBox aDamagedBox(aBounds.getMinimum(), basegfx::B2IPoint(nX, nY));
+            damaged(aDamagedBox);
         }
 
         template< typename Iterator, typename Accessor, typename RawAcc >
@@ -745,8 +763,8 @@ namespace
             sal_Int32 nDestX = rDstRect.getMinX();
             sal_Int32 nDestY = rDstRect.getMinY();
 
-            char* dstBuf =  (char*)getBuffer().get();
-            char* srcBuf =  (char*)rSrcBitmap->getBuffer().get();
+            char* dstBuf =  reinterpret_cast<char*>(getBuffer().get());
+            char* srcBuf =  reinterpret_cast<char*>(rSrcBitmap->getBuffer().get());
             sal_Int32 dstStride =  getScanlineStride();
             sal_Int32 srcStride =  rSrcBitmap->getScanlineStride();
             sal_Int32 bytesPerPixel = (bitsPerPixel[getScanlineFormat()] + 7) >> 3; // round up to bytes
@@ -1933,18 +1951,17 @@ inline sal_uInt32 nextPow2( sal_uInt32 x )
     return ++x;
 }
 
-
-
-
 namespace
 {
 BitmapDeviceSharedPtr createBitmapDeviceImplInner( const basegfx::B2IVector&                  rSize,
                                                    bool                                       bTopDown,
                                                    Format                                     nScanlineFormat,
+                                                   sal_Int32                                  nScanlineStride,
                                                    boost::shared_array< sal_uInt8 >           pMem,
                                                    PaletteMemorySharedVector                  pPal,
                                                    const basegfx::B2IBox*                     pSubset,
-                                                   const IBitmapDeviceDamageTrackerSharedPtr& rDamage )
+                                                   const IBitmapDeviceDamageTrackerSharedPtr& rDamage,
+                                                   bool bBlack = true)
 {
     OSL_ASSERT(rSize.getX() > 0 && rSize.getY() > 0);
 
@@ -1959,15 +1976,6 @@ BitmapDeviceSharedPtr createBitmapDeviceImplInner( const basegfx::B2IVector&
                  rSize.getX() << " for depth " << nBitsPerPixel);
         return BitmapDeviceSharedPtr();
     }
-    // round up to full 8 bit, divide by 8
-    sal_Int32 nScanlineStride = (rSize.getX()*nBitsPerPixel + 7) >> 3;
-
-    // rounded up to next full power-of-two number of bytes
-    const sal_uInt32 bytesPerPixel = nextPow2(
-        (bitsPerPixel[nScanlineFormat] + 7) >> 3);
-
-    // now make nScanlineStride a multiple of bytesPerPixel
-    nScanlineStride = (nScanlineStride + bytesPerPixel - 1) / bytesPerPixel * bytesPerPixel;
 
     // factor in bottom-up scanline order case
     nScanlineStride *= bTopDown ? 1 : -1;
@@ -1986,11 +1994,14 @@ BitmapDeviceSharedPtr createBitmapDeviceImplInner( const basegfx::B2IVector&
     if( !pMem )
     {
         pMem.reset(
-            reinterpret_cast<sal_uInt8*>(rtl_allocateMemory( nMemSize )),
+            static_cast<sal_uInt8*>(rtl_allocateMemory( nMemSize )),
             &rtl_freeMemory );
         if (pMem.get() == 0 && nMemSize != 0)
             return BitmapDeviceSharedPtr();
-        memset(pMem.get(), 0, nMemSize);
+        if (bBlack)
+            memset(pMem.get(), 0, nMemSize);
+        else
+            memset(pMem.get(), 0xFF, nMemSize);
     }
 
     sal_uInt8* pFirstScanline = nScanlineStride < 0 ?
@@ -2083,35 +2094,37 @@ BitmapDeviceSharedPtr createBitmapDeviceImplInner( const basegfx::B2IVector&
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal, rDamage );
 
-
-
         // twentyfour bit formats
         case FORMAT_TWENTYFOUR_BIT_TC_MASK:
             return createRenderer<PixelFormatTraits_BGR24,StdMasks>(
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal, rDamage );
 
-
-
         // thirtytwo bit formats
 
-        case FORMAT_THIRTYTWO_BIT_TC_MASK_BGRA:
+        // 8 red bits, 8 green bits, 8 blue bits, and 8 ignored bits like CAIRO_FORMAT_RGB24
+        case FORMAT_THIRTYTWO_BIT_TC_MASK_BGRX:
             return createRenderer<PixelFormatTraits_BGRX32_8888,StdMasks>(
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal, rDamage );
 
+        case FORMAT_THIRTYTWO_BIT_TC_MASK_BGRA:
+            return createRenderer<PixelFormatTraits_BGRA32_8888,StdMasks>(
+                aBounds, rSize, nScanlineFormat, nScanlineStride,
+                pFirstScanline, pMem, pPal, rDamage );
+
         case FORMAT_THIRTYTWO_BIT_TC_MASK_ARGB:
-            return createRenderer<PixelFormatTraits_XRGB32_8888,StdMasks>(
+            return createRenderer<PixelFormatTraits_ARGB32_8888,StdMasks>(
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal, rDamage );
 
         case FORMAT_THIRTYTWO_BIT_TC_MASK_ABGR:
-            return createRenderer<PixelFormatTraits_XBGR32_8888,StdMasks>(
+            return createRenderer<PixelFormatTraits_ABGR32_8888,StdMasks>(
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal, rDamage );
 
         case FORMAT_THIRTYTWO_BIT_TC_MASK_RGBA:
-            return createRenderer<PixelFormatTraits_RGBX32_8888,StdMasks>(
+            return createRenderer<PixelFormatTraits_RGBA32_8888,StdMasks>(
                 aBounds, rSize, nScanlineFormat, nScanlineStride,
                 pFirstScanline, pMem, pPal, rDamage );
 
@@ -2126,12 +2139,14 @@ BitmapDeviceSharedPtr createBitmapDeviceImplInner( const basegfx::B2IVector&
 BitmapDeviceSharedPtr createBitmapDeviceImpl( const basegfx::B2IVector&                  rSize,
                                               bool                                       bTopDown,
                                               Format                                     nScanlineFormat,
+                                              sal_Int32                                  nScanlineStride,
                                               boost::shared_array< sal_uInt8 >           pMem,
                                               PaletteMemorySharedVector                  pPal,
                                               const basegfx::B2IBox*                     pSubset,
-                                              const IBitmapDeviceDamageTrackerSharedPtr& rDamage )
+                                              const IBitmapDeviceDamageTrackerSharedPtr& rDamage,
+                                              bool bBlack = true)
 {
-    BitmapDeviceSharedPtr result( createBitmapDeviceImplInner( rSize, bTopDown, nScanlineFormat, pMem, pPal, pSubset, rDamage ) );
+    BitmapDeviceSharedPtr result( createBitmapDeviceImplInner( rSize, bTopDown, nScanlineFormat, nScanlineStride, pMem, pPal, pSubset, rDamage, bBlack ) );
 
 #ifdef SAL_LOG_INFO
     std::ostringstream subset;
@@ -2151,14 +2166,30 @@ BitmapDeviceSharedPtr createBitmapDeviceImpl( const basegfx::B2IVector&
 }
 } // namespace
 
+sal_Int32 getBitmapDeviceStrideForWidth(Format nScanlineFormat, sal_Int32 nWidth)
+{
+    sal_uInt8 nBitsPerPixel = bitsPerPixel[nScanlineFormat];
+    // round up to full 8 bit, divide by 8
+    sal_Int32 nScanlineStride = (nWidth*nBitsPerPixel + 7) >> 3;
+
+    // rounded up to next full power-of-two number of bytes
+    const sal_uInt32 bytesPerPixel = nextPow2(
+        (bitsPerPixel[nScanlineFormat] + 7) >> 3);
+
+    // now make nScanlineStride a multiple of bytesPerPixel
+    nScanlineStride = (nScanlineStride + bytesPerPixel - 1) / bytesPerPixel * bytesPerPixel;
+    return nScanlineStride;
+}
 
 BitmapDeviceSharedPtr createBitmapDevice( const basegfx::B2IVector& rSize,
                                           bool                      bTopDown,
-                                          Format                    nScanlineFormat )
+                                          Format                    nScanlineFormat,
+                                          sal_Int32                 nScanlineStride )
 {
     return createBitmapDeviceImpl( rSize,
                                    bTopDown,
                                    nScanlineFormat,
+                                   nScanlineStride,
                                    boost::shared_array< sal_uInt8 >(),
                                    PaletteMemorySharedVector(),
                                    NULL,
@@ -2168,11 +2199,13 @@ BitmapDeviceSharedPtr createBitmapDevice( const basegfx::B2IVector& rSize,
 BitmapDeviceSharedPtr createBitmapDevice( const basegfx::B2IVector&        rSize,
                                           bool                             bTopDown,
                                           Format                           nScanlineFormat,
+                                          sal_Int32                        nScanlineStride,
                                           const PaletteMemorySharedVector& rPalette )
 {
     return createBitmapDeviceImpl( rSize,
                                    bTopDown,
                                    nScanlineFormat,
+                                   nScanlineStride,
                                    boost::shared_array< sal_uInt8 >(),
                                    rPalette,
                                    NULL,
@@ -2182,18 +2215,35 @@ BitmapDeviceSharedPtr createBitmapDevice( const basegfx::B2IVector&        rSize
 BitmapDeviceSharedPtr createBitmapDevice( const basegfx::B2IVector&        rSize,
                                           bool                             bTopDown,
                                           Format                           nScanlineFormat,
+                                          sal_Int32                        nScanlineStride,
                                           const RawMemorySharedArray&      rMem,
                                           const PaletteMemorySharedVector& rPalette )
 {
     return createBitmapDeviceImpl( rSize,
                                    bTopDown,
                                    nScanlineFormat,
+                                   nScanlineStride,
                                    rMem,
                                    rPalette,
                                    NULL,
                                    IBitmapDeviceDamageTrackerSharedPtr() );
 }
 
+BitmapDeviceSharedPtr createClipDevice( const basegfx::B2IVector&        rSize )
+{
+    BitmapDeviceSharedPtr xClip(
+             createBitmapDeviceImpl( rSize,
+                                     false, /* bTopDown */
+                                     basebmp::FORMAT_ONE_BIT_MSB_GREY,
+                                     getBitmapDeviceStrideForWidth(basebmp::FORMAT_ONE_BIT_MSB_GREY, rSize.getX()),
+                                     boost::shared_array< sal_uInt8 >(),
+                                     PaletteMemorySharedVector(),
+                                     NULL,
+                                     IBitmapDeviceDamageTrackerSharedPtr(),
+                                     false /* white */) );
+    return xClip;
+}
+
 BitmapDeviceSharedPtr subsetBitmapDevice( const BitmapDeviceSharedPtr& rProto,
                                           const basegfx::B2IBox&       rSubset )
 {
@@ -2201,6 +2251,7 @@ BitmapDeviceSharedPtr subsetBitmapDevice( const BitmapDeviceSharedPtr& rProto,
     return createBitmapDeviceImpl( rProto->getSize(),
                                    rProto->isTopDown(),
                                    rProto->getScanlineFormat(),
+                                   rProto->getScanlineStride(),
                                    rProto->getBuffer(),
                                    rProto->getPalette(),
                                    &rSubset,
@@ -2213,6 +2264,7 @@ BitmapDeviceSharedPtr cloneBitmapDevice( const basegfx::B2IVector&    rSize,
     return createBitmapDeviceImpl( rSize,
                                    rProto->isTopDown(),
                                    rProto->getScanlineFormat(),
+                                   rProto->getScanlineStride(),
                                    boost::shared_array< sal_uInt8 >(),
                                    rProto->getPalette(),
                                    NULL,
