@@ -29,8 +29,6 @@
 #include <basegfx/tools/rectcliptools.hxx>
 #include <basegfx/matrix/b2dhommatrixtools.hxx>
 
-//////////////////////////////////////////////////////////////////////////////
-
 namespace basegfx
 {
     namespace tools
@@ -337,14 +335,14 @@ namespace basegfx
             return aRetval;
         }
 
-        //////////////////////////////////////////////////////////////////////////////
-
         B2DPolyPolygon clipPolyPolygonOnPolyPolygon(const B2DPolyPolygon& rCandidate, const B2DPolyPolygon& rClip, bool bInside, bool bStroke)
         {
             B2DPolyPolygon aRetval;
 
             if(rCandidate.count() && rClip.count())
             {
+                // one or both are no rectangle - go the hard way and clip PolyPolygon
+                // against PolyPolygon...
                 if(bStroke)
                 {
                     // line clipping, create line snippets by first adding all cut points and
@@ -413,6 +411,77 @@ namespace basegfx
                 }
                 else
                 {
+                    // check for simplification with ranges if !bStroke (handling as stroke is more simple),
+                    // but also only when bInside, else the simplification may lead to recursive calls (see
+                    // calls to clipPolyPolygonOnPolyPolygon in clipPolyPolygonOnRange and clipPolygonOnRange)
+                    if(bInside)
+                    {
+                        // #i125349# detect if both given PolyPolygons are indeed ranges
+                        bool bBothRectangle(false);
+
+                        if(basegfx::tools::isRectangle(rCandidate))
+                        {
+                            if(basegfx::tools::isRectangle(rClip))
+                            {
+                                // both are ranges
+                                bBothRectangle = true;
+                            }
+                            else
+                            {
+                                // rCandidate is rectangle -> clip rClip on rRectangle, use the much
+                                // cheaper and numerically more stable clipping against a range
+                                // This simplification (exchanging content and clip) is valid
+                                // since we do a logical AND operation
+                                return clipPolyPolygonOnRange(rClip, rCandidate.getB2DRange(), bInside, bStroke);
+                            }
+                        }
+                        else if(basegfx::tools::isRectangle(rClip))
+                        {
+                            if(basegfx::tools::isRectangle(rCandidate))
+                            {
+                                // both are ranges
+                                bBothRectangle = true;
+                            }
+                            else
+                            {
+                                // rClip is rectangle -> clip rCandidate on rRectangle, use the much
+                                // cheaper and numerically more stable clipping against a range
+                                return clipPolyPolygonOnRange(rCandidate, rClip.getB2DRange(), bInside, bStroke);
+                            }
+                        }
+
+                        if(bBothRectangle)
+                        {
+                            // both are rectangle
+                            if(rCandidate.getB2DRange().equal(rClip.getB2DRange()))
+                            {
+                                // if both are equal -> no change
+                                return rCandidate;
+                            }
+                            else
+                            {
+                                // not equal -> create new intersection from both ranges,
+                                // but much cheaper based on the ranges
+                                basegfx::B2DRange aIntersectionRange(rCandidate.getB2DRange());
+
+                                aIntersectionRange.intersect(rClip.getB2DRange());
+
+                                if(aIntersectionRange.isEmpty())
+                                {
+                                    // no common IntersectionRange -> the clip will be empty
+                                    return B2DPolyPolygon();
+                                }
+                                else
+                                {
+                                    // use common aIntersectionRange as result, convert
+                                    // to expected tools::PolyPolygon form
+                                    return basegfx::B2DPolyPolygon(
+                                        basegfx::tools::createPolygonFromRect(aIntersectionRange));
+                                }
+                            }
+                        }
+                    }
+
                     // area clipping
                     B2DPolyPolygon aMergePolyPolygonA(rClip);
 
@@ -420,7 +489,7 @@ namespace basegfx
                     // Also get rid of some not-needed polygons (neutral, no area -> when
                     // no intersections, these are tubes).
                     // Now it is possible to correct the orientations in the cut-free
-                    // polygons to values corresponding to painting the PolyPolygon with
+                    // polygons to values corresponding to painting the tools::PolyPolygon with
                     // a XOR-WindingRule.
                     aMergePolyPolygonA = solveCrossovers(aMergePolyPolygonA);
                     aMergePolyPolygonA = stripNeutralPolygons(aMergePolyPolygonA);
@@ -461,8 +530,6 @@ namespace basegfx
             return aRetval;
         }
 
-        //////////////////////////////////////////////////////////////////////////////
-
         B2DPolyPolygon clipPolygonOnPolyPolygon(const B2DPolygon& rCandidate, const B2DPolyPolygon& rClip, bool bInside, bool bStroke)
         {
             B2DPolyPolygon aRetval;
@@ -475,8 +542,6 @@ namespace basegfx
             return aRetval;
         }
 
-        //////////////////////////////////////////////////////////////////////////////
-
         /*
         * let a plane be defined as
         *
@@ -521,8 +586,6 @@ namespace basegfx
                                        scissor_plane                 *pPlane,       // scissoring plane
                                        const ::basegfx::B2DRectangle &rR )          // clipping rectangle
         {
-            ::basegfx::B2DPoint *curr;
-            ::basegfx::B2DPoint *next;
 
             sal_uInt32 out_count=0;
 
@@ -531,8 +594,8 @@ namespace basegfx
 
                 // vertices are relative to the coordinate
                 // system defined by the rectangle.
-                curr = &in_vertex[i];
-                next = &in_vertex[(i+1)%in_count];
+                ::basegfx::B2DPoint *curr = &in_vertex[i];
+                ::basegfx::B2DPoint *next = &in_vertex[(i+1)%in_count];
 
                 // perform clipping judgement & mask against current plane.
                 sal_uInt32 clip = pPlane->clipmask & ((getCohenSutherlandClipFlags(*curr,rR)<<4)|getCohenSutherlandClipFlags(*next,rR));
@@ -619,16 +682,12 @@ namespace basegfx
 
                 if(nVertexCount)
                 {
-                    ////////////////////////////////////////////////////////////////////////
-                    ////////////////////////////////////////////////////////////////////////
-                    ////////////////////////////////////////////////////////////////////////
-                    //
                     // Upper bound for the maximal number of vertices when intersecting an
                     // axis-aligned rectangle with a triangle in E2
-                    //
+
                     // The rectangle and the triangle are in general position, and have 4 and 3
                     // vertices, respectively.
-                    //
+
                     //   Lemma: Since the rectangle is a convex polygon ( see
                     //   http://mathworld.wolfram.com/ConvexPolygon.html for a definition), and
                     //   has no holes, it follows that any straight line will intersect the
@@ -640,7 +699,7 @@ namespace basegfx
                     //   other 'outside') will at utmost add _one_  vertex to the resulting
                     //   intersection polygon (adding two intersection vertices, and removing at
                     //   least one rectangle vertex):
-                    //
+
                     //         *
                     //     +--+-----------------+
                     //     | *                  |
@@ -649,7 +708,7 @@ namespace basegfx
                     //    *|                    |
                     //   * |                    |
                     //     +--------------------+
-                    //
+
                     //   Proof: If the straight line intersects the rectangle two
                     //   times, it does so for distinct edges, i.e. the intersection has
                     //   minimally one of the rectangle's vertices on either side of the straight
@@ -657,17 +716,17 @@ namespace basegfx
                     //   minimally _one_ rectangle vertex removed from the resulting clip
                     //   polygon, and therefore, a clip against a half-plane has the net effect
                     //   of adding at utmost _one_ vertex to the resulting clip polygon.
-                    //
+
                     // Theorem: The intersection of a rectangle and a triangle results in a
                     // polygon with at utmost 7 vertices.
-                    //
+
                     // Proof: The inside of the triangle can be described as the consecutive
                     // intersection with three half-planes. Together with the lemma above, this
                     // results in at utmost 3 additional vertices added to the already existing 4
                     // rectangle vertices.
-                    //
+
                     // This upper bound is attained with the following example configuration:
-                    //
+
                     //                               *
                     //                             ***
                     //                           ** *
@@ -689,7 +748,7 @@ namespace basegfx
                     //     --*6-----5-----
                     //         **  *
                     //           **
-                    //
+
                     // As we need to scissor all triangles against the
                     // output rectangle we employ an output buffer for the
                     // resulting vertices.  the question is how large this
@@ -707,10 +766,6 @@ namespace basegfx
                     // fan.  for the maximum number of 7 vertices of
                     // resulting triangle fans we therefore need 15 times
                     // the number of original vertices.
-                    //
-                    ////////////////////////////////////////////////////////////////////////
-                    ////////////////////////////////////////////////////////////////////////
-                    ////////////////////////////////////////////////////////////////////////
 
                     //const size_t nBufferSize = sizeof(vertex)*(nVertexCount*16);
                     //vertex *pVertices = (vertex*)alloca(nBufferSize);
@@ -732,7 +787,7 @@ namespace basegfx
                         stack[2] = rCandidate.getB2DPoint(nIndex);
 
                         // clipping judgement
-                        clipflag |= !(rRange.isInside(stack[2]));
+                        clipflag |= unsigned(!(rRange.isInside(stack[2])));
 
                         if(nIndex > 1)
                         {
@@ -787,8 +842,6 @@ namespace basegfx
             return aResult;
         }
 
-        //////////////////////////////////////////////////////////////////////////////
-
     } // end of namespace tools
 } // end of namespace basegfx
 
