@@ -20,9 +20,11 @@ package com.sun.star.comp.beans;
 
 import java.awt.Container;
 import java.io.File;
+import java.io.UnsupportedEncodingException;
 import java.util.Iterator;
 import java.util.List;
 import java.util.ArrayList;
+import java.util.Arrays;
 
 import com.sun.star.lang.XMultiComponentFactory;
 import com.sun.star.lang.XComponent;
@@ -46,11 +48,10 @@ public class LocalOfficeConnection
     implements OfficeConnection
 {
     public static final String      OFFICE_APP_NAME     = "soffice";
-    public static final String      OFFICE_LIB_NAME     = "officebean";
+    public static final String       OFFICE_LIB_NAME     = "officebean";
     public static final String      OFFICE_ID_SUFFIX    = "_Office";
 
     private Process                 mProcess;
-    private ContainerFactory        mContainerFactory;
     private XComponentContext       mContext;
     private XBridge mBridge;
 
@@ -61,7 +62,7 @@ public class LocalOfficeConnection
     private String                  mProtocol;
     private String                  mInitialObject;
 
-    private List<XEventListener> mComponents = new ArrayList<XEventListener>();
+    private final List<XEventListener> mComponents = new ArrayList<XEventListener>();
 
     private static long m_nBridgeCounter = 0;
 
@@ -132,7 +133,13 @@ public class LocalOfficeConnection
             setUnoUrl( "uno:pipe,name=" + getPipeName() + ";urp;StarOffice.ServiceManager" );
         }
         catch ( java.net.MalformedURLException e )
-        {}
+        {
+            throw new com.sun.star.uno.RuntimeException(e);
+        }
+        catch ( UnsupportedEncodingException e)
+        {
+            throw new com.sun.star.uno.RuntimeException(e);
+        }
     }
 
         /**
@@ -158,7 +165,7 @@ public class LocalOfficeConnection
      * pipev  := local_office_connection_pipe_name
      * </pre>
      *
-     * @param url This is UNO URL which discribes the type of a connection.
+     * @param url This is UNO URL which describes the type of a connection.
      */
     public void setUnoUrl(String url)
         throws java.net.MalformedURLException
@@ -179,10 +186,12 @@ public class LocalOfficeConnection
                 mProtocol = aURL.getProtocol();
                 mInitialObject = aURL.getRootOid();
             }
-            catch ( com.sun.star.lang.IllegalArgumentException eIll )
+            catch ( com.sun.star.lang.IllegalArgumentException ex1 )
             {
-                throw new java.net.MalformedURLException(
+                java.net.MalformedURLException ex2 = new java.net.MalformedURLException(
                     "Invalid UNO connection URL.");
+                ex2.initCause(ex1);
+                throw ex2;
             }
         }
         mURL    = url;
@@ -194,9 +203,9 @@ public class LocalOfficeConnection
      * @param containerFactory This is a application provided AWT container
      *  factory.
      */
+    @Deprecated
     public void setContainerFactory(ContainerFactory containerFactory)
     {
-        mContainerFactory   = containerFactory;
     }
 
     /**
@@ -223,6 +232,7 @@ public class LocalOfficeConnection
      * @param container This is an AWT container.
      * @return The office window instance.
      */
+    @Deprecated
     public OfficeWindow createOfficeWindow(Container container)
     {
         return new LocalOfficeWindow(this);
@@ -234,7 +244,7 @@ public class LocalOfficeConnection
     public void dispose()
     {
         Iterator<XEventListener> itr = mComponents.iterator();
-        while (itr.hasNext() == true) {
+        while (itr.hasNext()) {
             // ignore runtime exceptions in dispose
             try { itr.next().disposing(null); }
             catch ( RuntimeException aExc ) {}
@@ -258,8 +268,6 @@ public class LocalOfficeConnection
 
             mBridge = null;
         }
-
-        mContainerFactory = null;
         mContext = null;
     }
 
@@ -295,7 +303,7 @@ public class LocalOfficeConnection
                 com.sun.star.comp.helper.Bootstrap.createInitialComponentContext(null);
 
             // initial serviceManager
-            XMultiComponentFactory xLocalServiceManager = xLocalContext.getServiceManager();
+            xLocalContext.getServiceManager();
 
             // try to connect to soffice
             Object aInitialObject = null;
@@ -310,7 +318,7 @@ public class LocalOfficeConnection
                 aSOffice.startupService();
 
                 // wait until soffice is started
-                long nMaxMillis = System.currentTimeMillis() + 1000*aSOffice.getStartupTime();
+                long nMaxMillis = System.currentTimeMillis() + 1000L*aSOffice.getStartupTime();
                 while ( aInitialObject == null )
                 {
                     try
@@ -329,9 +337,6 @@ public class LocalOfficeConnection
                     }
                 }
             }
-            finally
-            {
-            }
 
             // XComponentContext
             if( null != aInitialObject )
@@ -372,7 +377,7 @@ public class LocalOfficeConnection
             System.out.println( e );
             e.printStackTrace();
             System.out.println( "--- end." );
-            throw new com.sun.star.uno.RuntimeException( e.toString() );
+            throw new com.sun.star.uno.RuntimeException(e);
         }
 
         return null;
@@ -398,7 +403,6 @@ public class LocalOfficeConnection
         }
         else { // new style
             int index = dcp.indexOf(':');
-            String url = dcp.substring(0, index).trim();
             dcp = dcp.substring(index + 1).trim();
 
             index = dcp.indexOf(';');
@@ -422,7 +426,7 @@ public class LocalOfficeConnection
                     xLocalServiceManager.createInstanceWithContext(
                         "com.sun.star.bridge.BridgeFactory", xLocalContext));
         } catch (com.sun.star.uno.Exception e) {
-            throw new com.sun.star.uno.RuntimeException(e.getMessage());
+            throw new com.sun.star.uno.RuntimeException(e);
         }
         synchronized(this) {
             if(mBridge == null) {
@@ -431,7 +435,7 @@ public class LocalOfficeConnection
                     connector = xLocalServiceManager.createInstanceWithContext(
                             "com.sun.star.connection.Connector", xLocalContext);
                 } catch (com.sun.star.uno.Exception e) {
-                    throw new com.sun.star.uno.RuntimeException(e.getMessage());
+                    throw new com.sun.star.uno.RuntimeException(e);
                 }
                 XConnector connector_xConnector = UnoRuntime.queryInterface(XConnector.class, connector);
                 // connect to the server
@@ -440,11 +444,11 @@ public class LocalOfficeConnection
                 // empty string as bridge name into createBridge. Then we should always get
                 // a new bridge. This does not work because of (i51323). Therefore we
                 // create unique bridge names for the current process.
-                String sBridgeName = "OOoBean_private_bridge_" + String.valueOf(m_nBridgeCounter++);
+                String sBridgeName = "OOoBean_private_bridge_" + (m_nBridgeCounter++);
                 try {
                     mBridge = xBridgeFactory.createBridge(sBridgeName, protDcp, xConnection, null);
                 } catch (com.sun.star.bridge.BridgeExistsException e) {
-                    throw new com.sun.star.uno.RuntimeException(e.getMessage());
+                    throw new com.sun.star.uno.RuntimeException(e);
                 }
             }
             rootObject = mBridge.getInstance(rootOid);
@@ -572,12 +576,12 @@ public class LocalOfficeConnection
                         if (path == null)
                             path    = buffer.toString();
                         else
-                            state   = -3;   // error: more then one 'path'
+                            state   = -3;   // error: more than one 'path'
                     } else if (name.equals("pipe")) {
                         if (pipe == null)
                             pipe    = buffer.toString();
                         else
-                            state   = -4;   // error: more then one 'pipe'
+                            state   = -4;   // error: more than one 'pipe'
                     } else
                         state   = -2;       // error: unknown parameter
                     buffer.delete(0, buffer.length());
@@ -635,32 +639,14 @@ public class LocalOfficeConnection
             mPipe = pipe;
     }
 
-    /* replaces each substring aSearch in aString by aReplace.
-
-        StringBuffer.replaceAll() is not avaialable in Java 1.3.x.
-     */
-    private static String replaceAll(String aString, String aSearch, String aReplace )
-    {
-        StringBuffer aBuffer = new StringBuffer(aString);
-
-        int nPos = aString.length();
-        int nOfs = aSearch.length();
-
-        while ( ( nPos = aString.lastIndexOf( aSearch, nPos - 1 ) ) > -1 )
-            aBuffer.replace( nPos, nPos+nOfs, aReplace );
-
-        return aBuffer.toString();
-    }
-
-
     /** creates a unique pipe name.
     */
-    static String getPipeName()
+    private static String getPipeName() throws UnsupportedEncodingException
     {
         // turn user name into a URL and file system safe name (% chars will not work)
         String aPipeName = System.getProperty("user.name") + OFFICE_ID_SUFFIX;
-        aPipeName = replaceAll( aPipeName, "_", "%B7" );
-        return replaceAll( replaceAll( java.net.URLEncoder.encode(aPipeName), "+", "%20" ), "%", "_" );
+        aPipeName = aPipeName.replace( "_", "%B7" );
+        return java.net.URLEncoder.encode( aPipeName, "UTF-8" ).replace( "+", "%20" ).replace( "%", "_" );
     }
 
     /**
@@ -676,10 +662,16 @@ public class LocalOfficeConnection
          */
         public String getIdentifier()
         {
-            if ( mPipe == null)
-                return getPipeName();
-            else
-                return mPipe;
+            String identifier = null;
+            try
+            {
+                identifier = ( mPipe == null) ? getPipeName() : mPipe;
+            }
+            catch (UnsupportedEncodingException e)
+            {
+                throw new com.sun.star.uno.RuntimeException(e);
+            }
+            return identifier;
         }
 
         /**
@@ -729,7 +721,7 @@ public class LocalOfficeConnection
             // start process
             mProcess = Runtime.getRuntime().exec(cmdArray);
             if ( mProcess == null )
-                throw new RuntimeException( "cannot start soffice: " + cmdArray );
+                throw new com.sun.star.uno.RuntimeException( "cannot start soffice: " + Arrays.toString(cmdArray) );
             new StreamProcessor(mProcess.getInputStream(), System.out);
             new StreamProcessor(mProcess.getErrorStream(), System.err);
         }
@@ -747,18 +739,21 @@ public class LocalOfficeConnection
 
 
 
-    class StreamProcessor extends Thread
+    private class StreamProcessor extends Thread
     {
-        java.io.InputStream m_in;
-        java.io.PrintStream m_print;
+        private final java.io.InputStream m_in;
+        private final java.io.PrintStream m_print;
 
         public StreamProcessor(final java.io.InputStream in, final java.io.PrintStream out)
         {
+            super("StreamProcessor");
+
             m_in = in;
             m_print = out;
             start();
         }
 
+        @Override
         public void run() {
             java.io.BufferedReader r = new java.io.BufferedReader(
                 new java.io.InputStreamReader(m_in) );
