@@ -76,7 +76,7 @@ static void PrintHelp()
 class TestWindow : public Dialog
 {
     public:
-        TestWindow() : Dialog( (Window *) NULL )
+        TestWindow() : Dialog( (vcl::Window *) NULL )
         {
             SetText( OUString( "Canvas test" ) );
             SetSizePixel( Size( 600, 450 ) );
@@ -208,14 +208,13 @@ class DemoRenderer
             const int    VERTICES = 10;
             const double RADIUS = 60.0;
             int i, j;
-            double a;
 
             rendering::RenderState maOldRenderState = maRenderState; // push
             translate( center_x, center_y );
 
             for (i = 0; i < VERTICES; i++)
             {
-                a = 2.0 * M_PI * i / VERTICES;
+                double a = 2.0 * M_PI * i / VERTICES;
                 geometry::RealPoint2D aSrc( RADIUS * cos (a), RADIUS * sin (a) );
 
                 for (j = i + 1; j < VERTICES; j++)
@@ -282,7 +281,7 @@ class DemoRenderer
             aStrokeAttrs.StartCapType = rendering::PathCapType::BUTT;
             aStrokeAttrs.EndCapType = rendering::PathCapType::BUTT;
             aStrokeAttrs.JoinType = rendering::PathJoinType::MITER;
-            //fprintf( stderr, "FIXME: stroking a PolyPolygon doesn't show up\n" );
+            //fprintf( stderr, "FIXME: stroking a tools::PolyPolygon doesn't show up\n" );
             //yes it does
             mxCanvas->strokePolyPolygon( xPP, maViewState, aRenderState, aStrokeAttrs );
             // FIXME: do this instead:
@@ -463,8 +462,6 @@ class DemoRenderer
             //This stuff doesn't belong here, but probably in curves
             //This stuff doesn't work in VCL b/c vcl doesn't do beziers
             //Hah!  Every time the window redraws, we do this
-            double ax;
-            double ay;
             double bx;
             double by;
             bx= gimmerand();
@@ -472,6 +469,8 @@ class DemoRenderer
 
             for (int i= 0; i < 1; i++)
             {
+                double ax;
+                double ay;
                 //point a= point b;
                 ax= bx;
                 ay= by;
