@@ -23,6 +23,7 @@
 #include "PropertyHelper.hxx"
 #include "ContainerHelper.hxx"
 #include <com/sun/star/beans/PropertyAttribute.hpp>
+#include <cppuhelper/supportsservice.hxx>
 
 using namespace ::com::sun::star;
 using ::com::sun::star::uno::Sequence;
@@ -43,14 +44,14 @@ void lcl_AddPropertiesToVector(
     rOutProperties.push_back(
         Property( "OverlapSequence",
                   PROP_BARCHARTTYPE_OVERLAP_SEQUENCE,
-                  ::getCppuType( reinterpret_cast< const Sequence< sal_Int32 > * >(0)),
+                  cppu::UnoType<Sequence< sal_Int32 >>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEDEFAULT ));
 
     rOutProperties.push_back(
         Property( "GapwidthSequence",
                   PROP_BARCHARTTYPE_GAPWIDTH_SEQUENCE,
-                  ::getCppuType( reinterpret_cast< const Sequence< sal_Int32 > * >(0)),
+                  cppu::UnoType<Sequence< sal_Int32 >>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEDEFAULT ));
 }
@@ -64,7 +65,7 @@ struct StaticColumnChartTypeDefaults_Initializer
         return &aStaticDefaults;
     }
 private:
-    void lcl_AddDefaultsToMap( ::chart::tPropertyValueMap & rOutMap )
+    static void lcl_AddDefaultsToMap( ::chart::tPropertyValueMap & rOutMap )
     {
         Sequence< sal_Int32 > aSeq(2);
 
@@ -89,7 +90,7 @@ struct StaticColumnChartTypeInfoHelper_Initializer
     }
 
 private:
-    Sequence< Property > lcl_GetPropertySequence()
+    static Sequence< Property > lcl_GetPropertySequence()
     {
         ::std::vector< ::com::sun::star::beans::Property > aProperties;
         lcl_AddPropertiesToVector( aProperties );
@@ -149,7 +150,7 @@ uno::Reference< util::XCloneable > SAL_CALL ColumnChartType::createClone()
 OUString SAL_CALL ColumnChartType::getChartType()
     throw (uno::RuntimeException, std::exception)
 {
-    return CHART2_SERVICE_NAME_CHARTTYPE_COLUMN;
+    return OUString(CHART2_SERVICE_NAME_CHARTTYPE_COLUMN);
 }
 
 uno::Sequence< OUString > ColumnChartType::getSupportedPropertyRoles()
@@ -194,9 +195,36 @@ uno::Sequence< OUString > ColumnChartType::getSupportedServiceNames_Static()
 }
 
 // implement XServiceInfo methods basing upon getSupportedServiceNames_Static
-APPHELPER_XSERVICEINFO_IMPL( ColumnChartType,
-                             OUString("com.sun.star.comp.chart.ColumnChartType") );
+OUString SAL_CALL ColumnChartType::getImplementationName()
+    throw( css::uno::RuntimeException, std::exception )
+{
+    return getImplementationName_Static();
+}
+
+OUString ColumnChartType::getImplementationName_Static()
+{
+    return OUString("com.sun.star.comp.chart.ColumnChartType");
+}
+
+sal_Bool SAL_CALL ColumnChartType::supportsService( const OUString& rServiceName )
+    throw( css::uno::RuntimeException, std::exception )
+{
+    return cppu::supportsService(this, rServiceName);
+}
+
+css::uno::Sequence< OUString > SAL_CALL ColumnChartType::getSupportedServiceNames()
+    throw( css::uno::RuntimeException, std::exception )
+{
+    return getSupportedServiceNames_Static();
+}
 
 } //  namespace chart
 
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface * SAL_CALL
+com_sun_star_comp_chart_ColumnChartType_get_implementation(css::uno::XComponentContext *context,
+        css::uno::Sequence<css::uno::Any> const &)
+{
+    return cppu::acquire(new ::chart::ColumnChartType(context));
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
