@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "sal/config.h"
+#include <sal/config.h>
 
 #include <cassert>
 
@@ -78,6 +78,7 @@ static const char* strListBasicKeyWords[] = {
     "defvar",
     "dim",
     "do",
+    "doevents",
     "double",
     "each",
     "else",
@@ -241,7 +242,7 @@ static const char* strListSqlKeyWords[] = {
 
 extern "C" int compare_strings( const void *arg1, const void *arg2 )
 {
-    return strcmp( (char *)arg1, *(char **)arg2 );
+    return strcmp( static_cast<char const *>(arg1), *static_cast<char * const *>(arg2) );
 }
 
 
@@ -261,11 +262,11 @@ class SyntaxHighlighter::Tokenizer
     sal_uInt16 aCharTypeTab[256];
 
     // Auxiliary function: testing of the character flags
-    sal_Bool testCharFlags( sal_Unicode c, sal_uInt16 nTestFlags );
+    bool testCharFlags(sal_Unicode c, sal_uInt16 nTestFlags) const;
 
     // Get new token, EmptyString == nothing more over there
-    sal_Bool getNextToken( const sal_Unicode*& pos, /*out*/TokenTypes& reType,
-        /*out*/const sal_Unicode*& rpStartPos, /*out*/const sal_Unicode*& rpEndPos );
+    bool getNextToken(const sal_Unicode*& pos, /*out*/TokenTypes& reType,
+        /*out*/const sal_Unicode*& rpStartPos, /*out*/const sal_Unicode*& rpEndPos) const;
 
     const char** ppListKeyWords;
     sal_uInt16 nKeyWordCount;
@@ -274,15 +275,15 @@ public:
     HighlighterLanguage const aLanguage;
 
     Tokenizer( HighlighterLanguage aLang );
-    ~Tokenizer( void );
+    ~Tokenizer();
 
-    void getHighlightPortions( const OUString& rLine,
-                               /*out*/std::vector<HighlightPortion>& portions );
+    void getHighlightPortions(const OUString& rLine,
+                               /*out*/std::vector<HighlightPortion>& portions) const;
     void setKeyWords( const char** ppKeyWords, sal_uInt16 nCount );
 };
 
 // Helper function: test character flag
-sal_Bool SyntaxHighlighter::Tokenizer::testCharFlags( sal_Unicode c, sal_uInt16 nTestFlags )
+bool SyntaxHighlighter::Tokenizer::testCharFlags(sal_Unicode c, sal_uInt16 nTestFlags) const
 {
     bool bRet = false;
     if( c != 0 && c <= 255 )
@@ -292,7 +293,7 @@ sal_Bool SyntaxHighlighter::Tokenizer::testCharFlags( sal_Unicode c, sal_uInt16
     else if( c > 255 )
     {
         bRet = (( CHAR_START_IDENTIFIER | CHAR_IN_IDENTIFIER ) & nTestFlags) != 0
-            ? isAlpha(c) : false;
+            && isAlpha(c);
     }
     return bRet;
 }
@@ -303,8 +304,8 @@ void SyntaxHighlighter::Tokenizer::setKeyWords( const char** ppKeyWords, sal_uIn
     nKeyWordCount = nCount;
 }
 
-sal_Bool SyntaxHighlighter::Tokenizer::getNextToken( const sal_Unicode*& pos, /*out*/TokenTypes& reType,
-    /*out*/const sal_Unicode*& rpStartPos, /*out*/const sal_Unicode*& rpEndPos )
+bool SyntaxHighlighter::Tokenizer::getNextToken(const sal_Unicode*& pos, /*out*/TokenTypes& reType,
+    /*out*/const sal_Unicode*& rpStartPos, /*out*/const sal_Unicode*& rpEndPos) const
 {
     reType = TT_UNKNOWN;
 
@@ -312,24 +313,24 @@ sal_Bool SyntaxHighlighter::Tokenizer::getNextToken( const sal_Unicode*& pos, /*
 
     sal_Unicode c = *pos;
     if( c == 0 )
-        return sal_False;
+        return false;
 
     ++pos;
 
     //*** Go through all possibilities ***
     // Space?
-    if ( (testCharFlags( c, CHAR_SPACE ) == sal_True) )
+    if ( testCharFlags( c, CHAR_SPACE ) )
     {
-        while( testCharFlags( *pos, CHAR_SPACE ) == sal_True )
+        while( testCharFlags( *pos, CHAR_SPACE ) )
             ++pos;
 
         reType = TT_WHITESPACE;
     }
 
     // Identifier?
-    else if ( (testCharFlags( c, CHAR_START_IDENTIFIER ) == sal_True) )
+    else if ( testCharFlags( c, CHAR_START_IDENTIFIER ) )
     {
-        sal_Bool bIdentifierChar;
+        bool bIdentifierChar;
         do
         {
             // Naechstes Zeichen holen
@@ -368,11 +369,11 @@ sal_Bool SyntaxHighlighter::Tokenizer::getNextToken( const sal_Unicode*& pos, /*
                 {
                     reType = TT_KEYWORDS;
 
-                    if (aByteStr.equalsL(RTL_CONSTASCII_STRINGPARAM("rem")))
+                    if( aByteStr == "rem" )
                     {
                         // Remove all characters until end of line or EOF
                         sal_Unicode cPeek = *pos;
-                        while( cPeek != 0 && testCharFlags( cPeek, CHAR_EOL ) == sal_False )
+                        while( cPeek != 0 && !testCharFlags( cPeek, CHAR_EOL ) )
                         {
                             c = *pos++;
                             cPeek = *pos;
@@ -387,14 +388,14 @@ sal_Bool SyntaxHighlighter::Tokenizer::getNextToken( const sal_Unicode*& pos, /*
 
     // Operator?
     // only for BASIC '\'' should be a comment, otherwise it is a normal string and handled there
-    else if ( ( testCharFlags( c, CHAR_OPERATOR ) == sal_True ) || ( (c == '\'') && (aLanguage==HIGHLIGHT_BASIC)) )
+    else if ( testCharFlags( c, CHAR_OPERATOR ) || ( (c == '\'') && (aLanguage==HIGHLIGHT_BASIC)) )
     {
         // parameters for SQL view
         if ( (c==':') || (c=='?'))
         {
             if (c!='?')
             {
-                sal_Bool bIdentifierChar;
+                bool bIdentifierChar;
                 do
                 {
                     // Get next character
@@ -413,7 +414,7 @@ sal_Bool SyntaxHighlighter::Tokenizer::getNextToken( const sal_Unicode*& pos, /*
             if (cPeekNext=='-')
             {
                 // Remove all characters until end of line or EOF
-                while( cPeekNext != 0 && testCharFlags( cPeekNext, CHAR_EOL ) == sal_False )
+                while( cPeekNext != 0 && !testCharFlags( cPeekNext, CHAR_EOL ) )
                 {
                     ++pos;
                     cPeekNext = *pos;
@@ -427,7 +428,7 @@ sal_Bool SyntaxHighlighter::Tokenizer::getNextToken( const sal_Unicode*& pos, /*
            if (cPeekNext=='/')
            {
                // Remove all characters until end of line or EOF
-               while( cPeekNext != 0 && testCharFlags( cPeekNext, CHAR_EOL ) == sal_False )
+               while( cPeekNext != 0 && !testCharFlags( cPeekNext, CHAR_EOL ) )
                {
                    ++pos;
                    cPeekNext = *pos;
@@ -469,7 +470,7 @@ sal_Bool SyntaxHighlighter::Tokenizer::getNextToken( const sal_Unicode*& pos, /*
     }
 
     // Number?
-    else if( testCharFlags( c, CHAR_START_NUMBER ) == sal_True )
+    else if( testCharFlags( c, CHAR_START_NUMBER ) )
     {
         reType = TT_NUMBER;
 
@@ -488,7 +489,7 @@ sal_Bool SyntaxHighlighter::Tokenizer::getNextToken( const sal_Unicode*& pos, /*
 
                 // Read all numbers
                 while( testCharFlags( *pos, CHAR_IN_OCT_NUMBER ) )
-                    c = *pos++;
+                    ++pos;
             }
             // Hexadecimal?
             else if( *pos == 'h' || *pos == 'H' )
@@ -499,7 +500,7 @@ sal_Bool SyntaxHighlighter::Tokenizer::getNextToken( const sal_Unicode*& pos, /*
 
                 // Read all numbers
                 while( testCharFlags( *pos, CHAR_IN_HEX_NUMBER ) )
-                    c = *pos++;
+                    ++pos;
             }
             else
             {
@@ -511,7 +512,7 @@ sal_Bool SyntaxHighlighter::Tokenizer::getNextToken( const sal_Unicode*& pos, /*
         if( reType == TT_NUMBER && nRadix == 10 )
         {
             // Flag if the last character is an exponent
-            sal_Bool bAfterExpChar = sal_False;
+            bool bAfterExpChar = false;
 
             // Read all numbers
             while( testCharFlags( *pos, CHAR_IN_NUMBER ) ||
@@ -526,7 +527,7 @@ sal_Bool SyntaxHighlighter::Tokenizer::getNextToken( const sal_Unicode*& pos, /*
     }
 
     // String?
-    else if( testCharFlags( c, CHAR_START_STRING ) == sal_True )
+    else if( testCharFlags( c, CHAR_START_STRING ) )
     {
         // Remember which character has opened the string
         sal_Unicode cEndString = c;
@@ -536,7 +537,7 @@ sal_Bool SyntaxHighlighter::Tokenizer::getNextToken( const sal_Unicode*& pos, /*
         // Read all characters
         while( *pos != cEndString )
         {
-            // Detect EOF before reading next char, so we do not loose EOF
+            // Detect EOF before reading next char, so we do not lose EOF
             if( *pos == 0 )
             {
                 // ERROR: unterminated string literal
@@ -544,7 +545,7 @@ sal_Bool SyntaxHighlighter::Tokenizer::getNextToken( const sal_Unicode*& pos, /*
                 break;
             }
             c = *pos++;
-            if( testCharFlags( c, CHAR_EOL ) == sal_True )
+            if( testCharFlags( c, CHAR_EOL ) )
             {
                 // ERROR: unterminated string literal
                 reType = TT_ERROR;
@@ -563,11 +564,11 @@ sal_Bool SyntaxHighlighter::Tokenizer::getNextToken( const sal_Unicode*& pos, /*
     }
 
     // End of line?
-    else if( testCharFlags( c, CHAR_EOL ) == sal_True )
+    else if( testCharFlags( c, CHAR_EOL ) )
     {
         // If another EOL character comes, read it
         sal_Unicode cNext = *pos;
-        if( cNext != c && testCharFlags( cNext, CHAR_EOL ) == sal_True )
+        if( cNext != c && testCharFlags( cNext, CHAR_EOL ) )
             ++pos;
 
         reType = TT_EOL;
@@ -577,7 +578,7 @@ sal_Bool SyntaxHighlighter::Tokenizer::getNextToken( const sal_Unicode*& pos, /*
 
     // Save end position
     rpEndPos = pos;
-    return sal_True;
+    return true;
 }
 
 SyntaxHighlighter::Tokenizer::Tokenizer( HighlighterLanguage aLang ): aLanguage(aLang)
@@ -658,14 +659,15 @@ SyntaxHighlighter::Tokenizer::Tokenizer( HighlighterLanguage aLang ): aLanguage(
     aCharTypeTab[(int)'\n'] |= CHAR_EOL;
 
     ppListKeyWords = NULL;
+    nKeyWordCount = 0;
 }
 
-SyntaxHighlighter::Tokenizer::~Tokenizer( void )
+SyntaxHighlighter::Tokenizer::~Tokenizer()
 {
 }
 
-void SyntaxHighlighter::Tokenizer::getHighlightPortions( const OUString& rLine,
-                                                 /*out*/std::vector<HighlightPortion>& portions  )
+void SyntaxHighlighter::Tokenizer::getHighlightPortions(const OUString& rLine,
+                                                 /*out*/std::vector<HighlightPortion>& portions) const
 {
     // Set the position to the beginning of the source string
     const sal_Unicode* pos = rLine.getStr();
@@ -705,8 +707,8 @@ SyntaxHighlighter::SyntaxHighlighter(HighlighterLanguage language):
 
 SyntaxHighlighter::~SyntaxHighlighter() {}
 
-void SyntaxHighlighter::getHighlightPortions( const OUString& rLine,
-                                              /*out*/std::vector<HighlightPortion>& portions )
+void SyntaxHighlighter::getHighlightPortions(const OUString& rLine,
+                                              /*out*/std::vector<HighlightPortion>& portions) const
 {
     m_tokenizer->getHighlightPortions( rLine, portions );
 }
