@@ -17,26 +17,29 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "connectivity/TTableHelper.hxx"
+#include <sal/config.h>
+
+#include <boost/noncopyable.hpp>
+#include <connectivity/TTableHelper.hxx>
 #include <com/sun/star/sdbc/XRow.hpp>
 #include <com/sun/star/sdbc/XResultSet.hpp>
 #include <com/sun/star/sdbcx/KeyType.hpp>
 #include <com/sun/star/sdbc/KeyRule.hpp>
 #include <cppuhelper/typeprovider.hxx>
 #include <com/sun/star/lang/DisposedException.hpp>
+#include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/sdbc/ColumnValue.hpp>
-#include <comphelper/implementationreference.hxx>
 #include <comphelper/sequence.hxx>
-#include <comphelper/extract.hxx>
 #include <comphelper/types.hxx>
-#include "connectivity/dbtools.hxx"
-#include "connectivity/sdbcx/VCollection.hxx"
+#include <connectivity/dbtools.hxx>
+#include <connectivity/sdbcx/VCollection.hxx>
 #include <unotools/sharedunocomponent.hxx>
 #include "TConnection.hxx"
 
 #include <o3tl/compat_functional.hxx>
 
 #include <iterator>
+#include <set>
 
 using namespace ::comphelper;
 using namespace connectivity;
@@ -50,28 +53,27 @@ namespace
 {
     /// helper class for column property change events which holds the OComponentDefinition weak
 typedef ::cppu::WeakImplHelper1 < XContainerListener > OTableContainerListener_BASE;
-class OTableContainerListener : public OTableContainerListener_BASE
+class OTableContainerListener:
+    public OTableContainerListener_BASE, private boost::noncopyable
 {
     OTableHelper* m_pComponent;
     ::std::map< OUString,bool> m_aRefNames;
 
-    OTableContainerListener(const OTableContainerListener&);
-    void operator =(const OTableContainerListener&);
 protected:
     virtual ~OTableContainerListener(){}
 public:
     OTableContainerListener(OTableHelper* _pComponent) : m_pComponent(_pComponent){}
-    virtual void SAL_CALL elementInserted( const ::com::sun::star::container::ContainerEvent& /*Event*/ ) throw (RuntimeException)
+    virtual void SAL_CALL elementInserted( const ::com::sun::star::container::ContainerEvent& /*Event*/ ) throw (RuntimeException, std::exception) SAL_OVERRIDE
     {
     }
-    virtual void SAL_CALL elementRemoved( const ::com::sun::star::container::ContainerEvent& Event ) throw (RuntimeException)
+    virtual void SAL_CALL elementRemoved( const ::com::sun::star::container::ContainerEvent& Event ) throw (RuntimeException, std::exception) SAL_OVERRIDE
     {
         OUString sName;
         Event.Accessor  >>= sName;
         if ( m_aRefNames.find(sName) != m_aRefNames.end() )
             m_pComponent->refreshKeys();
     }
-    virtual void SAL_CALL elementReplaced( const ::com::sun::star::container::ContainerEvent& Event ) throw (RuntimeException)
+    virtual void SAL_CALL elementReplaced( const ::com::sun::star::container::ContainerEvent& Event ) throw (RuntimeException, std::exception) SAL_OVERRIDE
     {
         OUString sOldComposedName,sNewComposedName;
         Event.ReplacedElement   >>= sOldComposedName;
@@ -80,7 +82,7 @@ public:
             m_pComponent->refreshKeys();
     }
     // XEventListener
-    virtual void SAL_CALL disposing( const EventObject& /*_rSource*/ ) throw (RuntimeException)
+    virtual void SAL_CALL disposing( const EventObject& /*_rSource*/ ) throw (RuntimeException, std::exception) SAL_OVERRIDE
     {
     }
     void clear() { m_pComponent = NULL; }
@@ -110,8 +112,7 @@ namespace connectivity
 
         Reference< ::com::sun::star::sdbc::XDatabaseMetaData >      m_xMetaData;
         Reference< ::com::sun::star::sdbc::XConnection >            m_xConnection;
-        ::comphelper::ImplementationReference< OTableContainerListener,XContainerListener>
-                                    m_xTablePropertyListener;
+        rtl::Reference<OTableContainerListener> m_xTablePropertyListener;
         ::std::vector< ColumnDesc > m_aColumnDesc;
         OTableHelperImpl(const Reference< ::com::sun::star::sdbc::XConnection >& _xConnection)
             : m_xConnection(_xConnection)
@@ -122,14 +123,10 @@ namespace connectivity
                 Reference<XMultiServiceFactory> xFac(_xConnection,UNO_QUERY);
                 if ( xFac.is() )
                 {
-                    static const OUString s_sTableRename("TableRenameServiceName");
-                    m_xRename.set(xFac->createInstance(lcl_getServiceNameForSetting(m_xConnection,s_sTableRename)),UNO_QUERY);
-                    static const OUString s_sTableAlteration("TableAlterationServiceName");
-                    m_xAlter.set(xFac->createInstance(lcl_getServiceNameForSetting(m_xConnection,s_sTableAlteration)),UNO_QUERY);
-                    static const OUString s_sKeyAlteration("KeyAlterationServiceName");
-                    m_xKeyAlter.set(xFac->createInstance(lcl_getServiceNameForSetting(m_xConnection,s_sKeyAlteration)),UNO_QUERY);
-                    static const OUString s_sIndexAlteration("IndexAlterationServiceName");
-                    m_xIndexAlter.set(xFac->createInstance(lcl_getServiceNameForSetting(m_xConnection,s_sIndexAlteration)),UNO_QUERY);
+                    m_xRename.set(xFac->createInstance(lcl_getServiceNameForSetting(m_xConnection,"TableRenameServiceName")),UNO_QUERY);
+                    m_xAlter.set(xFac->createInstance(lcl_getServiceNameForSetting(m_xConnection,"TableAlterationServiceName")),UNO_QUERY);
+                    m_xKeyAlter.set(xFac->createInstance(lcl_getServiceNameForSetting(m_xConnection,"KeyAlterationServiceName")),UNO_QUERY);
+                    m_xIndexAlter.set(xFac->createInstance(lcl_getServiceNameForSetting(m_xConnection,"IndexAlterationServiceName")),UNO_QUERY);
                 }
             }
             catch(const Exception&)
@@ -141,15 +138,15 @@ namespace connectivity
 
 OTableHelper::OTableHelper( sdbcx::OCollection* _pTables,
                            const Reference< XConnection >& _xConnection,
-                           sal_Bool _bCase)
+                           bool _bCase)
     :OTable_TYPEDEF(_pTables,_bCase)
     ,m_pImpl(new OTableHelperImpl(_xConnection))
 {
 }
-// -------------------------------------------------------------------------
+
 OTableHelper::OTableHelper( sdbcx::OCollection* _pTables,
                             const Reference< XConnection >& _xConnection,
-                            sal_Bool _bCase,
+                            bool _bCase,
                             const OUString& _Name,
                             const OUString& _Type,
                             const OUString& _Description ,
@@ -165,19 +162,19 @@ OTableHelper::OTableHelper( sdbcx::OCollection* _pTables,
                         ,m_pImpl(new OTableHelperImpl(_xConnection))
 {
 }
-// -----------------------------------------------------------------------------
+
 OTableHelper::~OTableHelper()
 {
 }
-// -----------------------------------------------------------------------------
+
 void SAL_CALL OTableHelper::disposing()
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     if ( m_pImpl->m_xTablePropertyListener.is() )
     {
-        m_pTables->removeContainerListener(m_pImpl->m_xTablePropertyListener.getRef());
+        m_pTables->removeContainerListener(m_pImpl->m_xTablePropertyListener.get());
         m_pImpl->m_xTablePropertyListener->clear();
-        m_pImpl->m_xTablePropertyListener.dispose();
+        m_pImpl->m_xTablePropertyListener.clear();
     }
     OTable_TYPEDEF::disposing();
 
@@ -186,7 +183,7 @@ void SAL_CALL OTableHelper::disposing()
 
 }
 
-// -------------------------------------------------------------------------
+
 namespace
 {
     /** collects ColumnDesc's from a resultset produced by XDatabaseMetaData::getColumns
@@ -258,7 +255,7 @@ namespace
     }
 }
 
-// -------------------------------------------------------------------------
+
 void OTableHelper::refreshColumns()
 {
     TStringVector aVector;
@@ -304,7 +301,7 @@ void OTableHelper::refreshColumns()
     else
         m_pColumns  = createColumns(aVector);
 }
-// -----------------------------------------------------------------------------
+
 const ColumnDesc* OTableHelper::getColumnDescription(const OUString& _sName) const
 {
     const ColumnDesc* pRet = NULL;
@@ -319,7 +316,7 @@ const ColumnDesc* OTableHelper::getColumnDescription(const OUString& _sName) con
     } // for (::std::vector< ColumnDesc >::const_iterator aIter = m_pImpl->m_aColumnDesc.begin();aIter != aEnd;++aIter)
     return pRet;
 }
-// -------------------------------------------------------------------------
+
 void OTableHelper::refreshPrimaryKeys(TStringVector& _rNames)
 {
     Any aCatalog;
@@ -355,7 +352,7 @@ void OTableHelper::refreshPrimaryKeys(TStringVector& _rNames)
     } // if ( xResult.is() && xResult->next() )
     ::comphelper::disposeComponent(xResult);
 }
-// -------------------------------------------------------------------------
+
 void OTableHelper::refreshForeignKeys(TStringVector& _rNames)
 {
     Any aCatalog;
@@ -373,7 +370,7 @@ void OTableHelper::refreshForeignKeys(TStringVector& _rNames)
             // this must be outsid the "if" because we have to call in a right order
             sCatalog    = xRow->getString(1);
             if ( xRow->wasNull() )
-                sCatalog = OUString();
+                sCatalog.clear();
             aSchema     = xRow->getString(2);
             aName       = xRow->getString(3);
 
@@ -394,15 +391,15 @@ void OTableHelper::refreshForeignKeys(TStringVector& _rNames)
                     if ( pKeyProps.get() )
                         m_pImpl->m_aKeys.insert(TKeyMap::value_type(sOldFKName,pKeyProps));
 
-                    const OUString sReferencedName = ::dbtools::composeTableName(getMetaData(),sCatalog,aSchema,aName,sal_False,::dbtools::eInDataManipulation);
+                    const OUString sReferencedName = ::dbtools::composeTableName(getMetaData(),sCatalog,aSchema,aName,false,::dbtools::eInDataManipulation);
                     pKeyProps.reset(new sdbcx::KeyProperties(sReferencedName,KeyType::FOREIGN,nUpdateRule,nDeleteRule));
                     pKeyProps->m_aKeyColumnNames.push_back(sForeignKeyColumn);
                     _rNames.push_back(sFkName);
                     if ( m_pTables->hasByName(sReferencedName) )
                     {
                         if ( !m_pImpl->m_xTablePropertyListener.is() )
-                            m_pImpl->m_xTablePropertyListener = ::comphelper::ImplementationReference< OTableContainerListener,XContainerListener>( new OTableContainerListener(this) );
-                        m_pTables->addContainerListener(m_pImpl->m_xTablePropertyListener.getRef());
+                            m_pImpl->m_xTablePropertyListener = new OTableContainerListener(this);
+                        m_pTables->addContainerListener(m_pImpl->m_xTablePropertyListener.get());
                         m_pImpl->m_xTablePropertyListener->add(sReferencedName);
                     } // if ( m_pTables->hasByName(sReferencedName) )
                     sOldFKName = sFkName;
@@ -418,7 +415,7 @@ void OTableHelper::refreshForeignKeys(TStringVector& _rNames)
         ::comphelper::disposeComponent(xResult);
     }
 }
-// -------------------------------------------------------------------------
+
 void OTableHelper::refreshKeys()
 {
     m_pImpl->m_aKeys.clear();
@@ -438,7 +435,7 @@ void OTableHelper::refreshKeys()
     else*/
 
 }
-// -------------------------------------------------------------------------
+
 void OTableHelper::refreshIndexes()
 {
     TStringVector aVector;
@@ -479,7 +476,7 @@ void OTableHelper::refreshIndexes()
     else
         m_pIndexes  = createIndexes(aVector);
 }
-// -----------------------------------------------------------------------------
+
 OUString OTableHelper::getRenameStart() const
 {
     OUString sSql("RENAME ");
@@ -490,9 +487,9 @@ OUString OTableHelper::getRenameStart() const
 
     return sSql;
 }
-// -------------------------------------------------------------------------
+
 // XRename
-void SAL_CALL OTableHelper::rename( const OUString& newName ) throw(SQLException, ElementExistException, RuntimeException)
+void SAL_CALL OTableHelper::rename( const OUString& newName ) throw(SQLException, ElementExistException, RuntimeException, std::exception)
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     checkDisposed(
@@ -517,10 +514,10 @@ void SAL_CALL OTableHelper::rename( const OUString& newName ) throw(SQLException
             ::dbtools::qualifiedNameComponents(getMetaData(),newName,sCatalog,sSchema,sTable,::dbtools::eInDataManipulation);
 
             OUString sComposedName;
-            sComposedName = ::dbtools::composeTableName(getMetaData(),m_CatalogName,m_SchemaName,m_Name,sal_True,::dbtools::eInDataManipulation);
+            sComposedName = ::dbtools::composeTableName(getMetaData(),m_CatalogName,m_SchemaName,m_Name,true,::dbtools::eInDataManipulation);
             sSql += sComposedName
-                 + OUString(" TO ");
-            sComposedName = ::dbtools::composeTableName(getMetaData(),sCatalog,sSchema,sTable,sal_True,::dbtools::eInDataManipulation);
+                 + " TO ";
+            sComposedName = ::dbtools::composeTableName(getMetaData(),sCatalog,sSchema,sTable,true,::dbtools::eInDataManipulation);
             sSql += sComposedName;
 
             Reference< XStatement > xStmt = m_pImpl->m_xConnection->createStatement(  );
@@ -536,13 +533,13 @@ void SAL_CALL OTableHelper::rename( const OUString& newName ) throw(SQLException
     else
         ::dbtools::qualifiedNameComponents(getMetaData(),newName,m_CatalogName,m_SchemaName,m_Name,::dbtools::eInTableDefinitions);
 }
-// -----------------------------------------------------------------------------
+
 Reference< XDatabaseMetaData> OTableHelper::getMetaData() const
 {
     return m_pImpl->m_xMetaData;
 }
-// -------------------------------------------------------------------------
-void SAL_CALL OTableHelper::alterColumnByIndex( sal_Int32 index, const Reference< XPropertySet >& descriptor ) throw(SQLException, ::com::sun::star::lang::IndexOutOfBoundsException, RuntimeException)
+
+void SAL_CALL OTableHelper::alterColumnByIndex( sal_Int32 index, const Reference< XPropertySet >& descriptor ) throw(SQLException, ::com::sun::star::lang::IndexOutOfBoundsException, RuntimeException, std::exception)
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     checkDisposed(
@@ -553,29 +550,30 @@ void SAL_CALL OTableHelper::alterColumnByIndex( sal_Int32 index, const Reference
 #endif
         );
 
-    Reference< XPropertySet > xOld;
-    if(::cppu::extractInterface(xOld,m_pColumns->getByIndex(index)) && xOld.is())
+    Reference< XPropertySet > xOld(
+        m_pColumns->getByIndex(index), css::uno::UNO_QUERY);
+    if(xOld.is())
         alterColumnByName(getString(xOld->getPropertyValue(OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_NAME))),descriptor);
 }
 
-// -------------------------------------------------------------------------
-OUString SAL_CALL OTableHelper::getName() throw(RuntimeException)
+
+OUString SAL_CALL OTableHelper::getName() throw(RuntimeException, std::exception)
 {
     OUString sComposedName;
-    sComposedName = ::dbtools::composeTableName(getMetaData(),m_CatalogName,m_SchemaName,m_Name,sal_False,::dbtools::eInDataManipulation);
+    sComposedName = ::dbtools::composeTableName(getMetaData(),m_CatalogName,m_SchemaName,m_Name,false,::dbtools::eInDataManipulation);
     return sComposedName;
 }
-// -----------------------------------------------------------------------------
+
 void SAL_CALL OTableHelper::acquire() throw()
 {
     OTable_TYPEDEF::acquire();
 }
-// -----------------------------------------------------------------------------
+
 void SAL_CALL OTableHelper::release() throw()
 {
     OTable_TYPEDEF::release();
 }
-// -----------------------------------------------------------------------------
+
 sdbcx::TKeyProperties OTableHelper::getKeyProperties(const OUString& _sName) const
 {
     sdbcx::TKeyProperties pKeyProps;
@@ -592,41 +590,41 @@ sdbcx::TKeyProperties OTableHelper::getKeyProperties(const OUString& _sName) con
 
     return pKeyProps;
 }
-// -----------------------------------------------------------------------------
+
 void OTableHelper::addKey(const OUString& _sName,const sdbcx::TKeyProperties& _aKeyProperties)
 {
     m_pImpl->m_aKeys.insert(TKeyMap::value_type(_sName,_aKeyProperties));
 }
-// -----------------------------------------------------------------------------
+
 OUString OTableHelper::getTypeCreatePattern() const
 {
     return OUString();
 }
-// -----------------------------------------------------------------------------
+
 Reference< XConnection> OTableHelper::getConnection() const
 {
     return m_pImpl->m_xConnection;
 }
-// -----------------------------------------------------------------------------
+
 Reference< ::com::sun::star::sdb::tools::XTableRename>      OTableHelper::getRenameService() const
 {
     return m_pImpl->m_xRename;
 }
-// -----------------------------------------------------------------------------
+
 Reference< ::com::sun::star::sdb::tools::XTableAlteration>  OTableHelper::getAlterService() const
 {
     return m_pImpl->m_xAlter;
 }
-// -----------------------------------------------------------------------------
+
 Reference< ::com::sun::star::sdb::tools::XKeyAlteration>  OTableHelper::getKeyService() const
 {
     return m_pImpl->m_xKeyAlter;
 }
-// -----------------------------------------------------------------------------
+
 Reference< ::com::sun::star::sdb::tools::XIndexAlteration>  OTableHelper::getIndexService() const
 {
     return m_pImpl->m_xIndexAlter;
 }
-// -----------------------------------------------------------------------------
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
