@@ -31,7 +31,7 @@ using namespace com::sun::star::sdbc;
 using namespace com::sun::star::util;
 using namespace ::dbtools;
 
-// -------------------------------------------------------------------------
+
 MacabHeader::MacabHeader(const sal_Int32 _size, macabfield **_fields)
 {
     sal_Int32 i;
@@ -58,19 +58,19 @@ MacabHeader::MacabHeader(const sal_Int32 _size, macabfield **_fields)
 
 }
 
-// -------------------------------------------------------------------------
+
 MacabHeader::MacabHeader()
 {
     size = 0;
     fields = NULL;
 }
 
-// -------------------------------------------------------------------------
+
 MacabHeader::~MacabHeader()
 {
 }
 
-// -------------------------------------------------------------------------
+
 void MacabHeader::operator+= (const MacabHeader *r)
 {
     /* Add one MacabHeader to another. Anything not already in the header is
@@ -139,7 +139,7 @@ void MacabHeader::operator+= (const MacabHeader *r)
     }
 }
 
-// -------------------------------------------------------------------------
+
 OUString MacabHeader::getString(const sal_Int32 i) const
 {
     OUString nRet;
@@ -150,7 +150,7 @@ OUString MacabHeader::getString(const sal_Int32 i) const
             return OUString();
         try
         {
-            nRet = CFStringToOUString( (CFStringRef) fields[i]->value);
+            nRet = CFStringToOUString(static_cast<CFStringRef>(fields[i]->value));
         }
         catch(...){ }
     }
@@ -158,13 +158,13 @@ OUString MacabHeader::getString(const sal_Int32 i) const
     return nRet;
 }
 
-// -------------------------------------------------------------------------
+
 void MacabHeader::sortRecord()
 {
     sortRecord(0,size);
 }
 
-// -------------------------------------------------------------------------
+
 macabfield **MacabHeader::sortRecord(const sal_Int32 _start, const sal_Int32 _length)
 {
     /* Sort using mergesort. Because it uses mergesort, it is recursive and
@@ -198,11 +198,9 @@ macabfield **MacabHeader::sortRecord(const sal_Int32 _start, const sal_Int32 _le
         sal_Int32 halfLength = floor(_length/2);
         sal_Int32 fp = 0, lp = 0;
         sal_Int32 i;
-        macabfield **firstHalf = new macabfield *[halfLength];
-        macabfield **lastHalf = new macabfield *[_length - halfLength];
+        macabfield **firstHalf = sortRecord(_start, halfLength);
+        macabfield **lastHalf = sortRecord(_start+halfLength, _length-halfLength);
 
-        firstHalf = sortRecord(_start, halfLength);
-        lastHalf = sortRecord(_start+halfLength, _length-halfLength);
         for(i = 0; i < _length; i++)
         {
             if(compareFields(firstHalf[fp],lastHalf[lp]) < 0)
@@ -234,6 +232,8 @@ macabfield **MacabHeader::sortRecord(const sal_Int32 _start, const sal_Int32 _le
         {
             fields = sorted;
         }
+        delete firstHalf;
+        delete lastHalf;
     }
     return sorted;
 }
@@ -256,15 +256,15 @@ sal_Int32 MacabHeader::compareFields(const macabfield *_field1, const macabfield
         return -1;
 
     CFComparisonResult result = CFStringCompare(
-        (CFStringRef) _field1->value,
-        (CFStringRef) _field2->value,
+        static_cast<CFStringRef>(_field1->value),
+        static_cast<CFStringRef>(_field2->value),
         0); // 0 = no options (like ignore case)
 
     return (sal_Int32) result;
 }
 
-// -------------------------------------------------------------------------
-sal_Int32 MacabHeader::getColumnNumber(const OUString s) const
+
+sal_Int32 MacabHeader::getColumnNumber(const OUString& s) const
 {
     sal_Int32 i;
     for(i = 0; i < size; i++)
@@ -279,18 +279,18 @@ sal_Int32 MacabHeader::getColumnNumber(const OUString s) const
     return i;
 }
 
-// -------------------------------------------------------------------------
+
 MacabHeader *MacabHeader::begin()
 {
     return this;
 }
 
-// -------------------------------------------------------------------------
+
 MacabHeader::iterator::iterator ()
 {
 }
 
-// -------------------------------------------------------------------------
+
 MacabHeader::iterator::~iterator ()
 {
 }
@@ -302,31 +302,31 @@ MacabHeader::iterator& MacabHeader::iterator::operator= (MacabHeader *_record)
     return *this;
 }
 
-// -------------------------------------------------------------------------
+
 void MacabHeader::iterator::operator++ ()
 {
     id++;
 }
 
-// -------------------------------------------------------------------------
-sal_Bool MacabHeader::iterator::operator!= (const sal_Int32 i) const
+
+bool MacabHeader::iterator::operator!= (const sal_Int32 i) const
 {
     return(id != i);
 }
 
-// -------------------------------------------------------------------------
-sal_Bool MacabHeader::iterator::operator== (const sal_Int32 i) const
+
+bool MacabHeader::iterator::operator== (const sal_Int32 i) const
 {
     return(id == i);
 }
 
-// -------------------------------------------------------------------------
+
 macabfield *MacabHeader::iterator::operator* () const
 {
     return record->get(id);
 }
 
-// -------------------------------------------------------------------------
+
 sal_Int32 MacabHeader::end() const
 {
     return size;
