@@ -32,14 +32,14 @@ using namespace connectivity::macab;
 using namespace com::sun::star::util;
 using namespace ::dbtools;
 
-// -------------------------------------------------------------------------
+
 MacabRecord::MacabRecord()
 {
     size = 0;
     fields = NULL;
 }
 
-// -------------------------------------------------------------------------
+
 MacabRecord::MacabRecord(const sal_Int32 _size)
 {
     size = _size;
@@ -49,7 +49,7 @@ MacabRecord::MacabRecord(const sal_Int32 _size)
         fields[i] = NULL;
 }
 
-// -------------------------------------------------------------------------
+
 MacabRecord::~MacabRecord()
 {
     if(size > 0)
@@ -65,7 +65,7 @@ MacabRecord::~MacabRecord()
     fields = NULL;
 }
 
-// -------------------------------------------------------------------------
+
 void MacabRecord::insertAtColumn (CFTypeRef _value, ABPropertyType _type, const sal_Int32 _column)
 {
     if(_column < size)
@@ -80,17 +80,17 @@ void MacabRecord::insertAtColumn (CFTypeRef _value, ABPropertyType _type, const
     }
 }
 
-// -------------------------------------------------------------------------
-sal_Bool MacabRecord::contains (const macabfield *_field) const
+
+bool MacabRecord::contains (const macabfield *_field) const
 {
     if(_field == NULL)
-        return sal_False;
+        return false;
     else
         return contains(_field->value);
 }
 
-// -------------------------------------------------------------------------
-sal_Bool MacabRecord::contains (const CFTypeRef _value) const
+
+bool MacabRecord::contains (const CFTypeRef _value) const
 {
     sal_Int32 i;
     for(i = 0; i < size; i++)
@@ -99,21 +99,21 @@ sal_Bool MacabRecord::contains (const CFTypeRef _value) const
         {
             if(CFEqual(fields[i]->value, _value))
             {
-                return sal_True;
+                return true;
             }
         }
     }
 
-    return sal_False;
+    return false;
 }
 
-// -------------------------------------------------------------------------
+
 sal_Int32 MacabRecord::getSize() const
 {
     return size;
 }
 
-// -------------------------------------------------------------------------
+
 macabfield *MacabRecord::copy(const sal_Int32 i) const
 {
     /* Note: copy(i) creates a new macabfield identical to that at
@@ -133,7 +133,7 @@ macabfield *MacabRecord::copy(const sal_Int32 i) const
     return NULL;
 }
 
-// -------------------------------------------------------------------------
+
 macabfield *MacabRecord::get(const sal_Int32 i) const
 {
     /* Note: copy(i) creates a new macabfield identical to that at
@@ -148,7 +148,7 @@ macabfield *MacabRecord::get(const sal_Int32 i) const
     return NULL;
 }
 
-// -------------------------------------------------------------------------
+
 void MacabRecord::releaseFields()
 {
     /* This method is, at the moment, only used in MacabHeader.cxx, but
@@ -161,7 +161,7 @@ void MacabRecord::releaseFields()
         CFRelease(fields[i]->value);
 }
 
-// -------------------------------------------------------------------------
+
 sal_Int32 MacabRecord::compareFields(const macabfield *_field1, const macabfield *_field2)
 {
 
@@ -190,23 +190,23 @@ sal_Int32 MacabRecord::compareFields(const macabfield *_field1, const macabfield
     {
         case kABStringProperty:
             result = CFStringCompare(
-                (CFStringRef) _field1->value,
-                (CFStringRef) _field2->value,
+                static_cast<CFStringRef>(_field1->value),
+                static_cast<CFStringRef>(_field2->value),
                 kCFCompareLocalized); // Specifies that the comparison should take into account differences related to locale, such as the thousands separator character.
             break;
 
         case kABDateProperty:
             result = CFDateCompare(
-                (CFDateRef) _field1->value,
-                (CFDateRef) _field2->value,
+                static_cast<CFDateRef>(_field1->value),
+                static_cast<CFDateRef>(_field2->value),
                 NULL); // NULL = unused variable
             break;
 
         case kABIntegerProperty:
         case kABRealProperty:
             result = CFNumberCompare(
-                (CFNumberRef) _field1->value,
-                (CFNumberRef) _field2->value,
+                static_cast<CFNumberRef>(_field1->value),
+                static_cast<CFNumberRef>(_field2->value),
                 NULL); // NULL = unused variable
         break;
 
@@ -217,13 +217,13 @@ sal_Int32 MacabRecord::compareFields(const macabfield *_field1, const macabfield
     return (sal_Int32) result;
 }
 
-// -------------------------------------------------------------------------
+
 /* Create a macabfield out of an OUString and type. Together with the
  * method fieldToString() (below), it is possible to switch conveniently
  * between an OUString and a macabfield (for use when creating and handling
  * SQL statement).
  */
-macabfield *MacabRecord::createMacabField(const OUString _newFieldString, const ABPropertyType _abType)
+macabfield *MacabRecord::createMacabField(const OUString& _newFieldString, const ABPropertyType _abType)
 {
     macabfield *newField = NULL;
     switch(_abType)
@@ -285,7 +285,7 @@ macabfield *MacabRecord::createMacabField(const OUString _newFieldString, const
     return newField;
 }
 
-// -------------------------------------------------------------------------
+
 /* Create an OUString out of a macabfield. Together with the method
  * createMacabField() (above), it is possible to switch conveniently
  * between an OUString and a macabfield (for use when creating and handling
@@ -301,31 +301,31 @@ OUString MacabRecord::fieldToString(const macabfield *_aField)
     switch(_aField->type)
     {
         case kABStringProperty:
-            fieldString = CFStringToOUString((CFStringRef) _aField->value);
+            fieldString = CFStringToOUString(static_cast<CFStringRef>(_aField->value));
             break;
         case kABDateProperty:
             {
-                DateTime aTime = CFDateToDateTime((CFDateRef) _aField->value);
+                DateTime aTime = CFDateToDateTime(static_cast<CFDateRef>(_aField->value));
                 fieldString = DBTypeConversion::toDateTimeString(aTime);
             }
             break;
         case kABIntegerProperty:
             {
-                CFNumberType numberType = CFNumberGetType( (CFNumberRef) _aField->value );
+                CFNumberType numberType = CFNumberGetType( static_cast<CFNumberRef>(_aField->value) );
                 sal_Int64 nVal;
                 // Should we check for the wrong type here, e.g., a float?
-                sal_Bool m_bSuccess = !CFNumberGetValue((CFNumberRef) _aField->value, numberType, &nVal);
-                if(m_bSuccess != sal_False)
+                bool m_bSuccess = !CFNumberGetValue(static_cast<CFNumberRef>(_aField->value), numberType, &nVal);
+                if(m_bSuccess)
                     fieldString = OUString::number(nVal);
             }
             break;
         case kABRealProperty:
             {
-                CFNumberType numberType = CFNumberGetType( (CFNumberRef) _aField->value );
+                CFNumberType numberType = CFNumberGetType( static_cast<CFNumberRef>(_aField->value) );
                 double nVal;
                 // Should we check for the wrong type here, e.g., an int?
-                sal_Bool m_bSuccess = !CFNumberGetValue((CFNumberRef) _aField->value, numberType, &nVal);
-                if(m_bSuccess != sal_False)
+                bool m_bSuccess = !CFNumberGetValue(static_cast<CFNumberRef>(_aField->value), numberType, &nVal);
+                if(m_bSuccess)
                     fieldString = OUString::number(nVal);
             }
             break;
