@@ -20,6 +20,7 @@
 #include <basic/basmgr.hxx>
 
 #include "macropg.hxx"
+#include <vcl/layout.hxx>
 #include <vcl/msgbox.hxx>
 #include <svtools/svmedit.hxx>
 #include <svtools/svlbitm.hxx>
@@ -28,66 +29,48 @@
 #include <tools/diagnose_ex.h>
 #include <sfx2/app.hxx>
 #include <sfx2/objsh.hxx>
-#include <sfx2/sfxdefs.hxx>
 #include <com/sun/star/container/NoSuchElementException.hpp>
 #include <com/sun/star/lang/IllegalArgumentException.hpp>
 #include <dialmgr.hxx>
 #include "selector.hxx"
 #include "cfg.hxx"
-#include "macropg.hrc"
 #include "helpid.hrc"
 #include <cuires.hrc>
 #include "headertablistbox.hxx"
 #include "macropg_impl.hxx"
 #include <svx/dialogs.hrc>
+#include <vcl/builderfactory.hxx>
 #include <comphelper/namedvaluecollection.hxx>
 
 #include <algorithm>
 #include <set>
+#include <boost/scoped_ptr.hpp>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 
-static OUString aVndSunStarUNO( "vnd.sun.star.UNO:" );
-static OUString aVndSunStarScript( "vnd.sun.star.script:" );
+static const char aVndSunStarUNO[] = "vnd.sun.star.UNO:";
+static const char aVndSunStarScript[] = "vnd.sun.star.script:";
 
-_SvxMacroTabPage_Impl::_SvxMacroTabPage_Impl( const SfxItemSet& rAttrSet ) :
-    pAssignFT( NULL ),
-    pAssignPB( NULL ),
-    pAssignComponentPB( NULL ),
-    pDeletePB( NULL ),
-    pMacroImg( NULL ),
-    pComponentImg( NULL ),
-    pStrEvent( NULL ),
-    pAssignedMacro( NULL ),
-    pEventLB( NULL ),
-    bReadOnly( sal_False ),
-    bIDEDialogMode( sal_False )
+_SvxMacroTabPage_Impl::_SvxMacroTabPage_Impl( const SfxItemSet& rAttrSet )
+    : pAssignPB(NULL)
+    , pAssignComponentPB(NULL)
+    , pDeletePB(NULL)
+    , pEventLB(NULL)
+    , bReadOnly(false)
+    , bIDEDialogMode(false)
 {
     const SfxPoolItem* pItem;
-    if ( SFX_ITEM_SET == rAttrSet.GetItemState( SID_ATTR_MACROITEM, sal_False, &pItem ) )
-        bIDEDialogMode = ((const SfxBoolItem*)pItem)->GetValue();
-}
-
-_SvxMacroTabPage_Impl::~_SvxMacroTabPage_Impl()
-{
-    delete pAssignFT;
-    delete pAssignPB;
-    delete pAssignComponentPB;
-    delete pDeletePB;
-    delete pMacroImg;
-    delete pComponentImg;
-    delete pStrEvent;
-    delete pAssignedMacro;
-    delete pEventLB;
+    if ( SfxItemState::SET == rAttrSet.GetItemState( SID_ATTR_MACROITEM, false, &pItem ) )
+        bIDEDialogMode = static_cast<const SfxBoolItem*>(pItem)->GetValue();
 }
 
 // attention, this array is indexed directly (0, 1, ...) in the code
 static long nTabs[] =
-    {
-        2, // Number of Tabs
-        0, 90
-    };
+{
+    2, // Number of Tabs
+    0, 90
+};
 
 #define TAB_WIDTH_MIN        10
 
@@ -99,95 +82,130 @@ static long nTabs[] =
 #define LB_MACROS_ITEMPOS    2
 
 
-IMPL_LINK( _HeaderTabListBox, HeaderEndDrag_Impl, HeaderBar*, pBar )
+IMPL_LINK( MacroEventListBox, HeaderEndDrag_Impl, HeaderBar*, pBar )
 {
-    DBG_ASSERT( pBar == &maHeaderBar, "*_HeaderTabListBox::HeaderEndDrag_Impl: something is wrong here..." );
+    DBG_ASSERT( pBar == maHeaderBar.get(), "*MacroEventListBox::HeaderEndDrag_Impl: something is wrong here..." );
     (void)pBar;
 
-    if( !maHeaderBar.GetCurItemId() )
+    if( !maHeaderBar->GetCurItemId() )
         return 0;
 
-    if( !maHeaderBar.IsItemMode() )
+    if( !maHeaderBar->IsItemMode() )
     {
         Size    aSz;
-        sal_uInt16    _nTabs = maHeaderBar.GetItemCount();
-        long    nWidth = maHeaderBar.GetItemSize( ITEMID_EVENT );
-        long    nBarWidth = maHeaderBar.GetSizePixel().Width();
+        sal_uInt16    _nTabs = maHeaderBar->GetItemCount();
+        long    nWidth = maHeaderBar->GetItemSize( ITEMID_EVENT );
+        long    nBarWidth = maHeaderBar->GetSizePixel().Width();
 
         if( nWidth < TAB_WIDTH_MIN )
-            maHeaderBar.SetItemSize( ITEMID_EVENT, TAB_WIDTH_MIN );
+            maHeaderBar->SetItemSize( ITEMID_EVENT, TAB_WIDTH_MIN );
         else if( ( nBarWidth - nWidth ) < TAB_WIDTH_MIN )
-            maHeaderBar.SetItemSize( ITEMID_EVENT, nBarWidth - TAB_WIDTH_MIN );
+            maHeaderBar->SetItemSize( ITEMID_EVENT, nBarWidth - TAB_WIDTH_MIN );
 
         {
-            long _nWidth, nTmpSz = 0;
+            long nTmpSz = 0;
             for( sal_uInt16 i = 1 ; i < _nTabs ; ++i )
             {
-                _nWidth = maHeaderBar.GetItemSize( i );
+                long _nWidth = maHeaderBar->GetItemSize( i );
                 aSz.Width() =  _nWidth + nTmpSz;
                 nTmpSz += _nWidth;
-                maListBox.SetTab( i, PixelToLogic( aSz, MapMode( MAP_APPFONT ) ).Width(), MAP_APPFONT );
+                maListBox->SetTab( i, PixelToLogic( aSz, MapMode( MAP_APPFONT ) ).Width(), MAP_APPFONT );
             }
         }
     }
     return 1;
 }
 
-long _HeaderTabListBox::Notify( NotifyEvent& rNEvt )
+bool MacroEventListBox::Notify( NotifyEvent& rNEvt )
 {
-    long    nRet = Control::Notify( rNEvt );
+    bool nRet = Control::Notify( rNEvt );
 
-    if( rNEvt.GetType() == EVENT_GETFOCUS )
+    if( rNEvt.GetType() == MouseNotifyEvent::GETFOCUS )
     {
-        if ( rNEvt.GetWindow() != &maListBox )
-            maListBox.GrabFocus();
+        if ( rNEvt.GetWindow() != maListBox.get() )
+            if (maListBox)
+                maListBox->GrabFocus();
     }
 
     return nRet;
 }
 
-_HeaderTabListBox::_HeaderTabListBox( Window* pParent, const ResId& rId ) :
-    Control( pParent, rId ),
-    maListBox( this, WB_HSCROLL | WB_CLIPCHILDREN | WB_TABSTOP ),
-    maHeaderBar( this, WB_BUTTONSTYLE | WB_BOTTOMBORDER )
+MacroEventListBox::MacroEventListBox( vcl::Window* pParent, WinBits nStyle )
+    : Control( pParent, nStyle )
+    , maHeaderBar( VclPtr<HeaderBar>::Create( this, WB_BUTTONSTYLE | WB_BOTTOMBORDER ) )
+    , maListBox( VclPtr<SvHeaderTabListBox>::Create( this, WB_HSCROLL | WB_CLIPCHILDREN | WB_TABSTOP ) )
 {
-    maListBox.SetHelpId( HID_MACRO_HEADERTABLISTBOX );
+    maListBox->SetHelpId( HID_MACRO_HEADERTABLISTBOX );
+
+    // enable the cell focus to show visible focus
+    maListBox->EnableCellFocus();
 }
 
-_HeaderTabListBox::~_HeaderTabListBox()
+MacroEventListBox::~MacroEventListBox()
 {
+    disposeOnce();
 }
 
-void _HeaderTabListBox::ConnectElements( void )
+void MacroEventListBox::dispose()
 {
+    maHeaderBar.disposeAndClear();
+    maListBox.disposeAndClear();
+    Control::dispose();
+}
+
+VCL_BUILDER_DECL_FACTORY(MacroEventListBox)
+{
+    WinBits nWinBits = WB_TABSTOP;
+
+    OString sBorder = VclBuilder::extractCustomProperty(rMap);
+    if (!sBorder.isEmpty())
+       nWinBits |= WB_BORDER;
+
+    rRet = VclPtr<MacroEventListBox>::Create(pParent, nWinBits);
+}
+
+Size MacroEventListBox::GetOptimalSize() const
+{
+    return LogicToPixel(Size(192, 72), MapMode(MAP_APPFONT ));
+}
+
+void MacroEventListBox::Resize()
+{
+    Control::Resize();
+
     // calc pos and size of header bar
     Point    aPnt( 0, 0 );
-    Size    aSize( maHeaderBar.CalcWindowSizePixel() );
+    Size    aSize( maHeaderBar->CalcWindowSizePixel() );
     Size    aCtrlSize( GetOutputSizePixel() );
     aSize.Width() = aCtrlSize.Width();
-    maHeaderBar.SetPosSizePixel( aPnt, aSize );
+    maHeaderBar->SetPosSizePixel( aPnt, aSize );
 
     // calc pos and size of ListBox
     aPnt.Y() += aSize.Height();
     aSize.Height() = aCtrlSize.Height() - aSize.Height();
-    maListBox.SetPosSizePixel( aPnt, aSize );
+    maListBox->SetPosSizePixel( aPnt, aSize );
+}
+
+void MacroEventListBox::ConnectElements()
+{
+    Resize();
 
     // set handler
-    maHeaderBar.SetEndDragHdl( LINK( this, _HeaderTabListBox, HeaderEndDrag_Impl ) );
+    maHeaderBar->SetEndDragHdl( LINK( this, MacroEventListBox, HeaderEndDrag_Impl ) );
 
-    maListBox.InitHeaderBar( &maHeaderBar );
+    maListBox->InitHeaderBar( maHeaderBar.get() );
 }
 
-void _HeaderTabListBox::Show( sal_Bool bVisible, sal_uInt16 nFlags )
+void MacroEventListBox::Show( bool bVisible, sal_uInt16 nFlags )
 {
-    maListBox.Show( bVisible, nFlags );
-    maHeaderBar.Show( bVisible, nFlags );
+    maListBox->Show( bVisible, nFlags );
+    maHeaderBar->Show( bVisible, nFlags );
 }
 
-void _HeaderTabListBox::Enable( bool bEnable, bool bChild )
+void MacroEventListBox::Enable( bool bEnable, bool bChild )
 {
-    maListBox.Enable( bEnable, bChild );
-    maHeaderBar.Enable( bEnable, bChild );
+    maListBox->Enable( bEnable, bChild );
+    maHeaderBar->Enable( bEnable, bChild );
 }
 
 // assign button ("Add Command") is enabled only if it is not read only
@@ -198,7 +216,7 @@ void _SvxMacroTabPage::EnableButtons()
     const SvTreeListEntry* pE = mpImpl->pEventLB->GetListBox().FirstSelected();
     if ( pE )
     {
-        SvLBoxString* pEventMacro = (SvLBoxString*)pE->GetItem( LB_MACROS_ITEMPOS );
+        const SvLBoxString* pEventMacro = static_cast<const SvLBoxString*>(pE->GetItem( LB_MACROS_ITEMPOS ));
         mpImpl->pDeletePB->Enable( 0 != pEventMacro && !mpImpl->bReadOnly );
 
         mpImpl->pAssignPB->Enable( !mpImpl->bReadOnly );
@@ -207,8 +225,9 @@ void _SvxMacroTabPage::EnableButtons()
     }
 }
 
-_SvxMacroTabPage::_SvxMacroTabPage( Window* pParent, const ResId& rResId, const SfxItemSet& rAttrSet )
-    : SfxTabPage( pParent, rResId, rAttrSet ),
+_SvxMacroTabPage::_SvxMacroTabPage(vcl::Window* pParent, const OString& rID,
+    const OUString& rUIXMLDescription, const SfxItemSet& rAttrSet)
+    : SfxTabPage( pParent, rID, rUIXMLDescription, &rAttrSet ),
     m_xAppEvents(0),
     m_xDocEvents(0),
     bReadOnly(false),
@@ -221,19 +240,15 @@ _SvxMacroTabPage::_SvxMacroTabPage( Window* pParent, const ResId& rResId, const
 
 _SvxMacroTabPage::~_SvxMacroTabPage()
 {
-    // need to delete the user data
-    SvHeaderTabListBox& rListBox = mpImpl->pEventLB->GetListBox();
-    SvTreeListEntry* pE = rListBox.GetEntry( 0 );
-    while( pE )
-    {
-        OUString* pEventName = (OUString*)pE->GetUserData();
-        delete pEventName;
-        pE->SetUserData((void*)0);
-        pE = rListBox.NextSibling( pE );
-    }
-    DELETEZ( mpImpl );
+    disposeOnce();
 }
-// -----------------------------------------------------------------------------
+
+void _SvxMacroTabPage::dispose()
+{
+    DELETEZ( mpImpl );
+    SfxTabPage::dispose();
+}
+
 void _SvxMacroTabPage::InitResources()
 {
     // Note: the order here controls the order in which the events are displayed in the UI!
@@ -280,7 +295,7 @@ void _SvxMacroTabPage::InitResources()
     aDisplayNames.push_back( EventDisplayName( "OnChange",              RID_SVXSTR_EVENT_CONTENTCHANGED ) );
 
     // the event name to UI string mappings for forms & dialogs
-    //
+
     aDisplayNames.push_back( EventDisplayName( "approveAction",         RID_SVXSTR_EVENT_APPROVEACTIONPERFORMED ) );
     aDisplayNames.push_back( EventDisplayName( "actionPerformed",       RID_SVXSTR_EVENT_ACTIONPERFORMED ) );
     aDisplayNames.push_back( EventDisplayName( "changed",               RID_SVXSTR_EVENT_CHANGED ) );
@@ -318,7 +333,7 @@ void _SvxMacroTabPage::InitResources()
 
 // the following method is called when the user clicks OK
 // We use the contents of the hashes to replace the settings
-sal_Bool _SvxMacroTabPage::FillItemSet( SfxItemSet& /*rSet*/ )
+bool _SvxMacroTabPage::FillItemSet( SfxItemSet* /*rSet*/ )
 {
     try
     {
@@ -369,11 +384,11 @@ sal_Bool _SvxMacroTabPage::FillItemSet( SfxItemSet& /*rSet*/ )
     {
     }
     // what is the return value about??
-    return sal_False;
+    return false;
 }
 
 // the following method clears the bindings in the hashes for both doc & app
-void _SvxMacroTabPage::Reset()
+void _SvxMacroTabPage::Reset( const SfxItemSet* )
 {
     // called once in creation - don't reset the data this time
     if(!bInitialized)
@@ -416,12 +431,12 @@ void _SvxMacroTabPage::Reset()
     DisplayAppEvents(bAppEvents);
 }
 
-void _SvxMacroTabPage::SetReadOnly( sal_Bool bSet )
+void _SvxMacroTabPage::SetReadOnly( bool bSet )
 {
     mpImpl->bReadOnly = bSet;
 }
 
-sal_Bool _SvxMacroTabPage::IsReadOnly() const
+bool _SvxMacroTabPage::IsReadOnly() const
 {
     return mpImpl->bReadOnly;
 }
@@ -436,8 +451,8 @@ class IconLBoxString : public SvLBoxString
 public:
     IconLBoxString( SvTreeListEntry* pEntry, sal_uInt16 nFlags, const OUString& sText,
         Image* pMacroImg, Image* pComponentImg );
-    virtual void Paint(
-        const Point& rPos, SvTreeListBox& rOutDev, const SvViewDataEntry* pView, const SvTreeListEntry* pEntry);
+    virtual void Paint(const Point& rPos, SvTreeListBox& rOutDev, vcl::RenderContext& rRenderContext,
+                       const SvViewDataEntry* pView, const SvTreeListEntry* pEntry) SAL_OVERRIDE;
 };
 
 
@@ -450,37 +465,34 @@ IconLBoxString::IconLBoxString( SvTreeListEntry* pEntry, sal_uInt16 nFlags, cons
     m_nxImageOffset = 20;
 }
 
-//===============================================
-void IconLBoxString::Paint(
-    const Point& aPos, SvTreeListBox& aDevice, const SvViewDataEntry* /*pView*/,
-    const SvTreeListEntry* /*pEntry*/)
+
+void IconLBoxString::Paint(const Point& aPos, SvTreeListBox& /*aDevice*/, vcl::RenderContext& rRenderContext,
+                           const SvViewDataEntry* /*pView*/, const SvTreeListEntry* /*pEntry*/)
 {
-    OUString aTxt( GetText() );
-    if( !aTxt.isEmpty() )
+    OUString aTxt(GetText());
+    if (!aTxt.isEmpty())
     {
-        OUString aURL( aTxt );
-        sal_Int32 nIndex = aURL.indexOf( aVndSunStarUNO );
+        OUString aURL(aTxt);
+        sal_Int32 nIndex = aURL.indexOf(aVndSunStarUNO);
         bool bUNO = nIndex == 0;
 
         const Image* pImg = bUNO ? m_pComponentImg : m_pMacroImg;
-        aDevice.DrawImage( aPos, *pImg );
+        rRenderContext.DrawImage(aPos, *pImg);
 
         OUString aPureMethod;
-        if( bUNO )
+        if (bUNO)
         {
-            sal_Int32 nBegin = aVndSunStarUNO.getLength();
-            aPureMethod = aURL.copy( nBegin );
+            aPureMethod = aURL.copy(strlen(aVndSunStarUNO));
         }
         else
         {
-            sal_Int32 nBegin = aVndSunStarScript.getLength();
-            aPureMethod = aURL.copy( nBegin );
+            aPureMethod = aURL.copy(strlen(aVndSunStarScript));
             aPureMethod = aPureMethod.copy( 0, aPureMethod.indexOf( '?' ) );
         }
 
         Point aPnt(aPos);
         aPnt.X() += m_nxImageOffset;
-        aDevice.DrawText( aPnt, aPureMethod );
+        rRenderContext.DrawText(aPnt, aPureMethod);
     }
 }
 
@@ -491,7 +503,7 @@ void _SvxMacroTabPage::DisplayAppEvents( bool appEvents)
     bAppEvents = appEvents;
 
     SvHeaderTabListBox&        rListBox = mpImpl->pEventLB->GetListBox();
-    mpImpl->pEventLB->SetUpdateMode( sal_False );
+    mpImpl->pEventLB->SetUpdateMode( false );
     rListBox.Clear();
     EventsHash* eventsHash;
     Reference< container::XNameReplace> nameReplace;
@@ -508,9 +520,7 @@ void _SvxMacroTabPage::DisplayAppEvents( bool appEvents)
     // have to use the original XNameReplace since the hash iterators do
     // not guarantee the order in which the elements are returned
     if(!nameReplace.is())
-    {
         return;
-    }
 
     Sequence< OUString > eventNames = nameReplace->getElementNames();
     ::std::set< OUString > aEventNamesCache;
@@ -540,12 +550,13 @@ void _SvxMacroTabPage::DisplayAppEvents( bool appEvents)
         OUString displayName( CUI_RES( displayableEvent->nEventResourceID ) );
 
         displayName += "\t";
+
         SvTreeListEntry*    _pE = rListBox.InsertEntry( displayName );
         OUString* pEventName = new OUString( sEventName );
         _pE->SetUserData( (void*)pEventName );
         OUString sNew( eventURL );
         _pE->ReplaceItem( new IconLBoxString( _pE, 0, sNew,
-            mpImpl->pMacroImg, mpImpl->pComponentImg ), LB_MACROS_ITEMPOS );
+            &mpImpl->aMacroImg, &mpImpl->aComponentImg ), LB_MACROS_ITEMPOS );
         rListBox.GetModel()->InvalidateEntry( _pE );
         rListBox.Select( _pE );
         rListBox.MakeVisible( _pE );
@@ -558,15 +569,14 @@ void _SvxMacroTabPage::DisplayAppEvents( bool appEvents)
         rListBox.MakeVisible( pE );
     }
 
-    rListBox.SetUpdateMode( sal_True );
+    rListBox.SetUpdateMode( true );
     EnableButtons();
 }
 
 // select event handler on the listbox
-IMPL_STATIC_LINK( _SvxMacroTabPage, SelectEvent_Impl, SvTabListBox*, EMPTYARG )
+IMPL_LINK( _SvxMacroTabPage, SelectEvent_Impl, SvTabListBox*, )
 {
-    _SvxMacroTabPage_Impl*    pImpl = pThis->mpImpl;
-    SvHeaderTabListBox&        rListBox = pImpl->pEventLB->GetListBox();
+    SvHeaderTabListBox&        rListBox = mpImpl->pEventLB->GetListBox();
     SvTreeListEntry*            pE = rListBox.FirstSelected();
     sal_uLong                    nPos;
 
@@ -577,18 +587,18 @@ IMPL_STATIC_LINK( _SvxMacroTabPage, SelectEvent_Impl, SvTabListBox*, EMPTYARG )
         return 0;
     }
 
-    pThis->EnableButtons();
+    EnableButtons();
     return 0;
 }
 
-IMPL_STATIC_LINK( _SvxMacroTabPage, AssignDeleteHdl_Impl, PushButton*, pBtn )
+IMPL_LINK( _SvxMacroTabPage, AssignDeleteHdl_Impl, PushButton*, pBtn )
 {
-    return GenericHandler_Impl( pThis, pBtn );
+    return GenericHandler_Impl( this, pBtn );
 }
 
-IMPL_STATIC_LINK( _SvxMacroTabPage, DoubleClickHdl_Impl, SvTabListBox *, EMPTYARG )
+IMPL_LINK( _SvxMacroTabPage, DoubleClickHdl_Impl, SvTabListBox *, )
 {
-    return GenericHandler_Impl( pThis, NULL );
+    return GenericHandler_Impl( this, NULL );
 }
 
 // handler for double click on the listbox, and for the assign/delete buttons
@@ -605,9 +615,9 @@ long _SvxMacroTabPage::GenericHandler_Impl( _SvxMacroTabPage* pThis, PushButton*
         return 0;
     }
 
-    const sal_Bool bAssEnabled = pBtn != pImpl->pDeletePB && pImpl->pAssignPB->IsEnabled();
+    const bool bAssEnabled = pBtn != pImpl->pDeletePB && pImpl->pAssignPB->IsEnabled();
 
-    OUString* pEventName = (OUString*)pE->GetUserData();
+    OUString* pEventName = static_cast<OUString*>(pE->GetUserData());
 
     OUString sEventURL;
     OUString sEventType;
@@ -636,7 +646,7 @@ long _SvxMacroTabPage::GenericHandler_Impl( _SvxMacroTabPage* pThis, PushButton*
     {
         // delete pressed
         sEventType =  "Script" ;
-        sEventURL = "";
+        sEventURL.clear();
         if(!pThis->bAppEvents)
             pThis->bDocModified = true;
     }
@@ -648,7 +658,7 @@ long _SvxMacroTabPage::GenericHandler_Impl( _SvxMacroTabPage* pThis, PushButton*
                 )
             )
     {
-        AssignComponentDialog* pAssignDlg = new AssignComponentDialog( pThis, sEventURL );
+        VclPtrInstance< AssignComponentDialog > pAssignDlg( pThis, sEventURL );
 
         short ret = pAssignDlg->Execute();
         if( ret )
@@ -658,12 +668,11 @@ long _SvxMacroTabPage::GenericHandler_Impl( _SvxMacroTabPage* pThis, PushButton*
             if(!pThis->bAppEvents)
                 pThis->bDocModified = true;
         }
-        delete pAssignDlg;
     }
     else if( bAssEnabled )
     {
         // assign pressed
-        SvxScriptSelectorDialog* pDlg = new SvxScriptSelectorDialog( pThis, sal_False, pThis->GetFrame() );
+        VclPtrInstance< SvxScriptSelectorDialog > pDlg( pThis, false, pThis->GetFrame() );
         if( pDlg )
         {
             short ret = pDlg->Execute();
@@ -692,14 +701,14 @@ long _SvxMacroTabPage::GenericHandler_Impl( _SvxMacroTabPage* pThis, PushButton*
     }
 
     // update the listbox entry
-    pImpl->pEventLB->SetUpdateMode( sal_False );
+    pImpl->pEventLB->SetUpdateMode( false );
     pE->ReplaceItem( new IconLBoxString( pE, 0, sEventURL,
-            pImpl->pMacroImg, pImpl->pComponentImg ), LB_MACROS_ITEMPOS );
+            &pImpl->aMacroImg, &pImpl->aComponentImg ), LB_MACROS_ITEMPOS );
 
     rListBox.GetModel()->InvalidateEntry( pE );
     rListBox.Select( pE );
     rListBox.MakeVisible( pE );
-    rListBox.SetUpdateMode( sal_True );
+    rListBox.SetUpdateMode( true );
 
     pThis->EnableButtons();
     return 0;
@@ -714,32 +723,32 @@ void _SvxMacroTabPage::InitAndSetHandler( Reference< container::XNameReplace> xA
     m_xModifiable = xModifiable;
     SvHeaderTabListBox&    rListBox = mpImpl->pEventLB->GetListBox();
     HeaderBar&            rHeaderBar = mpImpl->pEventLB->GetHeaderBar();
-    Link                aLnk(STATIC_LINK(this, _SvxMacroTabPage, AssignDeleteHdl_Impl ));
+    Link<>              aLnk(LINK(this, _SvxMacroTabPage, AssignDeleteHdl_Impl ));
     mpImpl->pDeletePB->SetClickHdl(    aLnk );
     mpImpl->pAssignPB->SetClickHdl(    aLnk );
     if( mpImpl->pAssignComponentPB )
         mpImpl->pAssignComponentPB->SetClickHdl( aLnk );
-    rListBox.SetDoubleClickHdl( STATIC_LINK(this, _SvxMacroTabPage, DoubleClickHdl_Impl ) );
+    rListBox.SetDoubleClickHdl( LINK(this, _SvxMacroTabPage, DoubleClickHdl_Impl ) );
 
-    rListBox.SetSelectHdl( STATIC_LINK( this, _SvxMacroTabPage, SelectEvent_Impl ));
+    rListBox.SetSelectHdl( LINK( this, _SvxMacroTabPage, SelectEvent_Impl ));
 
     rListBox.SetSelectionMode( SINGLE_SELECTION );
     rListBox.SetTabs( &nTabs[0], MAP_APPFONT );
     Size aSize( nTabs[ 2 ], 0 );
-    rHeaderBar.InsertItem( ITEMID_EVENT, *mpImpl->pStrEvent, LogicToPixel( aSize, MapMode( MAP_APPFONT ) ).Width() );
+    rHeaderBar.InsertItem( ITEMID_EVENT, mpImpl->sStrEvent, LogicToPixel( aSize, MapMode( MAP_APPFONT ) ).Width() );
     aSize.Width() = 1764;        // don't know what, so 42^2 is best to use...
-    rHeaderBar.InsertItem( ITMEID_ASSMACRO, *mpImpl->pAssignedMacro, LogicToPixel( aSize, MapMode( MAP_APPFONT ) ).Width() );
+    rHeaderBar.InsertItem( ITMEID_ASSMACRO, mpImpl->sAssignedMacro, LogicToPixel( aSize, MapMode( MAP_APPFONT ) ).Width() );
     rListBox.SetSpaceBetweenEntries( 0 );
 
     mpImpl->pEventLB->Show();
     mpImpl->pEventLB->ConnectElements();
 
-    long nMinLineHeight = mpImpl->pMacroImg->GetSizePixel().Height() + 2;
+    long nMinLineHeight = mpImpl->aMacroImg.GetSizePixel().Height() + 2;
     if( nMinLineHeight > mpImpl->pEventLB->GetListBox().GetEntryHeight() )
         mpImpl->pEventLB->GetListBox().SetEntryHeight(
             sal::static_int_cast< short >(nMinLineHeight) );
 
-    mpImpl->pEventLB->Enable( sal_True );
+    mpImpl->pEventLB->Enable( true );
 
     if(!m_xAppEvents.is())
     {
@@ -798,7 +807,7 @@ Any _SvxMacroTabPage::GetPropsByName( const OUString& eventName, EventsHash& eve
 {
     Sequence< beans::PropertyValue > props;
     OUString type, url;
-    if( sal_True == ( aAny >>= props ) )
+    if( aAny >>= props )
     {
         ::comphelper::NamedValueCollection aProps( props );
         type = aProps.getOrDefault( "EventType", type );
@@ -807,42 +816,32 @@ Any _SvxMacroTabPage::GetPropsByName( const OUString& eventName, EventsHash& eve
     return ::std::make_pair( type, url );
 }
 
-SvxMacroTabPage::SvxMacroTabPage( Window* pParent, const Reference< frame::XFrame >& _rxDocumentFrame, const SfxItemSet& rSet, Reference< container::XNameReplace > xNameReplace, sal_uInt16 nSelectedIndex )
-    : _SvxMacroTabPage( pParent, CUI_RES( RID_SVXPAGE_MACROASSIGN ), rSet )
+SvxMacroTabPage::SvxMacroTabPage(vcl::Window* pParent,
+    const Reference< frame::XFrame >& _rxDocumentFrame,
+    const SfxItemSet& rSet,
+    Reference< container::XNameReplace > xNameReplace,
+    sal_uInt16 nSelectedIndex)
+    : _SvxMacroTabPage(pParent, "MacroAssignPage", "cui/ui/macroassignpage.ui", rSet)
 {
-    mpImpl->pStrEvent           = new OUString(                     CUI_RES( STR_EVENT ) );
-    mpImpl->pAssignedMacro      = new OUString(                     CUI_RES( STR_ASSMACRO ) );
-    mpImpl->pEventLB            = new _HeaderTabListBox( this,      CUI_RES( LB_EVENT ) );
-    mpImpl->pAssignFT           = new FixedText( this,              CUI_RES( FT_ASSIGN ) );
-    mpImpl->pAssignPB           = new PushButton( this,             CUI_RES( PB_ASSIGN ) );
-    mpImpl->pDeletePB           = new PushButton( this,             CUI_RES( PB_DELETE ) );
-    mpImpl->pAssignComponentPB  = new PushButton( this,         CUI_RES( PB_ASSIGN_COMPONENT ) );
-    mpImpl->pMacroImg           = new Image(                        CUI_RES(IMG_MACRO) );
-    mpImpl->pComponentImg       = new Image(                        CUI_RES(IMG_COMPONENT) );
-
-    FreeResource();
+    mpImpl->sStrEvent = get<FixedText>("eventft")->GetText();
+    mpImpl->sAssignedMacro = get<FixedText>("assignft")->GetText();
+    get(mpImpl->pEventLB, "assignments");
+    get(mpImpl->pAssignPB, "assign");
+    get(mpImpl->pDeletePB, "delete");
+    get(mpImpl->pAssignComponentPB, "component");
+    mpImpl->aMacroImg = get<FixedImage>("macroimg")->GetImage();
+    mpImpl->aComponentImg = get<FixedImage>("componentimg")->GetImage();
 
     SetFrame( _rxDocumentFrame );
 
     if( !mpImpl->bIDEDialogMode )
     {
-        Point aPosAssign = mpImpl->pAssignPB->GetPosPixel();
-        Point aPosComp = mpImpl->pAssignComponentPB->GetPosPixel();
-
-        Point aPosDelete = mpImpl->pDeletePB->GetPosPixel();
-        long nYDiff = aPosComp.Y() - aPosAssign.Y();
-        aPosDelete.Y() -= nYDiff;
-        mpImpl->pDeletePB->SetPosPixel( aPosDelete );
-
         mpImpl->pAssignComponentPB->Hide();
         mpImpl->pAssignComponentPB->Disable();
     }
 
-    // must be done after FreeResource is called
     InitResources();
 
-    mpImpl->pEventLB->GetListBox().SetHelpId( HID_SVX_MACRO_LB_EVENT );
-
     InitAndSetHandler( xNameReplace, Reference< container::XNameReplace>(0), Reference< util::XModifiable >(0));
     DisplayAppEvents(true);
     SvHeaderTabListBox& rListBox = mpImpl->pEventLB->GetListBox();
@@ -851,28 +850,19 @@ SvxMacroTabPage::SvxMacroTabPage( Window* pParent, const Reference< frame::XFram
         rListBox.Select(pE);
 }
 
-SvxMacroTabPage::~SvxMacroTabPage()
-{
-}
-
-SvxMacroAssignDlg::SvxMacroAssignDlg( Window* pParent, const Reference< frame::XFrame >& _rxDocumentFrame, const SfxItemSet& rSet,
+SvxMacroAssignDlg::SvxMacroAssignDlg( vcl::Window* pParent, const Reference< frame::XFrame >& _rxDocumentFrame, const SfxItemSet& rSet,
     const Reference< container::XNameReplace >& xNameReplace, sal_uInt16 nSelectedIndex )
-        : SvxMacroAssignSingleTabDialog( pParent, rSet, 0 )
-{
-    SetTabPage( new SvxMacroTabPage( this, _rxDocumentFrame, rSet, xNameReplace, nSelectedIndex ) );
-}
-
-SvxMacroAssignDlg::~SvxMacroAssignDlg()
+        : SvxMacroAssignSingleTabDialog(pParent, rSet)
 {
+    SetTabPage(VclPtr<SvxMacroTabPage>::Create(get_content_area(), _rxDocumentFrame, rSet, xNameReplace, nSelectedIndex));
 }
 
 
-//===============================================
 
 IMPL_LINK_NOARG(AssignComponentDialog, ButtonHandler)
 {
-    OUString aMethodName = maMethodEdit.GetText();
-    maURL = "";
+    OUString aMethodName = mpMethodEdit->GetText();
+    maURL.clear();
     if( !aMethodName.isEmpty() )
     {
         maURL = aVndSunStarUNO;
@@ -882,133 +872,49 @@ IMPL_LINK_NOARG(AssignComponentDialog, ButtonHandler)
     return 0;
 }
 
-AssignComponentDialog::AssignComponentDialog( Window * pParent, const OUString& rURL )
-    : ModalDialog( pParent, CUI_RES( RID_SVXDLG_ASSIGNCOMPONENT ) )
-    , maMethodLabel( this, CUI_RES( FT_METHOD ) )
-    , maMethodEdit( this, CUI_RES( EDIT_METHOD ) )
-    , maOKButton( this, CUI_RES( RID_PB_OK ) )
-    , maCancelButton( this, CUI_RES( RID_PB_CANCEL ) )
-    , maHelpButton( this, CUI_RES( RID_PB_HELP ) )
+AssignComponentDialog::AssignComponentDialog( vcl::Window * pParent, const OUString& rURL )
+    : ModalDialog( pParent, "AssignComponent", "cui/ui/assigncomponentdialog.ui" )
     , maURL( rURL )
 {
-    FreeResource();
-    maOKButton.SetClickHdl(LINK(this, AssignComponentDialog, ButtonHandler));
+    get(mpMethodEdit, "methodEntry");
+    get(mpOKButton, "ok");
+    mpOKButton->SetClickHdl(LINK(this, AssignComponentDialog, ButtonHandler));
 
     OUString aMethodName;
     if( maURL.startsWith( aVndSunStarUNO ) )
     {
-        sal_Int32 nBegin = aVndSunStarUNO.getLength();
-        aMethodName = maURL.copy( nBegin );
+        aMethodName = maURL.copy( strlen(aVndSunStarUNO) );
     }
-    maMethodEdit.SetText( aMethodName, Selection( 0, SELECTION_MAX ) );
+    mpMethodEdit->SetText( aMethodName, Selection( 0, SELECTION_MAX ) );
 }
 
 AssignComponentDialog::~AssignComponentDialog()
 {
+    disposeOnce();
 }
 
-// -----------------------------------------------------------------------
+void AssignComponentDialog::dispose()
+{
+    mpMethodEdit.clear();
+    mpOKButton.clear();
+    ModalDialog::dispose();
+}
 
 IMPL_LINK( SvxMacroAssignSingleTabDialog, OKHdl_Impl, Button *, pButton )
 {
     (void)pButton; //unused
-    pPage->FillItemSet( *pOutSet );
+    GetTabPage()->FillItemSet( 0 );
     EndDialog( RET_OK );
     return 0;
 }
 
-// -----------------------------------------------------------------------
-
-SvxMacroAssignSingleTabDialog::SvxMacroAssignSingleTabDialog
-    ( Window *pParent, const SfxItemSet& rSet, sal_uInt16 nUniqueId ) :
-        SfxModalDialog( pParent, nUniqueId, WinBits( WB_STDMODAL | WB_3DLOOK ) ),
-        pFixedLine      ( 0 ),
-        pOKBtn          ( 0 ),
-        pCancelBtn      ( 0 ),
-        pHelpBtn        ( 0 ),
-        pPage           ( 0 ),
-        pOptions        ( &rSet ),
-        pOutSet         ( 0 )
-{}
 
 
-// -----------------------------------------------------------------------
-
-SvxMacroAssignSingleTabDialog::~SvxMacroAssignSingleTabDialog()
+SvxMacroAssignSingleTabDialog::SvxMacroAssignSingleTabDialog(vcl::Window *pParent,
+    const SfxItemSet& rSet)
+    : SfxSingleTabDialog(pParent, rSet, "MacroAssignDialog", "cui/ui/macroassigndialog.ui")
 {
-    delete pFixedLine;
-    delete pOKBtn;
-    delete pCancelBtn;
-    delete pHelpBtn;
-    delete pPage;
-}
-
-// -----------------------------------------------------------------------
-
-// According to SfxNoLayoutSingleTabDialog
-void SvxMacroAssignSingleTabDialog::SetTabPage( SfxTabPage* pTabPage )
-{
-    pFixedLine = new FixedLine( this );
-
-    pOKBtn = new OKButton( this, WB_DEFBUTTON );
-    pOKBtn->SetClickHdl( LINK( this, SvxMacroAssignSingleTabDialog, OKHdl_Impl ) );
-
-    pCancelBtn = new CancelButton( this );
-    pHelpBtn = new HelpButton( this );
-
-    pPage = pTabPage;
-
-    if ( pPage )
-    {
-        OUString sUserData;
-        pPage->SetUserData( sUserData );
-        pPage->Reset( *pOptions );
-        pPage->Show();
-
-        // Set dialog's and buttons' size and position according to tabpage size
-        long nSpaceX = LogicToPixel( Size( 6, 0 ), MAP_APPFONT ).Width();
-        long nSpaceY = LogicToPixel( Size( 0, 6 ), MAP_APPFONT ).Height();
-        long nHalfSpaceX = LogicToPixel( Size( 3, 0 ), MAP_APPFONT ).Width();
-        long nHalfSpaceY = LogicToPixel( Size( 0, 3 ), MAP_APPFONT ).Height();
-
-        pPage->SetPosPixel( Point() );
-        Size aTabpageSize( pPage->GetSizePixel() );
-        Size aDialogSize( aTabpageSize );
-        Size aButtonSize = LogicToPixel( Size( 50, 14 ), MAP_APPFONT );
-        long nButtonWidth  = aButtonSize.Width();
-        long nButtonHeight = aButtonSize.Height();
-
-        Size aFixedLineSize( aTabpageSize );
-        long nFixedLineHeight = LogicToPixel( Size( 0, 8 ), MAP_APPFONT ).Height();
-        aFixedLineSize.Height() = nFixedLineHeight;
-
-        aDialogSize.Height() += nFixedLineHeight + nButtonHeight + nSpaceY + nHalfSpaceY;
-        SetOutputSizePixel( aDialogSize );
-
-        long nButtonPosY = aTabpageSize.Height() + nFixedLineHeight + nHalfSpaceY;
-        long nHelpButtonPosX = nSpaceX;
-        pHelpBtn->SetPosSizePixel( Point( nHelpButtonPosX, nButtonPosY), aButtonSize );
-        pHelpBtn->Show();
-
-        long nCancelButtonPosX = aDialogSize.Width() - nButtonWidth - nSpaceX + 1;
-        pCancelBtn->SetPosSizePixel( Point( nCancelButtonPosX, nButtonPosY), aButtonSize );
-        pCancelBtn->Show();
-
-        long nOkButtonPosX = nCancelButtonPosX - nButtonWidth - nHalfSpaceX;
-        pOKBtn->SetPosSizePixel( Point( nOkButtonPosX, nButtonPosY), aButtonSize );
-        pOKBtn->Show();
-
-        long nFixedLinePosY = aTabpageSize.Height();
-        pFixedLine->SetPosSizePixel( Point( 0, nFixedLinePosY), aFixedLineSize );
-        pFixedLine->Show();
-
-        // Get text from TabPage
-        SetText( pPage->GetText() );
-
-        // Get IDs from TabPage
-        SetHelpId( pPage->GetHelpId() );
-        SetUniqueId( pPage->GetUniqueId() );
-    }
+    GetOKButton()->SetClickHdl( LINK( this, SvxMacroAssignSingleTabDialog, OKHdl_Impl ) );
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
