@@ -25,11 +25,11 @@
 #include <svl/macitem.hxx>
 #include <svx/dialogs.hrc>
 #include <svtools/svmedit.hxx>
+#include <vcl/idle.hxx>
 #include "cfgutil.hxx"
 #include <sfx2/app.hxx>
 #include <sfx2/evntconf.hxx>
 #include <sfx2/objsh.hxx>
-#include "macroass.hrc"
 #include "cuires.hrc"
 #include <vcl/fixed.hxx>
 #include "headertablistbox.hxx"
@@ -42,60 +42,39 @@ using ::com::sun::star::frame::XFrame;
 class _SfxMacroTabPage_Impl
 {
 public:
-    _SfxMacroTabPage_Impl( void );
-    ~_SfxMacroTabPage_Impl();
+    _SfxMacroTabPage_Impl();
 
-    OUString                        maStaticMacroLBLabel;
-    PushButton*                     pAssignPB;
-    PushButton*                     pDeletePB;
-    OUString*                       pStrEvent;
-    OUString*                       pAssignedMacro;
-    _HeaderTabListBox*              pEventLB;
-    SfxConfigGroupListBox_Impl*     pGroupLB;
-    FixedText*                      pFT_MacroLBLabel;
-    SfxConfigFunctionListBox_Impl*  pMacroLB;
+    OUString                               maStaticMacroLBLabel;
+    VclPtr<PushButton>                     pAssignPB;
+    VclPtr<PushButton>                     pDeletePB;
+    OUString                               sStrEvent;
+    OUString                               sAssignedMacro;
+    VclPtr<MacroEventListBox>              pEventLB;
+    VclPtr<VclFrame>                       pGroupFrame;
+    VclPtr<SfxConfigGroupListBox>          pGroupLB;
+    VclPtr<VclFrame>                       pMacroFrame;
+    VclPtr<SfxConfigFunctionListBox>       pMacroLB;
 
-    FixedText*                      pMacroFT;
-    OUString*                       pMacroStr;
-
-    sal_Bool                            bReadOnly;
-    Timer                           maFillGroupTimer;
-    sal_Bool                            bGotEvents;
+    bool                            bReadOnly;
+    Idle                            maFillGroupIdle;
+    bool                            bGotEvents;
     bool m_bDummyActivated; ///< has this tab page already been activated
 };
 
-_SfxMacroTabPage_Impl::_SfxMacroTabPage_Impl( void ) :
-    pAssignPB( NULL ),
-    pDeletePB( NULL ),
-    pStrEvent( NULL ),
-    pAssignedMacro( NULL ),
-    pEventLB( NULL ),
-    pGroupLB( NULL ),
-    pFT_MacroLBLabel( NULL ),
-    pMacroLB( NULL ),
-    pMacroFT( NULL ),
-    pMacroStr( NULL ),
-    bReadOnly( sal_False ),
-    bGotEvents( sal_False )
+_SfxMacroTabPage_Impl::_SfxMacroTabPage_Impl()
+    : pAssignPB(NULL)
+    , pDeletePB(NULL)
+    , pEventLB(NULL)
+    , pGroupFrame(NULL)
+    , pGroupLB(NULL)
+    , pMacroFrame(NULL)
+    , pMacroLB(NULL)
+    , bReadOnly(false)
+    , bGotEvents(false)
     , m_bDummyActivated(false)
 {
 }
 
-_SfxMacroTabPage_Impl::~_SfxMacroTabPage_Impl()
-{
-    delete pAssignPB;
-    delete pDeletePB;
-    delete pStrEvent;
-    delete pAssignedMacro;
-    delete pEventLB;
-    delete pGroupLB;
-    delete pMacroLB;
-    delete pFT_MacroLBLabel;
-    delete pMacroFT;
-    delete pMacroStr;
-}
-
-
 static sal_uInt16 aPageRg[] = {
     SID_ATTR_MACROITEM, SID_ATTR_MACROITEM,
     0
@@ -144,29 +123,33 @@ void _SfxMacroTabPage::EnableButtons()
     if ( pE )
     {
         // get bound macro
-        const SvxMacro* pM = aTbl.Get( (sal_uInt16)(sal_uLong) pE->GetUserData() );
+        const SvxMacro* pM = aTbl.Get( (sal_uInt16)reinterpret_cast<sal_uLong>(pE->GetUserData()) );
         mpImpl->pDeletePB->Enable( 0 != pM && !mpImpl->bReadOnly );
 
-        OUString sEventMacro;
-        sEventMacro = ((SvLBoxString*)pE->GetItem( LB_MACROS_ITEMPOS ))->GetText();
+        OUString sEventMacro = static_cast<const SvLBoxString*>(pE->GetItem( LB_MACROS_ITEMPOS ))->GetText();
 
         OUString sScriptURI = mpImpl->pMacroLB->GetSelectedScriptURI();
         mpImpl->pAssignPB->Enable( !mpImpl->bReadOnly && !sScriptURI.equalsIgnoreAsciiCase( sEventMacro ) );
     }
     else
-        mpImpl->pAssignPB->Enable( sal_False );
+        mpImpl->pAssignPB->Enable( false );
 }
 
-_SfxMacroTabPage::_SfxMacroTabPage( Window* pParent, const ResId& rResId, const SfxItemSet& rAttrSet )
-    : SfxTabPage( pParent, rResId, rAttrSet )
-
+_SfxMacroTabPage::_SfxMacroTabPage(vcl::Window* pParent, const SfxItemSet& rAttrSet)
+    : SfxTabPage(pParent, "EventAssignPage", "cui/ui/eventassignpage.ui", &rAttrSet)
 {
     mpImpl = new _SfxMacroTabPage_Impl;
 }
 
 _SfxMacroTabPage::~_SfxMacroTabPage()
+{
+    disposeOnce();
+}
+
+void _SfxMacroTabPage::dispose()
 {
     DELETEZ( mpImpl );
+    SfxTabPage::dispose();
 }
 
 void _SfxMacroTabPage::AddEvent( const OUString & rEventName, sal_uInt16 nEventId )
@@ -189,37 +172,34 @@ void _SfxMacroTabPage::AddEvent( const OUString & rEventName, sal_uInt16 nEventI
 void _SfxMacroTabPage::ScriptChanged()
 {
     // get new areas and their functions
-    {
-        mpImpl->pGroupLB->Show();
-        mpImpl->pMacroLB->Show();
-        mpImpl->pMacroFT->SetText( *mpImpl->pMacroStr );
-    }
+    mpImpl->pGroupFrame->Show();
+    mpImpl->pMacroFrame->Show();
 
     EnableButtons();
 }
 
-sal_Bool _SfxMacroTabPage::FillItemSet( SfxItemSet& rSet )
+bool _SfxMacroTabPage::FillItemSet( SfxItemSet* rSet )
 {
     SvxMacroItem aItem( GetWhich( aPageRg[0] ) );
     ((SvxMacroTableDtor&)aItem.GetMacroTable()) = aTbl;
 
     const SfxPoolItem* pItem;
-    if( SFX_ITEM_SET != GetItemSet().GetItemState( aItem.Which(), sal_True, &pItem )
-        || aItem != *(SvxMacroItem*)pItem )
+    if( SfxItemState::SET != GetItemSet().GetItemState( aItem.Which(), true, &pItem )
+        || aItem != *static_cast<const SvxMacroItem*>(pItem) )
     {
-        rSet.Put( aItem );
-        return sal_True;
+        rSet->Put( aItem );
+        return true;
     }
-    return sal_False;
+    return false;
 }
 
 void _SfxMacroTabPage::LaunchFillGroup()
 {
-    if (!mpImpl->maFillGroupTimer.GetTimeoutHdl().IsSet())
+    if (!mpImpl->maFillGroupIdle.GetIdleHdl().IsSet())
     {
-        mpImpl->maFillGroupTimer.SetTimeoutHdl( STATIC_LINK( this, _SfxMacroTabPage, TimeOut_Impl ) );
-        mpImpl->maFillGroupTimer.SetTimeout( 0 );
-        mpImpl->maFillGroupTimer.Start();
+        mpImpl->maFillGroupIdle.SetIdleHdl( LINK( this, _SfxMacroTabPage, TimeOut_Impl ) );
+        mpImpl->maFillGroupIdle.SetPriority( SchedulerPriority::HIGHEST );
+        mpImpl->maFillGroupIdle.Start();
     }
 }
 
@@ -235,13 +215,13 @@ void _SfxMacroTabPage::ActivatePage( const SfxItemSet& )
     LaunchFillGroup();
 }
 
-void _SfxMacroTabPage::PageCreated (SfxAllItemSet aSet)
+void _SfxMacroTabPage::PageCreated(const SfxAllItemSet& aSet)
 {
     const SfxPoolItem* pEventsItem;
-    if( !mpImpl->bGotEvents && SFX_ITEM_SET == aSet.GetItemState( SID_EVENTCONFIG, sal_True, &pEventsItem ) )
+    if( !mpImpl->bGotEvents && SfxItemState::SET == aSet.GetItemState( SID_EVENTCONFIG, true, &pEventsItem ) )
     {
-        mpImpl->bGotEvents = sal_True;
-        const SfxEventNamesList& rList = ((SfxEventNamesItem*)pEventsItem)->GetEvents();
+        mpImpl->bGotEvents = true;
+        const SfxEventNamesList& rList = static_cast<const SfxEventNamesItem*>(pEventsItem)->GetEvents();
         for ( size_t nNo = 0, nCnt = rList.size(); nNo < nCnt; ++nNo )
         {
             const SfxEventName *pOwn = rList.at(nNo);
@@ -250,17 +230,17 @@ void _SfxMacroTabPage::PageCreated (SfxAllItemSet aSet)
     }
 }
 
-void _SfxMacroTabPage::Reset( const SfxItemSet& rSet )
+void _SfxMacroTabPage::Reset( const SfxItemSet* rSet )
 {
     const SfxPoolItem* pItem;
-    if( SFX_ITEM_SET == rSet.GetItemState( GetWhich( aPageRg[0] ), sal_True, &pItem ))
-        aTbl = ((SvxMacroItem*)pItem)->GetMacroTable();
+    if( SfxItemState::SET == rSet->GetItemState( GetWhich( aPageRg[0] ), true, &pItem ))
+        aTbl = static_cast<const SvxMacroItem*>(pItem)->GetMacroTable();
 
     const SfxPoolItem* pEventsItem;
-    if( !mpImpl->bGotEvents && SFX_ITEM_SET == rSet.GetItemState( SID_EVENTCONFIG, sal_True, &pEventsItem ) )
+    if( !mpImpl->bGotEvents && SfxItemState::SET == rSet->GetItemState( SID_EVENTCONFIG, true, &pEventsItem ) )
     {
-        mpImpl->bGotEvents = sal_True;
-        const SfxEventNamesList& rList = ((SfxEventNamesItem*)pEventsItem)->GetEvents();
+        mpImpl->bGotEvents = true;
+        const SfxEventNamesList& rList = static_cast<const SfxEventNamesItem*>(pEventsItem)->GetEvents();
         for ( size_t nNo = 0, nCnt = rList.size(); nNo < nCnt; ++nNo )
         {
             const SfxEventName *pOwn = rList.at(nNo);
@@ -276,15 +256,14 @@ void _SfxMacroTabPage::Reset( const SfxItemSet& rSet )
         rListBox.SetCurEntry( pE );
 }
 
-sal_Bool _SfxMacroTabPage::IsReadOnly() const
+bool _SfxMacroTabPage::IsReadOnly() const
 {
     return mpImpl->bReadOnly;
 }
 
-IMPL_STATIC_LINK( _SfxMacroTabPage, SelectEvent_Impl, SvTabListBox*, EMPTYARG )
+IMPL_LINK( _SfxMacroTabPage, SelectEvent_Impl, SvTabListBox*, )
 {
-    _SfxMacroTabPage_Impl*  pImpl = pThis->mpImpl;
-    SvHeaderTabListBox&     rListBox = pImpl->pEventLB->GetListBox();
+    SvHeaderTabListBox&     rListBox = mpImpl->pEventLB->GetListBox();
     SvTreeListEntry*            pE = rListBox.FirstSelected();
     sal_uLong                   nPos;
     if( !pE || LISTBOX_ENTRY_NOTFOUND ==
@@ -294,37 +273,33 @@ IMPL_STATIC_LINK( _SfxMacroTabPage, SelectEvent_Impl, SvTabListBox*, EMPTYARG )
         return 0;
     }
 
-    pThis->ScriptChanged();
-    pThis->EnableButtons();
+    ScriptChanged();
+    EnableButtons();
     return 0;
 }
 
-IMPL_STATIC_LINK( _SfxMacroTabPage, SelectGroup_Impl, ListBox*, EMPTYARG )
+IMPL_LINK( _SfxMacroTabPage, SelectGroup_Impl, ListBox*, )
 {
-    _SfxMacroTabPage_Impl*  pImpl = pThis->mpImpl;
-    pImpl->pGroupLB->GroupSelected();
-    const OUString sScriptURI = pImpl->pMacroLB->GetSelectedScriptURI();
+    mpImpl->pGroupLB->GroupSelected();
+    const OUString sScriptURI = mpImpl->pMacroLB->GetSelectedScriptURI();
     OUString       aLabelText;
     if( !sScriptURI.isEmpty() )
-        aLabelText = pImpl->maStaticMacroLBLabel;
-    pImpl->pFT_MacroLBLabel->SetText( aLabelText );
+        aLabelText = mpImpl->maStaticMacroLBLabel;
+    mpImpl->pMacroFrame->set_label( aLabelText );
 
-    pThis->EnableButtons();
+    EnableButtons();
     return 0;
 }
 
-IMPL_STATIC_LINK( _SfxMacroTabPage, SelectMacro_Impl, ListBox*, EMPTYARG )
+IMPL_LINK( _SfxMacroTabPage, SelectMacro_Impl, ListBox*, )
 {
-    _SfxMacroTabPage_Impl*  pImpl = pThis->mpImpl;
-    pImpl->pMacroLB->FunctionSelected();
-    pThis->EnableButtons();
+    EnableButtons();
     return 0;
 }
 
-IMPL_STATIC_LINK( _SfxMacroTabPage, AssignDeleteHdl_Impl, PushButton*, pBtn )
+IMPL_LINK( _SfxMacroTabPage, AssignDeleteHdl_Impl, PushButton*, pBtn )
 {
-    _SfxMacroTabPage_Impl*  pImpl = pThis->mpImpl;
-    SvHeaderTabListBox& rListBox = pImpl->pEventLB->GetListBox();
+    SvHeaderTabListBox& rListBox = mpImpl->pEventLB->GetListBox();
     SvTreeListEntry* pE = rListBox.FirstSelected();
     sal_uLong nPos;
     if( !pE || LISTBOX_ENTRY_NOTFOUND ==
@@ -334,87 +309,86 @@ IMPL_STATIC_LINK( _SfxMacroTabPage, AssignDeleteHdl_Impl, PushButton*, pBtn )
         return 0;
     }
 
-    const sal_Bool bAssEnabled = pBtn != pImpl->pDeletePB && pImpl->pAssignPB->IsEnabled();
+    const bool bAssEnabled = pBtn != mpImpl->pDeletePB && mpImpl->pAssignPB->IsEnabled();
 
     // remove from the table
-    sal_uInt16 nEvent = (sal_uInt16)(sal_uLong)pE->GetUserData();
-    pThis->aTbl.Erase( nEvent );
+    sal_uInt16 nEvent = (sal_uInt16)reinterpret_cast<sal_uLong>(pE->GetUserData());
+    aTbl.Erase( nEvent );
 
     OUString sScriptURI;
     if( bAssEnabled )
     {
-        sScriptURI = pImpl->pMacroLB->GetSelectedScriptURI();
+        sScriptURI = mpImpl->pMacroLB->GetSelectedScriptURI();
         if( sScriptURI.startsWith( "vnd.sun.star.script:" ) )
         {
-            pThis->aTbl.Insert(
+            aTbl.Insert(
                 nEvent, SvxMacro( sScriptURI, OUString( SVX_MACRO_LANGUAGE_SF ) ) );
         }
         else
         {
             OSL_ENSURE( false, "_SfxMacroTabPage::AssignDeleteHdl_Impl: this branch is *not* dead? (out of interest: tell fs, please!)" );
-            pThis->aTbl.Insert(
+            aTbl.Insert(
                 nEvent, SvxMacro( sScriptURI, OUString( SVX_MACRO_LANGUAGE_STARBASIC ) ) );
         }
     }
 
-    pImpl->pEventLB->SetUpdateMode( sal_False );
+    mpImpl->pEventLB->SetUpdateMode( false );
     pE->ReplaceItem( new SvLBoxString( pE, 0, sScriptURI ), LB_MACROS_ITEMPOS );
     rListBox.GetModel()->InvalidateEntry( pE );
     rListBox.Select( pE );
     rListBox.MakeVisible( pE );
-    rListBox.SetUpdateMode( sal_True );
+    rListBox.SetUpdateMode( true );
 
-    pThis->EnableButtons();
+    EnableButtons();
     return 0;
 }
 
-IMPL_STATIC_LINK( _SfxMacroTabPage, TimeOut_Impl, Timer*, EMPTYARG )
+IMPL_LINK_TYPED( _SfxMacroTabPage, TimeOut_Impl, Idle*,, void )
 {
     // FillMacroList() can take a long time -> show wait cursor and disable input
-    SfxTabDialog* pTabDlg = pThis->GetTabDialog();
+    SfxTabDialog* pTabDlg = GetTabDialog();
     // perhaps the tabpage is part of a SingleTabDialog then pTabDlg == NULL
     if ( pTabDlg )
     {
         pTabDlg->EnterWait();
-        pTabDlg->EnableInput( sal_False );
+        pTabDlg->EnableInput( false );
     }
-    pThis->FillMacroList();
+    FillMacroList();
     if ( pTabDlg )
     {
-        pTabDlg->EnableInput( sal_True );
+        pTabDlg->EnableInput( true );
         pTabDlg->LeaveWait();
     }
-    return 0;
 }
 
 void _SfxMacroTabPage::InitAndSetHandler()
 {
     SvHeaderTabListBox& rListBox = mpImpl->pEventLB->GetListBox();
     HeaderBar&          rHeaderBar = mpImpl->pEventLB->GetHeaderBar();
-    Link                aLnk(STATIC_LINK(this, _SfxMacroTabPage, AssignDeleteHdl_Impl ));
+    Link<>              aLnk(LINK(this, _SfxMacroTabPage, AssignDeleteHdl_Impl ));
     mpImpl->pMacroLB->SetDoubleClickHdl( aLnk );
     mpImpl->pDeletePB->SetClickHdl( aLnk );
     mpImpl->pAssignPB->SetClickHdl( aLnk );
     rListBox.SetDoubleClickHdl( aLnk );
 
-    rListBox.SetSelectHdl( STATIC_LINK( this, _SfxMacroTabPage, SelectEvent_Impl ));
-    mpImpl->pGroupLB->SetSelectHdl( STATIC_LINK( this, _SfxMacroTabPage, SelectGroup_Impl ));
-    mpImpl->pMacroLB->SetSelectHdl( STATIC_LINK( this, _SfxMacroTabPage, SelectMacro_Impl ));
+    rListBox.SetSelectHdl( LINK( this, _SfxMacroTabPage, SelectEvent_Impl ));
+    mpImpl->pGroupLB->SetSelectHdl( LINK( this, _SfxMacroTabPage, SelectGroup_Impl ));
+    mpImpl->pMacroLB->SetSelectHdl( LINK( this, _SfxMacroTabPage, SelectMacro_Impl ));
 
     rListBox.SetSelectionMode( SINGLE_SELECTION );
     rListBox.SetTabs( &nTabs[0], MAP_APPFONT );
     Size aSize( nTabs[ 2 ], 0 );
-    rHeaderBar.InsertItem( ITEMID_EVENT, *mpImpl->pStrEvent, LogicToPixel( aSize, MapMode( MAP_APPFONT ) ).Width() );
+    rHeaderBar.InsertItem( ITEMID_EVENT, mpImpl->sStrEvent, LogicToPixel( aSize, MapMode( MAP_APPFONT ) ).Width() );
     aSize.Width() = 1764;       // don't know what, so 42^2 is best to use...
-    rHeaderBar.InsertItem( ITMEID_ASSMACRO, *mpImpl->pAssignedMacro, LogicToPixel( aSize, MapMode( MAP_APPFONT ) ).Width() );
+    rHeaderBar.InsertItem( ITMEID_ASSMACRO, mpImpl->sAssignedMacro, LogicToPixel( aSize, MapMode( MAP_APPFONT ) ).Width() );
     rListBox.SetSpaceBetweenEntries( 0 );
 
     mpImpl->pEventLB->Show();
     mpImpl->pEventLB->ConnectElements();
 
-    mpImpl->pEventLB->Enable( sal_True );
-    mpImpl->pGroupLB->Enable( sal_True );
-    mpImpl->pMacroLB->Enable( sal_True );
+    mpImpl->pEventLB->Enable( true );
+    mpImpl->pGroupLB->Enable( true );
+    mpImpl->pMacroLB->Enable( true );
 
     mpImpl->pGroupLB->SetFunctionListBox( mpImpl->pMacroLB );
 
@@ -426,7 +400,7 @@ void _SfxMacroTabPage::FillMacroList()
         ::com::sun::star::uno::Reference<
             ::com::sun::star::uno::XComponentContext >(),
         GetFrame(),
-        OUString() );
+        OUString(), false);
 }
 
 void _SfxMacroTabPage::FillEvents()
@@ -441,12 +415,12 @@ void _SfxMacroTabPage::FillEvents()
         SvTreeListEntry*    pE = rListBox.GetEntry( n );
         if( pE )
         {
-            SvLBoxString*   pLItem = ( SvLBoxString* ) pE->GetItem( LB_MACROS_ITEMPOS );
+            SvLBoxString*   pLItem = static_cast<SvLBoxString*>( pE->GetItem( LB_MACROS_ITEMPOS ) );
             DBG_ASSERT( pLItem && SV_ITEM_ID_LBOXSTRING == pLItem->GetType(), "_SfxMacroTabPage::FillEvents(): no LBoxString" );
 
             OUString          sOld( pLItem->GetText() );
             OUString          sNew;
-            sal_uInt16          nEventId = ( sal_uInt16 ) ( sal_uLong ) pE->GetUserData();
+            sal_uInt16        nEventId = ( sal_uInt16 ) reinterpret_cast<sal_uLong>( pE->GetUserData() );
             if( aTbl.IsKeyValid( nEventId ) )
                 sNew = ConvertToUIName_Impl( aTbl.Get( nEventId ) );
 
@@ -459,22 +433,19 @@ void _SfxMacroTabPage::FillEvents()
     }
 }
 
-SfxMacroTabPage::SfxMacroTabPage( Window* pParent, const ResId& rResId, const Reference< XFrame >& rxDocumentFrame, const SfxItemSet& rSet )
-    : _SfxMacroTabPage( pParent, rResId, rSet )
+SfxMacroTabPage::SfxMacroTabPage(vcl::Window* pParent, const Reference< XFrame >& rxDocumentFrame, const SfxItemSet& rSet )
+    : _SfxMacroTabPage( pParent, rSet )
 {
-    mpImpl->pStrEvent           = new OUString(                 CUI_RES( STR_EVENT ) );
-    mpImpl->pAssignedMacro      = new OUString(                 CUI_RES( STR_ASSMACRO ) );
-    mpImpl->pEventLB            = new _HeaderTabListBox( this,  CUI_RES( LB_EVENT ) );
-    mpImpl->pAssignPB           = new PushButton( this,         CUI_RES( PB_ASSIGN ) );
-    mpImpl->pDeletePB           = new PushButton( this,         CUI_RES( PB_DELETE ) );
-    mpImpl->pMacroFT            = new FixedText( this,          CUI_RES( FT_MACRO ) );
-    mpImpl->pGroupLB            = new SfxConfigGroupListBox_Impl( this,     CUI_RES( LB_GROUP ) );
-    mpImpl->pFT_MacroLBLabel    = new FixedText( this,          CUI_RES( FT_LABEL4LB_MACROS ) );
-    mpImpl->maStaticMacroLBLabel= mpImpl->pFT_MacroLBLabel->GetText();
-    mpImpl->pMacroLB            = new SfxConfigFunctionListBox_Impl( this,  CUI_RES( LB_MACROS ) );
-    mpImpl->pMacroStr           = new OUString(                 CUI_RES( STR_MACROS ) );
-
-    FreeResource();
+    mpImpl->sStrEvent = get<FixedText>("eventft")->GetText();
+    mpImpl->sAssignedMacro = get<FixedText>("assignft")->GetText();
+    get(mpImpl->pEventLB , "assignments");
+    get(mpImpl->pAssignPB, "assign");
+    get(mpImpl->pDeletePB, "delete");
+    get(mpImpl->pGroupFrame, "groupframe");
+    get(mpImpl->pGroupLB, "libraries");
+    get(mpImpl->pMacroFrame, "macroframe");
+    mpImpl->maStaticMacroLBLabel = mpImpl->pMacroFrame->get_label();
+    get(mpImpl->pMacroLB, "macros");
 
     SetFrame( rxDocumentFrame );
 
@@ -485,29 +456,26 @@ SfxMacroTabPage::SfxMacroTabPage( Window* pParent, const ResId& rResId, const Re
 
 namespace
 {
-    SfxMacroTabPage* CreateSfxMacroTabPage( Window* pParent, const SfxItemSet& rAttrSet )
+    VclPtr<SfxMacroTabPage> CreateSfxMacroTabPage( vcl::Window* pParent, const SfxItemSet& rAttrSet )
     {
-        return new SfxMacroTabPage( pParent, CUI_RES( RID_SVXPAGE_EVENTASSIGN ), NULL, rAttrSet );
+        return VclPtr<SfxMacroTabPage>::Create( pParent, nullptr, rAttrSet );
     }
 }
 
-SfxTabPage* SfxMacroTabPage::Create( Window* pParent, const SfxItemSet& rAttrSet )
+VclPtr<SfxTabPage> SfxMacroTabPage::Create( vcl::Window* pParent, const SfxItemSet* rAttrSet )
 {
-    return CreateSfxMacroTabPage(pParent, rAttrSet);
+    return CreateSfxMacroTabPage(pParent, *rAttrSet);
 }
 
-SfxMacroAssignDlg::SfxMacroAssignDlg( Window* pParent, const Reference< XFrame >& rxDocumentFrame, const SfxItemSet& rSet )
-    : SfxNoLayoutSingleTabDialog( pParent, rSet, 0 )
+SfxMacroAssignDlg::SfxMacroAssignDlg(vcl::Window* pParent,
+    const Reference< XFrame >& rxDocumentFrame, const SfxItemSet& rSet)
+    : SfxSingleTabDialog(pParent, rSet, "EventAssignDialog",
+        "cui/ui/eventassigndialog.ui")
 {
-    SfxMacroTabPage* pPage = CreateSfxMacroTabPage(this, rSet);
+    SfxMacroTabPage* pPage = CreateSfxMacroTabPage(get_content_area(), rSet);
     pPage->SetFrame( rxDocumentFrame );
     SetTabPage( pPage );
     pPage->LaunchFillGroup();
 }
 
-SfxMacroAssignDlg::~SfxMacroAssignDlg()
-{
-}
-
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
