@@ -29,6 +29,7 @@
 #include <comphelper/sequence.hxx>
 #include <comphelper/enumhelper.hxx>
 #include <comphelper/extract.hxx>
+#include <cppuhelper/exc_hlp.hxx>
 #include <com/sun/star/lang/XComponent.hpp>
 #include <com/sun/star/ucb/CommandInfo.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
@@ -85,7 +86,6 @@ ODefinitionContainer_Impl::iterator ODefinitionContainer_Impl::find( TContentPtr
 }
 
 // ODefinitionContainer
-DBG_NAME(ODefinitionContainer)
 
 ODefinitionContainer::ODefinitionContainer(   const Reference< XComponentContext >& _xORB
                                             , const Reference< XInterface >&    _xParentContainer
@@ -95,11 +95,11 @@ ODefinitionContainer::ODefinitionContainer(   const Reference< XComponentContext
     :OContentHelper(_xORB,_xParentContainer,_pImpl)
     ,m_aApproveListeners(m_aMutex)
     ,m_aContainerListeners(m_aMutex)
-    ,m_bInPropertyChange(sal_False)
+    ,m_bInPropertyChange(false)
     ,m_bCheckSlash(_bCheckSlash)
 {
-    m_pImpl->m_aProps.bIsDocument = sal_False;
-    m_pImpl->m_aProps.bIsFolder = sal_True;
+    m_pImpl->m_aProps.bIsDocument = false;
+    m_pImpl->m_aProps.bIsFolder = true;
 
     const ODefinitionContainer_Impl& rDefinitions( getDefinitions() );
     ODefinitionContainer_Impl::const_iterator aEnd = rDefinitions.end();
@@ -111,7 +111,6 @@ ODefinitionContainer::ODefinitionContainer(   const Reference< XComponentContext
             m_aDocumentMap.insert(
                 Documents::value_type( aDefinition->first, Documents::mapped_type() ) ).first );
 
-    DBG_CTOR(ODefinitionContainer, NULL);
 }
 
 void SAL_CALL ODefinitionContainer::disposing()
@@ -147,18 +146,24 @@ void SAL_CALL ODefinitionContainer::disposing()
 
 ODefinitionContainer::~ODefinitionContainer()
 {
-    DBG_DTOR(ODefinitionContainer, NULL);
 }
 
 IMPLEMENT_FORWARD_XINTERFACE2( ODefinitionContainer,OContentHelper,ODefinitionContainer_Base)
-IMPLEMENT_TYPEPROVIDER2(ODefinitionContainer,OContentHelper,ODefinitionContainer_Base);
+IMPLEMENT_GETTYPES2(ODefinitionContainer,OContentHelper,ODefinitionContainer_Base);
+
+css::uno::Sequence<sal_Int8> ODefinitionContainer::getImplementationId()
+    throw (css::uno::RuntimeException, std::exception)
+{
+    return css::uno::Sequence<sal_Int8>();
+}
+
 // XServiceInfo
-OUString SAL_CALL ODefinitionContainer::getImplementationName(  ) throw(RuntimeException)
+OUString SAL_CALL ODefinitionContainer::getImplementationName(  ) throw(RuntimeException, std::exception)
 {
     return OUString("com.sun.star.sdb.ODefinitionContainer");
 }
 
-Sequence< OUString > SAL_CALL ODefinitionContainer::getSupportedServiceNames(  ) throw(RuntimeException)
+Sequence< OUString > SAL_CALL ODefinitionContainer::getSupportedServiceNames(  ) throw(RuntimeException, std::exception)
 {
     Sequence< OUString > aReturn(2);
     aReturn.getArray()[0] = "com.sun.star.sdb.DefinitionContainer";
@@ -167,7 +172,7 @@ Sequence< OUString > SAL_CALL ODefinitionContainer::getSupportedServiceNames(  )
 }
 
 // XNameContainer
-void SAL_CALL ODefinitionContainer::insertByName( const OUString& _rName, const Any& aElement ) throw(IllegalArgumentException, ElementExistException, WrappedTargetException, RuntimeException)
+void SAL_CALL ODefinitionContainer::insertByName( const OUString& _rName, const Any& aElement ) throw(IllegalArgumentException, ElementExistException, WrappedTargetException, RuntimeException, std::exception)
 {
     ResettableMutexGuard aGuard(m_aMutex);
 
@@ -180,7 +185,7 @@ void SAL_CALL ODefinitionContainer::insertByName( const OUString& _rName, const
     notifyByName( aGuard, _rName, xNewElement, NULL, E_INSERTED, ContainerListemers );
 }
 
-void SAL_CALL ODefinitionContainer::removeByName( const OUString& _rName ) throw(NoSuchElementException, WrappedTargetException, RuntimeException)
+void SAL_CALL ODefinitionContainer::removeByName( const OUString& _rName ) throw(NoSuchElementException, WrappedTargetException, RuntimeException, std::exception)
 {
     ResettableMutexGuard aGuard(m_aMutex);
 
@@ -204,23 +209,45 @@ void SAL_CALL ODefinitionContainer::removeByName( const OUString& _rName ) throw
 }
 
 // XNameReplace
-void SAL_CALL ODefinitionContainer::replaceByName( const OUString& _rName, const Any& aElement ) throw(IllegalArgumentException, NoSuchElementException, WrappedTargetException, RuntimeException)
+void SAL_CALL ODefinitionContainer::replaceByName( const OUString& _rName, const Any& aElement ) throw(IllegalArgumentException, NoSuchElementException, WrappedTargetException, RuntimeException, std::exception)
 {
     ResettableMutexGuard aGuard(m_aMutex);
 
-    // let derived classes approve the new object
-    Reference< XContent > xNewElement(aElement,UNO_QUERY);
-    approveNewObject( _rName, xNewElement );    // will throw if necessary
+    try
+    {
+        // let derived classes approve the new object
+        Reference< XContent > xNewElement(aElement,UNO_QUERY);
+        approveNewObject( _rName, xNewElement );    // will throw if necessary
 
-    // the old element (for the notifications)
-    Reference< XContent > xOldElement = implGetByName( _rName, impl_haveAnyListeners_nothrow() );
+        // the old element (for the notifications)
+        Reference< XContent > xOldElement = implGetByName( _rName, impl_haveAnyListeners_nothrow() );
 
-    notifyByName( aGuard, _rName, xNewElement, xOldElement, E_REPLACED, ApproveListeners );
-    implReplace( _rName, xNewElement );
-    notifyByName( aGuard, _rName, xNewElement, xOldElement, E_REPLACED, ContainerListemers );
+        notifyByName( aGuard, _rName, xNewElement, xOldElement, E_REPLACED, ApproveListeners );
+        implReplace( _rName, xNewElement );
+        notifyByName( aGuard, _rName, xNewElement, xOldElement, E_REPLACED, ContainerListemers );
 
-    // and dispose it
-    disposeComponent(xOldElement);
+        // and dispose it
+        disposeComponent(xOldElement);
+    }
+    catch (const RuntimeException&)
+    {
+        throw;
+    }
+    catch (const NoSuchElementException&)
+    {
+        throw;
+    }
+    catch (const WrappedTargetException&)
+    {
+        throw;
+    }
+    catch (const Exception& e)
+    {
+        css::uno::Any a(cppu::getCaughtException());
+        throw css::lang::WrappedTargetException(
+          "wrapped Exception " + e.Message,
+          css::uno::Reference<css::uno::XInterface>(), a);
+    }
 }
 
 namespace
@@ -303,57 +330,57 @@ void ODefinitionContainer::notifyByName( ResettableMutexGuard& _rGuard, const OU
         _rGuard.reset();
 }
 
-void SAL_CALL ODefinitionContainer::addContainerListener( const Reference< XContainerListener >& _rxListener ) throw(RuntimeException)
+void SAL_CALL ODefinitionContainer::addContainerListener( const Reference< XContainerListener >& _rxListener ) throw(RuntimeException, std::exception)
 {
     if (_rxListener.is())
         m_aContainerListeners.addInterface(_rxListener);
 }
 
-void SAL_CALL ODefinitionContainer::removeContainerListener( const Reference< XContainerListener >& _rxListener ) throw(RuntimeException)
+void SAL_CALL ODefinitionContainer::removeContainerListener( const Reference< XContainerListener >& _rxListener ) throw(RuntimeException, std::exception)
 {
     if (_rxListener.is())
         m_aContainerListeners.removeInterface(_rxListener);
 }
 
-void SAL_CALL ODefinitionContainer::addContainerApproveListener( const Reference< XContainerApproveListener >& _Listener ) throw (RuntimeException)
+void SAL_CALL ODefinitionContainer::addContainerApproveListener( const Reference< XContainerApproveListener >& _Listener ) throw (RuntimeException, std::exception)
 {
     if ( _Listener.is() )
         m_aApproveListeners.addInterface( _Listener );
 }
 
-void SAL_CALL ODefinitionContainer::removeContainerApproveListener( const Reference< XContainerApproveListener >& _Listener ) throw (RuntimeException)
+void SAL_CALL ODefinitionContainer::removeContainerApproveListener( const Reference< XContainerApproveListener >& _Listener ) throw (RuntimeException, std::exception)
 {
     if ( _Listener.is() )
         m_aApproveListeners.removeInterface( _Listener );
 }
 
 // XElementAccess
-Type SAL_CALL ODefinitionContainer::getElementType( ) throw (RuntimeException)
+Type SAL_CALL ODefinitionContainer::getElementType( ) throw (RuntimeException, std::exception)
 {
-    return ::getCppuType( static_cast< Reference< XContent >* >(NULL) );
+    return cppu::UnoType<XContent>::get();
 }
 
-sal_Bool SAL_CALL ODefinitionContainer::hasElements( ) throw (RuntimeException)
+sal_Bool SAL_CALL ODefinitionContainer::hasElements( ) throw (RuntimeException, std::exception)
 {
     MutexGuard aGuard(m_aMutex);
     return !m_aDocuments.empty();
 }
 
 // XEnumerationAccess
-Reference< XEnumeration > SAL_CALL ODefinitionContainer::createEnumeration(  ) throw(RuntimeException)
+Reference< XEnumeration > SAL_CALL ODefinitionContainer::createEnumeration(  ) throw(RuntimeException, std::exception)
 {
     MutexGuard aGuard(m_aMutex);
     return new ::comphelper::OEnumerationByIndex(static_cast<XIndexAccess*>(this));
 }
 
 // XIndexAccess
-sal_Int32 SAL_CALL ODefinitionContainer::getCount(  ) throw(RuntimeException)
+sal_Int32 SAL_CALL ODefinitionContainer::getCount(  ) throw(RuntimeException, std::exception)
 {
     MutexGuard aGuard(m_aMutex);
     return m_aDocuments.size();
 }
 
-Any SAL_CALL ODefinitionContainer::getByIndex( sal_Int32 _nIndex ) throw(IndexOutOfBoundsException, WrappedTargetException, RuntimeException)
+Any SAL_CALL ODefinitionContainer::getByIndex( sal_Int32 _nIndex ) throw(IndexOutOfBoundsException, WrappedTargetException, RuntimeException, std::exception)
 {
     MutexGuard aGuard(m_aMutex);
 
@@ -373,14 +400,14 @@ Any SAL_CALL ODefinitionContainer::getByIndex( sal_Int32 _nIndex ) throw(IndexOu
     return makeAny(xProp);
 }
 
-Any SAL_CALL ODefinitionContainer::getByName( const OUString& _rName ) throw(NoSuchElementException, WrappedTargetException, RuntimeException)
+Any SAL_CALL ODefinitionContainer::getByName( const OUString& _rName ) throw(NoSuchElementException, WrappedTargetException, RuntimeException, std::exception)
 {
     MutexGuard aGuard(m_aMutex);
 
-    return makeAny( implGetByName( _rName, sal_True ) );
+    return makeAny( implGetByName( _rName, true ) );
 }
 
-Reference< XContent > ODefinitionContainer::implGetByName(const OUString& _rName, sal_Bool _bReadIfNeccessary) throw (NoSuchElementException)
+Reference< XContent > ODefinitionContainer::implGetByName(const OUString& _rName, bool _bReadIfNecessary) throw (NoSuchElementException)
 {
     Documents::iterator aMapPos = m_aDocumentMap.find(_rName);
     if (aMapPos == m_aDocumentMap.end())
@@ -388,7 +415,7 @@ Reference< XContent > ODefinitionContainer::implGetByName(const OUString& _rName
 
     Reference< XContent > xProp = aMapPos->second;
 
-    if (_bReadIfNeccessary && !xProp.is())
+    if (_bReadIfNecessary && !xProp.is())
     {   // the object has never been accessed before, so we have to read it now
         // (that's the expensive part)
 
@@ -401,7 +428,7 @@ Reference< XContent > ODefinitionContainer::implGetByName(const OUString& _rName
     return xProp;
 }
 
-Sequence< OUString > SAL_CALL ODefinitionContainer::getElementNames(  ) throw(RuntimeException)
+Sequence< OUString > SAL_CALL ODefinitionContainer::getElementNames(  ) throw(RuntimeException, std::exception)
 {
     MutexGuard aGuard(m_aMutex);
 
@@ -419,14 +446,14 @@ Sequence< OUString > SAL_CALL ODefinitionContainer::getElementNames(  ) throw(Ru
     return aNames;
 }
 
-sal_Bool SAL_CALL ODefinitionContainer::hasByName( const OUString& _rName ) throw(RuntimeException)
+sal_Bool SAL_CALL ODefinitionContainer::hasByName( const OUString& _rName ) throw(RuntimeException, std::exception)
 {
     MutexGuard aGuard(m_aMutex);
 
     return checkExistence(_rName);
 }
 
-void SAL_CALL ODefinitionContainer::disposing( const EventObject& _rSource ) throw(RuntimeException)
+void SAL_CALL ODefinitionContainer::disposing( const EventObject& _rSource ) throw(RuntimeException, std::exception)
 {
     MutexGuard aGuard(m_aMutex);
     Reference< XContent > xSource(_rSource.Source, UNO_QUERY);
@@ -595,12 +622,12 @@ void ODefinitionContainer::approveNewObject(const OUString& _sName,const Referen
 }
 
 // XPropertyChangeListener
-void SAL_CALL ODefinitionContainer::propertyChange( const PropertyChangeEvent& evt ) throw (RuntimeException)
+void SAL_CALL ODefinitionContainer::propertyChange( const PropertyChangeEvent& evt ) throw (RuntimeException, std::exception)
 {
     ClearableMutexGuard aGuard(m_aMutex);
-    if( evt.PropertyName == (OUString) PROPERTY_NAME || evt.PropertyName ==  "Title" )
+    if( evt.PropertyName == PROPERTY_NAME || evt.PropertyName ==  "Title" )
     {
-        m_bInPropertyChange = sal_True;
+        m_bInPropertyChange = true;
         try
         {
             OUString sNewName,sOldName;
@@ -616,16 +643,16 @@ void SAL_CALL ODefinitionContainer::propertyChange( const PropertyChangeEvent& e
             DBG_UNHANDLED_EXCEPTION();
             throw RuntimeException();
         }
-        m_bInPropertyChange = sal_False;
+        m_bInPropertyChange = false;
     }
 }
 
 // XVetoableChangeListener
-void SAL_CALL ODefinitionContainer::vetoableChange( const PropertyChangeEvent& aEvent ) throw (PropertyVetoException, RuntimeException)
+void SAL_CALL ODefinitionContainer::vetoableChange( const PropertyChangeEvent& aEvent ) throw (PropertyVetoException, RuntimeException, std::exception)
 {
     MutexGuard aGuard(m_aMutex);
 
-    if( aEvent.PropertyName == (OUString) PROPERTY_NAME || aEvent.PropertyName == "Title" )
+    if( aEvent.PropertyName == PROPERTY_NAME || aEvent.PropertyName == "Title" )
     {
         OUString sNewName;
         aEvent.NewValue >>= sNewName;
@@ -655,7 +682,7 @@ void ODefinitionContainer::removeObjectListener(const Reference< XContent >& _xN
     }
 }
 
-sal_Bool ODefinitionContainer::checkExistence(const OUString& _rName)
+bool ODefinitionContainer::checkExistence(const OUString& _rName)
 {
     return m_aDocumentMap.find(_rName) != m_aDocumentMap.end();
 }
