@@ -18,11 +18,11 @@
  */
 
 #include "RelationControl.hxx"
-#include "RelationControl.hrc"
 
 #include <svtools/editbrowsebox.hxx>
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <tools/diagnose_ex.h>
+#include <vcl/builderfactory.hxx>
 #include "TableConnectionData.hxx"
 #include "TableConnection.hxx"
 #include "TableWindow.hxx"
@@ -59,7 +59,7 @@ namespace dbaui
     {
         friend class OTableListBoxControl;
 
-        ::std::auto_ptr< ::svt::ListBoxControl> m_pListCell;
+        VclPtr< ::svt::ListBoxControl>          m_pListCell;
         TTableConnectionData::value_type        m_pConnData;
         OTableListBoxControl*                   m_pBoxControl;
         long                                    m_nDataPos;
@@ -78,8 +78,11 @@ namespace dbaui
         */
         sal_uInt16 getColumnIdent( sal_uInt16 _nColId ) const;
     public:
-        ORelationControl( OTableListBoxControl* pParent );
-        virtual ~ORelationControl();
+        ORelationControl(vcl::Window *pParent);
+        void SetController(OTableListBoxControl* pController)
+        {
+            m_pBoxControl = pController;
+        }
 
         /** searches for a connection between these two tables
             @param  _pSource
@@ -98,22 +101,24 @@ namespace dbaui
         void lateInit();
 
     protected:
-        virtual void Resize();
+        virtual ~ORelationControl() { disposeOnce(); }
+        virtual void dispose() SAL_OVERRIDE { m_pListCell.disposeAndClear(); ORelationControl_Base::dispose(); }
+        virtual void Resize() SAL_OVERRIDE;
+        virtual Size GetOptimalSize() const SAL_OVERRIDE;
+        virtual bool PreNotify(NotifyEvent& rNEvt ) SAL_OVERRIDE;
 
-        virtual long PreNotify(NotifyEvent& rNEvt );
+        virtual bool IsTabAllowed(bool bForward) const SAL_OVERRIDE;
 
-        virtual sal_Bool IsTabAllowed(sal_Bool bForward) const;
+        void Init(const TTableConnectionData::value_type& _pConnData);
+        virtual void Init() SAL_OVERRIDE { ORelationControl_Base::Init(); }
+        virtual void InitController( ::svt::CellControllerRef& rController, long nRow, sal_uInt16 nCol ) SAL_OVERRIDE;
+        virtual ::svt::CellController* GetController( long nRow, sal_uInt16 nCol ) SAL_OVERRIDE;
+        virtual void PaintCell( OutputDevice& rDev, const Rectangle& rRect, sal_uInt16 nColId ) const SAL_OVERRIDE;
+        virtual bool SeekRow( long nRow ) SAL_OVERRIDE;
+        virtual bool SaveModified() SAL_OVERRIDE;
+        virtual OUString GetCellText( long nRow, sal_uInt16 nColId ) const SAL_OVERRIDE;
 
-        virtual void Init(const TTableConnectionData::value_type& _pConnData);
-        virtual void Init() { ORelationControl_Base::Init(); }
-        virtual void InitController( ::svt::CellControllerRef& rController, long nRow, sal_uInt16 nCol );
-        virtual ::svt::CellController* GetController( long nRow, sal_uInt16 nCol );
-        virtual void PaintCell( OutputDevice& rDev, const Rectangle& rRect, sal_uInt16 nColId ) const;
-        virtual sal_Bool SeekRow( long nRow );
-        virtual sal_Bool SaveModified();
-        virtual OUString GetCellText( long nRow, sal_uInt16 nColId ) const;
-
-        virtual void CellModified();
+        virtual void CellModified() SAL_OVERRIDE;
 
         DECL_LINK( AsynchDeactivate, void* );
     private:
@@ -123,30 +128,29 @@ namespace dbaui
     };
 
     // class ORelationControl
-    DBG_NAME(ORelationControl)
-    ORelationControl::ORelationControl( OTableListBoxControl* pParent )
-        :EditBrowseBox( pParent, EBBF_SMART_TAB_TRAVEL | EBBF_NOROWPICTURE, WB_TABSTOP | WB_BORDER | BROWSER_AUTOSIZE_LASTCOL)
-        ,m_pBoxControl(pParent)
-        ,m_xSourceDef( NULL )
-        ,m_xDestDef( NULL )
+    ORelationControl::ORelationControl(vcl::Window *pParent)
+        : EditBrowseBox(pParent,
+            EditBrowseBoxFlags::SMART_TAB_TRAVEL | EditBrowseBoxFlags::NO_HANDLE_COLUMN_CONTENT,
+            WB_TABSTOP | WB_BORDER,
+            BrowserMode::AUTOSIZE_LASTCOL)
+        , m_pBoxControl(NULL)
+        , m_nDataPos(0)
+        , m_xSourceDef(NULL)
+        , m_xDestDef(NULL)
     {
-        DBG_CTOR(ORelationControl,NULL);
     }
 
-    ORelationControl::~ORelationControl()
-    {
-        DBG_DTOR(ORelationControl,NULL);
-    }
+    VCL_BUILDER_FACTORY(ORelationControl)
 
     void ORelationControl::Init(const TTableConnectionData::value_type& _pConnData)
     {
-        DBG_CHKTHIS(ORelationControl,NULL);
 
         m_pConnData = _pConnData;
         OSL_ENSURE(m_pConnData, "No data supplied!");
 
         m_pConnData->normalizeLines();
     }
+
     void ORelationControl::lateInit()
     {
         if ( !m_pConnData.get() )
@@ -160,39 +164,38 @@ namespace dbaui
             InsertDataColumn( DEST_COLUMN, m_pConnData->getReferencedTable()->GetWinName(), 100);
             // If the Defs do not yet exits, we need to set them with SetSource-/-DestDef
 
-            m_pListCell.reset( new ListBoxControl( &GetDataWindow() ) );
+            m_pListCell.reset( VclPtr<ListBoxControl>::Create( &GetDataWindow() ) );
 
             // set browse mode
-            SetMode(    BROWSER_COLUMNSELECTION |
-                        BROWSER_HLINESFULL      |
-                        BROWSER_VLINESFULL      |
-                        BROWSER_HIDECURSOR      |
-                        BROWSER_HIDESELECT      |
-                        BROWSER_AUTO_HSCROLL    |
-                        BROWSER_AUTO_VSCROLL);
+            SetMode(    BrowserMode::COLUMNSELECTION |
+                        BrowserMode::HLINES      |
+                        BrowserMode::VLINES      |
+                        BrowserMode::HIDECURSOR      |
+                        BrowserMode::HIDESELECT      |
+                        BrowserMode::AUTO_HSCROLL    |
+                        BrowserMode::AUTO_VSCROLL);
         }
         else
             // not the first call
             RowRemoved(0, GetRowCount());
 
-        RowInserted(0, m_pConnData->GetConnLineDataList()->size() + 1, sal_True); // add one extra row
+        RowInserted(0, m_pConnData->GetConnLineDataList().size() + 1, true); // add one extra row
     }
+
     void ORelationControl::Resize()
     {
-        DBG_CHKTHIS(ORelationControl,NULL);
         EditBrowseBox::Resize();
-        long nOutputWidth = GetOutputSizePixel().Width();
+        long nOutputWidth = GetOutputSizePixel().Width() - 1;
         SetColumnWidth(1, (nOutputWidth / 2));
         SetColumnWidth(2, (nOutputWidth / 2));
     }
 
-    long ORelationControl::PreNotify(NotifyEvent& rNEvt)
+    bool ORelationControl::PreNotify(NotifyEvent& rNEvt)
     {
-        DBG_CHKTHIS(ORelationControl,NULL);
-        if (rNEvt.GetType() == EVENT_LOSEFOCUS && !HasChildPathFocus() )
-            PostUserEvent(LINK(this, ORelationControl, AsynchDeactivate));
-        else if (rNEvt.GetType() == EVENT_GETFOCUS)
-            PostUserEvent(LINK(this, ORelationControl, AsynchActivate));
+        if (rNEvt.GetType() == MouseNotifyEvent::LOSEFOCUS && !HasChildPathFocus() )
+            PostUserEvent(LINK(this, ORelationControl, AsynchDeactivate), NULL, true);
+        else if (rNEvt.GetType() == MouseNotifyEvent::GETFOCUS)
+            PostUserEvent(LINK(this, ORelationControl, AsynchActivate), NULL, true);
 
         return EditBrowseBox::PreNotify(rNEvt);
     }
@@ -209,35 +212,33 @@ namespace dbaui
         return 0L;
     }
 
-    sal_Bool ORelationControl::IsTabAllowed(sal_Bool bForward) const
+    bool ORelationControl::IsTabAllowed(bool bForward) const
     {
-        DBG_CHKTHIS(ORelationControl,NULL);
         long nRow = GetCurRow();
         sal_uInt16 nCol = GetCurColumnId();
 
-        sal_Bool bRet = !((     ( bForward && (nCol == DEST_COLUMN)     && (nRow == GetRowCount() - 1)))
+        bool bRet = !((     ( bForward && (nCol == DEST_COLUMN)     && (nRow == GetRowCount() - 1)))
                         ||  (!bForward && (nCol == SOURCE_COLUMN)   && (nRow == 0)));
 
         return bRet && EditBrowseBox::IsTabAllowed(bForward);
     }
 
-    sal_Bool ORelationControl::SaveModified()
+    bool ORelationControl::SaveModified()
     {
-        DBG_CHKTHIS(ORelationControl,NULL);
         long nRow = GetCurRow();
         if ( nRow != BROWSER_ENDOFSELECTION )
         {
             OUString sFieldName(m_pListCell->GetSelectEntry());
-            OConnectionLineDataVec* pLines = m_pConnData->GetConnLineDataList();
-            if ( pLines->size() <= static_cast<OConnectionLineDataVec::size_type>(nRow) )
+            OConnectionLineDataVec& rLines = m_pConnData->GetConnLineDataList();
+            if ( rLines.size() <= static_cast<OConnectionLineDataVec::size_type>(nRow) )
             {
-                pLines->push_back(new OConnectionLineData());
-                nRow = pLines->size() - 1;
-                // add new past-pLines row
+                rLines.push_back(new OConnectionLineData());
+                nRow = rLines.size() - 1;
+                // add new past-rLines row
                 m_ops.push_back(make_pair(INSERT, make_pair(nRow+1, nRow+2)));
             }
 
-            OConnectionLineDataRef pConnLineData = (*pLines)[nRow];
+            OConnectionLineDataRef pConnLineData = rLines[nRow];
 
             switch( getColumnIdent( GetCurColumnId() ) )
             {
@@ -253,15 +254,16 @@ namespace dbaui
             //m_ops.push_back(make_pair(MODIFY, make_pair(nRow, nRow+1)));
         }
 
-        const OConnectionLineDataVec::size_type oldSize = m_pConnData->GetConnLineDataList()->size();
+        const OConnectionLineDataVec::size_type oldSize = m_pConnData->GetConnLineDataList().size();
         OConnectionLineDataVec::size_type line = m_pConnData->normalizeLines();
-        const OConnectionLineDataVec::size_type newSize = m_pConnData->GetConnLineDataList()->size();
+        const OConnectionLineDataVec::size_type newSize = m_pConnData->GetConnLineDataList().size();
         assert(newSize <= oldSize);
         m_ops.push_back(make_pair(MODIFY, make_pair(line, newSize)));
         m_ops.push_back(make_pair(DELETE, make_pair(newSize, oldSize)));
 
-        return sal_True;
+        return true;
     }
+
     sal_uInt16 ORelationControl::getColumnIdent( sal_uInt16 _nColId ) const
     {
         sal_uInt16 nId = _nColId;
@@ -272,11 +274,10 @@ namespace dbaui
 
     OUString ORelationControl::GetCellText( long nRow, sal_uInt16 nColId ) const
     {
-        DBG_CHKTHIS(ORelationControl,NULL);
         OUString sText;
-        if ( m_pConnData->GetConnLineDataList()->size() > static_cast<size_t>(nRow) )
+        if ( m_pConnData->GetConnLineDataList().size() > static_cast<size_t>(nRow) )
         {
-            OConnectionLineDataRef pConnLineData = (*m_pConnData->GetConnLineDataList())[nRow];
+            OConnectionLineDataRef pConnLineData = m_pConnData->GetConnLineDataList()[nRow];
             switch( getColumnIdent( nColId ) )
             {
             case SOURCE_COLUMN:
@@ -292,7 +293,6 @@ namespace dbaui
 
     void ORelationControl::InitController( CellControllerRef& /*rController*/, long nRow, sal_uInt16 nColumnId )
     {
-        DBG_CHKTHIS(ORelationControl,NULL);
 
         OString sHelpId( HID_RELATIONDIALOG_LEFTFIELDCELL );
 
@@ -329,29 +329,26 @@ namespace dbaui
 
     CellController* ORelationControl::GetController( long /*nRow*/, sal_uInt16 /*nColumnId*/ )
     {
-        DBG_CHKTHIS(ORelationControl,NULL);
         return new ListBoxCellController( m_pListCell.get() );
     }
 
-    sal_Bool ORelationControl::SeekRow( long nRow )
+    bool ORelationControl::SeekRow( long nRow )
     {
-        DBG_CHKTHIS(ORelationControl,NULL);
         m_nDataPos = nRow;
-        return sal_True;
+        return true;
     }
 
     void ORelationControl::PaintCell( OutputDevice& rDev, const Rectangle& rRect, sal_uInt16 nColumnId ) const
     {
-        DBG_CHKTHIS(ORelationControl,NULL);
-        OUString aText = const_cast< ORelationControl*>(this)->GetCellText( m_nDataPos, nColumnId );
+        OUString aText = GetCellText( m_nDataPos, nColumnId );
 
         Point aPos( rRect.TopLeft() );
-        Size aTextSize( GetDataWindow().GetTextHeight(),GetDataWindow().GetTextWidth( aText ));
+        Size aTextSize( GetDataWindow().GetTextWidth( aText ), GetDataWindow().GetTextHeight() );
 
-        if( aPos.X() < rRect.Right() || aPos.X() + aTextSize.Width() > rRect.Right() ||
+        if( aPos.X() < rRect.Left() || aPos.X() + aTextSize.Width() > rRect.Right() ||
             aPos.Y() < rRect.Top() || aPos.Y() + aTextSize.Height() > rRect.Bottom() )
         {
-            rDev.SetClipRegion(Region(rRect));
+            rDev.SetClipRegion(vcl::Region(rRect));
         }
 
         rDev.DrawText( aPos, aText );
@@ -387,7 +384,7 @@ namespace dbaui
     void ORelationControl::setWindowTables(const OTableWindow* _pSource,const OTableWindow* _pDest)
     {
         // If I edit here, hide
-        sal_Bool bWasEditing = IsEditing();
+        bool bWasEditing = IsEditing();
         if ( bWasEditing )
             DeactivateCell();
 
@@ -401,7 +398,7 @@ namespace dbaui
 
             const OJoinTableView* pView = _pSource->getTableView();
             OTableConnection* pConn = pView->GetTabConn(_pSource,_pDest);
-            if ( pConn && !m_pConnData->GetConnLineDataList()->empty() )
+            if ( pConn && !m_pConnData->GetConnLineDataList().empty() )
             {
                 m_pConnData->CopyFrom(*pConn->GetData());
                 m_pBoxControl->getContainer()->notifyConnectionChange();
@@ -409,9 +406,9 @@ namespace dbaui
             else
             {
                 // no connection found so we clear our data
-                OConnectionLineDataVec* pLines = m_pConnData->GetConnLineDataList();
-                ::std::for_each(pLines->begin(),
-                                pLines->end(),
+                OConnectionLineDataVec& rLines = m_pConnData->GetConnLineDataList();
+                ::std::for_each(rLines.begin(),
+                                rLines.end(),
                                 OUnaryRefFunctor<OConnectionLineData>( ::std::mem_fun(&OConnectionLineData::Reset))
                                 );
 
@@ -430,55 +427,45 @@ namespace dbaui
             ActivateCell();
         }
     }
+
     void ORelationControl::CellModified()
     {
-        DBG_CHKTHIS(ORelationControl,NULL);
         EditBrowseBox::CellModified();
         SaveModified();
-#if OSL_DEBUG_LEVEL > 0
-        OTableListBoxControl *parent = dynamic_cast<OTableListBoxControl*>(GetParent());
-#else
-        OTableListBoxControl *parent = static_cast<OTableListBoxControl*>(GetParent());
-#endif
-        assert(parent);
-        parent->NotifyCellChange();
+        assert(m_pBoxControl);
+        m_pBoxControl->NotifyCellChange();
     }
-    // class OTableListBoxControl
-DBG_NAME(OTableListBoxControl)
 
-OTableListBoxControl::OTableListBoxControl(  Window* _pParent
-                                            ,const ResId& _rResId
-                                            ,const OJoinTableView::OTableWindowMap* _pTableMap
-                                            ,IRelationControlInterface* _pParentDialog)
-     : Window(_pParent,_rResId)
-     , m_aFL_InvolvedTables(    this, ResId(FL_INVOLVED_TABLES,*_rResId.GetResMgr()))
-     , m_lmbLeftTable(          this, ResId(LB_LEFT_TABLE,*_rResId.GetResMgr()))
-     , m_lmbRightTable(         this, ResId(LB_RIGHT_TABLE,*_rResId.GetResMgr()))
-     , m_aFL_InvolvedFields(    this, ResId(FL_INVOLVED_FIELDS,*_rResId.GetResMgr()))
-     , m_pTableMap(_pTableMap)
-     , m_pParentDialog(_pParentDialog)
+    Size ORelationControl::GetOptimalSize() const
     {
-        m_pRC_Tables = new ORelationControl( this );
-        m_pRC_Tables->SetHelpId(HID_RELDLG_KEYFIELDS);
-        m_pRC_Tables->Init( );
-        m_pRC_Tables->SetZOrder(&m_lmbRightTable, WINDOW_ZORDER_BEHIND);
+        return LogicToPixel(Size(140, 80), MAP_APPFONT);
+    }
+
+    // class OTableListBoxControl
+    OTableListBoxControl::OTableListBoxControl(VclBuilderContainer* _pParent,
+        const OJoinTableView::OTableWindowMap* _pTableMap,
+        IRelationControlInterface* _pParentDialog)
+        : m_pTableMap(_pTableMap)
+        , m_pParentDialog(_pParentDialog)
+    {
+        _pParent->get(m_pLeftTable, "table1");
+        _pParent->get(m_pRightTable, "table2");
+
+        _pParent->get(m_pRC_Tables, "relations");
+        m_pRC_Tables->SetController(this);
+        m_pRC_Tables->Init();
 
         lateUIInit();
 
-        Link aLink(LINK(this, OTableListBoxControl, OnTableChanged));
-        m_lmbLeftTable.SetSelectHdl(aLink);
-        m_lmbRightTable.SetSelectHdl(aLink);
-
-        FreeResource();
-        DBG_CTOR(OTableListBoxControl,NULL);
+        Link<> aLink(LINK(this, OTableListBoxControl, OnTableChanged));
+        m_pLeftTable->SetSelectHdl(aLink);
+        m_pRightTable->SetSelectHdl(aLink);
     }
+
     OTableListBoxControl::~OTableListBoxControl()
     {
-        ORelationControl* pTemp = m_pRC_Tables;
-        m_pRC_Tables = NULL;
-        delete pTemp;
-        DBG_DTOR(OTableListBoxControl,NULL);
     }
+
     void OTableListBoxControl::fillListBoxes()
     {
         OSL_ENSURE( !m_pTableMap->empty(), "OTableListBoxControl::fillListBoxes: no table window!");
@@ -490,8 +477,8 @@ OTableListBoxControl::OTableListBoxControl(  Window* _pParent
         OJoinTableView::OTableWindowMap::const_iterator aEnd = m_pTableMap->end();
         for(;aIter != aEnd;++aIter)
         {
-            m_lmbLeftTable.InsertEntry(aIter->first);
-            m_lmbRightTable.InsertEntry(aIter->first);
+            m_pLeftTable->InsertEntry(aIter->first);
+            m_pRightTable->InsertEntry(aIter->first);
 
             if (!pInitialLeft)
             {
@@ -518,17 +505,18 @@ OTableListBoxControl::OTableListBoxControl(  Window* _pParent
 
         if ( m_pTableMap->size() > 2 )
         {
-            m_lmbLeftTable.RemoveEntry(m_strCurrentRight);
-            m_lmbRightTable.RemoveEntry(m_strCurrentLeft);
+            m_pLeftTable->RemoveEntry(m_strCurrentRight);
+            m_pRightTable->RemoveEntry(m_strCurrentLeft);
         }
 
         // Select the first one on the left side and on the right side,
         // select the second one
-        m_lmbLeftTable.SelectEntry(m_strCurrentLeft);
-        m_lmbRightTable.SelectEntry(m_strCurrentRight);
+        m_pLeftTable->SelectEntry(m_strCurrentLeft);
+        m_pRightTable->SelectEntry(m_strCurrentRight);
 
-        m_lmbLeftTable.GrabFocus();
+        m_pLeftTable->GrabFocus();
     }
+
     IMPL_LINK( OTableListBoxControl, OnTableChanged, ListBox*, pListBox )
     {
         OUString strSelected(pListBox->GetSelectEntry());
@@ -539,10 +527,10 @@ OTableListBoxControl::OTableListBoxControl(  Window* _pParent
         if ( m_pTableMap->size() == 2 )
         {
             ListBox* pOther;
-            if ( pListBox == &m_lmbLeftTable )
-                pOther = &m_lmbRightTable;
+            if (pListBox == m_pLeftTable)
+                pOther = m_pRightTable;
             else
-                pOther = &m_lmbLeftTable;
+                pOther = m_pLeftTable;
             pOther->SelectEntryPos(1 - pOther->GetSelectEntryPos());
 
             OJoinTableView::OTableWindowMap::const_iterator aIter = m_pTableMap->begin();
@@ -550,7 +538,7 @@ OTableListBoxControl::OTableListBoxControl(  Window* _pParent
             ++aIter;
             OTableWindow* pSecond = aIter->second;
 
-            if ( m_lmbLeftTable.GetSelectEntry() == pFirst->GetName() )
+            if ( m_pLeftTable->GetSelectEntry() == pFirst->GetName() )
             {
                 pLeft   = pFirst;
                 pRight  = pSecond;
@@ -570,33 +558,33 @@ OTableListBoxControl::OTableListBoxControl(  Window* _pParent
                 pLoop = aFind->second;
             OSL_ENSURE(pLoop != NULL, "ORelationDialog::OnTableChanged: invalid ListBox entry!");
                 // We need to find strSelect, because we filled the ListBoxes with the table names with which we compare now
-            if (pListBox == &m_lmbLeftTable)
+            if (pListBox == m_pLeftTable)
             {
                 // Insert the previously selected Entry on the left side on the right side
-                m_lmbRightTable.InsertEntry(m_strCurrentLeft);
+                m_pRightTable->InsertEntry(m_strCurrentLeft);
                 // Remove the currently selected Entry
-                m_lmbRightTable.RemoveEntry(strSelected);
+                m_pRightTable->RemoveEntry(strSelected);
                 m_strCurrentLeft    = strSelected;
 
                 pLeft = pLoop;
 
-                OJoinTableView::OTableWindowMap::const_iterator aIter = m_pTableMap->find(m_lmbRightTable.GetSelectEntry());
+                OJoinTableView::OTableWindowMap::const_iterator aIter = m_pTableMap->find(m_pRightTable->GetSelectEntry());
                 OSL_ENSURE( aIter != m_pTableMap->end(), "Invalid name");
                 if ( aIter != m_pTableMap->end() )
                     pRight = aIter->second;
 
-                m_lmbLeftTable.GrabFocus();
+                m_pLeftTable->GrabFocus();
             }
             else
             {
                 // Insert the previously selected Entry on the right side on the left side
-                m_lmbLeftTable.InsertEntry(m_strCurrentRight);
+                m_pLeftTable->InsertEntry(m_strCurrentRight);
                 // Remove the currently selected Entry
-                m_lmbLeftTable.RemoveEntry(strSelected);
+                m_pLeftTable->RemoveEntry(strSelected);
                 m_strCurrentRight = strSelected;
 
                 pRight = pLoop;
-                OJoinTableView::OTableWindowMap::const_iterator aIter = m_pTableMap->find(m_lmbLeftTable.GetSelectEntry());
+                OJoinTableView::OTableWindowMap::const_iterator aIter = m_pTableMap->find(m_pLeftTable->GetSelectEntry());
                 OSL_ENSURE( aIter != m_pTableMap->end(), "Invalid name");
                 if ( aIter != m_pTableMap->end() )
                     pLeft = aIter->second;
@@ -610,16 +598,17 @@ OTableListBoxControl::OTableListBoxControl(  Window* _pParent
         NotifyCellChange();
         return 0;
     }
+
     void OTableListBoxControl::NotifyCellChange()
     {
         // Enable/disable the OK button, depending on having a valid situation
         TTableConnectionData::value_type pConnData = m_pRC_Tables->getData();
-        const OConnectionLineDataVec* pLines = pConnData->GetConnLineDataList();
-        bool bValid = !pLines->empty();
+        const OConnectionLineDataVec& rLines = pConnData->GetConnLineDataList();
+        bool bValid = !rLines.empty();
         if (bValid)
         {
-            OConnectionLineDataVec::const_iterator l(pLines->begin());
-            const OConnectionLineDataVec::const_iterator le(pLines->end());
+            OConnectionLineDataVec::const_iterator l(rLines.begin());
+            const OConnectionLineDataVec::const_iterator le(rLines.end());
             for (; bValid && l!=le; ++l)
             {
                 bValid = ! ((*l)->GetSourceFieldName().isEmpty() || (*l)->GetDestFieldName().isEmpty());
@@ -649,62 +638,64 @@ OTableListBoxControl::OTableListBoxControl(  Window* _pParent
         m_pRC_Tables->ActivateCell();
         m_pRC_Tables->m_ops.clear();
     }
+
     void fillEntryAndDisable(ListBox& _rListBox,const OUString& _sEntry)
     {
         _rListBox.InsertEntry(_sEntry);
         _rListBox.SelectEntryPos(0);
         _rListBox.Disable();
     }
+
     void OTableListBoxControl::fillAndDisable(const TTableConnectionData::value_type& _pConnectionData)
     {
-        fillEntryAndDisable(m_lmbLeftTable,_pConnectionData->getReferencingTable()->GetWinName());
-        fillEntryAndDisable(m_lmbRightTable,_pConnectionData->getReferencedTable()->GetWinName());
+        fillEntryAndDisable(*m_pLeftTable, _pConnectionData->getReferencingTable()->GetWinName());
+        fillEntryAndDisable(*m_pRightTable, _pConnectionData->getReferencedTable()->GetWinName());
     }
+
     void OTableListBoxControl::Init(const TTableConnectionData::value_type& _pConnData)
     {
         m_pRC_Tables->Init(_pConnData);
     }
-    void OTableListBoxControl::lateUIInit(Window* _pTableSeparator)
+
+    void OTableListBoxControl::lateUIInit()
     {
-        const sal_Int32 nDiff = LogicToPixel( Point(0,6), MAP_APPFONT ).Y();
-        Point aDlgPoint = LogicToPixel( Point(12,43), MAP_APPFONT );
-        if ( _pTableSeparator )
-        {
-            _pTableSeparator->SetZOrder(&m_lmbRightTable, WINDOW_ZORDER_BEHIND);
-            m_pRC_Tables->SetZOrder(_pTableSeparator, WINDOW_ZORDER_BEHIND);
-            _pTableSeparator->SetPosPixel(Point(0,m_aFL_InvolvedFields.GetPosPixel().Y()));
-            const Size aSize = _pTableSeparator->GetSizePixel();
-            aDlgPoint.Y() = _pTableSeparator->GetPosPixel().Y() + aSize.Height();
-            m_aFL_InvolvedFields.SetPosPixel(Point(m_aFL_InvolvedFields.GetPosPixel().X(),aDlgPoint.Y()));
-            aDlgPoint.Y() += nDiff + m_aFL_InvolvedFields.GetSizePixel().Height();
-        }
-        // positing BrowseBox control
-        const Size aCurrentSize = GetSizePixel();
-        Size aDlgSize = LogicToPixel( Size(24,0), MAP_APPFONT );
-        aDlgSize.Width() = aCurrentSize.Width() - aDlgSize.Width();
-        aDlgSize.Height() = aCurrentSize.Height() - aDlgPoint.Y() - nDiff;
-
-        m_pRC_Tables->SetPosSizePixel( aDlgPoint, aDlgSize );
         m_pRC_Tables->Show();
-
         lateInit();
     }
+
     void OTableListBoxControl::lateInit()
     {
         m_pRC_Tables->lateInit();
     }
-    sal_Bool OTableListBoxControl::SaveModified()
+
+    void OTableListBoxControl::Disable()
+    {
+        m_pLeftTable->Disable();
+        m_pRightTable->Disable();
+        m_pRC_Tables->Disable();
+    }
+
+    void OTableListBoxControl::Invalidate()
+    {
+        m_pLeftTable->Invalidate();
+        m_pRightTable->Invalidate();
+        m_pRC_Tables->Invalidate();
+    }
+
+    bool OTableListBoxControl::SaveModified()
     {
         return m_pRC_Tables->SaveModified();
     }
+
     TTableWindowData::value_type OTableListBoxControl::getReferencingTable()    const
     {
         return m_pRC_Tables->getData()->getReferencingTable();
     }
+
     void OTableListBoxControl::enableRelation(bool _bEnable)
     {
         if ( !_bEnable )
-            PostUserEvent(LINK(m_pRC_Tables, ORelationControl, AsynchDeactivate));
+            m_pRC_Tables->PostUserEvent(LINK(m_pRC_Tables, ORelationControl, AsynchDeactivate));
         m_pRC_Tables->Enable(_bEnable);
 
     }
