@@ -21,12 +21,14 @@
 #include "dbu_dlg.hrc"
 #include <osl/diagnose.h>
 #include "dbaccess_helpid.hrc"
+#include <vcl/settings.hxx>
+#include <vcl/builderfactory.hxx>
 
 namespace dbaui
 {
 
-#define BROWSER_STANDARD_FLAGS      BROWSER_COLUMNSELECTION | BROWSER_HLINESFULL | BROWSER_VLINESFULL | \
-                                    BROWSER_HIDECURSOR | BROWSER_HIDESELECT | BROWSER_AUTO_HSCROLL | BROWSER_AUTO_VSCROLL
+#define BROWSER_STANDARD_FLAGS      BrowserMode::COLUMNSELECTION | BrowserMode::HLINES | BrowserMode::VLINES | \
+                                    BrowserMode::HIDECURSOR | BrowserMode::HIDESELECT | BrowserMode::AUTO_HSCROLL | BrowserMode::AUTO_VSCROLL
 
 #define COLUMN_ID_FIELDNAME     1
 #define COLUMN_ID_ORDER         2
@@ -38,8 +40,8 @@ namespace dbaui
     class DbaMouseDownListBoxController : public ListBoxCellController
     {
     protected:
-        Link    m_aOriginalModifyHdl;
-        Link    m_aAdditionalModifyHdl;
+        Link<>  m_aOriginalModifyHdl;
+        Link<>  m_aAdditionalModifyHdl;
 
     public:
         DbaMouseDownListBoxController(ListBoxControl* _pParent)
@@ -47,24 +49,24 @@ namespace dbaui
         {
         }
 
-        void SetAdditionalModifyHdl(const Link& _rHdl);
+        void SetAdditionalModifyHdl(const Link<>& _rHdl);
 
     protected:
-        virtual sal_Bool WantMouseEvent() const { return sal_True; }
-        virtual void SetModifyHdl(const Link& _rHdl);
+        virtual bool WantMouseEvent() const SAL_OVERRIDE { return true; }
+        virtual void SetModifyHdl(const Link<>& _rHdl) SAL_OVERRIDE;
 
     private:
         void implCheckLinks();
         DECL_LINK( OnMultiplexModify, void* );
     };
 
-    void DbaMouseDownListBoxController::SetAdditionalModifyHdl(const Link& _rHdl)
+    void DbaMouseDownListBoxController::SetAdditionalModifyHdl(const Link<>& _rHdl)
     {
         m_aAdditionalModifyHdl = _rHdl;
         implCheckLinks();
     }
 
-    void DbaMouseDownListBoxController::SetModifyHdl(const Link& _rHdl)
+    void DbaMouseDownListBoxController::SetModifyHdl(const Link<>& _rHdl)
     {
         m_aOriginalModifyHdl = _rHdl;
         implCheckLinks();
@@ -84,37 +86,45 @@ namespace dbaui
         if (m_aAdditionalModifyHdl.IsSet() || m_aOriginalModifyHdl.IsSet())
             ListBoxCellController::SetModifyHdl(LINK(this, DbaMouseDownListBoxController, OnMultiplexModify));
         else
-            ListBoxCellController::SetModifyHdl(Link());
+            ListBoxCellController::SetModifyHdl(Link<>());
     }
 
     // IndexFieldsControl
-DBG_NAME(IndexFieldsControl)
-    IndexFieldsControl::IndexFieldsControl( Window* _pParent, const ResId& _rId ,sal_Int32 _nMaxColumnsInIndex,sal_Bool _bAddIndexAppendix)
-        :EditBrowseBox(_pParent, _rId, EBBF_SMART_TAB_TRAVEL | EBBF_ACTIVATE_ON_BUTTONDOWN, BROWSER_STANDARD_FLAGS)
-        ,m_aSeekRow(m_aFields.end())
-        ,m_pSortingCell(NULL)
-        ,m_pFieldNameCell(NULL)
-        ,m_nMaxColumnsInIndex(_nMaxColumnsInIndex)
-        ,m_bAddIndexAppendix(_bAddIndexAppendix)
+    IndexFieldsControl::IndexFieldsControl( vcl::Window* _pParent, WinBits nWinStyle)
+        : EditBrowseBox(_pParent, EditBrowseBoxFlags::SMART_TAB_TRAVEL | EditBrowseBoxFlags::ACTIVATE_ON_BUTTONDOWN, nWinStyle, BROWSER_STANDARD_FLAGS)
+        , m_aSeekRow(m_aFields.end())
+        , m_pSortingCell(NULL)
+        , m_pFieldNameCell(NULL)
+        , m_nMaxColumnsInIndex(0)
+        , m_bAddIndexAppendix(false)
     {
-        DBG_CTOR(IndexFieldsControl,NULL);
 
         SetUniqueId( UID_DLGINDEX_INDEXDETAILS_BACK );
         GetDataWindow().SetUniqueId( UID_DLGINDEX_INDEXDETAILS_MAIN );
     }
 
-    IndexFieldsControl::~IndexFieldsControl()
+    VCL_BUILDER_DECL_FACTORY(DbaIndexFieldsControl)
     {
-        delete m_pSortingCell;
-        delete m_pFieldNameCell;
-
-        DBG_DTOR(IndexFieldsControl,NULL);
+        (void)rMap;
+        rRet = VclPtr<IndexFieldsControl>::Create(pParent, WB_BORDER | WB_NOTABSTOP);
     }
 
-    sal_Bool IndexFieldsControl::SeekRow(long nRow)
+    IndexFieldsControl::~IndexFieldsControl()
+    {
+        disposeOnce();
+    }
+
+    void IndexFieldsControl::dispose()
+    {
+        m_pSortingCell.disposeAndClear();
+        m_pFieldNameCell.disposeAndClear();
+        ::svt::EditBrowseBox::dispose();
+    }
+
+    bool IndexFieldsControl::SeekRow(long nRow)
     {
         if (!EditBrowseBox::SeekRow(nRow))
-            return sal_False;
+            return false;
 
         if (nRow < 0)
         {
@@ -126,7 +136,7 @@ DBG_NAME(IndexFieldsControl)
             OSL_ENSURE(m_aSeekRow <= m_aFields.end(), "IndexFieldsControl::SeekRow: invalid row!");
         }
 
-        return sal_True;
+        return true;
     }
 
     void IndexFieldsControl::PaintCell( OutputDevice& _rDev, const Rectangle& _rRect, sal_uInt16 _nColumnId ) const
@@ -140,10 +150,10 @@ DBG_NAME(IndexFieldsControl)
         // clipping
         if (aPos.X() < _rRect.Right() || aPos.X() + TxtSize.Width() > _rRect.Right() ||
             aPos.Y() < _rRect.Top() || aPos.Y() + TxtSize.Height() > _rRect.Bottom())
-            _rDev.SetClipRegion(Region(_rRect));
+            _rDev.SetClipRegion(vcl::Region(_rRect));
 
         // allow for a disabled control ...
-        sal_Bool bEnabled = IsEnabled();
+        bool bEnabled = IsEnabled();
         Color aOriginalColor = _rDev.GetTextColor();
         if (!bEnabled)
             _rDev.SetTextColor(GetSettings().GetStyleSettings().GetDisableColor());
@@ -165,14 +175,14 @@ DBG_NAME(IndexFieldsControl)
         m_aFields = _rFields;
         m_aSeekRow = m_aFields.end();
 
-        SetUpdateMode(sal_False);
+        SetUpdateMode(false);
         // remove all rows
         RowRemoved(1, GetRowCount());
         // insert rows for the fields
-        RowInserted(GetRowCount(), m_aFields.size(), sal_False);
+        RowInserted(GetRowCount(), m_aFields.size(), false);
         // insert an additional row for a new field for that index
-        RowInserted(GetRowCount(), 1, sal_False);
-        SetUpdateMode(sal_True);
+        RowInserted(GetRowCount(), 1, false);
+        SetUpdateMode(true);
 
         GoToRowColumnId(0, COLUMN_ID_FIELDNAME);
     }
@@ -181,9 +191,9 @@ DBG_NAME(IndexFieldsControl)
     {
         // do not just copy the array, we may have empty field names (which should not be copied)
         _rFields.resize(m_aFields.size());
-        ConstIndexFieldsIterator aSource = m_aFields.begin();
-        ConstIndexFieldsIterator aSourceEnd = m_aFields.end();
-        IndexFieldsIterator aDest = _rFields.begin();
+        IndexFields::const_iterator aSource = m_aFields.begin();
+        IndexFields::const_iterator aSourceEnd = m_aFields.end();
+        IndexFields::iterator aDest = _rFields.begin();
         for (; aSource < aSourceEnd; ++aSource)
             if (!aSource->sFieldName.isEmpty())
             {
@@ -206,8 +216,11 @@ DBG_NAME(IndexFieldsControl)
         return EditBrowseBox::GetTotalCellWidth(_nRow, _nColId);
     }
 
-    void IndexFieldsControl::Init(const Sequence< OUString >& _rAvailableFields)
+    void IndexFieldsControl::Init(const Sequence< OUString >& _rAvailableFields, sal_Int32 _nMaxColumnsInIndex,bool _bAddIndexAppendix)
     {
+        m_nMaxColumnsInIndex = _nMaxColumnsInIndex;
+        m_bAddIndexAppendix = _bAddIndexAppendix;
+
         RemoveColumns();
 
         // for the width: both columns together should be somewhat smaller than the whole window (without the scrollbar)
@@ -231,9 +244,9 @@ DBG_NAME(IndexFieldsControl)
             nSortOrderColumnWidth = nSortOrderColumnWidth > nOther ? nSortOrderColumnWidth : nOther;
             // (plus some additional space)
             nSortOrderColumnWidth += GetTextWidth(OUString('0')) * 2;
-            InsertDataColumn(COLUMN_ID_ORDER, sColumnName, nSortOrderColumnWidth, HIB_STDSTYLE, 1);
+            InsertDataColumn(COLUMN_ID_ORDER, sColumnName, nSortOrderColumnWidth, HeaderBarItemBits::STDSTYLE, 1);
 
-            m_pSortingCell = new ListBoxControl(&GetDataWindow());
+            m_pSortingCell = VclPtr<ListBoxControl>::Create(&GetDataWindow());
             m_pSortingCell->InsertEntry(m_sAscendingText);
             m_pSortingCell->InsertEntry(m_sDescendingText);
             m_pSortingCell->SetHelpId( HID_DLGINDEX_INDEXDETAILS_SORTORDER );
@@ -245,11 +258,11 @@ DBG_NAME(IndexFieldsControl)
         nFieldNameWidth -= 8;
         // the "field name" column
         OUString sColumnName = ModuleRes(STR_TAB_INDEX_FIELD);
-        InsertDataColumn(COLUMN_ID_FIELDNAME, sColumnName, nFieldNameWidth, HIB_STDSTYLE, 0);
+        InsertDataColumn(COLUMN_ID_FIELDNAME, sColumnName, nFieldNameWidth, HeaderBarItemBits::STDSTYLE, 0);
 
         // create the cell controllers
         // for the field name cell
-        m_pFieldNameCell = new ListBoxControl(&GetDataWindow());
+        m_pFieldNameCell = VclPtr<ListBoxControl>::Create(&GetDataWindow());
         m_pFieldNameCell->InsertEntry(OUString());
         m_pFieldNameCell->SetHelpId( HID_DLGINDEX_INDEXDETAILS_FIELD );
         const OUString* pFields = _rAvailableFields.getConstArray();
@@ -263,8 +276,8 @@ DBG_NAME(IndexFieldsControl)
         if (!IsEnabled())
             return NULL;
 
-        ConstIndexFieldsIterator aRow;
-        sal_Bool bNewField = !implGetFieldDesc(_nRow, aRow);
+        IndexFields::const_iterator aRow;
+        bool bNewField = !implGetFieldDesc(_nRow, aRow);
 
         DbaMouseDownListBoxController* pReturn = NULL;
         switch (_nColumnId)
@@ -288,31 +301,31 @@ DBG_NAME(IndexFieldsControl)
         return pReturn;
     }
 
-    sal_Bool IndexFieldsControl::implGetFieldDesc(long _nRow, ConstIndexFieldsIterator& _rPos)
+    bool IndexFieldsControl::implGetFieldDesc(long _nRow, IndexFields::const_iterator& _rPos)
     {
         _rPos = m_aFields.end();
         if ((_nRow < 0) || (_nRow >= (sal_Int32)m_aFields.size()))
-            return sal_False;
+            return false;
         _rPos = m_aFields.begin() + _nRow;
-        return sal_True;
+        return true;
     }
 
-    sal_Bool IndexFieldsControl::IsModified() const
+    bool IndexFieldsControl::IsModified() const
     {
         return EditBrowseBox::IsModified();
     }
 
-    sal_Bool IndexFieldsControl::SaveModified()
+    bool IndexFieldsControl::SaveModified()
     {
         if (!IsModified())
-            return sal_True;
+            return true;
 
         switch (GetCurColumnId())
         {
             case COLUMN_ID_FIELDNAME:
             {
                 OUString sFieldSelected = m_pFieldNameCell->GetSelectEntry();
-                sal_Bool bEmptySelected = sFieldSelected.isEmpty();
+                bool bEmptySelected = sFieldSelected.isEmpty();
                 if (isNewField())
                 {
                     if (!bEmptySelected)
@@ -321,7 +334,7 @@ DBG_NAME(IndexFieldsControl)
                         OIndexField aNewField;
                         aNewField.sFieldName = sFieldSelected;
                         m_aFields.push_back(aNewField);
-                        RowInserted(GetRowCount(), 1, sal_True);
+                        RowInserted(GetRowCount(), 1, true);
                     }
                 }
                 else
@@ -331,20 +344,20 @@ DBG_NAME(IndexFieldsControl)
                     if (nRow >= 0)  // may be -1 in case the control was empty
                     {
                         // remove the field from the selection
-                        IndexFieldsIterator aPos = m_aFields.begin() + nRow;
+                        IndexFields::iterator aPos = m_aFields.begin() + nRow;
 
                         if (bEmptySelected)
                         {
-                            aPos->sFieldName = "";
+                            aPos->sFieldName.clear();
 
                             // invalidate the row to force repaint
                             Invalidate(GetRowRectPixel(nRow));
-                            return sal_True;
+                            return true;
                         }
 
                         if (sFieldSelected == aPos->sFieldName)
                             // nothing changed
-                            return sal_True;
+                            return true;
 
                         aPos->sFieldName = sFieldSelected;
                     }
@@ -357,7 +370,7 @@ DBG_NAME(IndexFieldsControl)
             {
                 OSL_ENSURE(!isNewField(), "IndexFieldsControl::SaveModified: why the hell ...!!!");
                 // selected entry
-                sal_uInt16 nPos = m_pSortingCell->GetSelectEntryPos();
+                sal_Int32 nPos = m_pSortingCell->GetSelectEntryPos();
                 OSL_ENSURE(LISTBOX_ENTRY_NOTFOUND != nPos, "IndexFieldsControl::SaveModified: how did you get this selection??");
                 // adjust the sort flag in the index field description
                 OIndexField& rCurrentField = m_aFields[GetCurRow()];
@@ -368,13 +381,13 @@ DBG_NAME(IndexFieldsControl)
             default:
                 OSL_FAIL("IndexFieldsControl::SaveModified: invalid column id!");
         }
-        return sal_True;
+        return true;
     }
 
     void IndexFieldsControl::InitController(CellControllerRef& /*_rController*/, long _nRow, sal_uInt16 _nColumnId)
     {
-        ConstIndexFieldsIterator aFieldDescription;
-        sal_Bool bNewField = !implGetFieldDesc(_nRow, aFieldDescription);
+        IndexFields::const_iterator aFieldDescription;
+        bool bNewField = !implGetFieldDesc(_nRow, aFieldDescription);
 
         switch (_nColumnId)
         {
@@ -430,7 +443,7 @@ DBG_NAME(IndexFieldsControl)
     }
     OUString IndexFieldsControl::GetCellText(long _nRow,sal_uInt16 nColId) const
     {
-        ConstIndexFieldsIterator aRow = m_aFields.end();
+        IndexFields::const_iterator aRow = m_aFields.end();
         if ( _nRow >= 0 )
         {
             aRow = m_aFields.begin() + _nRow;
@@ -438,7 +451,7 @@ DBG_NAME(IndexFieldsControl)
         }
         return GetRowCellText(aRow,nColId);
     }
-    OUString IndexFieldsControl::GetRowCellText(const ConstIndexFieldsIterator& _rRow,sal_uInt16 nColId) const
+    OUString IndexFieldsControl::GetRowCellText(const IndexFields::const_iterator& _rRow,sal_uInt16 nColId) const
     {
         if (_rRow < m_aFields.end())
         {
@@ -457,9 +470,9 @@ DBG_NAME(IndexFieldsControl)
         }
         return OUString();
     }
-    sal_Bool IndexFieldsControl::IsTabAllowed(sal_Bool /*bForward*/) const
+    bool IndexFieldsControl::IsTabAllowed(bool /*bForward*/) const
     {
-        return sal_False;
+        return false;
     }
 
 }   // namespace dbaui
