@@ -60,9 +60,9 @@ using namespace ::com::sun::star::accessibility;
 
 namespace
 {
-    sal_Bool isColumnInKeyType(const Reference<XIndexAccess>& _rxKeys,const OUString& _rColumnName,sal_Int32 _nKeyType)
+    bool isColumnInKeyType(const Reference<XIndexAccess>& _rxKeys,const OUString& _rColumnName,sal_Int32 _nKeyType)
     {
-        sal_Bool bReturn = sal_False;
+        bool bReturn = false;
         if(_rxKeys.is())
         {
             Reference<XColumnsSupplier> xColumnsSupplier;
@@ -83,7 +83,7 @@ namespace
                             Reference<XNameAccess> xColumns = xColumnsSupplier->getColumns();
                             if(xColumns.is() && xColumns->hasByName(_rColumnName))
                             {
-                                bReturn = sal_True;
+                                bReturn = true;
                                 break;
                             }
                         }
@@ -102,7 +102,7 @@ namespace
     void addUndoAction( OQueryTableView* _pView,
                         OQueryTabConnUndoAction* _pUndoAction,
                         OQueryTableConnection* _pConnection,
-                        sal_Bool _bOwner = sal_False)
+                        bool _bOwner = false)
     {
         _pUndoAction->SetOwnership(_bOwner);
         _pUndoAction->SetConnection(_pConnection);
@@ -114,15 +114,15 @@ namespace
 
         @return true when OK was pressed otherwise false
     */
-    sal_Bool openJoinDialog(OQueryTableView* _pView,const TTableConnectionData::value_type& _pConnectionData,sal_Bool _bSelectableTables)
+    bool openJoinDialog(OQueryTableView* _pView,const TTableConnectionData::value_type& _pConnectionData,bool _bSelectableTables)
     {
         OQueryTableConnectionData* pData = static_cast< OQueryTableConnectionData*>(_pConnectionData.get());
 
-        DlgQryJoin aDlg(_pView,_pConnectionData,_pView->GetTabWinMap(),_pView->getDesignView()->getController().getConnection(),_bSelectableTables);
-        sal_Bool bOk = aDlg.Execute() == RET_OK;
+        ScopedVclPtrInstance< DlgQryJoin > aDlg(_pView,_pConnectionData,&_pView->GetTabWinMap(),_pView->getDesignView()->getController().getConnection(),_bSelectableTables);
+        bool bOk = aDlg->Execute() == RET_OK;
         if( bOk )
         {
-            pData->SetJoinType(aDlg.GetJoinType());
+            pData->SetJoinType(aDlg->GetJoinType());
             _pView->getDesignView()->getController().setModified(sal_True);
         }
 
@@ -135,7 +135,7 @@ namespace
     */
     void connectionModified(OQueryTableView* _pView,
                             OTableConnection* _pConnection,
-                            sal_Bool _bAddUndo)
+                            bool _bAddUndo)
     {
         OSL_ENSURE(_pConnection,"Invalid connection!");
         _pConnection->UpdateLineList();
@@ -189,7 +189,7 @@ namespace
             pNewConnData->SetFieldType(JTCS_TO,isColumnInKeyType(xReferencedKeys,sRelatedColumn,KeyType::PRIMARY) ? TAB_PRIMARY_FIELD : TAB_NORMAL_FIELD);
 
             {
-                Sequence< sal_Int16> aFind(::comphelper::findValue(_rSource.GetOriginalColumns()->getElementNames(),*pIter,sal_True));
+                Sequence< sal_Int16> aFind(::comphelper::findValue(_rSource.GetOriginalColumns()->getElementNames(),*pIter,true));
                 if(aFind.getLength())
                     pNewConnData->SetFieldIndex(JTCS_FROM,aFind[0]+1);
                 else
@@ -199,7 +199,7 @@ namespace
             Reference<XNameAccess> xRefColumns = _rDest.GetOriginalColumns();
             if(xRefColumns.is())
             {
-                Sequence< sal_Int16> aFind(::comphelper::findValue(xRefColumns->getElementNames(),sRelatedColumn,sal_True));
+                Sequence< sal_Int16> aFind(::comphelper::findValue(xRefColumns->getElementNames(),sRelatedColumn,true));
                 if(aFind.getLength())
                     pNewConnData->SetFieldIndex(JTCS_TO,aFind[0]+1);
                 else
@@ -208,10 +208,10 @@ namespace
             pNewConnData->AppendConnLine(*pIter,sRelatedColumn);
 
             // now add the Conn itself
-            OQueryTableConnection aNewConn(_pView, aNewConnData);
-            // refering to the local variable is not important, as NotifyQueryTabConn creates a new copy
+            ScopedVclPtrInstance< OQueryTableConnection > aNewConn(_pView, aNewConnData);
+            // referring to the local variable is not important, as NotifyQueryTabConn creates a new copy
             // to add me (if not existent)
-            _pView->NotifyTabConnection(aNewConn, sal_False);
+            _pView->NotifyTabConnection(*aNewConn.get(), false);
                 // don't create an Undo-Action for the new connection : the connection is
                 // covered by the Undo-Action for the tabwin, as the "Undo the insert" will
                 // automatically remove all connections adjacent to the win.
@@ -222,29 +222,21 @@ namespace
 }
 
 // class OQueryTableView
-DBG_NAME(OQueryTableView)
-OQueryTableView::OQueryTableView( Window* pParent,OQueryDesignView* pView)
+OQueryTableView::OQueryTableView( vcl::Window* pParent,OQueryDesignView* pView)
     : OJoinTableView( pParent,pView)
 {
-    DBG_CTOR(OQueryTableView,NULL);
     SetHelpId(HID_CTL_QRYDGNTAB);
 }
 
-OQueryTableView::~OQueryTableView()
-{
-    DBG_DTOR(OQueryTableView,NULL);
-}
-
 sal_Int32 OQueryTableView::CountTableAlias(const OUString& rName, sal_Int32& rMax)
 {
-    DBG_CHKTHIS(OQueryTableView,NULL);
     sal_Int32 nRet = 0;
 
-    OTableWindowMapIterator aIter = GetTabWinMap()->find(rName);
-    while(aIter != GetTabWinMap()->end())
+    OTableWindowMap::iterator aIter = GetTabWinMap().find(rName);
+    while(aIter != GetTabWinMap().end())
     {
-        OUString aNewName = OUString(rName) + "_" + OUString::number(++nRet);
-        aIter = GetTabWinMap()->find(aNewName);
+        OUString aNewName = rName + "_" + OUString::number(++nRet);
+        aIter = GetTabWinMap().find(aNewName);
     }
 
     rMax = nRet;
@@ -254,21 +246,20 @@ sal_Int32 OQueryTableView::CountTableAlias(const OUString& rName, sal_Int32& rMa
 
 void OQueryTableView::ReSync()
 {
-    DBG_CHKTHIS(OQueryTableView,NULL);
-    TTableWindowData* pTabWinDataList = m_pView->getController().getTableWindowData();
-    OSL_ENSURE((getTableConnections()->size()==0) && (GetTabWinMap()->size()==0),
+    TTableWindowData& rTabWinDataList = m_pView->getController().getTableWindowData();
+    OSL_ENSURE((getTableConnections().size()==0) && (GetTabWinMap().size()==0),
         "before calling OQueryTableView::ReSync() please call ClearAll !");
 
     // I need a collection of all window names that cannot be created so that I do not initialize connections for them.
     ::std::vector<OUString> arrInvalidTables;
 
-    TTableWindowData::reverse_iterator aIter = pTabWinDataList->rbegin();
+    TTableWindowData::reverse_iterator aIter = rTabWinDataList.rbegin();
     // Create the window and add it
 
-    for(;aIter != pTabWinDataList->rend();++aIter)
+    for(;aIter != rTabWinDataList.rend();++aIter)
     {
         OQueryTableWindowData* pData = static_cast<OQueryTableWindowData*>(aIter->get());
-        OTableWindow* pTabWin = createWindow(*aIter);
+        VclPtr<OTableWindow> pTabWin = createWindow(*aIter);
 
         // I dont't use ShowTabWin as this adds the window data to the list of documents.
         // This would be bad as I am getting them from there.
@@ -278,14 +269,14 @@ void OQueryTableView::ReSync()
             // The initialisation has gone wrong, this TabWin is not available, so
             // I must clean up the data and the document
             pTabWin->clearListBox();
-            delete pTabWin;
+            pTabWin.disposeAndClear();
             arrInvalidTables.push_back(pData->GetAliasName());
 
-            pTabWinDataList->erase( ::std::remove(pTabWinDataList->begin(),pTabWinDataList->end(),*aIter) ,pTabWinDataList->end());
+            rTabWinDataList.erase( ::std::remove(rTabWinDataList.begin(), rTabWinDataList.end(), *aIter), rTabWinDataList.end());
             continue;
         }
 
-        (*GetTabWinMap())[pData->GetAliasName()] = pTabWin; // add at the beginning as I am going backwards through the DataList
+        GetTabWinMap()[pData->GetAliasName()] = pTabWin; // add at the beginning as I am going backwards through the DataList
         // Use the default if there is no position or size
         if (!pData->HasPosition() && !pData->HasSize())
             SetDefaultTabWinPosSize(pTabWin);
@@ -294,70 +285,68 @@ void OQueryTableView::ReSync()
     }
 
     // Add the connections
-    TTableConnectionData* pTabConnDataList = m_pView->getController().getTableConnectionData();
-    TTableConnectionData::reverse_iterator aConIter = pTabConnDataList->rbegin();
+    TTableConnectionData& rTabConnDataList = m_pView->getController().getTableConnectionData();
+    TTableConnectionData::reverse_iterator aConIter = rTabConnDataList.rbegin();
 
-    for(;aConIter != pTabConnDataList->rend();++aConIter)
+    for(;aConIter != rTabConnDataList.rend();++aConIter)
     {
         OQueryTableConnectionData* pTabConnData =  static_cast<OQueryTableConnectionData*>(aConIter->get());
 
         // do both tables for the connection exist ?
         OUString strTabExistenceTest = pTabConnData->getReferencingTable()->GetWinName();
-        sal_Bool bInvalid = ::std::find(arrInvalidTables.begin(),arrInvalidTables.end(),strTabExistenceTest) != arrInvalidTables.end();
+        bool bInvalid = ::std::find(arrInvalidTables.begin(),arrInvalidTables.end(),strTabExistenceTest) != arrInvalidTables.end();
         strTabExistenceTest = pTabConnData->getReferencedTable()->GetWinName();
         bInvalid = bInvalid && ::std::find(arrInvalidTables.begin(),arrInvalidTables.end(),strTabExistenceTest) != arrInvalidTables.end();
 
         if (bInvalid)
         {
             // no -> bad luck, no connection
-            pTabConnDataList->erase( ::std::remove(pTabConnDataList->begin(),pTabConnDataList->end(),*aConIter) ,pTabConnDataList->end());
+            rTabConnDataList.erase( ::std::remove(rTabConnDataList.begin(), rTabConnDataList.end(), *aConIter), rTabConnDataList.end());
             continue;
         }
 
         // adds a new connection to join view and notifies our accessible and invaldates the controller
-        addConnection(new OQueryTableConnection(this, *aConIter));
+        addConnection(VclPtr<OQueryTableConnection>::Create(this, *aConIter));
     }
 }
 
 void OQueryTableView::ClearAll()
 {
-    DBG_CHKTHIS(OQueryTableView,NULL);
     OJoinTableView::ClearAll();
 
-    SetUpdateMode(sal_True);
+    SetUpdateMode(true);
     m_pView->getController().setModified(sal_True);
 }
 
-OTableWindow* OQueryTableView::createWindow(const TTableWindowData::value_type& _pData)
+VclPtr<OTableWindow> OQueryTableView::createWindow(const TTableWindowData::value_type& _pData)
 {
-    return new OQueryTableWindow(this,_pData);
+    return VclPtr<OQueryTableWindow>::Create(this,_pData);
 }
 
-void OQueryTableView::NotifyTabConnection(const OQueryTableConnection& rNewConn, sal_Bool _bCreateUndoAction)
+void OQueryTableView::NotifyTabConnection(const OQueryTableConnection& rNewConn, bool _bCreateUndoAction)
 {
-    DBG_CHKTHIS(OQueryTableView,NULL);
     // let's first check if I have the connection already
     OQueryTableConnection* pTabConn = NULL;
-    const ::std::vector<OTableConnection*>* pConnections = getTableConnections();
-    ::std::vector<OTableConnection*>::const_iterator aEnd = pConnections->end();
-    ::std::vector<OTableConnection*>::const_iterator aIter = ::std::find(   pConnections->begin(),
-                                                    aEnd,
-                                                    static_cast<const OTableConnection*>(&rNewConn)
-                                                    );
+    const auto& rConnections = getTableConnections();
+    auto aEnd = rConnections.end();
+    auto aIter = ::std::find(   rConnections.begin(),
+                                aEnd,
+                                VclPtr<OTableConnection>(const_cast<OTableConnection*>(static_cast<const OTableConnection*>(&rNewConn)))
+                            );
     if(aIter == aEnd )
     {
-        aIter = pConnections->begin();
+        aIter = rConnections.begin();
         for(;aIter != aEnd;++aIter)
         {
-            if(*static_cast<OQueryTableConnection*>(*aIter) == rNewConn)
+            if(*static_cast<OQueryTableConnection*>((*aIter).get()) == rNewConn)
             {
-                pTabConn = static_cast<OQueryTableConnection*>(*aIter);
+                pTabConn = static_cast<OQueryTableConnection*>((*aIter).get());
                 break;
             }
         }
     }
     else
-        pTabConn = static_cast<OQueryTableConnection*>(*aIter);
+        pTabConn = static_cast<OQueryTableConnection*>((*aIter).get());
 
     // no -> insert
     if (pTabConn == NULL)
@@ -366,7 +355,7 @@ void OQueryTableView::NotifyTabConnection(const OQueryTableConnection& rNewConn,
         OQueryTableConnectionData* pNewData = static_cast< OQueryTableConnectionData*>(rNewConn.GetData()->NewInstance());
         pNewData->CopyFrom(*rNewConn.GetData());
         TTableConnectionData::value_type aData(pNewData);
-        OQueryTableConnection* pNewConn = new OQueryTableConnection(this, aData);
+        VclPtrInstance<OQueryTableConnection> pNewConn(this, aData);
         GetConnection(pNewConn);
 
         connectionModified(this,pNewConn,_bCreateUndoAction);
@@ -380,9 +369,8 @@ OTableWindowData* OQueryTableView::CreateImpl(const OUString& _rComposedName
     return new OQueryTableWindowData( _rComposedName, _sTableName,_rWinName );
 }
 
-void OQueryTableView::AddTabWin(const OUString& _rTableName, const OUString& _rAliasName, sal_Bool bNewTable)
+void OQueryTableView::AddTabWin(const OUString& _rTableName, const OUString& _rAliasName, bool bNewTable)
 {
-    DBG_CHKTHIS(OQueryTableView,NULL);
     // this method has been inherited from the base class, linking back to the parent and which constructs
     // an Alias and which passes on to my other AddTabWin
 
@@ -444,19 +432,18 @@ Reference<XPropertySet> getKeyReferencedTo(const Reference<XIndexAccess>& _rxKey
     return Reference<XPropertySet>();
 }
 
-void OQueryTableView::AddTabWin(const OUString& _rComposedName, const OUString& _rTableName, const OUString& strAlias, sal_Bool bNewTable)
+void OQueryTableView::AddTabWin(const OUString& _rComposedName, const OUString& _rTableName, const OUString& strAlias, bool bNewTable)
 {
-    DBG_CHKTHIS(OQueryTableView,NULL);
     OSL_ENSURE(!_rTableName.isEmpty() || !strAlias.isEmpty(), "OQueryTableView::AddTabWin : no tables or aliases !");
         // If the table is not set, then it is a dummy window, but at least the alias must be set
 
     // build a new data structure
     // first check if this already has its data
-    sal_Bool bAppend = bNewTable;
+    bool bAppend = bNewTable;
     TTableWindowData::value_type pNewTabWinData;
-    TTableWindowData* pWindowData = getDesignView()->getController().getTableWindowData();
-    TTableWindowData::iterator aWinIter = pWindowData->begin();
-    TTableWindowData::iterator aWinEnd = pWindowData->end();
+    TTableWindowData& rWindowData = getDesignView()->getController().getTableWindowData();
+    TTableWindowData::iterator aWinIter = rWindowData.begin();
+    TTableWindowData::iterator aWinEnd = rWindowData.end();
     for(;aWinIter != aWinEnd;++aWinIter)
     {
         pNewTabWinData = *aWinIter;
@@ -470,26 +457,26 @@ void OQueryTableView::AddTabWin(const OUString& _rComposedName, const OUString&
         // I do not need to add TabWinData to the DocShell list, ShowTabWin does that.
 
     // Create a new window
-    OQueryTableWindow* pNewTabWin = static_cast<OQueryTableWindow*>(createWindow(pNewTabWinData));
+    VclPtr<OQueryTableWindow> pNewTabWin = static_cast<OQueryTableWindow*>(createWindow(pNewTabWinData).get());
     // No need to initialize, as that happens in ShowTabWin
 
     // New UndoAction
     OQueryTabWinShowUndoAct* pUndoAction = new OQueryTabWinShowUndoAct(this);
     pUndoAction->SetTabWin(pNewTabWin); // Window
-    sal_Bool bSuccess = ShowTabWin(pNewTabWin, pUndoAction,bAppend);
+    bool bSuccess = ShowTabWin(pNewTabWin, pUndoAction,bAppend);
     if(!bSuccess)
     {
         // reset table window
         pUndoAction->SetTabWin(NULL);
-        pUndoAction->SetOwnership(sal_False);
+        pUndoAction->SetOwnership(false);
 
         delete pUndoAction;
         return;
     }
 
     // Show the relations between the individual tables
-    OTableWindowMap* pTabWins = GetTabWinMap();
-    if(bNewTable && !pTabWins->empty() && !_rTableName.isEmpty())
+    OTableWindowMap& rTabWins = GetTabWinMap();
+    if(bNewTable && !rTabWins.empty() && !_rTableName.isEmpty())
     {
         modified();
         if ( m_pAccessible )
@@ -532,31 +519,31 @@ void OQueryTableView::AddTabWin(const OUString& _rComposedName, const OUString&
                     xProp->getPropertyValue(PROPERTY_REFERENCEDTABLE) >>= aReferencedTable;
                     OSL_ENSURE(!aReferencedTable.isEmpty(),"Foreign key without referencedTableName");
 
-                    OTableWindowMap::const_iterator aIter = pTabWins->find(aReferencedTable);
-                    OTableWindowMap::const_iterator aEnd  = pTabWins->end();
+                    OTableWindowMap::const_iterator aIter = rTabWins.find(aReferencedTable);
+                    OTableWindowMap::const_iterator aEnd  = rTabWins.end();
                     if(aIter == aEnd)
                     {
-                        for(aIter = pTabWins->begin();aIter != aEnd;++aIter)
+                        for(aIter = rTabWins.begin();aIter != aEnd;++aIter)
                         {
-                            OQueryTableWindow* pTabWinTmp = static_cast<OQueryTableWindow*>(aIter->second);
+                            OQueryTableWindow* pTabWinTmp = static_cast<OQueryTableWindow*>(aIter->second.get());
                             OSL_ENSURE( pTabWinTmp,"TableWindow is null!" );
                             if ( pTabWinTmp != pNewTabWin && pTabWinTmp->GetComposedName() == aReferencedTable )
                                 break;
                         }
                     }
-                    if ( aIter != aEnd && pNewTabWin != aIter->second )
-                        addConnections( this, *pNewTabWin, *static_cast<OQueryTableWindow*>(aIter->second), xFKeyColumns );
+                    if ( aIter != aEnd && pNewTabWin.get() != aIter->second.get() )
+                        addConnections( this, *pNewTabWin, *static_cast<OQueryTableWindow*>(aIter->second.get()), xFKeyColumns );
                 }
                 break;
 
                 case KeyType::PRIMARY:
                 {
-                    // we have a primary key so look in our list if there exsits a key which this is refered to
-                    OTableWindowMap::const_iterator aIter = pTabWins->begin();
-                    OTableWindowMap::const_iterator aEnd  = pTabWins->end();
+                    // we have a primary key so look in our list if there exists a key which this is referred to
+                    OTableWindowMap::const_iterator aIter = rTabWins.begin();
+                    OTableWindowMap::const_iterator aEnd  = rTabWins.end();
                     for(;aIter != aEnd;++aIter)
                     {
-                        OQueryTableWindow* pTabWinTmp = static_cast<OQueryTableWindow*>(aIter->second);
+                        OQueryTableWindow* pTabWinTmp = static_cast<OQueryTableWindow*>(aIter->second.get());
                         if ( pTabWinTmp == pNewTabWin )
                             continue;
 
@@ -597,7 +584,6 @@ void OQueryTableView::AddTabWin(const OUString& _rComposedName, const OUString&
 
 void OQueryTableView::AddConnection(const OJoinExchangeData& jxdSource, const OJoinExchangeData& jxdDest)
 {
-    DBG_CHKTHIS(OQueryTableView,NULL);
     OQueryTableWindow* pSourceWin = static_cast< OQueryTableWindow*>(jxdSource.pListBox->GetTabWin());
     OQueryTableWindow* pDestWin = static_cast< OQueryTableWindow*>(jxdDest.pListBox->GetTabWin());
 
@@ -635,8 +621,8 @@ void OQueryTableView::AddConnection(const OJoinExchangeData& jxdSource, const OJ
 
         pNewConnectionData->AppendConnLine( aSourceFieldName,aDestFieldName );
 
-        OQueryTableConnection aNewConnection(this, aNewConnectionData);
-        NotifyTabConnection(aNewConnection);
+        ScopedVclPtrInstance< OQueryTableConnection > aNewConnection(this, aNewConnectionData);
+        NotifyTabConnection(*aNewConnection.get());
         // As usual with NotifyTabConnection, using a local variable is fine because a copy is made
     }
     else
@@ -651,16 +637,15 @@ void OQueryTableView::AddConnection(const OJoinExchangeData& jxdSource, const OJ
 
         pConn->GetData()->AppendConnLine( aSourceFieldName,aDestFieldName );
 
-        connectionModified(this,pConn,sal_False);
+        connectionModified(this,pConn,false);
     }
 }
 
 void OQueryTableView::ConnDoubleClicked(OTableConnection* pConnection)
 {
-    DBG_CHKTHIS(OQueryTableView,NULL);
-    if( openJoinDialog(this,pConnection->GetData(),sal_False) )
+    if( openJoinDialog(this,pConnection->GetData(),false) )
     {
-        connectionModified(this,pConnection,sal_False);
+        connectionModified(this,pConnection,false);
         SelectConn( pConnection );
     }
 }
@@ -668,23 +653,23 @@ void OQueryTableView::ConnDoubleClicked(OTableConnection* pConnection)
 void OQueryTableView::createNewConnection()
 {
     TTableConnectionData::value_type pData(new OQueryTableConnectionData());
-    if( openJoinDialog(this,pData,sal_True) )
+    if( openJoinDialog(this,pData,true) )
     {
-        OTableWindowMap* pMap = GetTabWinMap();
-        OQueryTableWindow* pSourceWin   = static_cast< OQueryTableWindow*>((*pMap)[pData->getReferencingTable()->GetWinName()]);
-        OQueryTableWindow* pDestWin     = static_cast< OQueryTableWindow*>((*pMap)[pData->getReferencedTable()->GetWinName()]);
+        OTableWindowMap& rMap = GetTabWinMap();
+        OQueryTableWindow* pSourceWin   = static_cast< OQueryTableWindow*>(rMap[pData->getReferencingTable()->GetWinName()].get());
+        OQueryTableWindow* pDestWin     = static_cast< OQueryTableWindow*>(rMap[pData->getReferencedTable()->GetWinName()].get());
         // first we have to look if the this connection already exists
         OTableConnection* pConn = GetTabConn(pSourceWin,pDestWin,true);
-        sal_Bool bNew = sal_True;
+        bool bNew = true;
         if ( pConn )
         {
             pConn->GetData()->CopyFrom( *pData );
-            bNew = sal_False;
+            bNew = false;
         }
         else
         {
             // create a new conenction and append it
-            OQueryTableConnection* pQConn = new OQueryTableConnection(this, pData);
+            VclPtrInstance<OQueryTableConnection> pQConn(this, pData);
             GetConnection(pQConn);
             pConn = pQConn;
         }
@@ -694,47 +679,43 @@ void OQueryTableView::createNewConnection()
     }
 }
 
-bool OQueryTableView::RemoveConnection( OTableConnection* _pConnection,sal_Bool /*_bDelete*/ )
+bool OQueryTableView::RemoveConnection( OTableConnection* _pConnection,bool /*_bDelete*/ )
 {
-    DBG_CHKTHIS(OQueryTableView,NULL);
 
     // we don't want that our connection will be deleted, we put it in the undo manager
-    bool bRet = OJoinTableView::RemoveConnection( _pConnection,sal_False);
+    bool bRet = OJoinTableView::RemoveConnection( _pConnection,false);
 
     // add undo action
     addUndoAction(  this,
                     new OQueryDelTabConnUndoAction(this),
                     static_cast< OQueryTableConnection*>(_pConnection),
-                    sal_True);
+                    true);
     return bRet;
 }
 
 void OQueryTableView::KeyInput( const KeyEvent& rEvt )
 {
-    DBG_CHKTHIS(OQueryTableView,NULL);
     OJoinTableView::KeyInput( rEvt );
 }
 
 OQueryTableWindow* OQueryTableView::FindTable(const OUString& rAliasName)
 {
-    DBG_CHKTHIS(OQueryTableView,NULL);
     OSL_ENSURE(!rAliasName.isEmpty(), "OQueryTableView::FindTable : the  AliasName should not be empty !");
         // (it is harmless but does not make sense and indicates that there is probably an error in the caller)
-    OTableWindowMap::const_iterator aIter = GetTabWinMap()->find(rAliasName);
-    if(aIter != GetTabWinMap()->end())
-        return static_cast<OQueryTableWindow*>(aIter->second);
+    OTableWindowMap::const_iterator aIter = GetTabWinMap().find(rAliasName);
+    if(aIter != GetTabWinMap().end())
+        return static_cast<OQueryTableWindow*>(aIter->second.get());
     return NULL;
 }
 
-sal_Bool OQueryTableView::FindTableFromField(const OUString& rFieldName, OTableFieldDescRef& rInfo, sal_uInt16& rCnt)
+bool OQueryTableView::FindTableFromField(const OUString& rFieldName, OTableFieldDescRef& rInfo, sal_uInt16& rCnt)
 {
-    DBG_CHKTHIS(OQueryTableView,NULL);
     rCnt = 0;
-    OTableWindowMap::const_iterator aIter = GetTabWinMap()->begin();
-    OTableWindowMap::const_iterator aEnd  = GetTabWinMap()->end();
+    OTableWindowMap::const_iterator aIter = GetTabWinMap().begin();
+    OTableWindowMap::const_iterator aEnd  = GetTabWinMap().end();
     for(;aIter != aEnd;++aIter)
     {
-        if(static_cast<OQueryTableWindow*>(aIter->second)->ExistsField(rFieldName, rInfo))
+        if(static_cast<OQueryTableWindow*>(aIter->second.get())->ExistsField(rFieldName, rInfo))
             ++rCnt;
     }
 
@@ -743,11 +724,10 @@ sal_Bool OQueryTableView::FindTableFromField(const OUString& rFieldName, OTableF
 
 bool OQueryTableView::ContainsTabWin(const OTableWindow& rTabWin)
 {
-    OTableWindowMap* pTabWins = GetTabWinMap();
-    OSL_ENSURE(pTabWins != NULL, "OQueryTableView::RemoveTabWin : Window should not be NULL !");
+    OTableWindowMap& rTabWins = GetTabWinMap();
 
-    OTableWindowMap::iterator aIter = pTabWins->begin();
-    OTableWindowMap::iterator aEnd  = pTabWins->end();
+    OTableWindowMap::iterator aIter = rTabWins.begin();
+    OTableWindowMap::iterator aEnd  = rTabWins.end();
 
     for ( ;aIter != aEnd ; ++aIter )
     {
@@ -762,7 +742,6 @@ bool OQueryTableView::ContainsTabWin(const OTableWindow& rTabWin)
 
 void OQueryTableView::RemoveTabWin(OTableWindow* pTabWin)
 {
-    DBG_CHKTHIS(OQueryTableView,NULL);
     OSL_ENSURE(pTabWin != NULL, "OQueryTableView::RemoveTabWin : Window should not be NULL !");
 
     if(pTabWin && ContainsTabWin(*pTabWin)) // #i122589# check if registered before deleting
@@ -803,7 +782,6 @@ void OQueryTableView::RemoveTabWin(OTableWindow* pTabWin)
 
 void OQueryTableView::EnsureVisible(const OTableWindow* pWin)
 {
-    DBG_CHKTHIS(OQueryTableView,NULL);
 
     Invalidate(INVALIDATE_NOCHILDREN);
     OJoinTableView::EnsureVisible(pWin);
@@ -811,7 +789,6 @@ void OQueryTableView::EnsureVisible(const OTableWindow* pWin)
 
 void OQueryTableView::GetConnection(OQueryTableConnection* pConn)
 {
-    DBG_CHKTHIS(OQueryTableView,NULL);
     // add to me and the document
 
     addConnection( pConn );
@@ -819,90 +796,83 @@ void OQueryTableView::GetConnection(OQueryTableConnection* pConn)
 
 void OQueryTableView::DropConnection(OQueryTableConnection* pConn)
 {
-    DBG_CHKTHIS(OQueryTableView,NULL);
     // Pay attention to the selection
     // remove from me and the document
-    RemoveConnection( pConn ,sal_False);
+    RemoveConnection( pConn ,false);
 }
 
 void OQueryTableView::HideTabWin( OQueryTableWindow* pTabWin, OQueryTabWinUndoAct* pUndoAction )
 {
-    DBG_CHKTHIS(OQueryTableView,NULL);
-    OTableWindowMap* pTabWins = GetTabWinMap();
-    OSL_ENSURE(pTabWins != NULL, "OQueryTableView::HideTabWin : have no TabWins !");
+    OTableWindowMap& rTabWins = GetTabWinMap();
 
-    if (pTabWin)
-    {
-        // Window
-        // save the position in its data
-        getDesignView()->SaveTabWinUIConfig(pTabWin);
-        // (I need to go via the parent, as only the parent knows the position of the scrollbars)
-        // and then out of the TabWins list and hide
-        OTableWindowMap::iterator aIter = pTabWins->begin();
-        OTableWindowMap::iterator aEnd  = pTabWins->end();
-        for ( ;aIter != aEnd ; ++aIter )
-            if ( aIter->second == pTabWin )
-            {
-                pTabWins->erase( aIter );
-                break;
-            }
-
-        pTabWin->Hide();    // do not destroy it, as it is still in the undo list!!
-
-        // the TabWin data must also be passed out of my responsibility
-        TTableWindowData* pTabWinDataList = m_pView->getController().getTableWindowData();
-        pTabWinDataList->erase( ::std::remove(pTabWinDataList->begin(),pTabWinDataList->end(),pTabWin->GetData()),pTabWinDataList->end());
-            // The data should not be destroyed as TabWin itself - which is still alive - needs them
-            // Either it goes back into my responsibility, (via ShowTabWin), then I add the data back,
-            // or the Undo-Action, which currently has full responsibility for the window
-            // and its data, gets destroyed and destroys both the window and its data
-
-        if (m_pLastFocusTabWin == pTabWin)
-            m_pLastFocusTabWin = NULL;
-
-        // collect connections belonging to the window and pass to UndoAction
-        sal_Int16 nCnt = 0;
-        const ::std::vector<OTableConnection*>* pTabConList = getTableConnections();
-        ::std::vector<OTableConnection*>::const_iterator aIter2 = pTabConList->begin();
-        for(;aIter2 != pTabConList->end();)// the end may change
+    // Window
+    // save the position in its data
+    getDesignView()->SaveTabWinUIConfig(pTabWin);
+    // (I need to go via the parent, as only the parent knows the position of the scrollbars)
+    // and then out of the TabWins list and hide
+    OTableWindowMap::iterator aIter = rTabWins.begin();
+    OTableWindowMap::iterator aEnd  = rTabWins.end();
+    for ( ;aIter != aEnd ; ++aIter )
+        if ( aIter->second == pTabWin )
         {
-            OQueryTableConnection* pTmpEntry = static_cast<OQueryTableConnection*>(*aIter2);
-            OSL_ENSURE(pTmpEntry,"OQueryTableConnection is null!");
-            if( pTmpEntry->GetAliasName(JTCS_FROM) == pTabWin->GetAliasName() ||
-                pTmpEntry->GetAliasName(JTCS_TO) == pTabWin->GetAliasName() )
-            {
-                // add to undo list
-                pUndoAction->InsertConnection(pTmpEntry);
-
-                // call base class because we append an undo action
-                // but this time we are in a undo action list
-                OJoinTableView::RemoveConnection(pTmpEntry,sal_False);
-                aIter2 = pTabConList->begin();
-                ++nCnt;
-            }
-            else
-                ++aIter2;
+            rTabWins.erase( aIter );
+            break;
         }
 
-        if (nCnt)
-            InvalidateConnections();
+    pTabWin->Hide();    // do not destroy it, as it is still in the undo list!!
 
-        m_pView->getController().InvalidateFeature(ID_BROWSER_ADDTABLE);
+    // the TabWin data must also be passed out of my responsibility
+    TTableWindowData& rTabWinDataList = m_pView->getController().getTableWindowData();
+    rTabWinDataList.erase( ::std::remove(rTabWinDataList.begin(), rTabWinDataList.end(), pTabWin->GetData()), rTabWinDataList.end());
+        // The data should not be destroyed as TabWin itself - which is still alive - needs them
+        // Either it goes back into my responsibility, (via ShowTabWin), then I add the data back,
+        // or the Undo-Action, which currently has full responsibility for the window
+        // and its data, gets destroyed and destroys both the window and its data
 
-        // inform the UndoAction that the window and connections belong to it
-        pUndoAction->SetOwnership(sal_True);
+    if (m_pLastFocusTabWin == pTabWin)
+        m_pLastFocusTabWin = NULL;
 
-        // by doing so, we have modified the document
-        m_pView->getController().setModified( sal_True );
-        m_pView->getController().InvalidateFeature(SID_BROWSER_CLEAR_QUERY);
+    // collect connections belonging to the window and pass to UndoAction
+    sal_Int16 nCnt = 0;
+    const auto& rTabConList = getTableConnections();
+    auto aIter2 = rTabConList.begin();
+    for(;aIter2 != rTabConList.end();)// the end may change
+    {
+        OQueryTableConnection* pTmpEntry = static_cast<OQueryTableConnection*>((*aIter2).get());
+        OSL_ENSURE(pTmpEntry,"OQueryTableConnection is null!");
+        if( pTmpEntry->GetAliasName(JTCS_FROM) == pTabWin->GetAliasName() ||
+            pTmpEntry->GetAliasName(JTCS_TO) == pTabWin->GetAliasName() )
+        {
+            // add to undo list
+            pUndoAction->InsertConnection(pTmpEntry);
+
+            // call base class because we append an undo action
+            // but this time we are in a undo action list
+            OJoinTableView::RemoveConnection(pTmpEntry,false);
+            aIter2 = rTabConList.begin();
+            ++nCnt;
+        }
+        else
+            ++aIter2;
     }
+
+    if (nCnt)
+        InvalidateConnections();
+
+    m_pView->getController().InvalidateFeature(ID_BROWSER_ADDTABLE);
+
+    // inform the UndoAction that the window and connections belong to it
+    pUndoAction->SetOwnership(true);
+
+    // by doing so, we have modified the document
+    m_pView->getController().setModified( sal_True );
+    m_pView->getController().InvalidateFeature(SID_BROWSER_CLEAR_QUERY);
 }
 
-sal_Bool OQueryTableView::ShowTabWin( OQueryTableWindow* pTabWin, OQueryTabWinUndoAct* pUndoAction,sal_Bool _bAppend )
+bool OQueryTableView::ShowTabWin( OQueryTableWindow* pTabWin, OQueryTabWinUndoAct* pUndoAction, bool _bAppend )
 {
-    DBG_CHKTHIS(OQueryTableView,NULL);
 
-    sal_Bool bSuccess = sal_False;
+    bool bSuccess = false;
 
     if (pTabWin)
     {
@@ -922,8 +892,8 @@ sal_Bool OQueryTableView::ShowTabWin( OQueryTableWindow* pTabWin, OQueryTabWinUn
 
             // Show the window and add to the list
             OUString sName = static_cast< OQueryTableWindowData*>(pData.get())->GetAliasName();
-            OSL_ENSURE(GetTabWinMap()->find(sName) == GetTabWinMap()->end(),"Alias name already in list!");
-            GetTabWinMap()->insert(OTableWindowMap::value_type(sName,pTabWin));
+            OSL_ENSURE(GetTabWinMap().find(sName) == GetTabWinMap().end(),"Alias name already in list!");
+            GetTabWinMap().insert(OTableWindowMap::value_type(sName,pTabWin));
 
             pTabWin->Show();
 
@@ -934,32 +904,29 @@ sal_Bool OQueryTableView::ShowTabWin( OQueryTableWindow* pTabWin, OQueryTabWinUn
             // GetEntryPos, and then in turn by the Connection, when its starting point to the window must be determined.
 
             // the Connections
-            ::std::vector<OTableConnection*>* pTableCon = pUndoAction->GetTabConnList();
-            ::std::vector<OTableConnection*>::iterator aIter = pTableCon->begin();
-            ::std::vector<OTableConnection*>::iterator aEnd = pTableCon->end();
+            auto rTableCon = pUndoAction->GetTabConnList();
+            for(auto conn : rTableCon)
+                addConnection(conn); // add all connections from the undo action
 
-            for(;aIter != aEnd;++aIter)
-                addConnection(*aIter); // add all connections from the undo action
-
-            pTableCon->clear();
+            rTableCon.clear();
 
             // and add the window's data to the list (of the document)
             if(_bAppend)
-                m_pView->getController().getTableWindowData()->push_back(pTabWin->GetData());
+                m_pView->getController().getTableWindowData().push_back(pTabWin->GetData());
 
             m_pView->getController().InvalidateFeature(ID_BROWSER_ADDTABLE);
 
             // and inform the UndoAction  that the window belongs to me
-            pUndoAction->SetOwnership(sal_False);
+            pUndoAction->SetOwnership(false);
 
-            bSuccess = sal_True;
+            bSuccess = true;
         }
         else
         {
             // Initialisation failed
             // (for example when the Connection to the database is not available at the moment)
             pTabWin->clearListBox();
-            delete pTabWin;
+            pTabWin->disposeOnce();
         }
     }
 
@@ -974,29 +941,21 @@ sal_Bool OQueryTableView::ShowTabWin( OQueryTableWindow* pTabWin, OQueryTabWinUn
 
 void OQueryTableView::InsertField(const OTableFieldDescRef& rInfo)
 {
-    DBG_CHKTHIS(OQueryTableView,NULL);
     OSL_ENSURE(getDesignView() != NULL, "OQueryTableView::InsertField : has no Parent !");
     static_cast<OQueryDesignView*>(getDesignView())->InsertField(rInfo);
 }
 
-sal_Bool OQueryTableView::ExistsAVisitedConn(const OQueryTableWindow* pFrom) const
+bool OQueryTableView::ExistsAVisitedConn(const OQueryTableWindow* pFrom) const
 {
-    DBG_CHKTHIS(OQueryTableView,NULL);
-    const ::std::vector<OTableConnection*>* pList = getTableConnections();
-    if (pList)
+    for(auto conn : getTableConnections())
     {
-        ::std::vector<OTableConnection*>::const_iterator aIter = pList->begin();
-        ::std::vector<OTableConnection*>::const_iterator aEnd = pList->end();
-        for(;aIter != aEnd;++aIter)
-        {
-            OQueryTableConnection* pTemp = static_cast<OQueryTableConnection*>(*aIter);
-            if (pTemp->IsVisited() &&
-                (pFrom == static_cast< OQueryTableWindow*>(pTemp->GetSourceWin()) || pFrom == static_cast< OQueryTableWindow*>(pTemp->GetDestWin())))
-                return pTemp != NULL;
-        }
+        OQueryTableConnection* pTemp = static_cast<OQueryTableConnection*>(conn.get());
+        if (pTemp->IsVisited() &&
+            (pFrom == static_cast< OQueryTableWindow*>(pTemp->GetSourceWin()) || pFrom == static_cast< OQueryTableWindow*>(pTemp->GetDestWin())))
+            return true;
     }
 
-    return sal_False;
+    return false;
 }
 
 void OQueryTableView::onNoColumns_throw()
