@@ -50,7 +50,7 @@ OSQLMessageDialog::OSQLMessageDialog(const Reference< XComponentContext >& _rxOR
     registerMayBeVoidProperty(PROPERTY_SQLEXCEPTION, PROPERTY_ID_SQLEXCEPTION, PropertyAttribute::TRANSIENT | PropertyAttribute::MAYBEVOID,
         &m_aException, ::cppu::UnoType<SQLException>::get());
     registerProperty( PROPERTY_HELP_URL, PROPERTY_ID_HELP_URL, PropertyAttribute::TRANSIENT,
-        &m_sHelpURL, ::getCppuType( &m_sHelpURL ) );
+        &m_sHelpURL, cppu::UnoType<decltype(m_sHelpURL)>::get() );
 }
 
 Sequence<sal_Int8> SAL_CALL OSQLMessageDialog::getImplementationId(  ) throw(RuntimeException, std::exception)
@@ -131,7 +131,7 @@ Reference<XPropertySetInfo>  SAL_CALL OSQLMessageDialog::getPropertySetInfo() th
 
 ::cppu::IPropertyArrayHelper& OSQLMessageDialog::getInfoHelper()
 {
-    return *const_cast<OSQLMessageDialog*>(this)->getArrayHelper();
+    return *getArrayHelper();
 }
 
 ::cppu::IPropertyArrayHelper* OSQLMessageDialog::createArrayHelper( ) const
@@ -141,13 +141,13 @@ Reference<XPropertySetInfo>  SAL_CALL OSQLMessageDialog::getPropertySetInfo() th
     return new ::cppu::OPropertyArrayHelper(aProps);
 }
 
-Dialog* OSQLMessageDialog::createDialog(vcl::Window* _pParent)
+VclPtr<Dialog> OSQLMessageDialog::createDialog(vcl::Window* _pParent)
 {
     if ( m_aException.hasValue() )
-        return new OSQLMessageBox( _pParent, SQLExceptionInfo( m_aException ), WB_OK | WB_DEF_OK, m_sHelpURL );
+        return VclPtr<OSQLMessageBox>::Create( _pParent, SQLExceptionInfo( m_aException ), WB_OK | WB_DEF_OK, m_sHelpURL );
 
     OSL_FAIL("OSQLMessageDialog::createDialog : You should use the SQLException property to specify the error to display!");
-    return new OSQLMessageBox(_pParent, SQLException());
+    return VclPtr<OSQLMessageBox>::Create(_pParent, SQLException());
 }
 
 }   // namespace dbaui
