@@ -33,7 +33,7 @@
 #include <drawinglayer/primitive2d/hiddengeometryprimitive2d.hxx>
 #include <drawinglayer/primitive2d/bitmapprimitive2d.hxx>
 
-//////////////////////////////////////////////////////////////////////////////
+
 
 namespace drawinglayer
 {
@@ -42,14 +42,16 @@ namespace drawinglayer
         HitTestProcessor2D::HitTestProcessor2D(const geometry::ViewInformation2D& rViewInformation,
             const basegfx::B2DPoint& rLogicHitPosition,
             double fLogicHitTolerance,
-            bool bHitTextOnly)
+            bool bHitTextOnly,
+            bool bTiledRendering)
         :   BaseProcessor2D(rViewInformation),
             maDiscreteHitPosition(),
             mfDiscreteHitTolerance(0.0),
             mbHit(false),
             mbHitToleranceUsed(false),
             mbUseInvisiblePrimitiveContent(true),
-            mbHitTextOnly(bHitTextOnly)
+            mbHitTextOnly(bHitTextOnly),
+            mbTiledRendering(bTiledRendering)
         {
             // init hit tolerance
             mfDiscreteHitTolerance = fLogicHitTolerance;
@@ -221,7 +223,7 @@ namespace drawinglayer
                 //
                 //     if(xExtracted2DSceneShadow.hasElements())
                 //     {
-                //         // proccess extracted 2D content
+                //         // process extracted 2D content
                 //         process(xExtracted2DSceneShadow);
                 //     }
                 // }
@@ -246,7 +248,7 @@ namespace drawinglayer
                 //
                 // if(xExtracted2DSceneGeometry.hasElements() || xExtracted2DSceneShadow.hasElements())
                 // {
-                //     // proccess extracted 2D content
+                //     // process extracted 2D content
                 //     process(xExtracted2DSceneGeometry);
                 //     process(xExtracted2DSceneShadow);
                 // }
@@ -289,7 +291,7 @@ namespace drawinglayer
                         getViewInformation2D().getExtendedInformationSequence());
                     updateViewInformation(aViewInformation2D);
 
-                    // proccess child content recursively
+                    // process child content recursively
                     process(rTransformCandidate.getChildren());
 
                     // restore transformations
@@ -483,7 +485,8 @@ namespace drawinglayer
                             const BitmapEx& rBitmapEx = rBitmapCandidate.getBitmapEx();
                             const Size& rSizePixel(rBitmapEx.GetSizePixel());
 
-                            if(rSizePixel.Width() && rSizePixel.Height())
+                            // When tiled rendering, don't bother with the pixel size of the candidate.
+                            if(rSizePixel.Width() && rSizePixel.Height() && !mbTiledRendering)
                             {
                                 basegfx::B2DHomMatrix aBackTransform(
                                     getViewInformation2D().getObjectToViewTransformation() *
@@ -541,7 +544,7 @@ namespace drawinglayer
                 case PRIMITIVE2D_ID_HIDDENGEOMETRYPRIMITIVE2D :
                 {
                     // HiddenGeometryPrimitive2D; the default decomposition would return an empty seqence,
-                    // so force this primitive to process it's children directly if the switch is set
+                    // so force this primitive to process its children directly if the switch is set
                     // (which is the default). Else, ignore invisible content
                     const primitive2d::HiddenGeometryPrimitive2D& rHiddenGeometry(static_cast< const primitive2d::HiddenGeometryPrimitive2D& >(rCandidate));
                        const primitive2d::Primitive2DSequence& rChildren = rHiddenGeometry.getChildren();
