@@ -19,7 +19,7 @@
 
 #include <com/sun/star/datatransfer/dnd/DNDConstants.hpp>
 #include <com/sun/star/datatransfer/XTransferable.hpp>
-
+#include <cppuhelper/supportsservice.hxx>
 #include <stdio.h>
 #include "target.hxx"
 #include "idroptarget.hxx"
@@ -27,13 +27,14 @@
 #include "targetdropcontext.hxx"
 #include "targetdragcontext.hxx"
 #include <rtl/ustring.h>
+#include <osl/thread.h>
+
 using namespace cppu;
 using namespace osl;
 using namespace com::sun::star::datatransfer;
 using namespace com::sun::star::datatransfer::dnd;
 using namespace com::sun::star::datatransfer::dnd::DNDConstants;
 
-
 #define WM_REGISTERDRAGDROP WM_USER + 1
 #define WM_REVOKEDRAGDROP WM_USER + 2
 extern Reference< XTransferable > g_XTransferable;
@@ -86,6 +87,7 @@ void SAL_CALL DropTarget::disposing()
     {
         CoLockObjectExternal( m_pDropTarget, FALSE, TRUE);
         m_pDropTarget->Release();
+        m_pDropTarget = nullptr;
     }
 
     if( m_oleThreadId)
@@ -134,7 +136,6 @@ void SAL_CALL DropTarget::initialize( const Sequence< Any >& aArguments )
             m_pDropTarget= new IDropTargetImpl( *static_cast<DropTarget*>( this) );
             m_pDropTarget->AddRef();
 
-
             // Obtain the id of the thread that created the window
             m_threadIdWindow= GetWindowThreadProcessId( m_hWnd, NULL);
             // The event is set by the thread that we will create momentarily.
@@ -171,6 +172,7 @@ void SAL_CALL DropTarget::initialize( const Sequence< Any >& aArguments )
                     // do clean up if drag and drop is not possible
                     CoLockObjectExternal( m_pDropTarget, FALSE, FALSE);
                     m_pDropTarget->Release();
+                    m_pDropTarget = nullptr;
                     m_hWnd= NULL;
                 }
             }
@@ -186,6 +188,8 @@ void SAL_CALL DropTarget::initialize( const Sequence< Any >& aArguments )
 // DoDragDrop. The thread also notifies all XSourceListener.
 DWORD WINAPI DndTargetOleSTAFunc(LPVOID pParams)
 {
+    osl_setThreadName("DropTarget DndTargetOleSTAFunc");
+
     HRESULT hr= OleInitialize( NULL);
     if( SUCCEEDED( hr) )
     {
@@ -217,6 +221,7 @@ DWORD WINAPI DndTargetOleSTAFunc(LPVOID pParams)
                         // do clean up if drag and drop is not possible
                         CoLockObjectExternal( pTarget->m_pDropTarget, FALSE, FALSE);
                         pTarget->m_pDropTarget->Release();
+                        pTarget->m_pDropTarget = nullptr;
                         pTarget->m_hWnd= NULL;
                     }
                 }
@@ -238,9 +243,6 @@ DWORD WINAPI DndTargetOleSTAFunc(LPVOID pParams)
     return 0;
 }
 
-
-
-
 // XServiceInfo
 OUString SAL_CALL DropTarget::getImplementationName(  ) throw (RuntimeException)
 {
@@ -249,9 +251,7 @@ OUString SAL_CALL DropTarget::getImplementationName(  ) throw (RuntimeException)
 // XServiceInfo
 sal_Bool SAL_CALL DropTarget::supportsService( const OUString& ServiceName ) throw (RuntimeException)
 {
-    if( ServiceName == DNDTARGET_SERVICE_NAME )
-        return sal_True;
-    return sal_False;
+    return cppu::supportsService(this, ServiceName);
 }
 
 Sequence< OUString > SAL_CALL DropTarget::getSupportedServiceNames(  ) throw (RuntimeException)
@@ -260,18 +260,17 @@ Sequence< OUString > SAL_CALL DropTarget::getSupportedServiceNames(  ) throw (Ru
     return Sequence<OUString>(names, 1);
 }
 
-
-// XDropTarget ----------------------------------------------------------------
+// XDropTarget
 void SAL_CALL DropTarget::addDropTargetListener( const Reference< XDropTargetListener >& dtl )
         throw(RuntimeException)
 {
-    rBHelper.addListener( ::getCppuType( &dtl ), dtl );
+    rBHelper.addListener( cppu::UnoType<decltype(dtl)>::get(), dtl );
 }
 
 void SAL_CALL DropTarget::removeDropTargetListener( const Reference< XDropTargetListener >& dtl )
         throw(RuntimeException)
 {
-    rBHelper.removeListener( ::getCppuType( &dtl ), dtl );
+    rBHelper.removeListener( cppu::UnoType<decltype(dtl)>::get(), dtl );
 }
 
 sal_Bool SAL_CALL DropTarget::isActive(  ) throw(RuntimeException)
@@ -279,14 +278,12 @@ sal_Bool SAL_CALL DropTarget::isActive(  ) throw(RuntimeException)
     return m_bActive; //m_bDropTargetRegistered;
 }
 
-
 void SAL_CALL DropTarget::setActive( sal_Bool _b ) throw(RuntimeException)
 {
     MutexGuard g(m_mutex);
     m_bActive= _b;
 }
 
-
 sal_Int8 SAL_CALL DropTarget::getDefaultActions(  ) throw(RuntimeException)
 {
     return m_nDefaultActions;
@@ -298,7 +295,6 @@ void SAL_CALL DropTarget::setDefaultActions( sal_Int8 actions ) throw(RuntimeExc
     m_nDefaultActions= actions;
 }
 
-
 HRESULT DropTarget::DragEnter( IDataObject *pDataObj,
                                     DWORD grfKeyState,
                                     POINTL pt,
@@ -351,7 +347,7 @@ HRESULT DropTarget::DragEnter( IDataObject *pDataObj,
             // by the listener (m_nCurrentDropAction) is allowed by the source. Only a allowed action is set
             // in pdwEffect. The listener notification is asynchron, that is we cannot expext that the listener
             // has already reacted to the notification.
-            // If there is more then one valid action which is the case when ALT or RIGHT MOUSE BUTTON is pressed
+            // If there is more than one valid action which is the case when ALT or RIGHT MOUSE BUTTON is pressed
             // then getDropEffect returns DROPEFFECT_MOVE which is the default value if no other modifier is pressed.
             // On drop the target should present the user a dialog from which the user may change the action.
             sal_Int8 allowedActions= dndOleDropEffectsToActions( *pdwEffect);
@@ -399,7 +395,7 @@ HRESULT DropTarget::DragOver( DWORD grfKeyState,
             // by the listener (m_nCurrentDropAction) is allowed by the source. Only a allowed action is set
             // in pdwEffect. The listener notification is asynchron, that is we cannot expext that the listener
             // has already reacted to the notification.
-            // If there is more then one valid action which is the case when ALT or RIGHT MOUSE BUTTON is pressed
+            // If there is more than one valid action which is the case when ALT or RIGHT MOUSE BUTTON is pressed
             // then getDropEffect returns DROPEFFECT_MOVE which is the default value if no other modifier is pressed.
             // On drop the target should present the user a dialog from which the user may change the action.
             sal_Int8 allowedActions= dndOleDropEffectsToActions( *pdwEffect);
@@ -417,7 +413,7 @@ HRESULT DropTarget::DragOver( DWORD grfKeyState,
     return S_OK;
 }
 
-HRESULT DropTarget::DragLeave( void)
+HRESULT DropTarget::DragLeave()
 {
 #if defined DBG_CONSOLE_OUT
     printf("\nDropTarget::DragLeave");
@@ -490,11 +486,9 @@ HRESULT DropTarget::Drop( IDataObject  * /*pDataObj*/,
     return S_OK;
 }
 
-
-
 void DropTarget::fire_drop( const DropTargetDropEvent& dte)
 {
-    OInterfaceContainerHelper* pContainer= rBHelper.getContainer( getCppuType( (Reference<XDropTargetListener>* )0 ) );
+    OInterfaceContainerHelper* pContainer= rBHelper.getContainer( cppu::UnoType<XDropTargetListener>::get());
     if( pContainer)
     {
         OInterfaceIteratorHelper iter( *pContainer);
@@ -508,7 +502,7 @@ void DropTarget::fire_drop( const DropTargetDropEvent& dte)
 
 void DropTarget::fire_dragEnter( const DropTargetDragEnterEvent& e )
 {
-    OInterfaceContainerHelper* pContainer= rBHelper.getContainer( getCppuType( (Reference<XDropTargetListener>* )0 ) );
+    OInterfaceContainerHelper* pContainer= rBHelper.getContainer( cppu::UnoType<XDropTargetListener>::get());
     if( pContainer)
     {
         OInterfaceIteratorHelper iter( *pContainer);
@@ -522,7 +516,7 @@ void DropTarget::fire_dragEnter( const DropTargetDragEnterEvent& e )
 
 void DropTarget::fire_dragExit( const DropTargetEvent& dte )
 {
-    OInterfaceContainerHelper* pContainer= rBHelper.getContainer( getCppuType( (Reference<XDropTargetListener>* )0 ) );
+    OInterfaceContainerHelper* pContainer= rBHelper.getContainer( cppu::UnoType<XDropTargetListener>::get());
 
     if( pContainer)
     {
@@ -537,7 +531,7 @@ void DropTarget::fire_dragExit( const DropTargetEvent& dte )
 
 void DropTarget::fire_dragOver( const DropTargetDragEvent& dtde )
 {
-    OInterfaceContainerHelper* pContainer= rBHelper.getContainer( getCppuType( (Reference<XDropTargetListener>* )0 ) );
+    OInterfaceContainerHelper* pContainer= rBHelper.getContainer( cppu::UnoType<XDropTargetListener>::get());
     if( pContainer)
     {
         OInterfaceIteratorHelper iter( *pContainer );
@@ -551,7 +545,7 @@ void DropTarget::fire_dragOver( const DropTargetDragEvent& dtde )
 
 void DropTarget::fire_dropActionChanged( const DropTargetDragEvent& dtde )
 {
-    OInterfaceContainerHelper* pContainer= rBHelper.getContainer( getCppuType( (Reference<XDropTargetListener>* )0 ) );
+    OInterfaceContainerHelper* pContainer= rBHelper.getContainer( cppu::UnoType<XDropTargetListener>::get());
     if( pContainer)
     {
         OInterfaceIteratorHelper iter( *pContainer);
@@ -563,7 +557,7 @@ void DropTarget::fire_dropActionChanged( const DropTargetDragEvent& dtde )
     }
 }
 
-// Non - interface functions ============================================================
+// Non - interface functions
 // DropTarget fires events to XDropTargetListeners. The event object contains an
 // XDropTargetDropContext implementaion. When the listener calls on that interface
 // then the calls are delegated from DropContext (XDropTargetDropContext) to these
@@ -597,7 +591,7 @@ void DropTarget::_dropComplete(sal_Bool success, const Reference<XDropTargetDrop
         m_bDropComplete= success;
     }
 }
-// --------------------------------------------------------------------------------------
+
 // DropTarget fires events to XDropTargetListeners. The event object can contains an
 // XDropTargetDragContext implementaion. When the listener calls on that interface
 // then the calls are delegated from DragContext (XDropTargetDragContext) to these
@@ -620,11 +614,7 @@ void DropTarget::_rejectDrag( const Reference<XDropTargetDragContext>& context)
     }
 }
 
-
-//--------------------------------------------------------------------------------------
-
-
-// This function determines the action dependend on the pressed
+// This function determines the action dependent on the pressed
 // key modifiers ( CTRL, SHIFT, ALT, Right Mouse Button). The result
 // is then checked against the allowed actions which can be set through
 // XDropTarget::setDefaultActions. Only those values which are also
@@ -637,5 +627,4 @@ inline sal_Int8 DropTarget::getFilteredActions( DWORD grfKeyState, DWORD dwEffec
     return actions &  m_nDefaultActions;
 }
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
