@@ -22,6 +22,7 @@
 #include <vcl/dialog.hxx>
 #include <vcl/msgbox.hxx>
 #include <vcl/svapp.hxx>
+#include <vcl/settings.hxx>
 #include <com/sun/star/linguistic2/LanguageGuessing.hpp>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <comphelper/processfactory.hxx>
@@ -38,6 +39,7 @@
 #include <editeng/scriptspaceitem.hxx>
 #include <editeng/numdef.hxx>
 #include <svl/itempool.hxx>
+#include <svl/grabbagitem.hxx>
 #include <vcl/virdev.hxx>
 
 #include <editeng/autokernitem.hxx>
@@ -87,9 +89,9 @@ GlobalEditData::GlobalEditData()
 GlobalEditData::~GlobalEditData()
 {
     // Destroy DefItems...
-    // Or simply keep them, since at end of excecution?!
+    // Or simply keep them, since at end of execution?!
     if ( ppDefItems )
-        SfxItemPool::ReleaseDefaults( ppDefItems, EDITITEMCOUNT, sal_True );
+        SfxItemPool::ReleaseDefaults( ppDefItems, EDITITEMCOUNT, true );
 }
 
 SfxPoolItem** GlobalEditData::GetDefItems()
@@ -99,17 +101,17 @@ SfxPoolItem** GlobalEditData::GetDefItems()
         ppDefItems = new SfxPoolItem*[EDITITEMCOUNT];
 
         // Paragraph attributes:
-        SvxNumRule aDefaultNumRule( NUM_BULLET_REL_SIZE|NUM_BULLET_COLOR|NUM_CHAR_TEXT_DISTANCE,
-                                    SVX_MAX_NUM, sal_False );
+        SvxNumRule aDefaultNumRule( SvxNumRuleFlags::BULLET_REL_SIZE | SvxNumRuleFlags::BULLET_COLOR | SvxNumRuleFlags::CHAR_TEXT_DISTANCE,
+                                    SVX_MAX_NUM, false );
 
         ppDefItems[0]  = new SvxFrameDirectionItem( FRMDIR_HORI_LEFT_TOP, EE_PARA_WRITINGDIR );
         ppDefItems[1]  = new SvXMLAttrContainerItem( EE_PARA_XMLATTRIBS );
-        ppDefItems[2]  = new SfxBoolItem( EE_PARA_HANGINGPUNCTUATION, sal_False );
-        ppDefItems[3]  = new SfxBoolItem( EE_PARA_FORBIDDENRULES, sal_True );
-        ppDefItems[4]  = new SvxScriptSpaceItem( sal_True, EE_PARA_ASIANCJKSPACING );
+        ppDefItems[2]  = new SfxBoolItem( EE_PARA_HANGINGPUNCTUATION, false );
+        ppDefItems[3]  = new SfxBoolItem( EE_PARA_FORBIDDENRULES, true );
+        ppDefItems[4]  = new SvxScriptSpaceItem( true, EE_PARA_ASIANCJKSPACING );
         ppDefItems[5]  = new SvxNumBulletItem( aDefaultNumRule, EE_PARA_NUMBULLET );
-        ppDefItems[6]  = new SfxBoolItem( EE_PARA_HYPHENATE, sal_False );
-        ppDefItems[7]  = new SfxBoolItem( EE_PARA_BULLETSTATE, sal_True );
+        ppDefItems[6]  = new SfxBoolItem( EE_PARA_HYPHENATE, false );
+        ppDefItems[7]  = new SfxBoolItem( EE_PARA_BULLETSTATE, true );
         ppDefItems[8]  = new SvxLRSpaceItem( EE_PARA_OUTLLRSPACE );
         ppDefItems[9]  = new SfxInt16Item( EE_PARA_OUTLLEVEL, -1 );
         ppDefItems[10] = new SvxBulletItem( EE_PARA_BULLET );
@@ -130,12 +132,12 @@ SfxPoolItem** GlobalEditData::GetDefItems()
         ppDefItems[23] = new SvxUnderlineItem( UNDERLINE_NONE, EE_CHAR_UNDERLINE );
         ppDefItems[24] = new SvxCrossedOutItem( STRIKEOUT_NONE, EE_CHAR_STRIKEOUT );
         ppDefItems[25] = new SvxPostureItem( ITALIC_NONE, EE_CHAR_ITALIC );
-        ppDefItems[26] = new SvxContourItem( sal_False, EE_CHAR_OUTLINE );
-        ppDefItems[27] = new SvxShadowedItem( sal_False, EE_CHAR_SHADOW );
+        ppDefItems[26] = new SvxContourItem( false, EE_CHAR_OUTLINE );
+        ppDefItems[27] = new SvxShadowedItem( false, EE_CHAR_SHADOW );
         ppDefItems[28] = new SvxEscapementItem( 0, 100, EE_CHAR_ESCAPEMENT );
-        ppDefItems[29] = new SvxAutoKernItem( sal_False, EE_CHAR_PAIRKERNING );
+        ppDefItems[29] = new SvxAutoKernItem( false, EE_CHAR_PAIRKERNING );
         ppDefItems[30] = new SvxKerningItem( 0, EE_CHAR_KERNING );
-        ppDefItems[31] = new SvxWordLineModeItem( sal_False, EE_CHAR_WLM );
+        ppDefItems[31] = new SvxWordLineModeItem( false, EE_CHAR_WLM );
         ppDefItems[32] = new SvxLanguageItem( LANGUAGE_DONTKNOW, EE_CHAR_LANGUAGE );
         ppDefItems[33] = new SvxLanguageItem( LANGUAGE_DONTKNOW, EE_CHAR_LANGUAGE_CJK );
         ppDefItems[34] = new SvxLanguageItem( LANGUAGE_DONTKNOW, EE_CHAR_LANGUAGE_CTL );
@@ -153,19 +155,20 @@ SfxPoolItem** GlobalEditData::GetDefItems()
         ppDefItems[46] = new SvXMLAttrContainerItem( EE_CHAR_XMLATTRIBS );
         ppDefItems[47] = new SvxOverlineItem( UNDERLINE_NONE, EE_CHAR_OVERLINE );
         ppDefItems[48] = new SvxCaseMapItem( SVX_CASEMAP_NOT_MAPPED, EE_CHAR_CASEMAP );
-
+        ppDefItems[49] = new SfxGrabBagItem( EE_CHAR_GRABBAG );
+        ppDefItems[50] = new SvxBackgroundColorItem( Color( COL_AUTO ), EE_CHAR_BKGCOLOR );
         // Features
-        ppDefItems[49] = new SfxVoidItem( EE_FEATURE_TAB );
-        ppDefItems[50] = new SfxVoidItem( EE_FEATURE_LINEBR );
-        ppDefItems[51] = new SvxCharSetColorItem( Color( COL_RED ), RTL_TEXTENCODING_DONTKNOW, EE_FEATURE_NOTCONV );
-        ppDefItems[52] = new SvxFieldItem( SvxFieldData(), EE_FEATURE_FIELD );
+        ppDefItems[51] = new SfxVoidItem( EE_FEATURE_TAB );
+        ppDefItems[52] = new SfxVoidItem( EE_FEATURE_LINEBR );
+        ppDefItems[53] = new SvxCharSetColorItem( Color( COL_RED ), RTL_TEXTENCODING_DONTKNOW, EE_FEATURE_NOTCONV );
+        ppDefItems[54] = new SvxFieldItem( SvxFieldData(), EE_FEATURE_FIELD );
 
-        DBG_ASSERT( EDITITEMCOUNT == 53, "ITEMCOUNT geaendert, DefItems nicht angepasst!" );
+        assert(EDITITEMCOUNT == 55 && "ITEMCOUNT changed, adjust DefItems!");
 
         // Init DefFonts:
-        GetDefaultFonts( *(SvxFontItem*)ppDefItems[EE_CHAR_FONTINFO - EE_ITEMS_START],
-                         *(SvxFontItem*)ppDefItems[EE_CHAR_FONTINFO_CJK - EE_ITEMS_START],
-                         *(SvxFontItem*)ppDefItems[EE_CHAR_FONTINFO_CTL - EE_ITEMS_START] );
+        GetDefaultFonts( *static_cast<SvxFontItem*>(ppDefItems[EE_CHAR_FONTINFO - EE_ITEMS_START]),
+                         *static_cast<SvxFontItem*>(ppDefItems[EE_CHAR_FONTINFO_CJK - EE_ITEMS_START]),
+                         *static_cast<SvxFontItem*>(ppDefItems[EE_CHAR_FONTINFO_CTL - EE_ITEMS_START]) );
     }
 
     return ppDefItems;
@@ -189,15 +192,14 @@ uno::Reference< linguistic2::XLanguageGuessing > GlobalEditData::GetLanguageGues
     return xLanguageGuesser;
 }
 
-EditResId::EditResId( sal_uInt16 nId ):
-    ResId( nId, *EE_DLL().GetResMgr() )
+EditResId::EditResId(sal_uInt16 nId)
+    : ResId(nId, *EditDLL::GetResMgr())
 {
 }
 
 EditDLL::EditDLL()
 {
     pGlobalData = new GlobalEditData;
-    pResMgr = ResMgr::CreateResMgr( "editeng", Application::GetSettings().GetUILanguageTag() );
 }
 
 EditDLL::~EditDLL()
@@ -205,4 +207,13 @@ EditDLL::~EditDLL()
     delete pGlobalData;
 }
 
+static ResMgr* pResMgr=0;
+
+ResMgr* EditDLL::GetResMgr()
+{
+    if (!pResMgr)
+        pResMgr = ResMgr::CreateResMgr("editeng", Application::GetSettings().GetUILanguageTag());
+    return pResMgr;
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
