@@ -23,6 +23,7 @@
 #include "componentmodule.hxx"
 #include "datasourcehandling.hxx"
 
+#include <boost/noncopyable.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/container/XNameAccess.hpp>
 #include <com/sun/star/frame/XStorable.hpp>
@@ -46,10 +47,10 @@
 #include <unotools/sharedunocomponent.hxx>
 #include <vcl/stdtext.hxx>
 
-//.........................................................................
+
 namespace abp
 {
-//.........................................................................
+
 
     using namespace ::utl;
     using namespace ::comphelper;
@@ -63,38 +64,38 @@ namespace abp
     using namespace ::com::sun::star::container;
     using namespace ::com::sun::star::frame;
 
-    //=====================================================================
+
     struct PackageAccessControl { };
 
-    //=====================================================================
-    //---------------------------------------------------------------------
-    static Reference< XDatabaseContext > lcl_getDataSourceContext( const Reference< XComponentContext >& _rxContext ) SAL_THROW (( Exception ))
+
+
+    static Reference< XDatabaseContext > lcl_getDataSourceContext( const Reference< XComponentContext >& _rxContext )
     {
         Reference<XDatabaseContext> xContext = DatabaseContext::create(_rxContext);
         return xContext;
     }
 
-    //---------------------------------------------------------------------
+
     /// creates a new data source and inserts it into the context
     static void lcl_implCreateAndInsert(
         const Reference< XComponentContext >& _rxContext, const OUString& _rName,
-        Reference< XPropertySet >& /* [out] */ _rxNewDataSource ) SAL_THROW (( ::com::sun::star::uno::Exception ))
+        Reference< XPropertySet >& /* [out] */ _rxNewDataSource )
     {
-        //.............................................................
+
         // get the data source context
         Reference< XDatabaseContext > xContext = lcl_getDataSourceContext( _rxContext );
 
         DBG_ASSERT( !xContext->hasByName( _rName ), "lcl_implCreateAndInsert: name already used!" );
         (void)_rName;
 
-        //.............................................................
+
         // create a new data source
         Reference< XPropertySet > xNewDataSource;
         if (xContext.is())
             xNewDataSource = Reference< XPropertySet >( xContext->createInstance(), UNO_QUERY );
         DBG_ASSERT( xNewDataSource.is(), "lcl_implCreateAndInsert: could not create a new data source!" );
 
-        //.............................................................
+
         // insert the data source into the context
         DBG_ASSERT( xContext.is(), "lcl_implCreateAndInsert: missing an interface on the context (XNamingService)!" );
         if (xContext.is())
@@ -104,11 +105,11 @@ namespace abp
         }
     }
 
-    //---------------------------------------------------------------------
-    /// creates and inserts a data source, and sets it's URL property to the string given
+
+    /// creates and inserts a data source, and sets its URL property to the string given
     static ODataSource lcl_implCreateAndSetURL(
         const Reference< XComponentContext >& _rxORB, const OUString& _rName,
-        const sal_Char* _pInitialAsciiURL ) SAL_THROW (( ))
+        const sal_Char* _pInitialAsciiURL )
     {
         ODataSource aReturn( _rxORB );
         try
@@ -117,7 +118,7 @@ namespace abp
             Reference< XPropertySet > xNewDataSource;
             lcl_implCreateAndInsert( _rxORB, _rName, xNewDataSource );
 
-            //.............................................................
+
             // set the URL property
             if (xNewDataSource.is())
             {
@@ -136,10 +137,10 @@ namespace abp
 
         return aReturn;
     }
-    //---------------------------------------------------------------------
+
     void lcl_registerDataSource(
         const Reference< XComponentContext >& _rxORB, const OUString& _sName,
-        const OUString& _sURL ) SAL_THROW (( ::com::sun::star::uno::Exception ))
+        const OUString& _sURL )
     {
         OSL_ENSURE( !_sName.isEmpty(), "lcl_registerDataSource: invalid name!" );
         OSL_ENSURE( !_sURL.isEmpty(), "lcl_registerDataSource: invalid URL!" );
@@ -157,27 +158,15 @@ namespace abp
         }
     }
 
-    //=====================================================================
-    //= ODataSourceContextImpl
-    //=====================================================================
-    struct ODataSourceContextImpl
+    struct ODataSourceContextImpl: private boost::noncopyable
     {
         Reference< XComponentContext >      xORB;
         Reference< XNameAccess >            xContext;           /// the UNO data source context
         StringBag                           aDataSourceNames;   /// for quicker name checks (without the UNO overhead)
 
         ODataSourceContextImpl( const Reference< XComponentContext >& _rxORB ) : xORB( _rxORB ) { }
-        ODataSourceContextImpl( const ODataSourceContextImpl& _rSource )
-            :xORB       ( _rSource.xORB )
-            ,xContext   ( _rSource.xContext )
-        {
-        }
     };
 
-    //=====================================================================
-    //= ODataSourceContext
-    //=====================================================================
-    //---------------------------------------------------------------------
     ODataSourceContext::ODataSourceContext(const Reference< XComponentContext >& _rxORB)
         :m_pImpl( new ODataSourceContextImpl( _rxORB ) )
     {
@@ -209,17 +198,17 @@ namespace abp
         delete(m_pImpl);
     }
 
-    //---------------------------------------------------------------------
+
     OUString& ODataSourceContext::disambiguate(OUString& _rDataSourceName)
     {
         OUString sCheck( _rDataSourceName );
-        ConstStringBagIterator aPos = m_pImpl->aDataSourceNames.find( sCheck );
+        StringBag::const_iterator aPos = m_pImpl->aDataSourceNames.find( sCheck );
 
-        sal_Int32 nPostFix = 1;
-        while ( ( m_pImpl->aDataSourceNames.end() != aPos ) && ( nPostFix < 65535 ) )
+        sal_Int32 nPostfix = 1;
+        while ( ( m_pImpl->aDataSourceNames.end() != aPos ) && ( nPostfix < 65535 ) )
         {   // there already is a data source with this name
             sCheck = _rDataSourceName;
-            sCheck += OUString::number( nPostFix++ );
+            sCheck += OUString::number( nPostfix++ );
 
             aPos = m_pImpl->aDataSourceNames.find( sCheck );
         }
@@ -228,79 +217,76 @@ namespace abp
         return _rDataSourceName;
     }
 
-    //---------------------------------------------------------------------
-    void ODataSourceContext::getDataSourceNames( StringBag& _rNames ) const SAL_THROW (( ))
+
+    void ODataSourceContext::getDataSourceNames( StringBag& _rNames ) const
     {
         _rNames = m_pImpl->aDataSourceNames;
     }
 
-    //---------------------------------------------------------------------
-    ODataSource ODataSourceContext::createNewLDAP( const OUString& _rName) SAL_THROW (( ))
+
+    ODataSource ODataSourceContext::createNewLDAP( const OUString& _rName)
     {
         return lcl_implCreateAndSetURL( m_pImpl->xORB, _rName, "sdbc:address:ldap:" );
     }
 
-    //---------------------------------------------------------------------
-    ODataSource ODataSourceContext::createNewMORK( const OUString& _rName) SAL_THROW (( ))
+
+    ODataSource ODataSourceContext::createNewMORK( const OUString& _rName)
     {
         return lcl_implCreateAndSetURL( m_pImpl->xORB, _rName, "sdbc:address:mozilla" );
     }
 
-    //---------------------------------------------------------------------
-    ODataSource ODataSourceContext::createNewThunderbird( const OUString& _rName ) SAL_THROW (( ))
+
+    ODataSource ODataSourceContext::createNewThunderbird( const OUString& _rName )
     {
         return lcl_implCreateAndSetURL( m_pImpl->xORB, _rName, "sdbc:address:thunderbird" );
     }
 
-    //---------------------------------------------------------------------
-    ODataSource ODataSourceContext::createNewEvolutionLdap( const OUString& _rName) SAL_THROW (( ))
+
+    ODataSource ODataSourceContext::createNewEvolutionLdap( const OUString& _rName)
     {
         return lcl_implCreateAndSetURL( m_pImpl->xORB, _rName, "sdbc:address:evolution:ldap" );
     }
-    //---------------------------------------------------------------------
-    ODataSource ODataSourceContext::createNewEvolutionGroupwise( const OUString& _rName) SAL_THROW (( ))
+
+    ODataSource ODataSourceContext::createNewEvolutionGroupwise( const OUString& _rName)
     {
         return lcl_implCreateAndSetURL( m_pImpl->xORB, _rName, "sdbc:address:evolution:groupwise" );
     }
-    //---------------------------------------------------------------------
-    ODataSource ODataSourceContext::createNewEvolution( const OUString& _rName) SAL_THROW (( ))
+
+    ODataSource ODataSourceContext::createNewEvolution( const OUString& _rName)
     {
         return lcl_implCreateAndSetURL( m_pImpl->xORB, _rName, "sdbc:address:evolution:local" );
     }
 
-    //---------------------------------------------------------------------
-    ODataSource ODataSourceContext::createNewKab( const OUString& _rName) SAL_THROW (( ))
+
+    ODataSource ODataSourceContext::createNewKab( const OUString& _rName)
     {
         return lcl_implCreateAndSetURL( m_pImpl->xORB, _rName, "sdbc:address:kab" );
     }
 
-    //---------------------------------------------------------------------
-    ODataSource ODataSourceContext::createNewMacab( const OUString& _rName) SAL_THROW (( ))
+
+    ODataSource ODataSourceContext::createNewMacab( const OUString& _rName)
     {
         return lcl_implCreateAndSetURL( m_pImpl->xORB, _rName, "sdbc:address:macab" );
     }
 
-    //---------------------------------------------------------------------
-    ODataSource ODataSourceContext::createNewOutlook( const OUString& _rName) SAL_THROW (( ))
+
+    ODataSource ODataSourceContext::createNewOutlook( const OUString& _rName)
     {
         return lcl_implCreateAndSetURL( m_pImpl->xORB, _rName, "sdbc:address:outlook" );
     }
 
-    //---------------------------------------------------------------------
-    ODataSource ODataSourceContext::createNewOE( const OUString& _rName) SAL_THROW (( ))
+
+    ODataSource ODataSourceContext::createNewOE( const OUString& _rName)
     {
         return lcl_implCreateAndSetURL( m_pImpl->xORB, _rName, "sdbc:address:outlookexp" );
     }
 
-    //---------------------------------------------------------------------
-    ODataSource ODataSourceContext::createNewDBase( const OUString& _rName) SAL_THROW (( ))
+
+    ODataSource ODataSourceContext::createNewDBase( const OUString& _rName)
     {
         return lcl_implCreateAndSetURL( m_pImpl->xORB, _rName, "sdbc:dbase:" );
     }
 
-    //=====================================================================
-    //= ODataSourceImpl
-    //=====================================================================
     struct ODataSourceImpl
     {
     public:
@@ -310,18 +296,18 @@ namespace abp
                                                 xConnection;
         StringBag                               aTables;            // the cached table names
         OUString                         sName;
-        sal_Bool                                bTablesUpToDate;    // table name cache up-to-date?
+        bool                                bTablesUpToDate;    // table name cache up-to-date?
 
         ODataSourceImpl( const Reference< XComponentContext >& _rxORB )
             :xORB( _rxORB )
-            ,bTablesUpToDate( sal_False )
+            ,bTablesUpToDate( false )
         {
         }
 
         ODataSourceImpl( const ODataSourceImpl& _rSource );
     };
 
-    //---------------------------------------------------------------------
+
     ODataSourceImpl::ODataSourceImpl( const ODataSourceImpl& _rSource )
         :xORB( _rSource.xORB )
         ,xDataSource( _rSource.xDataSource )
@@ -332,17 +318,13 @@ namespace abp
     {
     }
 
-    //=====================================================================
-    //= ODataSource
-    //=====================================================================
-    //---------------------------------------------------------------------
     ODataSource::ODataSource( const ODataSource& _rSource )
         :m_pImpl( NULL )
     {
         *this = _rSource;
     }
 
-    //---------------------------------------------------------------------
+
     ODataSource& ODataSource::operator=( const ODataSource& _rSource )
     {
         if( this != &_rSource )
@@ -353,20 +335,20 @@ namespace abp
         return *this;
     }
 
-    //---------------------------------------------------------------------
+
     ODataSource::ODataSource( const Reference< XComponentContext >& _rxORB )
         :m_pImpl(new ODataSourceImpl(_rxORB))
     {
     }
 
-    //---------------------------------------------------------------------
+
     ODataSource::~ODataSource( )
     {
         delete m_pImpl;
     }
 
-    //---------------------------------------------------------------------
-    void ODataSource::store() SAL_THROW (( ))
+
+    void ODataSource::store()
     {
         if (!isValid())
             // nothing to do
@@ -376,7 +358,7 @@ namespace abp
             Reference< XDocumentDataSource > xDocAccess( m_pImpl->xDataSource, UNO_QUERY );
             Reference< XStorable > xStorable;
             if ( xDocAccess.is() )
-                xStorable = xStorable.query( xDocAccess->getDatabaseDocument() );
+                xStorable.set(xDocAccess->getDatabaseDocument(), css::uno::UNO_QUERY);
             OSL_ENSURE( xStorable.is(),"DataSource is no XStorable!" );
             if ( xStorable.is() )
                 xStorable->storeAsURL(m_pImpl->sName,Sequence<PropertyValue>());
@@ -386,8 +368,8 @@ namespace abp
             OSL_FAIL( "ODataSource::registerDataSource: caught an exception while creating the data source!" );
         }
     }
-    //---------------------------------------------------------------------
-    void ODataSource::registerDataSource( const OUString& _sRegisteredDataSourceName) SAL_THROW (( ))
+
+    void ODataSource::registerDataSource( const OUString& _sRegisteredDataSourceName)
     {
         if (!isValid())
             // nothing to do
@@ -404,7 +386,7 @@ namespace abp
         }
     }
 
-    //---------------------------------------------------------------------
+
     void ODataSource::setDataSource( const Reference< XPropertySet >& _rxDS,const OUString& _sName, PackageAccessControl )
     {
         if (m_pImpl->xDataSource.get() == _rxDS.get())
@@ -418,8 +400,8 @@ namespace abp
         m_pImpl->xDataSource = _rxDS;
     }
 
-    //---------------------------------------------------------------------
-    void ODataSource::remove() SAL_THROW (( ))
+
+    void ODataSource::remove()
     {
         if (!isValid())
             // nothing to do
@@ -436,26 +418,26 @@ namespace abp
         }
     }
 
-    //---------------------------------------------------------------------
-    sal_Bool ODataSource::rename( const OUString& _rName ) SAL_THROW (( ))
+
+    bool ODataSource::rename( const OUString& _rName )
     {
         if (!isValid())
             // nothing to do
-            return sal_False;
+            return false;
 
         m_pImpl->sName = _rName;
-        return sal_True;
+        return true;
     }
 
-    //---------------------------------------------------------------------
-    OUString ODataSource::getName() const SAL_THROW (( ))
+
+    OUString ODataSource::getName() const
     {
         if ( !isValid() )
             return OUString();
         return m_pImpl->sName;
     }
 
-    //---------------------------------------------------------------------
+
     bool ODataSource::hasTable( const OUString& _rTableName ) const
     {
         if ( !isConnected() )
@@ -465,8 +447,8 @@ namespace abp
         return aTables.find( _rTableName ) != aTables.end();
     }
 
-    //---------------------------------------------------------------------
-    const StringBag& ODataSource::getTableNames() const SAL_THROW (( ))
+
+    const StringBag& ODataSource::getTableNames() const
     {
         m_pImpl->aTables.clear();
         if ( !isConnected() )
@@ -501,18 +483,18 @@ namespace abp
         }
 
         // now the table cache is up-to-date
-        m_pImpl->bTablesUpToDate = sal_True;
+        m_pImpl->bTablesUpToDate = true;
         return m_pImpl->aTables;
     }
 
-    //---------------------------------------------------------------------
-    sal_Bool ODataSource::connect( Window* _pMessageParent ) SAL_THROW (( ))
+
+    bool ODataSource::connect( vcl::Window* _pMessageParent )
     {
         if ( isConnected( ) )
             // nothing to do
-            return sal_True;
+            return true;
+
 
-        // ................................................................
         // create the interaction handler (needed for authentication and error handling)
         Reference< XInteractionHandler > xInteractions;
         try
@@ -525,17 +507,17 @@ namespace abp
         {
         }
 
-        // ................................................................
+
         // failure to create the interaction handler is a serious issue ...
         if (!xInteractions.is())
         {
             OUString s_sInteractionHandlerServiceName("com.sun.star.task.InteractionHandler");
             if ( _pMessageParent )
-                ShowServiceNotAvailableError( _pMessageParent, s_sInteractionHandlerServiceName, sal_True );
-            return sal_False;
+                ShowServiceNotAvailableError( _pMessageParent, s_sInteractionHandlerServiceName, true );
+            return false;
         }
 
-        // ................................................................
+
         // open the connection
         Any aError;
         Reference< XConnection > xConnection;
@@ -554,7 +536,7 @@ namespace abp
             OSL_FAIL( "ODataSource::connect: caught a generic exception!" );
         }
 
-        // ................................................................
+
         // handle errors
         if ( aError.hasValue() && _pMessageParent )
         {
@@ -585,44 +567,44 @@ namespace abp
         }
 
         if ( !xConnection.is() )
-            return sal_False;
+            return false;
+
 
-        // ................................................................
         // success
         m_pImpl->xConnection.reset( xConnection );
         m_pImpl->aTables.clear();
-        m_pImpl->bTablesUpToDate = sal_False;
+        m_pImpl->bTablesUpToDate = false;
 
-        return sal_True;
+        return true;
     }
 
-    //---------------------------------------------------------------------
-    void ODataSource::disconnect( ) SAL_THROW (( ))
+
+    void ODataSource::disconnect( )
     {
         m_pImpl->xConnection.clear();
         m_pImpl->aTables.clear();
-        m_pImpl->bTablesUpToDate = sal_False;
+        m_pImpl->bTablesUpToDate = false;
     }
 
-    //---------------------------------------------------------------------
-    sal_Bool ODataSource::isConnected( ) const SAL_THROW (( ))
+
+    bool ODataSource::isConnected( ) const
     {
         return m_pImpl->xConnection.is();
     }
 
-    //---------------------------------------------------------------------
-    sal_Bool ODataSource::isValid() const SAL_THROW (( ))
+
+    bool ODataSource::isValid() const
     {
         return m_pImpl && m_pImpl->xDataSource.is();
     }
-    //---------------------------------------------------------------------
-    Reference< XPropertySet > ODataSource::getDataSource() const SAL_THROW (( ))
+
+    Reference< XPropertySet > ODataSource::getDataSource() const
     {
         return m_pImpl ? m_pImpl->xDataSource : Reference< XPropertySet >();
     }
 
-//.........................................................................
+
 }   // namespace abp
-//.........................................................................
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
