@@ -19,6 +19,7 @@
 
 
 #include "eventhandler.hxx"
+#include "pcrservices.hxx"
 #include "propctrlr.hrc"
 #include "formbrowsertools.hxx"
 #include "formresid.hrc"
@@ -32,7 +33,7 @@
 #include <com/sun/star/awt/XTabControllerModel.hpp>
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 #include <com/sun/star/beans/UnknownPropertyException.hpp>
-#include <com/sun/star/beans/Introspection.hpp>
+#include <com/sun/star/beans/theIntrospection.hpp>
 #include <com/sun/star/beans/XIntrospectionAccess.hpp>
 #include <com/sun/star/container/NoSuchElementException.hpp>
 #include <com/sun/star/container/XChild.hpp>
@@ -54,6 +55,7 @@
 #include <comphelper/evtmethodhelper.hxx>
 #include <comphelper/types.hxx>
 #include <cppuhelper/implbase1.hxx>
+#include <cppuhelper/supportsservice.hxx>
 #include <rtl/ref.hxx>
 #include <rtl/ustrbuf.hxx>
 #include <sfx2/app.hxx>
@@ -68,16 +70,13 @@
 #include <algorithm>
 #include <o3tl/compat_functional.hxx>
 
-//------------------------------------------------------------------------
 extern "C" void SAL_CALL createRegistryInfo_EventHandler()
 {
     ::pcr::OAutoRegistration< ::pcr::EventHandler > aAutoRegistration;
 }
 
-//........................................................................
 namespace pcr
 {
-//........................................................................
 
     using ::com::sun::star::uno::Reference;
     using ::com::sun::star::uno::XComponentContext;
@@ -85,7 +84,7 @@ namespace pcr
     using ::com::sun::star::uno::Any;
     using ::com::sun::star::uno::TypeClass_STRING;
     using ::com::sun::star::uno::Type;
-    using ::com::sun::star::beans::Introspection;
+    using ::com::sun::star::beans::theIntrospection;
     using ::com::sun::star::beans::XPropertyChangeListener;
     using ::com::sun::star::beans::Property;
     using ::com::sun::star::beans::PropertyState;
@@ -138,9 +137,6 @@ namespace pcr
     namespace PropertyAttribute = ::com::sun::star::beans::PropertyAttribute;
     namespace FormComponentType = ::com::sun::star::form::FormComponentType;
 
-    //====================================================================
-    //= EventDescription
-    //====================================================================
     EventDescription::EventDescription( EventId _nId, const sal_Char* _pListenerNamespaceAscii, const sal_Char* _pListenerClassAsciiName,
             const sal_Char* _pListenerMethodAsciiName, sal_uInt16 _nDisplayNameResId, const OString& _sHelpId, const OString& _sUniqueBrowseId )
         :sDisplayName(PcrRes( _nDisplayNameResId ).toString())
@@ -157,18 +153,13 @@ namespace pcr
         sListenerClassName = aQualifiedListenerClass.makeStringAndClear();
     }
 
-    //========================================================================
-    //= helper
-    //========================================================================
     namespace
     {
-        //....................................................................
         #define DESCRIBE_EVENT( asciinamespace, asciilistener, asciimethod, id_postfix ) \
             s_aKnownEvents.insert( EventMap::value_type( \
-                OUString::createFromAscii( asciimethod ), \
+                asciimethod, \
                 EventDescription( ++nEventId, asciinamespace, asciilistener, asciimethod, RID_STR_EVT_##id_postfix, HID_EVT_##id_postfix, UID_BRWEVT_##id_postfix ) ) )
 
-        //....................................................................
         bool lcl_getEventDescriptionForMethod( const OUString& _rMethodName, EventDescription& _out_rDescription )
         {
             static EventMap s_aKnownEvents;
@@ -223,7 +214,6 @@ namespace pcr
             return true;
         }
 
-        //....................................................................
         OUString lcl_getEventPropertyName( const OUString& _rListenerClassName, const OUString& _rMethodName )
         {
             OUStringBuffer aPropertyName;
@@ -233,7 +223,6 @@ namespace pcr
             return aPropertyName.makeStringAndClear();
         }
 
-        //................................................................
         ScriptEventDescriptor lcl_getAssignedScriptEvent( const EventDescription& _rEvent, const Sequence< ScriptEventDescriptor >& _rAllAssignedMacros )
         {
             ScriptEventDescriptor aScriptEvent;
@@ -288,7 +277,6 @@ namespace pcr
             return aScriptEvent;
         }
 
-        //................................................................
         OUString lcl_getQualifiedKnownListenerName( const ScriptEventDescriptor& _rFormComponentEventDescriptor )
         {
             EventDescription aKnownEvent;
@@ -302,10 +290,8 @@ namespace pcr
             return _rFormComponentEventDescriptor.ListenerType;
         }
 
-        //................................................................
         typedef ::std::set< Type, TypeLessByName > TypeBag;
 
-        //................................................................
         void lcl_addListenerTypesFor_throw( const Reference< XInterface >& _rxComponent,
             const Reference< XIntrospection >& _rxIntrospection, TypeBag& _out_rTypes )
         {
@@ -322,8 +308,7 @@ namespace pcr
                 ::std::insert_iterator< TypeBag >( _out_rTypes, _out_rTypes.begin() ) );
         }
 
-        //................................................................
-        bool operator ==( const ScriptEventDescriptor _lhs, const ScriptEventDescriptor _rhs )
+        bool operator ==( const ScriptEventDescriptor& _lhs, const ScriptEventDescriptor& _rhs )
         {
             return  (   ( _lhs.ListenerType         == _rhs.ListenerType        )
                     &&  ( _lhs.EventMethod          == _rhs.EventMethod         )
@@ -334,17 +319,13 @@ namespace pcr
         }
     }
 
-    //====================================================================
-    //= EventHandler
-    //====================================================================
     typedef ::cppu::WeakImplHelper1 <   ::com::sun::star::container::XNameReplace
                                     >   EventHolder_Base;
-    /** a UNO component holding assigned event descriptions, for use with a SvxMacroAssignDlg
-    */
+    /* An UNO component holding assigned event descriptions, for use with a SvxMacroAssignDlg */
     class EventHolder : public EventHolder_Base
     {
     private:
-        typedef ::boost::unordered_map< OUString, ScriptEventDescriptor, OUStringHash >  EventMap;
+        typedef std::unordered_map< OUString, ScriptEventDescriptor, OUStringHash >  EventMap;
         typedef ::std::map< EventId, EventMap::iterator >                                       EventMapIndexAccess;
 
         EventMap            m_aEventNameAccess;
@@ -361,36 +342,31 @@ namespace pcr
         ScriptEventDescriptor getNormalizedDescriptorByName( const OUString& _rEventName ) const;
 
         // XNameReplace
-        virtual void SAL_CALL replaceByName( const OUString& _rName, const Any& aElement ) throw (IllegalArgumentException, NoSuchElementException, WrappedTargetException, RuntimeException);
-        virtual Any SAL_CALL getByName( const OUString& _rName ) throw (NoSuchElementException, WrappedTargetException, RuntimeException);
-        virtual Sequence< OUString > SAL_CALL getElementNames(  ) throw (RuntimeException);
-        virtual ::sal_Bool SAL_CALL hasByName( const OUString& _rName ) throw (RuntimeException);
-        virtual Type SAL_CALL getElementType(  ) throw (RuntimeException);
-        virtual ::sal_Bool SAL_CALL hasElements(  ) throw (RuntimeException);
+        virtual void SAL_CALL replaceByName( const OUString& _rName, const Any& aElement ) throw (IllegalArgumentException, NoSuchElementException, WrappedTargetException, RuntimeException, std::exception) SAL_OVERRIDE;
+        virtual Any SAL_CALL getByName( const OUString& _rName ) throw (NoSuchElementException, WrappedTargetException, RuntimeException, std::exception) SAL_OVERRIDE;
+        virtual Sequence< OUString > SAL_CALL getElementNames(  ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
+        virtual sal_Bool SAL_CALL hasByName( const OUString& _rName ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
+        virtual Type SAL_CALL getElementType(  ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
+        virtual sal_Bool SAL_CALL hasElements(  ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
 
     protected:
-        ~EventHolder( );
+        virtual ~EventHolder( );
 
     private:
         ScriptEventDescriptor impl_getDescriptor_throw( const OUString& _rEventName ) const;
     };
 
-    DBG_NAME( EventHolder )
-    //------------------------------------------------------------------------
+
     EventHolder::EventHolder()
     {
-        DBG_CTOR( EventHolder, NULL );
     }
 
-    //------------------------------------------------------------------------
     EventHolder::~EventHolder()
     {
         m_aEventNameAccess.clear();
         m_aEventIndexAccess.clear();
-        DBG_DTOR( EventHolder, NULL );
     }
 
-    //------------------------------------------------------------------------
     void EventHolder::addEvent( EventId _nId, const OUString& _rEventName, const ScriptEventDescriptor& _rScriptEvent )
     {
         ::std::pair< EventMap::iterator, bool > insertionResult =
@@ -399,13 +375,11 @@ namespace pcr
         m_aEventIndexAccess[ _nId ] = insertionResult.first;
     }
 
-    //------------------------------------------------------------------------
     ScriptEventDescriptor EventHolder::getNormalizedDescriptorByName( const OUString& _rEventName ) const
     {
         return impl_getDescriptor_throw( _rEventName );
     }
 
-    //------------------------------------------------------------------------
     ScriptEventDescriptor EventHolder::impl_getDescriptor_throw( const OUString& _rEventName ) const
     {
         EventMap::const_iterator pos = m_aEventNameAccess.find( _rEventName );
@@ -414,8 +388,7 @@ namespace pcr
         return pos->second;
     }
 
-    //------------------------------------------------------------------------
-    void SAL_CALL EventHolder::replaceByName( const OUString& _rName, const Any& _rElement ) throw (IllegalArgumentException, NoSuchElementException, WrappedTargetException, RuntimeException)
+    void SAL_CALL EventHolder::replaceByName( const OUString& _rName, const Any& _rElement ) throw (IllegalArgumentException, NoSuchElementException, WrappedTargetException, RuntimeException, std::exception)
     {
         EventMap::iterator pos = m_aEventNameAccess.find( _rName );
         if ( pos == m_aEventNameAccess.end() )
@@ -430,8 +403,7 @@ namespace pcr
         pos->second.ScriptCode = aExtractor.getOrDefault( "Script", OUString() );
     }
 
-    //------------------------------------------------------------------------
-    Any SAL_CALL EventHolder::getByName( const OUString& _rName ) throw (NoSuchElementException, WrappedTargetException, RuntimeException)
+    Any SAL_CALL EventHolder::getByName( const OUString& _rName ) throw (NoSuchElementException, WrappedTargetException, RuntimeException, std::exception)
     {
         ScriptEventDescriptor aDescriptor( impl_getDescriptor_throw( _rName ) );
 
@@ -444,14 +416,13 @@ namespace pcr
         return makeAny( aScriptDescriptor );
     }
 
-    //------------------------------------------------------------------------
-    Sequence< OUString > SAL_CALL EventHolder::getElementNames(  ) throw (RuntimeException)
+    Sequence< OUString > SAL_CALL EventHolder::getElementNames(  ) throw (RuntimeException, std::exception)
     {
         Sequence< OUString > aReturn( m_aEventIndexAccess.size() );
         OUString* pReturn = aReturn.getArray();
 
         // SvxMacroAssignDlg has a weird API: It expects a XNameReplace, means a container whose
-        // main access method is by name. In it's UI, it shows the possible events in exactly the
+        // main access method is by name. In its UI, it shows the possible events in exactly the
         // order in which XNameAccess::getElementNames returns them.
         // However, SvxMacroAssignDlg *also* takes an index for the initial selection, which is
         // relative to the sequence returned by XNameAccess::getElementNames.
@@ -467,31 +438,23 @@ namespace pcr
         return aReturn;
     }
 
-     //------------------------------------------------------------------------
-    sal_Bool SAL_CALL EventHolder::hasByName( const OUString& _rName ) throw (RuntimeException)
+    sal_Bool SAL_CALL EventHolder::hasByName( const OUString& _rName ) throw (RuntimeException, std::exception)
     {
         EventMap::const_iterator pos = m_aEventNameAccess.find( _rName );
         return pos != m_aEventNameAccess.end();
     }
 
-    //------------------------------------------------------------------------
-    Type SAL_CALL EventHolder::getElementType(  ) throw (RuntimeException)
+    Type SAL_CALL EventHolder::getElementType(  ) throw (RuntimeException, std::exception)
     {
-        return ::getCppuType( static_cast< Sequence< PropertyValue >* >( NULL ) );
+        return cppu::UnoType<Sequence< PropertyValue >>::get();
     }
 
-    //------------------------------------------------------------------------
-    sal_Bool SAL_CALL EventHolder::hasElements(  ) throw (RuntimeException)
+    sal_Bool SAL_CALL EventHolder::hasElements(  ) throw (RuntimeException, std::exception)
     {
         return !m_aEventNameAccess.empty();
     }
 
 
-    //====================================================================
-    //= EventHandler
-    //====================================================================
-    DBG_NAME( EventHandler )
-    //--------------------------------------------------------------------
     EventHandler::EventHandler( const Reference< XComponentContext >& _rxContext )
         :EventHandler_Base( m_aMutex )
         ,m_xContext( _rxContext )
@@ -500,41 +463,32 @@ namespace pcr
         ,m_bIsDialogElement( false )
         ,m_nGridColumnType( -1 )
     {
-        DBG_CTOR( EventHandler, NULL );
     }
 
-    //--------------------------------------------------------------------
     EventHandler::~EventHandler()
     {
-        DBG_DTOR( EventHandler, NULL );
     }
 
-    //--------------------------------------------------------------------
-    OUString SAL_CALL EventHandler::getImplementationName(  ) throw (RuntimeException)
+    OUString SAL_CALL EventHandler::getImplementationName(  ) throw (RuntimeException, std::exception)
     {
         return getImplementationName_static();
     }
 
-    //--------------------------------------------------------------------
-    ::sal_Bool SAL_CALL EventHandler::supportsService( const OUString& ServiceName ) throw (RuntimeException)
+    sal_Bool SAL_CALL EventHandler::supportsService( const OUString& ServiceName ) throw (RuntimeException, std::exception)
     {
-        StlSyntaxSequence< OUString > aAllServices( getSupportedServiceNames() );
-        return ::std::find( aAllServices.begin(), aAllServices.end(), ServiceName ) != aAllServices.end();
+        return cppu::supportsService(this, ServiceName);
     }
 
-    //--------------------------------------------------------------------
-    Sequence< OUString > SAL_CALL EventHandler::getSupportedServiceNames(  ) throw (RuntimeException)
+    Sequence< OUString > SAL_CALL EventHandler::getSupportedServiceNames(  ) throw (RuntimeException, std::exception)
     {
         return getSupportedServiceNames_static();
     }
 
-    //--------------------------------------------------------------------
     OUString SAL_CALL EventHandler::getImplementationName_static(  ) throw (RuntimeException)
     {
         return OUString(  "com.sun.star.comp.extensions.EventHandler"  );
     }
 
-    //--------------------------------------------------------------------
     Sequence< OUString > SAL_CALL EventHandler::getSupportedServiceNames_static(  ) throw (RuntimeException)
     {
         Sequence< OUString > aSupported( 1 );
@@ -542,14 +496,12 @@ namespace pcr
         return aSupported;
     }
 
-    //--------------------------------------------------------------------
     Reference< XInterface > SAL_CALL EventHandler::Create( const Reference< XComponentContext >& _rxContext )
     {
         return *( new EventHandler( _rxContext ) );
     }
 
-    //--------------------------------------------------------------------
-    void SAL_CALL EventHandler::inspect( const Reference< XInterface >& _rxIntrospectee ) throw (RuntimeException, NullPointerException)
+    void SAL_CALL EventHandler::inspect( const Reference< XInterface >& _rxIntrospectee ) throw (RuntimeException, NullPointerException, std::exception)
     {
         ::osl::MutexGuard aGuard( m_aMutex );
 
@@ -588,8 +540,7 @@ namespace pcr
         }
     }
 
-    //--------------------------------------------------------------------
-    Any SAL_CALL EventHandler::getPropertyValue( const OUString& _rPropertyName ) throw (UnknownPropertyException, RuntimeException)
+    Any SAL_CALL EventHandler::getPropertyValue( const OUString& _rPropertyName ) throw (UnknownPropertyException, RuntimeException, std::exception)
     {
         ::osl::MutexGuard aGuard( m_aMutex );
 
@@ -616,8 +567,7 @@ namespace pcr
         return makeAny( aPropertyValue );
     }
 
-    //--------------------------------------------------------------------
-    void SAL_CALL EventHandler::setPropertyValue( const OUString& _rPropertyName, const Any& _rValue ) throw (UnknownPropertyException, RuntimeException)
+    void SAL_CALL EventHandler::setPropertyValue( const OUString& _rPropertyName, const Any& _rValue ) throw (UnknownPropertyException, RuntimeException, std::exception)
     {
         ::osl::MutexGuard aGuard( m_aMutex );
 
@@ -647,8 +597,7 @@ namespace pcr
         m_aPropertyListeners.notify( aEvent, &XPropertyChangeListener::propertyChange );
     }
 
-    //--------------------------------------------------------------------
-    Any SAL_CALL EventHandler::convertToPropertyValue( const OUString& _rPropertyName, const Any& _rControlValue ) throw (UnknownPropertyException, RuntimeException)
+    Any SAL_CALL EventHandler::convertToPropertyValue( const OUString& _rPropertyName, const Any& _rControlValue ) throw (UnknownPropertyException, RuntimeException, std::exception)
     {
         ::osl::MutexGuard aGuard( m_aMutex );
 
@@ -675,8 +624,7 @@ namespace pcr
         return makeAny( aAssignedScript );
     }
 
-    //--------------------------------------------------------------------
-    Any SAL_CALL EventHandler::convertToControlValue( const OUString& /*_rPropertyName*/, const Any& _rPropertyValue, const Type& _rControlValueType ) throw (UnknownPropertyException, RuntimeException)
+    Any SAL_CALL EventHandler::convertToControlValue( const OUString& /*_rPropertyName*/, const Any& _rPropertyValue, const Type& _rControlValueType ) throw (UnknownPropertyException, RuntimeException, std::exception)
     {
         ::osl::MutexGuard aGuard( m_aMutex );
 
@@ -740,14 +688,12 @@ namespace pcr
         return makeAny( sScript );
     }
 
-    //--------------------------------------------------------------------
-    PropertyState SAL_CALL EventHandler::getPropertyState( const OUString& /*_rPropertyName*/ ) throw (UnknownPropertyException, RuntimeException)
+    PropertyState SAL_CALL EventHandler::getPropertyState( const OUString& /*_rPropertyName*/ ) throw (UnknownPropertyException, RuntimeException, std::exception)
     {
         return PropertyState_DIRECT_VALUE;
     }
 
-    //--------------------------------------------------------------------
-    void SAL_CALL EventHandler::addPropertyChangeListener( const Reference< XPropertyChangeListener >& _rxListener ) throw (RuntimeException)
+    void SAL_CALL EventHandler::addPropertyChangeListener( const Reference< XPropertyChangeListener >& _rxListener ) throw (NullPointerException, RuntimeException, std::exception)
     {
         ::osl::MutexGuard aGuard( m_aMutex );
         if ( !_rxListener.is() )
@@ -755,15 +701,13 @@ namespace pcr
         m_aPropertyListeners.addListener( _rxListener );
     }
 
-    //--------------------------------------------------------------------
-    void SAL_CALL EventHandler::removePropertyChangeListener( const Reference< XPropertyChangeListener >& _rxListener ) throw (RuntimeException)
+    void SAL_CALL EventHandler::removePropertyChangeListener( const Reference< XPropertyChangeListener >& _rxListener ) throw (RuntimeException, std::exception)
     {
         ::osl::MutexGuard aGuard( m_aMutex );
         m_aPropertyListeners.removeListener( _rxListener );
     }
 
-    //--------------------------------------------------------------------
-    Sequence< Property > SAL_CALL EventHandler::getSupportedProperties() throw (RuntimeException)
+    Sequence< Property > SAL_CALL EventHandler::getSupportedProperties() throw (RuntimeException, std::exception)
     {
         ::osl::MutexGuard aGuard( m_aMutex );
         if ( !m_bEventsMapInitialized )
@@ -826,7 +770,7 @@ namespace pcr
         {
             aOrderedProperties[ loop->second.nId ] = Property(
                 loop->first, loop->second.nId,
-                ::getCppuType( static_cast< const OUString* >( NULL ) ),
+                ::cppu::UnoType<OUString>::get(),
                 PropertyAttribute::BOUND );
         }
 
@@ -836,24 +780,21 @@ namespace pcr
         return aReturn;
     }
 
-    //--------------------------------------------------------------------
-    Sequence< OUString > SAL_CALL EventHandler::getSupersededProperties( ) throw (RuntimeException)
+    Sequence< OUString > SAL_CALL EventHandler::getSupersededProperties( ) throw (RuntimeException, std::exception)
     {
         // none
         return Sequence< OUString >( );
     }
 
-    //--------------------------------------------------------------------
-    Sequence< OUString > SAL_CALL EventHandler::getActuatingProperties( ) throw (RuntimeException)
+    Sequence< OUString > SAL_CALL EventHandler::getActuatingProperties( ) throw (RuntimeException, std::exception)
     {
         // none
         return Sequence< OUString >( );
     }
 
-    //--------------------------------------------------------------------
     LineDescriptor SAL_CALL EventHandler::describePropertyLine( const OUString& _rPropertyName,
         const Reference< XPropertyControlFactory >& _rxControlFactory )
-        throw (UnknownPropertyException, NullPointerException, RuntimeException)
+        throw (UnknownPropertyException, NullPointerException, RuntimeException, std::exception)
     {
         if ( !_rxControlFactory.is() )
             throw NullPointerException();
@@ -874,14 +815,12 @@ namespace pcr
         return aDescriptor;
     }
 
-    //--------------------------------------------------------------------
-    ::sal_Bool SAL_CALL EventHandler::isComposable( const OUString& /*_rPropertyName*/ ) throw (UnknownPropertyException, RuntimeException)
+    sal_Bool SAL_CALL EventHandler::isComposable( const OUString& /*_rPropertyName*/ ) throw (UnknownPropertyException, RuntimeException, std::exception)
     {
         return sal_False;
     }
 
-    //--------------------------------------------------------------------
-    InteractiveSelectionResult SAL_CALL EventHandler::onInteractivePropertySelection( const OUString& _rPropertyName, sal_Bool /*_bPrimary*/, Any& /*_rData*/, const Reference< XObjectInspectorUI >& _rxInspectorUI ) throw (UnknownPropertyException, NullPointerException, RuntimeException)
+    InteractiveSelectionResult SAL_CALL EventHandler::onInteractivePropertySelection( const OUString& _rPropertyName, sal_Bool /*_bPrimary*/, Any& /*_rData*/, const Reference< XObjectInspectorUI >& _rxInspectorUI ) throw (UnknownPropertyException, NullPointerException, RuntimeException, std::exception)
     {
         if ( !_rxInspectorUI.is() )
             throw NullPointerException();
@@ -915,7 +854,7 @@ namespace pcr
         if ( !pFactory )
             return InteractiveSelectionResult_Cancelled;
 
-        ::std::auto_ptr< VclAbstractDialog > pDialog( pFactory->CreateSvxMacroAssignDlg(
+        ::std::unique_ptr< VclAbstractDialog > pDialog( pFactory->CreateSvxMacroAssignDlg(
             PropertyHandlerHelper::getDialogParentWindow( m_xContext ),
             impl_getContextFrame_nothrow(),
             m_bIsDialogElement,
@@ -955,16 +894,13 @@ namespace pcr
         return InteractiveSelectionResult_Success;
     }
 
-    //--------------------------------------------------------------------
-    void SAL_CALL EventHandler::actuatingPropertyChanged( const OUString& /*_rActuatingPropertyName*/, const Any& /*_rNewValue*/, const Any& /*_rOldValue*/, const Reference< XObjectInspectorUI >& /*_rxInspectorUI*/, sal_Bool /*_bFirstTimeInit*/ ) throw (NullPointerException, RuntimeException)
+    void SAL_CALL EventHandler::actuatingPropertyChanged( const OUString& /*_rActuatingPropertyName*/, const Any& /*_rNewValue*/, const Any& /*_rOldValue*/, const Reference< XObjectInspectorUI >& /*_rxInspectorUI*/, sal_Bool /*_bFirstTimeInit*/ ) throw (NullPointerException, RuntimeException, std::exception)
     {
         OSL_FAIL( "EventHandler::actuatingPropertyChanged: no actuating properties -> no callback (well, this is how it *should* be!)" );
     }
 
-    //--------------------------------------------------------------------
     IMPLEMENT_FORWARD_XCOMPONENT( EventHandler, EventHandler_Base )
 
-    //--------------------------------------------------------------------
     void SAL_CALL EventHandler::disposing()
     {
         EventMap aEmpty;
@@ -972,13 +908,11 @@ namespace pcr
         m_xComponent.clear();
     }
 
-    //--------------------------------------------------------------------
-    sal_Bool SAL_CALL EventHandler::suspend( sal_Bool /*_bSuspend*/ ) throw (RuntimeException)
+    sal_Bool SAL_CALL EventHandler::suspend( sal_Bool /*_bSuspend*/ ) throw (RuntimeException, std::exception)
     {
         return sal_True;
     }
 
-    //------------------------------------------------------------------------
     Reference< XFrame > EventHandler::impl_getContextFrame_nothrow() const
     {
         Reference< XFrame > xContextFrame;
@@ -997,13 +931,12 @@ namespace pcr
         return xContextFrame;
     }
 
-    //--------------------------------------------------------------------
     sal_Int32 EventHandler::impl_getComponentIndexInParent_throw() const
     {
         Reference< XChild > xChild( m_xComponent, UNO_QUERY_THROW );
         Reference< XIndexAccess > xParentAsIndexAccess( xChild->getParent(), UNO_QUERY_THROW );
 
-        // get the index of the inspected object within it's parent container
+        // get the index of the inspected object within its parent container
         sal_Int32 nElements = xParentAsIndexAccess->getCount();
         for ( sal_Int32 i=0; i<nElements; ++i )
         {
@@ -1014,7 +947,6 @@ namespace pcr
         throw NoSuchElementException();
     }
 
-    //--------------------------------------------------------------------
     void EventHandler::impl_getFormComponentScriptEvents_nothrow( Sequence < ScriptEventDescriptor >& _out_rEvents ) const
     {
         _out_rEvents = Sequence < ScriptEventDescriptor >();
@@ -1040,7 +972,6 @@ namespace pcr
         }
     }
 
-    //--------------------------------------------------------------------
     void EventHandler::impl_getCopmonentListenerTypes_nothrow( Sequence< Type >& _out_rTypes ) const
     {
         _out_rTypes.realloc( 0 );
@@ -1049,7 +980,7 @@ namespace pcr
             // we use a set to avoid duplicates
             TypeBag aListeners;
 
-            Reference< XIntrospection > xIntrospection = Introspection::create( m_xContext );
+            Reference< XIntrospection > xIntrospection = theIntrospection::get( m_xContext );
 
             // --- model listeners
             lcl_addListenerTypesFor_throw(
@@ -1072,7 +1003,6 @@ namespace pcr
         }
     }
 
-    //--------------------------------------------------------------------
     void EventHandler::impl_getDialogElementScriptEvents_nothrow( Sequence < ScriptEventDescriptor >& _out_rEvents ) const
     {
         _out_rEvents = Sequence < ScriptEventDescriptor >();
@@ -1097,7 +1027,6 @@ namespace pcr
         }
     }
 
-    //--------------------------------------------------------------------
     Reference< XInterface > EventHandler::impl_getSecondaryComponentForEventInspection_throw( ) const
     {
         Reference< XInterface > xReturn;
@@ -1122,7 +1051,6 @@ namespace pcr
         return xReturn;
     }
 
-    //--------------------------------------------------------------------
     const EventDescription& EventHandler::impl_getEventForName_throw( const OUString& _rPropertyName ) const
     {
         EventMap::const_iterator pos = m_aEvents.find( _rPropertyName );
@@ -1131,7 +1059,6 @@ namespace pcr
         return pos->second;
     }
 
-    //--------------------------------------------------------------------
     namespace
     {
         static bool lcl_endsWith( const OUString& _rText, const OUString& _rCheck )
@@ -1144,7 +1071,7 @@ namespace pcr
             return _rText.indexOf( _rCheck ) == ( nTextLen - nCheckLen );
         }
     }
-    //--------------------------------------------------------------------
+
     void EventHandler::impl_setFormComponentScriptEvent_nothrow( const ScriptEventDescriptor& _rScriptEvent )
     {
         try
@@ -1203,7 +1130,6 @@ namespace pcr
         }
     }
 
-    //--------------------------------------------------------------------
     void EventHandler::impl_setDialogElementScriptEvent_nothrow( const ScriptEventDescriptor& _rScriptEvent )
     {
         try
@@ -1243,7 +1169,6 @@ namespace pcr
         }
     }
 
-    //--------------------------------------------------------------------
     bool EventHandler::impl_filterMethod_nothrow( const EventDescription& _rEvent ) const
     {
         // some (control-triggered) events do not make sense for certain grid control columns. However,
@@ -1266,8 +1191,6 @@ namespace pcr
         return true;
     }
 
-//........................................................................
 } // namespace pcr
-//........................................................................
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
