@@ -18,8 +18,6 @@
  */
 
 #include <jobs/job.hxx>
-#include <threadhelp/readguard.hxx>
-#include <threadhelp/writeguard.hxx>
 #include <general.h>
 #include <services.h>
 
@@ -36,7 +34,6 @@
 
 namespace framework{
 
-//________________________________
 /**
     @short      standard ctor
     @descr      It initialize this new instance. But it set some generic parameters here only.
@@ -52,20 +49,18 @@ namespace framework{
 */
 Job::Job( /*IN*/ const css::uno::Reference< css::uno::XComponentContext >& xContext  ,
           /*IN*/ const css::uno::Reference< css::frame::XFrame >&              xFrame )
-    : ThreadHelpBase       (&Application::GetSolarMutex())
-    , m_aJobCfg            (xContext                     )
+    : m_aJobCfg            (xContext                     )
     , m_xContext           (xContext                     )
     , m_xFrame             (xFrame                       )
-    , m_bListenOnDesktop   (sal_False                    )
-    , m_bListenOnFrame     (sal_False                    )
-    , m_bListenOnModel     (sal_False                    )
-    , m_bPendingCloseFrame (sal_False                    )
-    , m_bPendingCloseModel (sal_False                    )
+    , m_bListenOnDesktop   (false                    )
+    , m_bListenOnFrame     (false                    )
+    , m_bListenOnModel     (false                    )
+    , m_bPendingCloseFrame (false                    )
+    , m_bPendingCloseModel (false                    )
     , m_eRunState          (E_NEW                        )
 {
 }
 
-//________________________________
 /**
     @short      standard ctor
     @descr      It initialize this new instance. But it set some generic parameters here only.
@@ -81,20 +76,18 @@ Job::Job( /*IN*/ const css::uno::Reference< css::uno::XComponentContext >& xCont
 */
 Job::Job( /*IN*/ const css::uno::Reference< css::uno::XComponentContext >& xContext  ,
           /*IN*/ const css::uno::Reference< css::frame::XModel >&              xModel )
-    : ThreadHelpBase       (&Application::GetSolarMutex())
-    , m_aJobCfg            (xContext                     )
+    : m_aJobCfg            (xContext                     )
     , m_xContext           (xContext                     )
     , m_xModel             (xModel                       )
-    , m_bListenOnDesktop   (sal_False                    )
-    , m_bListenOnFrame     (sal_False                    )
-    , m_bListenOnModel     (sal_False                    )
-    , m_bPendingCloseFrame (sal_False                    )
-    , m_bPendingCloseModel (sal_False                    )
+    , m_bListenOnDesktop   (false                    )
+    , m_bListenOnFrame     (false                    )
+    , m_bListenOnModel     (false                    )
+    , m_bPendingCloseFrame (false                    )
+    , m_bPendingCloseModel (false                    )
     , m_eRunState          (E_NEW                        )
 {
 }
 
-//________________________________
 /**
     @short  superflous!
     @descr  Releasing of memory and reference must be done inside die() call.
@@ -104,7 +97,6 @@ Job::~Job()
 {
 }
 
-//________________________________
 /**
     @short  set (or delete) a listener for sending dispatch result events
     @descr  Because this object is used in a wrapped mode ... the original listener
@@ -121,8 +113,7 @@ Job::~Job()
 void Job::setDispatchResultFake( /*IN*/ const css::uno::Reference< css::frame::XDispatchResultListener >& xListener   ,
                                  /*IN*/ const css::uno::Reference< css::uno::XInterface >&                xSourceFake )
 {
-    /* SAFE { */
-    WriteGuard aWriteLock(m_aLock);
+    SolarMutexGuard g;
 
     // reject dangerous calls
     if (m_eRunState != E_NEW)
@@ -131,16 +122,13 @@ void Job::setDispatchResultFake( /*IN*/ const css::uno::Reference< css::frame::X
         return;
     }
 
-    m_xResultListener   = xListener  ;
+    m_xResultListener   = xListener;
     m_xResultSourceFake = xSourceFake;
-    aWriteLock.unlock();
-    /* } SAFE */
 }
 
 void Job::setJobData( const JobData& aData )
 {
-    /* SAFE { */
-    WriteGuard aWriteLock(m_aLock);
+    SolarMutexGuard g;
 
     // reject dangerous calls
     if (m_eRunState != E_NEW)
@@ -150,11 +138,8 @@ void Job::setJobData( const JobData& aData )
     }
 
     m_aJobCfg = aData;
-    aWriteLock.unlock();
-    /* } SAFE */
 }
 
-//________________________________
 /**
     @short  runs the job
     @descr  It doesn't matter, if the job is an asynchronous or
@@ -169,7 +154,7 @@ void Job::setJobData( const JobData& aData )
 void Job::execute( /*IN*/ const css::uno::Sequence< css::beans::NamedValue >& lDynamicArgs )
 {
     /* SAFE { */
-    WriteGuard aWriteLock(m_aLock);
+    SolarMutexResettableGuard aWriteLock;
 
     // reject dangerous calls
     if (m_eRunState != E_NEW)
@@ -204,23 +189,23 @@ void Job::execute( /*IN*/ const css::uno::Sequence< css::beans::NamedValue >& lD
         if (xAJob.is())
         {
             m_aAsyncWait.reset();
-            aWriteLock.unlock();
+            aWriteLock.clear();
             /* } SAFE */
             xAJob->executeAsync(lJobArgs, xThis);
             // wait for finishing this job - so this method
             // does the same for synchronous and asynchronous jobs!
             m_aAsyncWait.wait();
-            aWriteLock.lock();
+            aWriteLock.reset();
             /* SAFE { */
             // Note: Result handling was already done inside the callback!
         }
         // execute it synchron
         else if (xSJob.is())
         {
-            aWriteLock.unlock();
+            aWriteLock.clear();
             /* } SAFE */
             css::uno::Any aResult = xSJob->execute(lJobArgs);
-            aWriteLock.lock();
+            aWriteLock.reset();
             /* SAFE { */
             impl_reactForJobResult(aResult);
         }
@@ -248,7 +233,7 @@ void Job::execute( /*IN*/ const css::uno::Sequence< css::beans::NamedValue >& lD
     // and to disable ourself!
     if (m_bPendingCloseFrame)
     {
-        m_bPendingCloseFrame = sal_False;
+        m_bPendingCloseFrame = false;
         css::uno::Reference< css::util::XCloseable > xClose(m_xFrame, css::uno::UNO_QUERY);
         if (xClose.is())
         {
@@ -262,7 +247,7 @@ void Job::execute( /*IN*/ const css::uno::Sequence< css::beans::NamedValue >& lD
 
     if (m_bPendingCloseModel)
     {
-        m_bPendingCloseModel = sal_False;
+        m_bPendingCloseModel = false;
         css::uno::Reference< css::util::XCloseable > xClose(m_xModel, css::uno::UNO_QUERY);
         if (xClose.is())
         {
@@ -274,14 +259,13 @@ void Job::execute( /*IN*/ const css::uno::Sequence< css::beans::NamedValue >& lD
         }
     }
 
-    aWriteLock.unlock();
+    aWriteLock.clear();
     /* SAFE { */
 
     // release this instance ...
     die();
 }
 
-//________________________________
 /**
     @short  kill this job
     @descr  It doesn't matter if this request is called from inside or
@@ -292,8 +276,7 @@ void Job::execute( /*IN*/ const css::uno::Sequence< css::beans::NamedValue >& lD
 */
 void Job::die()
 {
-    /* SAFE { */
-    WriteGuard aWriteLock(m_aLock);
+    SolarMutexGuard g;
 
     impl_stopListening();
 
@@ -320,14 +303,10 @@ void Job::die()
     m_xDesktop           = css::uno::Reference< css::frame::XDesktop2 >();
     m_xResultListener    = css::uno::Reference< css::frame::XDispatchResultListener >();
     m_xResultSourceFake  = css::uno::Reference< css::uno::XInterface >();
-    m_bPendingCloseFrame = sal_False;
-    m_bPendingCloseModel = sal_False;
-
-    aWriteLock.unlock();
-    /* SAFE { */
+    m_bPendingCloseFrame = false;
+    m_bPendingCloseModel = false;
 }
 
-//________________________________
 /**
     @short  generates list of arguments for job execute
     @descr  There exist a set of information, which can be needed by a job.
@@ -348,43 +327,43 @@ css::uno::Sequence< css::beans::NamedValue > Job::impl_generateJobArgs( /*IN*/ c
     css::uno::Sequence< css::beans::NamedValue > lAllArgs;
 
     /* SAFE { */
-    ReadGuard aReadLock(m_aLock);
+    SolarMutexClearableGuard aReadLock;
 
     // the real structure of the returned list depends from the environment of this job!
     JobData::EMode eMode = m_aJobCfg.getMode();
 
     // Create list of environment variables. This list must be part of the
-    // returned structure everytimes ... but some of its members are opetional!
+    // returned structure every time... but some of its members are opetional!
     css::uno::Sequence< css::beans::NamedValue > lEnvArgs(1);
-    lEnvArgs[0].Name    = OUString::createFromAscii(JobData::PROP_ENVTYPE);
+    lEnvArgs[0].Name = "EnvType";
     lEnvArgs[0].Value <<= m_aJobCfg.getEnvironmentDescriptor();
 
     if (m_xFrame.is())
     {
         sal_Int32 c = lEnvArgs.getLength();
         lEnvArgs.realloc(c+1);
-        lEnvArgs[c].Name    = OUString::createFromAscii(JobData::PROP_FRAME);
+        lEnvArgs[c].Name = "Frame";
         lEnvArgs[c].Value <<= m_xFrame;
     }
     if (m_xModel.is())
     {
         sal_Int32 c = lEnvArgs.getLength();
         lEnvArgs.realloc(c+1);
-        lEnvArgs[c].Name    = OUString::createFromAscii(JobData::PROP_MODEL);
+        lEnvArgs[c].Name = "Model";
         lEnvArgs[c].Value <<= m_xModel;
     }
     if (eMode==JobData::E_EVENT)
     {
         sal_Int32 c = lEnvArgs.getLength();
         lEnvArgs.realloc(c+1);
-        lEnvArgs[c].Name    = OUString::createFromAscii(JobData::PROP_EVENTNAME);
+        lEnvArgs[c].Name = "EventName";
         lEnvArgs[c].Value <<= m_aJobCfg.getEvent();
     }
 
     // get the configuration data from the job data container ... if possible
-    // Means: if this job has any configuration data. Note: only realy
+    // Means: if this job has any configuration data. Note: only really
     // filled lists will be set to the return structure at the end of this method.
-    css::uno::Sequence< css::beans::NamedValue > lConfigArgs   ;
+    css::uno::Sequence< css::beans::NamedValue > lConfigArgs;
     css::uno::Sequence< css::beans::NamedValue > lJobConfigArgs;
     if (eMode==JobData::E_ALIAS || eMode==JobData::E_EVENT)
     {
@@ -392,7 +371,7 @@ css::uno::Sequence< css::beans::NamedValue > Job::impl_generateJobArgs( /*IN*/ c
         lJobConfigArgs = m_aJobCfg.getJobConfig();
     }
 
-    aReadLock.unlock();
+    aReadLock.clear();
     /* } SAFE */
 
     // Add all valid (not empty) lists to the return list
@@ -400,41 +379,40 @@ css::uno::Sequence< css::beans::NamedValue > Job::impl_generateJobArgs( /*IN*/ c
     {
         sal_Int32 nLength = lAllArgs.getLength();
         lAllArgs.realloc(nLength+1);
-        lAllArgs[nLength].Name    = OUString::createFromAscii(JobData::PROPSET_CONFIG);
+        lAllArgs[nLength].Name = "Config";
         lAllArgs[nLength].Value <<= lConfigArgs;
     }
     if (lJobConfigArgs.getLength()>0)
     {
         sal_Int32 nLength = lAllArgs.getLength();
         lAllArgs.realloc(nLength+1);
-        lAllArgs[nLength].Name    = OUString::createFromAscii(JobData::PROPSET_OWNCONFIG);
+        lAllArgs[nLength].Name = "JobConfig";
         lAllArgs[nLength].Value <<= lJobConfigArgs;
     }
     if (lEnvArgs.getLength()>0)
     {
         sal_Int32 nLength = lAllArgs.getLength();
         lAllArgs.realloc(nLength+1);
-        lAllArgs[nLength].Name    = OUString::createFromAscii(JobData::PROPSET_ENVIRONMENT);
+        lAllArgs[nLength].Name = "Environment";
         lAllArgs[nLength].Value <<= lEnvArgs;
     }
     if (lDynamicArgs.getLength()>0)
     {
         sal_Int32 nLength = lAllArgs.getLength();
         lAllArgs.realloc(nLength+1);
-        lAllArgs[nLength].Name    = OUString::createFromAscii(JobData::PROPSET_DYNAMICDATA);
+        lAllArgs[nLength].Name = "DynamicData";
         lAllArgs[nLength].Value <<= lDynamicArgs;
     }
 
     return lAllArgs;
 }
 
-//________________________________
 /**
     @short  analyze the given job result and change the job configuration
     @descr  Note: Some results can be handled only, if this job has a valid configuration!
             For "not configured jobs" (means pure services) they can be ignored.
-            But these cases are handled by our JobData member. We can call it everytime.
-            It does the right things automaticly. E.g. if the job has no configuration ...
+            But these cases are handled by our JobData member. We can call it every time.
+            It does the right things automatically. E.g. if the job has no configuration ...
             it does nothing during setJobConfig()!
 
     @param  aResult
@@ -442,8 +420,7 @@ css::uno::Sequence< css::beans::NamedValue > Job::impl_generateJobArgs( /*IN*/ c
 */
 void Job::impl_reactForJobResult( /*IN*/ const css::uno::Any& aResult )
 {
-    /* SAFE { */
-    WriteGuard aWriteLock(m_aLock);
+    SolarMutexGuard g;
 
     // analyze the result set ...
     JobResult aAnalyzedResult(aResult);
@@ -489,12 +466,8 @@ void Job::impl_reactForJobResult( /*IN*/ const css::uno::Any& aResult )
                                         aEvent.Source = m_xResultSourceFake;
         m_xResultListener->dispatchFinished(aEvent);
     }
-
-    aWriteLock.unlock();
-    /* SAFE { */
 }
 
-//________________________________
 /**
     @short  starts listening for office shutdown and closing of our
             given target frame (if it's a valid reference)
@@ -502,19 +475,18 @@ void Job::impl_reactForJobResult( /*IN*/ const css::uno::Any& aResult )
             at the global desktop instance. That will hold us
             alive and additional we get the information, if the
             office wish to shutdown. If then an internal job
-            is running we will have the chance to supress that
+            is running we will have the chance to suppress that
             by throwing a veto exception. If our internal wrapped
             job finished his work, we can release this listener
             connection.
 
             Further we are listener for closing of the (possible valid)
-            given frame. We must be shure, that this resource won't be gone
+            given frame. We must be sure, that this resource won't be gone
             if our internal job is still running.
 */
 void Job::impl_startListening()
 {
-    /* SAFE { */
-    WriteGuard aWriteLock(m_aLock);
+    SolarMutexGuard g;
 
     // listening for office shutdown
     if (!m_xDesktop.is() && !m_bListenOnDesktop)
@@ -524,7 +496,7 @@ void Job::impl_startListening()
             m_xDesktop = css::frame::Desktop::create( m_xContext );
             css::uno::Reference< css::frame::XTerminateListener > xThis(static_cast< ::cppu::OWeakObject* >(this), css::uno::UNO_QUERY);
             m_xDesktop->addTerminateListener(xThis);
-            m_bListenOnDesktop = sal_True;
+            m_bListenOnDesktop = true;
         }
         catch(const css::uno::Exception&)
         {
@@ -542,12 +514,12 @@ void Job::impl_startListening()
             if (xCloseable.is())
             {
                 xCloseable->addCloseListener(xThis);
-                m_bListenOnFrame = sal_True;
+                m_bListenOnFrame = true;
             }
         }
         catch(const css::uno::Exception&)
         {
-            m_bListenOnFrame = sal_False;
+            m_bListenOnFrame = false;
         }
     }
 
@@ -561,28 +533,23 @@ void Job::impl_startListening()
             if (xCloseable.is())
             {
                 xCloseable->addCloseListener(xThis);
-                m_bListenOnModel = sal_True;
+                m_bListenOnModel = true;
             }
         }
         catch(const css::uno::Exception&)
         {
-            m_bListenOnModel = sal_False;
+            m_bListenOnModel = false;
         }
     }
-
-    aWriteLock.unlock();
-    /* } SAFE */
 }
 
-//________________________________
 /**
     @short  release listener connection for office shutdown
     @descr  see description of impl_startListening()
 */
 void Job::impl_stopListening()
 {
-    /* SAFE { */
-    WriteGuard aWriteLock(m_aLock);
+    SolarMutexGuard g;
 
     // stop listening for office shutdown
     if (m_xDesktop.is() && m_bListenOnDesktop)
@@ -592,7 +559,7 @@ void Job::impl_stopListening()
             css::uno::Reference< css::frame::XTerminateListener > xThis(static_cast< ::cppu::OWeakObject* >(this)   , css::uno::UNO_QUERY);
             m_xDesktop->removeTerminateListener(xThis);
             m_xDesktop.clear();
-            m_bListenOnDesktop = sal_False;
+            m_bListenOnDesktop = false;
         }
         catch(const css::uno::Exception&)
         {
@@ -609,7 +576,7 @@ void Job::impl_stopListening()
             if (xCloseable.is())
             {
                 xCloseable->removeCloseListener(xThis);
-                m_bListenOnFrame = sal_False;
+                m_bListenOnFrame = false;
             }
         }
         catch(const css::uno::Exception&)
@@ -627,19 +594,15 @@ void Job::impl_stopListening()
             if (xCloseable.is())
             {
                 xCloseable->removeCloseListener(xThis);
-                m_bListenOnModel = sal_False;
+                m_bListenOnModel = false;
             }
         }
         catch(const css::uno::Exception&)
         {
         }
     }
-
-    aWriteLock.unlock();
-    /* } SAFE */
 }
 
-//________________________________
 /**
     @short  callback from any asynchronous executed job
 
@@ -652,13 +615,12 @@ void Job::impl_stopListening()
                 the job, which was running and inform us now
 
     @param  aResult
-                it's results
+                its results
 */
 void SAL_CALL Job::jobFinished( /*IN*/ const css::uno::Reference< css::task::XAsyncJob >& xJob    ,
-                                /*IN*/ const css::uno::Any&                               aResult ) throw(css::uno::RuntimeException)
+                                /*IN*/ const css::uno::Any&                               aResult ) throw(css::uno::RuntimeException, std::exception)
 {
-    /* SAFE { */
-    WriteGuard aWriteLock(m_aLock);
+    SolarMutexGuard g;
 
     // It's necessary to check this.
     // May this job was cancelled by any other reason
@@ -675,15 +637,11 @@ void SAL_CALL Job::jobFinished( /*IN*/ const css::uno::Reference< css::task::XAs
     }
 
     // And let the start method "execute()" finishing it's job.
-    // But do it everytime. So any outside blocking code can finish
+    // But do it every time. So any outside blocking code can finish
     // his work too.
     m_aAsyncWait.set();
-
-    aWriteLock.unlock();
-    /* } SAFE */
 }
 
-//________________________________
 /**
     @short  prevent internal wrapped job against office termination
     @descr  This event is broadcasted by the desktop instance and ask for an office termination.
@@ -699,11 +657,9 @@ void SAL_CALL Job::jobFinished( /*IN*/ const css::uno::Reference< css::task::XAs
                 if our internal wrapped job is still running.
  */
 void SAL_CALL Job::queryTermination( /*IN*/ const css::lang::EventObject& ) throw(css::frame::TerminationVetoException,
-                                                                                         css::uno::RuntimeException          )
+                                                                                         css::uno::RuntimeException, std::exception          )
 {
-    /* SAFE { */
-    ReadGuard aReadLock(m_aLock);
-
+    SolarMutexGuard g;
 
     // Otherwhise try to close() it
     css::uno::Reference< css::util::XCloseable > xClose(m_xJob, css::uno::UNO_QUERY);
@@ -722,13 +678,8 @@ void SAL_CALL Job::queryTermination( /*IN*/ const css::lang::EventObject& ) thro
         css::uno::Reference< css::uno::XInterface > xThis(static_cast< ::cppu::OWeakObject* >(this), css::uno::UNO_QUERY);
         throw css::frame::TerminationVetoException("job still in progress", xThis);
     }
-
-    aReadLock.unlock();
-    /* } SAFE */
 }
 
-
-//________________________________
 /**
     @short  inform us about office termination
     @descr  Instead of the method queryTermination(), here is no chance to disagree with that.
@@ -737,18 +688,17 @@ void SAL_CALL Job::queryTermination( /*IN*/ const css::lang::EventObject& ) thro
             Then we had not throwed a veto exception. But now we must agree with this situation and break
             all our internal processes. Its not a good idea to mark this instance as non startable any longer
             inside queryTermination() if no job was unning too. Because that would disable this job and may
-            the office does not realy shutdownm, because another listener has thrown the suitable exception.
+            the office does not really shutdownm, because another listener has thrown the suitable exception.
 
     @param  aEvent
                 describes the broadcaster and must be the desktop instance
  */
-void SAL_CALL Job::notifyTermination( /*IN*/ const css::lang::EventObject& ) throw(css::uno::RuntimeException)
+void SAL_CALL Job::notifyTermination( /*IN*/ const css::lang::EventObject& ) throw(css::uno::RuntimeException, std::exception)
 {
     die();
     // Do nothing else here. Our internal resources was released ...
 }
 
-//________________________________
 /**
     @short  prevent internal wrapped job against frame closing
     @descr  This event is broadcasted by the frame instance and ask for closing.
@@ -769,10 +719,9 @@ void SAL_CALL Job::notifyTermination( /*IN*/ const css::lang::EventObject& ) thr
  */
 void SAL_CALL Job::queryClosing( const css::lang::EventObject& aEvent         ,
                                        sal_Bool                bGetsOwnership ) throw(css::util::CloseVetoException,
-                                                                                      css::uno::RuntimeException   )
+                                                                                      css::uno::RuntimeException, std::exception   )
 {
-    /* SAFE { */
-    WriteGuard aWriteLock(m_aLock);
+    SolarMutexGuard g;
 
     // do nothing, if no internal job is still running ...
     // The frame or model can be closed then successfully.
@@ -826,14 +775,10 @@ void SAL_CALL Job::queryClosing( const css::lang::EventObject& aEvent         ,
     // No veto ...
     // But don't call die() here or free our internal member.
     // This must be done inside notifyClosing() only. Otherwhise the
-    // might stopped job has no chance to return it's results or
+    // might stopped job has no chance to return its results or
     // call us back. We must give him the chance to finish it's work successfully.
-
-    aWriteLock.unlock();
-    /* } SAFE */
 }
 
-//________________________________
 /**
     @short  inform us about frame closing
     @descr  Instead of the method queryClosing(), here is no chance to disagree with that.
@@ -842,43 +787,42 @@ void SAL_CALL Job::queryClosing( const css::lang::EventObject& aEvent         ,
     @param  aEvent
             describes the broadcaster and must be the frame or model instance we know
  */
-void SAL_CALL Job::notifyClosing( const css::lang::EventObject& ) throw(css::uno::RuntimeException)
+void SAL_CALL Job::notifyClosing( const css::lang::EventObject& ) throw(css::uno::RuntimeException, std::exception)
 {
     die();
     // Do nothing else here. Our internal resources was released ...
 }
 
-//________________________________
 /**
-    @short      shouldn't be called normaly
+    @short      shouldn't be called normally
     @descr      But it doesn't matter, who called it. We have to kill our internal
                 running processes hardly.
 
     @param      aEvent
                 describe the broadcaster
 */
-void SAL_CALL Job::disposing( const css::lang::EventObject& aEvent ) throw(css::uno::RuntimeException)
+void SAL_CALL Job::disposing( const css::lang::EventObject& aEvent ) throw(css::uno::RuntimeException, std::exception)
 {
     /* SAFE { */
-    WriteGuard aWriteLock(m_aLock);
+    SolarMutexClearableGuard aWriteLock;
 
     if (m_xDesktop.is() && aEvent.Source == m_xDesktop)
     {
         m_xDesktop.clear();
-        m_bListenOnDesktop = sal_False;
+        m_bListenOnDesktop = false;
     }
     else if (m_xFrame.is() && aEvent.Source == m_xFrame)
     {
         m_xFrame = css::uno::Reference< css::frame::XFrame >();
-        m_bListenOnFrame = sal_False;
+        m_bListenOnFrame = false;
     }
     else if (m_xModel.is() && aEvent.Source == m_xModel)
     {
         m_xModel = css::uno::Reference< css::frame::XModel >();
-        m_bListenOnModel = sal_False;
+        m_bListenOnModel = false;
     }
 
-    aWriteLock.unlock();
+    aWriteLock.clear();
     /* } SAFE */
 
     die();
