@@ -34,10 +34,6 @@ FrameworkStatusBar::FrameworkStatusBar(
     SetOutputSizePixel( CalcWindowSizePixel() );
 }
 
-FrameworkStatusBar::~FrameworkStatusBar()
-{
-}
-
 void FrameworkStatusBar::SetStatusBarManager( StatusBarManager* pStatusBarManager )
 {
     SolarMutexGuard aSolarMutexGuard;
@@ -56,10 +52,8 @@ void FrameworkStatusBar::Command( const CommandEvent& rEvt )
         m_pMgr->Command( rEvt );
 }
 
-void FrameworkStatusBar::StateChanged( StateChangedType nType )
+void FrameworkStatusBar::StateChanged( StateChangedType )
 {
-    if ( m_pMgr )
-        m_pMgr->StateChanged( nType );
 }
 
 void FrameworkStatusBar::DataChanged( const DataChangedEvent& rDCEvt )
