@@ -62,11 +62,11 @@ void TestLanguageTag::testAllTags()
         CPPUNIT_ASSERT_MESSAGE("Default script should be stripped after canonicalize.", aBcp47 == "de-DE" );
         CPPUNIT_ASSERT( aLocale.Language == "de" );
         CPPUNIT_ASSERT( aLocale.Country == "DE" );
-        CPPUNIT_ASSERT( aLocale.Variant == "" );
+        CPPUNIT_ASSERT( aLocale.Variant.isEmpty() );
         CPPUNIT_ASSERT( nLanguageType == LANGUAGE_GERMAN );
         CPPUNIT_ASSERT( de_DE.getLanguage() == "de" );
         CPPUNIT_ASSERT( de_DE.getCountry() == "DE" );
-        CPPUNIT_ASSERT( de_DE.getScript() == "" );
+        CPPUNIT_ASSERT( de_DE.getScript().isEmpty() );
         CPPUNIT_ASSERT( de_DE.getLanguageAndScript() == "de" );
 #else
         // The simple replacement code doesn't do any fancy stuff.
@@ -90,12 +90,12 @@ void TestLanguageTag::testAllTags()
 #if USE_LIBLANGTAG
         CPPUNIT_ASSERT( klingon.getBcp47() == "tlh" );
         CPPUNIT_ASSERT( aLocale.Language == "tlh" );
-        CPPUNIT_ASSERT( aLocale.Country == "" );
-        CPPUNIT_ASSERT( aLocale.Variant == "" );
+        CPPUNIT_ASSERT( aLocale.Country.isEmpty() );
+        CPPUNIT_ASSERT( aLocale.Variant.isEmpty() );
         CPPUNIT_ASSERT( LanguageTag::isOnTheFlyID( klingon.getLanguageType()) );
-        CPPUNIT_ASSERT( klingon.isValidBcp47() == true );
-        CPPUNIT_ASSERT( klingon.isIsoLocale() == true );
-        CPPUNIT_ASSERT( klingon.isIsoODF() == true );
+        CPPUNIT_ASSERT( klingon.isValidBcp47() );
+        CPPUNIT_ASSERT( klingon.isIsoLocale() );
+        CPPUNIT_ASSERT( klingon.isIsoODF() );
         LanguageType nLang = klingon.getLanguageType();
         LanguageTag klingon_id( nLang);
         CPPUNIT_ASSERT( klingon_id.getBcp47() == "tlh" );
@@ -121,11 +121,11 @@ void TestLanguageTag::testAllTags()
         CPPUNIT_ASSERT( sr_RS.getBcp47() == s_sr_RS );
         CPPUNIT_ASSERT( aLocale.Language == "sr" );
         CPPUNIT_ASSERT( aLocale.Country == "RS" );
-        CPPUNIT_ASSERT( aLocale.Variant == "" );
+        CPPUNIT_ASSERT( aLocale.Variant.isEmpty() );
         CPPUNIT_ASSERT( sr_RS.getLanguageType() == LANGUAGE_USER_SERBIAN_CYRILLIC_SERBIA );
-        CPPUNIT_ASSERT( sr_RS.isValidBcp47() == true );
-        CPPUNIT_ASSERT( sr_RS.isIsoLocale() == true );
-        CPPUNIT_ASSERT( sr_RS.isIsoODF() == true );
+        CPPUNIT_ASSERT( sr_RS.isValidBcp47() );
+        CPPUNIT_ASSERT( sr_RS.isIsoLocale() );
+        CPPUNIT_ASSERT( sr_RS.isIsoODF() );
     }
 
     {
@@ -137,9 +137,9 @@ void TestLanguageTag::testAllTags()
         CPPUNIT_ASSERT( aLocale.Country == "RS" );
         CPPUNIT_ASSERT( aLocale.Variant == s_sr_Latn_RS );
         CPPUNIT_ASSERT( sr_RS.getLanguageType() == LANGUAGE_USER_SERBIAN_LATIN_SERBIA );
-        CPPUNIT_ASSERT( sr_RS.isValidBcp47() == true );
-        CPPUNIT_ASSERT( sr_RS.isIsoLocale() == false );
-        CPPUNIT_ASSERT( sr_RS.isIsoODF() == true );
+        CPPUNIT_ASSERT( sr_RS.isValidBcp47() );
+        CPPUNIT_ASSERT( !sr_RS.isIsoLocale() );
+        CPPUNIT_ASSERT( sr_RS.isIsoODF() );
         CPPUNIT_ASSERT( sr_RS.getLanguage() == "sr" );
         CPPUNIT_ASSERT( sr_RS.getCountry() == "RS" );
         CPPUNIT_ASSERT( sr_RS.getScript() == "Latn" );
@@ -155,9 +155,9 @@ void TestLanguageTag::testAllTags()
         CPPUNIT_ASSERT( aLocale.Country == "CS" );
         CPPUNIT_ASSERT( aLocale.Variant == s_sr_Latn_CS );
         CPPUNIT_ASSERT( sr_Latn_CS.getLanguageType() == LANGUAGE_SERBIAN_LATIN_SAM );
-        CPPUNIT_ASSERT( sr_Latn_CS.isValidBcp47() == true );
-        CPPUNIT_ASSERT( sr_Latn_CS.isIsoLocale() == false );
-        CPPUNIT_ASSERT( sr_Latn_CS.isIsoODF() == true );
+        CPPUNIT_ASSERT( sr_Latn_CS.isValidBcp47() );
+        CPPUNIT_ASSERT( !sr_Latn_CS.isIsoLocale() );
+        CPPUNIT_ASSERT( sr_Latn_CS.isIsoODF() );
         CPPUNIT_ASSERT( sr_Latn_CS.getLanguage() == "sr" );
         CPPUNIT_ASSERT( sr_Latn_CS.getCountry() == "CS" );
         CPPUNIT_ASSERT( sr_Latn_CS.getScript() == "Latn" );
@@ -186,9 +186,9 @@ void TestLanguageTag::testAllTags()
         CPPUNIT_ASSERT( aLocale.Country == "RS" );
         CPPUNIT_ASSERT( aLocale.Variant == "sr-Latn-RS" );
         CPPUNIT_ASSERT( sh_RS.getLanguageType() == LANGUAGE_USER_SERBIAN_LATIN_SERBIA );
-        CPPUNIT_ASSERT( sh_RS.isValidBcp47() == true );
-        CPPUNIT_ASSERT( sh_RS.isIsoLocale() == false );
-        CPPUNIT_ASSERT( sh_RS.isIsoODF() == true );
+        CPPUNIT_ASSERT( sh_RS.isValidBcp47() );
+        CPPUNIT_ASSERT( !sh_RS.isIsoLocale() );
+        CPPUNIT_ASSERT( sh_RS.isIsoODF() );
         CPPUNIT_ASSERT( sh_RS.getLanguage() == "sr" );
         CPPUNIT_ASSERT( sh_RS.getCountry() == "RS" );
         CPPUNIT_ASSERT( sh_RS.getScript() == "Latn" );
@@ -216,14 +216,14 @@ void TestLanguageTag::testAllTags()
         CPPUNIT_ASSERT( bs_Latn_BA.getBcp47() == "bs-BA" );
         CPPUNIT_ASSERT( aLocale.Language == "bs" );
         CPPUNIT_ASSERT( aLocale.Country == "BA" );
-        CPPUNIT_ASSERT( aLocale.Variant == "" );
+        CPPUNIT_ASSERT( aLocale.Variant.isEmpty() );
         CPPUNIT_ASSERT( bs_Latn_BA.getLanguageType() == LANGUAGE_BOSNIAN_LATIN_BOSNIA_HERZEGOVINA );
-        CPPUNIT_ASSERT( bs_Latn_BA.isValidBcp47() == true );
-        CPPUNIT_ASSERT( bs_Latn_BA.isIsoLocale() == true );
-        CPPUNIT_ASSERT( bs_Latn_BA.isIsoODF() == true );
+        CPPUNIT_ASSERT( bs_Latn_BA.isValidBcp47() );
+        CPPUNIT_ASSERT( bs_Latn_BA.isIsoLocale() );
+        CPPUNIT_ASSERT( bs_Latn_BA.isIsoODF() );
         CPPUNIT_ASSERT( bs_Latn_BA.getLanguage() == "bs" );
         CPPUNIT_ASSERT( bs_Latn_BA.getCountry() == "BA" );
-        CPPUNIT_ASSERT( bs_Latn_BA.getScript() == "" );
+        CPPUNIT_ASSERT( bs_Latn_BA.getScript().isEmpty() );
         CPPUNIT_ASSERT( bs_Latn_BA.getLanguageAndScript() == "bs" );
         ::std::vector< OUString > bs_Latn_BA_Fallbacks( bs_Latn_BA.getFallbackStrings( true));
         CPPUNIT_ASSERT( bs_Latn_BA_Fallbacks.size() == 2);
@@ -243,12 +243,12 @@ void TestLanguageTag::testAllTags()
         CPPUNIT_ASSERT( aLocale.Country == "ES" );
         CPPUNIT_ASSERT( aLocale.Variant == s_ca_ES_valencia );
         CPPUNIT_ASSERT( ca_ES_valencia.getLanguageType() == LANGUAGE_CATALAN_VALENCIAN );
-        CPPUNIT_ASSERT( ca_ES_valencia.isValidBcp47() == true );
-        CPPUNIT_ASSERT( ca_ES_valencia.isIsoLocale() == false );
-        CPPUNIT_ASSERT( ca_ES_valencia.isIsoODF() == false );
+        CPPUNIT_ASSERT( ca_ES_valencia.isValidBcp47() );
+        CPPUNIT_ASSERT( !ca_ES_valencia.isIsoLocale() );
+        CPPUNIT_ASSERT( !ca_ES_valencia.isIsoODF() );
         CPPUNIT_ASSERT( ca_ES_valencia.getLanguage() == "ca" );
         CPPUNIT_ASSERT( ca_ES_valencia.getCountry() == "ES" );
-        CPPUNIT_ASSERT( ca_ES_valencia.getScript() == "" );
+        CPPUNIT_ASSERT( ca_ES_valencia.getScript().isEmpty() );
         CPPUNIT_ASSERT( ca_ES_valencia.getLanguageAndScript() == "ca" );
         ::std::vector< OUString > ca_ES_valencia_Fallbacks( ca_ES_valencia.getFallbackStrings( true));
         CPPUNIT_ASSERT( ca_ES_valencia_Fallbacks.size() == 5);
@@ -266,15 +266,15 @@ void TestLanguageTag::testAllTags()
         lang::Locale aLocale = ca_valencia.getLocale();
         CPPUNIT_ASSERT( ca_valencia.getBcp47() == s_ca_valencia );
         CPPUNIT_ASSERT( aLocale.Language == "qlt" );
-        CPPUNIT_ASSERT( aLocale.Country == "" );
+        CPPUNIT_ASSERT( aLocale.Country.isEmpty() );
         CPPUNIT_ASSERT( aLocale.Variant == s_ca_valencia );
         CPPUNIT_ASSERT( LanguageTag::isOnTheFlyID( ca_valencia.getLanguageType()) );
-        CPPUNIT_ASSERT( ca_valencia.isValidBcp47() == true );
-        CPPUNIT_ASSERT( ca_valencia.isIsoLocale() == false );
-        CPPUNIT_ASSERT( ca_valencia.isIsoODF() == false );
+        CPPUNIT_ASSERT( ca_valencia.isValidBcp47() );
+        CPPUNIT_ASSERT( !ca_valencia.isIsoLocale() );
+        CPPUNIT_ASSERT( !ca_valencia.isIsoODF() );
         CPPUNIT_ASSERT( ca_valencia.getLanguage() == "ca" );
-        CPPUNIT_ASSERT( ca_valencia.getCountry() == "" );
-        CPPUNIT_ASSERT( ca_valencia.getScript() == "" );
+        CPPUNIT_ASSERT( ca_valencia.getCountry().isEmpty() );
+        CPPUNIT_ASSERT( ca_valencia.getScript().isEmpty() );
         CPPUNIT_ASSERT( ca_valencia.getLanguageAndScript() == "ca" );
         ::std::vector< OUString > ca_valencia_Fallbacks( ca_valencia.getFallbackStrings( true));
         CPPUNIT_ASSERT( ca_valencia_Fallbacks.size() == 2);
@@ -294,12 +294,12 @@ void TestLanguageTag::testAllTags()
         CPPUNIT_ASSERT( aLocale.Country == "ES" );
         CPPUNIT_ASSERT( aLocale.Variant == s_ca_ES_valencia );
         CPPUNIT_ASSERT( ca_XV.getLanguageType() == LANGUAGE_CATALAN_VALENCIAN );
-        CPPUNIT_ASSERT( ca_XV.isValidBcp47() == true );
-        CPPUNIT_ASSERT( ca_XV.isIsoLocale() == false );
-        CPPUNIT_ASSERT( ca_XV.isIsoODF() == false );
+        CPPUNIT_ASSERT( ca_XV.isValidBcp47() );
+        CPPUNIT_ASSERT( !ca_XV.isIsoLocale() );
+        CPPUNIT_ASSERT( !ca_XV.isIsoODF() );
         CPPUNIT_ASSERT( ca_XV.getLanguage() == "ca" );
         CPPUNIT_ASSERT( ca_XV.getCountry() == "ES" );
-        CPPUNIT_ASSERT( ca_XV.getScript() == "" );
+        CPPUNIT_ASSERT( ca_XV.getScript().isEmpty() );
         CPPUNIT_ASSERT( ca_XV.getLanguageAndScript() == "ca" );
         ::std::vector< OUString > ca_XV_Fallbacks( ca_XV.getFallbackStrings( true));
         CPPUNIT_ASSERT( ca_XV_Fallbacks.size() == 5);
@@ -318,14 +318,14 @@ void TestLanguageTag::testAllTags()
         CPPUNIT_ASSERT( de_DE.getBcp47() == s_de_DE );
         CPPUNIT_ASSERT( aLocale.Language == "de" );
         CPPUNIT_ASSERT( aLocale.Country == "DE" );
-        CPPUNIT_ASSERT( aLocale.Variant == "" );
+        CPPUNIT_ASSERT( aLocale.Variant.isEmpty() );
         CPPUNIT_ASSERT( de_DE.getLanguageType() == LANGUAGE_GERMAN );
-        CPPUNIT_ASSERT( de_DE.isValidBcp47() == true );
-        CPPUNIT_ASSERT( de_DE.isIsoLocale() == true );
-        CPPUNIT_ASSERT( de_DE.isIsoODF() == true );
+        CPPUNIT_ASSERT( de_DE.isValidBcp47() );
+        CPPUNIT_ASSERT( de_DE.isIsoLocale() );
+        CPPUNIT_ASSERT( de_DE.isIsoODF() );
         CPPUNIT_ASSERT( de_DE.getLanguage() == "de" );
         CPPUNIT_ASSERT( de_DE.getCountry() == "DE" );
-        CPPUNIT_ASSERT( de_DE.getScript() == "" );
+        CPPUNIT_ASSERT( de_DE.getScript().isEmpty() );
         CPPUNIT_ASSERT( de_DE.getLanguageAndScript() == "de" );
         ::std::vector< OUString > de_DE_Fallbacks( de_DE.getFallbackStrings( true));
         CPPUNIT_ASSERT( de_DE_Fallbacks.size() == 2);
@@ -341,7 +341,7 @@ void TestLanguageTag::testAllTags()
         CPPUNIT_ASSERT( de_DE.getBcp47() == s_de_DE );
         CPPUNIT_ASSERT( aLocale.Language == "de" );
         CPPUNIT_ASSERT( aLocale.Country == "DE" );
-        CPPUNIT_ASSERT( aLocale.Variant == "" );
+        CPPUNIT_ASSERT( aLocale.Variant.isEmpty() );
         CPPUNIT_ASSERT( de_DE.getLanguageType() == LANGUAGE_GERMAN );
     }
 
@@ -352,7 +352,7 @@ void TestLanguageTag::testAllTags()
         CPPUNIT_ASSERT( de_DE.getBcp47() == s_de_DE );
         CPPUNIT_ASSERT( aLocale.Language == "de" );
         CPPUNIT_ASSERT( aLocale.Country == "DE" );
-        CPPUNIT_ASSERT( aLocale.Variant == "" );
+        CPPUNIT_ASSERT( aLocale.Variant.isEmpty() );
         CPPUNIT_ASSERT( de_DE.getLanguageType() == LANGUAGE_GERMAN );
     }
 
@@ -363,8 +363,8 @@ void TestLanguageTag::testAllTags()
         lang::Locale aLocale = de.getLocale();
         CPPUNIT_ASSERT( de.getBcp47() == s_de );
         CPPUNIT_ASSERT( aLocale.Language == "de" );
-        CPPUNIT_ASSERT( aLocale.Country == "" );
-        CPPUNIT_ASSERT( aLocale.Variant == "" );
+        CPPUNIT_ASSERT( aLocale.Country.isEmpty() );
+        CPPUNIT_ASSERT( aLocale.Variant.isEmpty() );
         LanguageType de_LangID = de.getLanguageType();
         CPPUNIT_ASSERT( de_LangID != LANGUAGE_GERMAN );
         CPPUNIT_ASSERT( de_LangID == MsLangId::getPrimaryLanguage( LANGUAGE_GERMAN) );
@@ -405,12 +405,12 @@ void TestLanguageTag::testAllTags()
         lang::Locale aLocale = de_1901.getLocale();
         CPPUNIT_ASSERT( de_1901.getBcp47() == s_de_1901 );
         CPPUNIT_ASSERT( aLocale.Language == "qlt" );
-        CPPUNIT_ASSERT( aLocale.Country == "" );
+        CPPUNIT_ASSERT( aLocale.Country.isEmpty() );
         CPPUNIT_ASSERT( aLocale.Variant == s_de_1901 );
         CPPUNIT_ASSERT( LanguageTag::isOnTheFlyID( de_1901.getLanguageType()) );
-        CPPUNIT_ASSERT( de_1901.isValidBcp47() == true );
-        CPPUNIT_ASSERT( de_1901.isIsoLocale() == false );
-        CPPUNIT_ASSERT( de_1901.isIsoODF() == false );
+        CPPUNIT_ASSERT( de_1901.isValidBcp47() );
+        CPPUNIT_ASSERT( !de_1901.isIsoLocale() );
+        CPPUNIT_ASSERT( !de_1901.isIsoODF() );
         CPPUNIT_ASSERT( de_1901.getLanguageAndScript() == "de" );
         CPPUNIT_ASSERT( de_1901.getVariants() == "1901" );
         ::std::vector< OUString > de_1901_Fallbacks( de_1901.getFallbackStrings( true));
@@ -430,9 +430,9 @@ void TestLanguageTag::testAllTags()
         CPPUNIT_ASSERT( aLocale.Country == "GB" );  // only 'GB' because we handle it, liblangtag would not fill this
         CPPUNIT_ASSERT( aLocale.Variant == s_en_GB_oed );
         CPPUNIT_ASSERT( en_GB_oed.getLanguageType() == LANGUAGE_USER_ENGLISH_UK_OED );
-        CPPUNIT_ASSERT( en_GB_oed.isValidBcp47() == true );
-        CPPUNIT_ASSERT( en_GB_oed.isIsoLocale() == false );
-        CPPUNIT_ASSERT( en_GB_oed.isIsoODF() == false );
+        CPPUNIT_ASSERT( en_GB_oed.isValidBcp47() );
+        CPPUNIT_ASSERT( !en_GB_oed.isIsoLocale() );
+        CPPUNIT_ASSERT( !en_GB_oed.isIsoODF() );
         CPPUNIT_ASSERT( en_GB_oed.getLanguageAndScript() == "en" );
         CPPUNIT_ASSERT( en_GB_oed.getVariants() == "oed" );
         ::std::vector< OUString > en_GB_oed_Fallbacks( en_GB_oed.getFallbackStrings( true));
@@ -482,8 +482,8 @@ void TestLanguageTag::testAllTags()
         lang::Locale aLocale = qtz.getLocale();
         CPPUNIT_ASSERT( qtz.getBcp47() == s_qtz );
         CPPUNIT_ASSERT( aLocale.Language == "qtz" );
-        CPPUNIT_ASSERT( aLocale.Country == "" );
-        CPPUNIT_ASSERT( aLocale.Variant == "" );
+        CPPUNIT_ASSERT( aLocale.Country.isEmpty() );
+        CPPUNIT_ASSERT( aLocale.Variant.isEmpty() );
         CPPUNIT_ASSERT( qtz.getLanguageType() == LANGUAGE_USER_KEYID );
     }
 
@@ -494,8 +494,8 @@ void TestLanguageTag::testAllTags()
         lang::Locale aLocale = qty.getLocale();
         CPPUNIT_ASSERT( qty.getBcp47() == s_qty );
         CPPUNIT_ASSERT( aLocale.Language == "qty" );
-        CPPUNIT_ASSERT( aLocale.Country == "" );
-        CPPUNIT_ASSERT( aLocale.Variant == "" );
+        CPPUNIT_ASSERT( aLocale.Country.isEmpty() );
+        CPPUNIT_ASSERT( aLocale.Variant.isEmpty() );
         CPPUNIT_ASSERT( LanguageTag::isOnTheFlyID( qty.getLanguageType()) );
     }
 
@@ -506,7 +506,7 @@ void TestLanguageTag::testAllTags()
         lang::Locale aLocale = xcomment.getLocale();
         CPPUNIT_ASSERT( xcomment.getBcp47() == s_xcomment );
         CPPUNIT_ASSERT( aLocale.Language == "qlt" );
-        CPPUNIT_ASSERT( aLocale.Country == "" );
+        CPPUNIT_ASSERT( aLocale.Country.isEmpty() );
         CPPUNIT_ASSERT( aLocale.Variant == "x-comment" );
         CPPUNIT_ASSERT( xcomment.getLanguageType() == LANGUAGE_USER_PRIV_COMMENT );
     }
@@ -518,7 +518,7 @@ void TestLanguageTag::testAllTags()
         lang::Locale aLocale = xfoobar.getLocale();
         CPPUNIT_ASSERT( xfoobar.getBcp47() == s_xfoobar );
         CPPUNIT_ASSERT( aLocale.Language == "qlt" );
-        CPPUNIT_ASSERT( aLocale.Country == "" );
+        CPPUNIT_ASSERT( aLocale.Country.isEmpty() );
         CPPUNIT_ASSERT( aLocale.Variant == "x-foobar" );
         CPPUNIT_ASSERT( LanguageTag::isOnTheFlyID( xfoobar.getLanguageType()) );
     }
@@ -530,7 +530,7 @@ void TestLanguageTag::testAllTags()
         lang::Locale aLocale = joker.getLocale();
         CPPUNIT_ASSERT( joker.getBcp47() == s_joker );
         CPPUNIT_ASSERT( aLocale.Language == "qlt" );
-        CPPUNIT_ASSERT( aLocale.Country == "" );
+        CPPUNIT_ASSERT( aLocale.Country.isEmpty() );
         CPPUNIT_ASSERT( aLocale.Variant == "*" );
         CPPUNIT_ASSERT( joker.getLanguageType() == LANGUAGE_USER_PRIV_JOKER );
 
@@ -538,7 +538,7 @@ void TestLanguageTag::testAllTags()
         aLocale = joker.getLocale();
         CPPUNIT_ASSERT( joker.getBcp47() == s_joker );
         CPPUNIT_ASSERT( aLocale.Language == "qlt" );
-        CPPUNIT_ASSERT( aLocale.Country == "" );
+        CPPUNIT_ASSERT( aLocale.Country.isEmpty() );
         CPPUNIT_ASSERT( aLocale.Variant == "*" );
         CPPUNIT_ASSERT( joker.getLanguageType() == LANGUAGE_USER_PRIV_JOKER );
     }
@@ -553,7 +553,7 @@ void TestLanguageTag::testAllTags()
         CPPUNIT_ASSERT( aTag.getBcp47() == "de-DE" );
         CPPUNIT_ASSERT( aLocale.Language == "de" );
         CPPUNIT_ASSERT( aLocale.Country == "DE" );
-        CPPUNIT_ASSERT( aLocale.Variant == "" );
+        CPPUNIT_ASSERT( aLocale.Variant.isEmpty() );
         CPPUNIT_ASSERT( aTag.getLanguageType() == LANGUAGE_GERMAN );
 
         aTag.reset( "en-US" );
@@ -561,7 +561,7 @@ void TestLanguageTag::testAllTags()
         CPPUNIT_ASSERT( aTag.getBcp47() == "en-US" );
         CPPUNIT_ASSERT( aLocale.Language == "en" );
         CPPUNIT_ASSERT( aLocale.Country == "US" );
-        CPPUNIT_ASSERT( aLocale.Variant == "" );
+        CPPUNIT_ASSERT( aLocale.Variant.isEmpty() );
         CPPUNIT_ASSERT( aTag.getLanguageType() == LANGUAGE_ENGLISH_US );
 
         aTag.reset( lang::Locale( "de", "DE", "" ) );
@@ -569,7 +569,7 @@ void TestLanguageTag::testAllTags()
         CPPUNIT_ASSERT( aTag.getBcp47() == "de-DE" );
         CPPUNIT_ASSERT( aLocale.Language == "de" );
         CPPUNIT_ASSERT( aLocale.Country == "DE" );
-        CPPUNIT_ASSERT( aLocale.Variant == "" );
+        CPPUNIT_ASSERT( aLocale.Variant.isEmpty() );
         CPPUNIT_ASSERT( aTag.getLanguageType() == LANGUAGE_GERMAN );
     }
 
@@ -579,16 +579,39 @@ void TestLanguageTag::testAllTags()
         lang::Locale aLocale = uab.getLocale();
         CPPUNIT_ASSERT( uab.getBcp47() == s_uab );
         CPPUNIT_ASSERT( aLocale.Language == "qlt" );
-        CPPUNIT_ASSERT( aLocale.Country == "" );
+        CPPUNIT_ASSERT( aLocale.Country.isEmpty() );
         CPPUNIT_ASSERT( aLocale.Variant == s_uab );
         CPPUNIT_ASSERT( uab.getLanguageType() == LANGUAGE_DONTKNOW );
-        CPPUNIT_ASSERT( uab.isValidBcp47() == false );
-        CPPUNIT_ASSERT( uab.isIsoLocale() == false );
-        CPPUNIT_ASSERT( uab.isIsoODF() == false );
+        CPPUNIT_ASSERT( !uab.isValidBcp47() );
+        CPPUNIT_ASSERT( !uab.isIsoLocale() );
+        CPPUNIT_ASSERT( !uab.isIsoODF() );
+    }
+
+    // test static isValidBcp47() method
+    {
+        OUString aCanonicalized;
+        CPPUNIT_ASSERT( LanguageTag::isValidBcp47( "en-US", &aCanonicalized) && aCanonicalized == "en-US" );
+        CPPUNIT_ASSERT( LanguageTag::isValidBcp47( "x-foobar", &aCanonicalized) && aCanonicalized == "x-foobar" );
+        CPPUNIT_ASSERT( LanguageTag::isValidBcp47( "qaa", &aCanonicalized) && aCanonicalized == "qaa" );
+        CPPUNIT_ASSERT( !LanguageTag::isValidBcp47( "unreg-and-bad", &aCanonicalized) );
+        CPPUNIT_ASSERT( LanguageTag::isValidBcp47( "en-US", &aCanonicalized, true) && aCanonicalized == "en-US" );
+        CPPUNIT_ASSERT( !LanguageTag::isValidBcp47( "x-foobar", &aCanonicalized, true) && aCanonicalized == "x-foobar" );
+        CPPUNIT_ASSERT( LanguageTag::isValidBcp47( "qaa", &aCanonicalized, true) && aCanonicalized == "qaa" );
+#if USE_LIBLANGTAG
+        CPPUNIT_ASSERT( LanguageTag::isValidBcp47( "de-Latn-DE", &aCanonicalized) && aCanonicalized == "de-DE" );
+        /* TODO: at least some (those we know) grandfathered tags should be
+         * recognized by the replacement code. */
+        CPPUNIT_ASSERT( LanguageTag::isValidBcp47( "en-GB-oed", &aCanonicalized) );
+        // en-GB-oed has become deprecated in updated language-subtag-registry database
+        // (liblangtag 0.5.7)
+        CPPUNIT_ASSERT( ( aCanonicalized == "en-GB-oxendict" ) || ( aCanonicalized == "en-GB-oed" ) );
+#else
+        CPPUNIT_ASSERT( LanguageTag::isValidBcp47( "de-Latn-DE", &aCanonicalized) && aCanonicalized == "de-Latn-DE" );
+#endif
     }
 }
 
-static bool checkMapping( const OUString rStr1, const OUString& rStr2 )
+static bool checkMapping( const OUString& rStr1, const OUString& rStr2 )
 {
     if (rStr1 == "la-Latn"     ) return rStr2 == "la";
     if (rStr1 == "tzm-Latn-DZ" ) return rStr2 == "kab-DZ";
