@@ -101,16 +101,27 @@
 #include "lwptable.hxx"
 
 LwpPara::LwpPara(LwpObjectHeader& objHdr, LwpSvStream* pStrm)
-    : LwpDLVList(objHdr, pStrm), m_pBreaks(NULL), m_pIndentOverride(NULL)
-    , m_bHasBullet(sal_False), m_pSilverBullet(NULL)
-    , /*m_pParaNumbering(NULL),*/ m_pBullOver(NULL)
-    , m_bBullContinue(sal_False)
-    , m_bHasDropcap(sal_False), m_nLines(0), m_nChars(0)
-    , m_pDropcapLayout(NULL), m_BelowSpacing(0), m_pXFContainer(NULL)
+    : LwpDLVList(objHdr, pStrm)
+    , m_nOrdinal(0)
+    , m_nFlags(0)
+    , m_nLevel(0)
+    , m_pProps(NULL)
+    , m_pBreaks(NULL)
+    , m_pIndentOverride(NULL)
+    , m_FontID(0)
+    , m_AllText("")
+    , m_bHasBullet(false)
+    , m_pSilverBullet(NULL)
+    , m_pBullOver(NULL)
+    , m_bBullContinue(false)
+    , m_SectionStyleName("")
+    , m_bHasDropcap(false)
+    , m_nLines(0)
+    , m_nChars(0)
+    , m_pDropcapLayout(NULL)
+    , m_BelowSpacing(0)
+    , m_pXFContainer(NULL)
 {
-    m_pProps = NULL;
-    m_SectionStyleName = A2OUSTR("");
-    m_AllText = A2OUSTR("");
 }
 
 LwpPara::~LwpPara()
@@ -150,12 +161,12 @@ void LwpPara::Read()
 {
     LwpDLVList::Read();
 
-    sal_Bool Simple;
-    sal_Bool Notify = sal_False;
+    bool Simple;
+    bool Notify = false;
     if(LwpFileHeader::m_nFileRevision<0x0006)
-        Simple = sal_False;
+        Simple = false;
     else if(LwpFileHeader::m_nFileRevision<0x000B)
-        Simple = m_pObjStrm->QuickReaduInt8();
+        Simple = m_pObjStrm->QuickReaduInt8() != 0;
     else
     {
         sal_uInt8 Flag = m_pObjStrm->QuickReaduInt8();
@@ -163,8 +174,8 @@ void LwpPara::Read()
         const int DISK_SIMPLE = 1;
         const int DISK_NOTIFY = 2;
 
-        Simple = (Flag & DISK_SIMPLE) ? sal_True : sal_False;
-        Notify = (Flag & DISK_NOTIFY) ? sal_True : sal_False;
+        Simple = (Flag & DISK_SIMPLE) != 0;
+        Notify = (Flag & DISK_NOTIFY) != 0;
     }
 
     if(!Simple)
@@ -188,7 +199,7 @@ void LwpPara::Read()
             if (Notify)
             {
                 LwpForked3NotifyList* pNotifyList = new LwpForked3NotifyList();
-                pNotifyList->GetExtraList()->Read(m_pObjStrm);
+                pNotifyList->GetExtraList().Read(m_pObjStrm);
                 pNotifyList->Read(m_pObjStrm);
                 delete pNotifyList;
             }
@@ -203,11 +214,6 @@ void LwpPara::Read()
     if(!Simple)
     {
         m_Hint.Read(m_pObjStrm);
-        if (IsBadHintsInFile())
-        {
-            // This hint is no good, so throw it away -- SDC 9/28/95
-            m_Hint.Reset();
-        }
     }
 
     m_Story.ReadIndexed(m_pObjStrm);
@@ -257,9 +263,9 @@ void LwpPara::XFConvert(XFContentContainer* pCont)
 {
     m_pXFContainer = pCont;
 
-    LwpStory *pStory = dynamic_cast<LwpStory*>(m_Story.obj());
+    LwpStory *pStory = dynamic_cast<LwpStory*>(m_Story.obj().get());
 
-    if (pStory && pStory->GetDropcapFlag() == sal_True)
+    if (pStory && pStory->GetDropcapFlag())
     {
         ParseDropcapContent();
         return;
@@ -296,7 +302,7 @@ void LwpPara::XFConvert(XFContentContainer* pCont)
         if (pBulletStyleMgr)
         {
             pBulletStyleMgr->SetCurrentSilverBullet(LwpObjectID());
-            pBulletStyleMgr->SetContinueFlag(sal_False);
+            pBulletStyleMgr->SetContinueFlag(false);
         }
         m_pXFContainer->Add(pPara);
     }
@@ -308,31 +314,31 @@ void LwpPara::XFConvert(XFContentContainer* pCont)
         AddBreakAfter(m_pXFContainer);
 }
 
-sal_Bool LwpPara::RegisterMasterPage(XFParaStyle* pBaseStyle)
+bool LwpPara::RegisterMasterPage(XFParaStyle* pBaseStyle)
 {
-    sal_Bool bSuccess = sal_False;
+    bool bSuccess = false;
     //get story
-    LwpStory* pStory = dynamic_cast<LwpStory*>(m_Story.obj());
+    LwpStory* pStory = dynamic_cast<LwpStory*>(m_Story.obj().get());
     //if pagelayout is modified, register the pagelayout
     if(pStory && pStory->IsPMModified())
     {
-        sal_Bool bNewSection = pStory->IsNeedSection();
+        bool bNewSection = pStory->IsNeedSection();
         LwpPageLayout* pLayout = pStory->GetCurrentLayout();
         if(bNewSection)
         {
             RegisterNewSectionStyle(pLayout);
         }
 
-        bSuccess = sal_True;
+        bSuccess = true;
         //register master page style
         XFParaStyle* pOverStyle = new XFParaStyle();
         *pOverStyle = *pBaseStyle;
-        pOverStyle->SetStyleName( A2OUSTR(""));
+        pOverStyle->SetStyleName( "");
         pOverStyle->SetMasterPage(pLayout->GetStyleName());
         if (!m_ParentStyleName.isEmpty())
                     pOverStyle->SetParentStyleName(m_ParentStyleName);
         XFStyleManager* pXFStyleManager = LwpGlobalMgr::GetInstance()->GetXFStyleManager();
-        m_StyleName = pXFStyleManager->AddStyle(pOverStyle)->GetStyleName();
+        m_StyleName = pXFStyleManager->AddStyle(pOverStyle).m_pStyle->GetStyleName();
     }
     return bSuccess;
 }
@@ -355,37 +361,37 @@ void LwpPara::RegisterStyle()
 
     if (GetParaStyle()->GetIndent())
     {
-        std::auto_ptr<LwpIndentOverride> pIndentOverride(GetParaStyle()->GetIndent()->clone());
+        std::unique_ptr<LwpIndentOverride> pIndentOverride(GetParaStyle()->GetIndent()->clone());
         delete m_pIndentOverride;
         m_pIndentOverride = pIndentOverride.release();
     }
 
     XFParaStyle* pOverStyle = NULL;
-    sal_Bool noSpacing = sal_True;
-    sal_Bool noIndent = sal_True;
+    bool noSpacing = true;
     LwpParaProperty* pBulletProps = NULL, *pNumberingProps = NULL;
 
     if (m_pProps != NULL)
     {
+        bool noIndent = true;
         pOverStyle = new XFParaStyle;
         *pOverStyle = *pBaseStyle;
-        pOverStyle->SetStyleName(A2OUSTR(""));
+        pOverStyle->SetStyleName("");
         LwpParaProperty* pProps = m_pProps;
         sal_uInt32 PropType;
-        LwpParaStyle* pParaStyle = dynamic_cast<LwpParaStyle*>(m_ParaStyle.obj());
-        while(pProps)
+        LwpParaStyle& rParaStyle = dynamic_cast<LwpParaStyle&>(*m_ParaStyle.obj());
+        while (pProps)
         {
             PropType = pProps->GetType();
             switch(PropType)
             {
             case PP_LOCAL_ALIGN:
             {
-                if (!pParaStyle->GetAlignment())
+                if (!rParaStyle.GetAlignment())
                     OverrideAlignment(NULL,static_cast<LwpParaAlignProperty*>(pProps)->GetAlignment(),pOverStyle);
                 else
                 {
                     boost::scoped_ptr<LwpAlignmentOverride> const pAlign(
-                            pParaStyle->GetAlignment()->clone());
+                            rParaStyle.GetAlignment()->clone());
                     OverrideAlignment(pAlign.get(),
                             static_cast<LwpParaAlignProperty*>(pProps)->GetAlignment(),
                             pOverStyle);
@@ -394,8 +400,8 @@ void LwpPara::RegisterStyle()
                 break;
             case PP_LOCAL_INDENT:
             {
-                noIndent = sal_False;
-                if (!pParaStyle->GetIndent())
+                noIndent = false;
+                if (!rParaStyle.GetIndent())
                     OverrideIndent(NULL,static_cast<LwpParaIndentProperty*>(pProps)->GetIndent(),pOverStyle);
 
                 else
@@ -406,110 +412,109 @@ void LwpPara::RegisterStyle()
                 break;
             case PP_LOCAL_SPACING:
             {
-                noSpacing = sal_False;
-                if (!pParaStyle->GetSpacing())
+                noSpacing = false;
+                if (!rParaStyle.GetSpacing())
                     OverrideSpacing(NULL,static_cast<LwpParaSpacingProperty*>(pProps)->GetSpacing(),pOverStyle);
                 else
                 {
                     boost::scoped_ptr<LwpSpacingOverride> const
-                        pSpacing(pParaStyle->GetSpacing()->clone());
+                        pSpacing(rParaStyle.GetSpacing()->clone());
                     OverrideSpacing(pSpacing.get(),
                             static_cast<LwpParaSpacingProperty*>(pProps)->GetSpacing(),
                             pOverStyle);
                 }
             }
                 break;
-        // 01/25/2005
-        case PP_LOCAL_BORDER:
-        {
-            OverrideParaBorder(pProps, pOverStyle);
-            break;
-        }
-        case PP_LOCAL_BREAKS:
-        {
-            OverrideParaBreaks(pProps, pOverStyle);
-            break;
-        }
-        case PP_LOCAL_BULLET:
-        {
-            pBulletProps = pProps;
-//          OverrideParaBullet(pProps);
-            break;
-        }
-        case PP_LOCAL_NUMBERING:
-        {
-            pNumberingProps = pProps;
-//          OverrideParaNumbering(pProps);
-            break;
-        }
-        //end
-        case PP_LOCAL_TABRACK:
-        {
-            //, 01/28/05
-            /*LwpTabOverride* pTabOverride=pParaStyle->GetTabOverride();
-            if(!pTabOverride)
+            case PP_LOCAL_BORDER:
             {
-                OverrideTab(NULL,static_cast<LwpParaTabRackProperty*>(pProps)->GetTab(),pOverStyle);
+                OverrideParaBorder(pProps, pOverStyle);
+                break;
             }
-            else
+            case PP_LOCAL_BREAKS:
             {
-                OverrideTab(pTabOverride,static_cast<LwpParaTabRackProperty*>(pProps)->GetTab(),pOverStyle);
-            }*/
-            break;
-        }
-        case PP_LOCAL_BACKGROUND:
-        {
-/*          LwpBackgroundOverride aBackground;
-            if (!pParaStyle->GetBackground())
-                OverrideBackground(NULL,static_cast<LwpParaBackGroundProperty*>(pProps)->GetBackground(),pOverStyle);
-            else
-            {
-                aBackground = *(pParaStyle->GetaBackground());
-                OverrideBackground(&aBackground,static_cast<LwpParaBackGroundProperty*>(pProps)->GetBackground(),pOverStyle);
+                OverrideParaBreaks(pProps, pOverStyle);
+                break;
             }
-*/
-            // modified by , 06/03/2005
-            LwpBackgroundOverride* pBGOver = static_cast<LwpParaBackGroundProperty*>(pProps)->GetBackground();
-            if (pBGOver)
+            case PP_LOCAL_BULLET:
             {
-                LwpBackgroundStuff* pBGStuff = pBGOver->GetBGStuff();
-                if (pBGStuff && !pBGStuff->IsTransparent() )
+                pBulletProps = pProps;
+    //          OverrideParaBullet(pProps);
+                break;
+            }
+            case PP_LOCAL_NUMBERING:
+            {
+                pNumberingProps = pProps;
+    //          OverrideParaNumbering(pProps);
+                break;
+            }
+            //end
+            case PP_LOCAL_TABRACK:
+            {
+                //, 01/28/05
+                /*LwpTabOverride* pTabOverride=rParaStyle.GetTabOverride();
+                if(!pTabOverride)
                 {
-                    if (pBGStuff->IsPatternFill())
+                    OverrideTab(NULL,static_cast<LwpParaTabRackProperty*>(pProps)->GetTab(),pOverStyle);
+                }
+                else
+                {
+                    OverrideTab(pTabOverride,static_cast<LwpParaTabRackProperty*>(pProps)->GetTab(),pOverStyle);
+                }*/
+                break;
+            }
+            case PP_LOCAL_BACKGROUND:
+            {
+    /*          LwpBackgroundOverride aBackground;
+                if (!rParaStyle.GetBackground())
+                    OverrideBackground(NULL,static_cast<LwpParaBackGroundProperty*>(pProps)->GetBackground(),pOverStyle);
+                else
+                {
+                    aBackground = *(rParaStyle.GetaBackground());
+                    OverrideBackground(&aBackground,static_cast<LwpParaBackGroundProperty*>(pProps)->GetBackground(),pOverStyle);
+                }
+    */
+                // modified by , 06/03/2005
+                LwpBackgroundOverride* pBGOver = static_cast<LwpParaBackGroundProperty*>(pProps)->GetBackground();
+                if (pBGOver)
+                {
+                    LwpBackgroundStuff& rBGStuff = pBGOver->GetBGStuff();
+                    if (!rBGStuff.IsTransparent() )
                     {
-                        XFBGImage* pXFBGImage = pBGStuff->GetFillPattern();
-                        pOverStyle->SetBackImage(pXFBGImage);
-                    }
-                    else
-                    {
-                        LwpColor* pColor = pBGStuff->GetFillColor();
-                        if (pColor && pColor->IsValidColor())
+                        if (rBGStuff.IsPatternFill())
                         {
-                            XFColor aXFColor( pColor->To24Color());
-                            pOverStyle->SetBackColor( aXFColor );
+                            XFBGImage* pXFBGImage = rBGStuff.GetFillPattern();
+                            pOverStyle->SetBackImage(pXFBGImage);
+                        }
+                        else
+                        {
+                            LwpColor* pColor = rBGStuff.GetFillColor();
+                            if (pColor && pColor->IsValidColor())
+                            {
+                                XFColor aXFColor( pColor->To24Color());
+                                pOverStyle->SetBackColor( aXFColor );
+                            }
                         }
                     }
                 }
+                // end modified
+                        break;
+            }
+            default:
+                break;
             }
-            // end modified
-                    break;
-        }
-                default:
-                    break;
-                }
             pProps = pProps->GetNext();
         }
 
         if (noIndent && m_pIndentOverride)
+        {
+            if (m_pIndentOverride->IsUseRelative() && GetParent())
             {
-                if (m_pIndentOverride->IsUseRelative() && GetParent())
-                {
                 OverrideIndent(NULL,m_pIndentOverride,pOverStyle);
-                }
             }
-            if (!m_ParentStyleName.isEmpty())
-                pOverStyle->SetParentStyleName(m_ParentStyleName);
-            m_StyleName = pXFStyleManager->AddStyle(pOverStyle)->GetStyleName();
+        }
+        if (!m_ParentStyleName.isEmpty())
+            pOverStyle->SetParentStyleName(m_ParentStyleName);
+        m_StyleName = pXFStyleManager->AddStyle(pOverStyle).m_pStyle->GetStyleName();
 
     }
     else //use named style
@@ -523,7 +528,7 @@ void LwpPara::RegisterStyle()
                     OverrideIndent(NULL,m_pIndentOverride,pOverStyle);
                     if (!m_ParentStyleName.isEmpty())
                         pOverStyle->SetParentStyleName(m_ParentStyleName);
-                    m_StyleName = pXFStyleManager->AddStyle(pOverStyle)->GetStyleName();
+                    m_StyleName = pXFStyleManager->AddStyle(pOverStyle).m_pStyle->GetStyleName();
                 }
             }
     }
@@ -538,7 +543,7 @@ void LwpPara::RegisterStyle()
             pOverStyle->SetAlignType(enumXFAlignStart);
             if (!m_ParentStyleName.isEmpty())
                 pOverStyle->SetParentStyleName(m_ParentStyleName);
-            m_StyleName = pXFStyleManager->AddStyle(pOverStyle)->GetStyleName();
+            m_StyleName = pXFStyleManager->AddStyle(pOverStyle).m_pStyle->GetStyleName();
         }
     }
 
@@ -572,12 +577,9 @@ void LwpPara::RegisterStyle()
                     OUString aPreBullStyleName;
                     LwpNumberingOverride* pNumbering = this->GetParaNumbering();
                     sal_uInt16 nPosition = pNumbering->GetPosition();
-                    sal_Bool bLesser = m_pSilverBullet->IsLesserLevel(nPosition);
-                    /*sal_Bool bResetSection =*/ m_pSilverBullet->IsNewSection(nPosition);
-                    sal_Bool bHeading;
+                    bool bLesser = m_pSilverBullet->IsLesserLevel(nPosition);
                     LwpPara* pPara = this;
                     LwpPara* pPrePara = NULL;
-                    LwpSilverBullet* pParaSilverBullet = NULL;
                     sal_uInt16 nNum = 0, nLevel = 0, nFoundLevel = 0xffff, nFoundBound = 0;
 
                     nFoundBound = nLevel = pNumbering->GetLevel();
@@ -585,7 +587,7 @@ void LwpPara::RegisterStyle()
                     {
                         nFoundBound++;
                     }
-                    bHeading = pNumbering->IsHeading();
+                    bool bHeading = pNumbering->IsHeading();
 
                     while(true)
                     {
@@ -597,10 +599,10 @@ void LwpPara::RegisterStyle()
                             break;
                         }*/
 
-                        pParaSilverBullet = pPara->GetSilverBullet();
+                        LwpSilverBullet* pParaSilverBullet = pPara->GetSilverBullet();
                         pNumbering = pPara->GetParaNumbering();
 
-                        if (*(pPara->GetObjectID()) != *(this->GetObjectID()))
+                        if (pPara->GetObjectID() != this->GetObjectID())
                         {
                             if (!pParaSilverBullet)
                             {
@@ -611,7 +613,7 @@ void LwpPara::RegisterStyle()
                                 * higher than our current level.
                                 */
                             // restart based on Outline level?
-                            if (pNumbering && bLesser && (bHeading ? pNumbering->IsHeading() : sal_True))
+                            if (pNumbering && bLesser && (!bHeading || pNumbering->IsHeading()))
                             {
                                 if (nFoundLevel != 0xffff)
                                 {
@@ -620,7 +622,7 @@ void LwpPara::RegisterStyle()
                                         break;
                                     }
                                     if ((pNumbering->GetLevel() == nFoundLevel)
-                                        && (*(pParaSilverBullet->GetObjectID()) != *(m_pSilverBullet->GetObjectID())
+                                        && (pParaSilverBullet->GetObjectID() != m_pSilverBullet->GetObjectID()
                                             || pNumbering->GetPosition() != nPosition))
                                     {
                                         break;
@@ -629,7 +631,7 @@ void LwpPara::RegisterStyle()
                                 else
                                 {
                                     if (pNumbering && pNumbering->GetLevel() < nFoundBound && pParaSilverBullet
-                                        &&  (*(pParaSilverBullet->GetObjectID()) != *(m_pSilverBullet->GetObjectID())
+                                        &&  (pParaSilverBullet->GetObjectID() != m_pSilverBullet->GetObjectID()
                                             || pNumbering->GetPosition() != nPosition))
                                     {
                                         nFoundBound = pNumbering->GetLevel();
@@ -654,7 +656,7 @@ void LwpPara::RegisterStyle()
                         if (m_pBullOver->IsSkip())
                             ;
                         else if ( pParaSilverBullet
-                            && *(pParaSilverBullet->GetObjectID()) == *(m_pSilverBullet->GetObjectID())
+                            && pParaSilverBullet->GetObjectID() == m_pSilverBullet->GetObjectID()
                             && pNumbering && nPosition == pNumbering->GetPosition())
                         {
                             if (bLesser)
@@ -685,10 +687,7 @@ void LwpPara::RegisterStyle()
                             }
                         }
 
-                        if (pPara && pPara->GetPrevious())
-                            pPrePara = dynamic_cast<LwpPara*>(pPara->GetPrevious()->obj(VO_PARA));
-                        else
-                            pPrePara=NULL;
+                        pPrePara = dynamic_cast<LwpPara*>(pPara->GetPrevious().obj(VO_PARA).get());
 
                         if (!pPrePara)
                         {
@@ -707,18 +706,18 @@ void LwpPara::RegisterStyle()
                     if (nNum > 1)
                     {
                         m_aBulletStyleName = aPreBullStyleName;
-                        m_bBullContinue = sal_True;
+                        m_bBullContinue = true;
                     }
                     else
                     {
-                        m_bBullContinue = sal_False;
+                        m_bBullContinue = false;
                         if (this->IsInCell())
                         {
                             XFListStyle* pOldStyle = static_cast<XFListStyle*>(pXFStyleManager->FindStyle(m_aBulletStyleName));
                             if (pOldStyle)
                             {
                                 XFListStyle* pNewStyle = new XFListStyle(*pOldStyle);
-                                m_aBulletStyleName = pXFStyleManager->AddStyle(pNewStyle)->GetStyleName();
+                                m_aBulletStyleName = pXFStyleManager->AddStyle(pNewStyle).m_pStyle->GetStyleName();
                             }
                         }
                     }
@@ -743,9 +742,9 @@ void LwpPara::RegisterStyle()
     }
     //end add
 
-    if (noSpacing && GetPrevious())
+    if (noSpacing)
     {
-        LwpPara* pPrePara = dynamic_cast<LwpPara*>(GetPrevious()->obj());
+        LwpPara* pPrePara = dynamic_cast<LwpPara*>(GetPrevious().obj().get());
         if (pPrePara && pPrePara->GetBelowSpacing()!=0)
         {
             pOverStyle = new XFParaStyle;
@@ -754,7 +753,7 @@ void LwpPara::RegisterStyle()
             pMargin->SetTop(pMargin->GetTop()+pPrePara->GetBelowSpacing());
             if (!m_ParentStyleName.isEmpty())
                     pOverStyle->SetParentStyleName(m_ParentStyleName);
-            m_StyleName = pXFStyleManager->AddStyle(pOverStyle)->GetStyleName();
+            m_StyleName = pXFStyleManager->AddStyle(pOverStyle).m_pStyle->GetStyleName();
         }
     }
 
@@ -763,11 +762,11 @@ void LwpPara::RegisterStyle()
     {
         XFParaStyle* pParaStyle = new XFParaStyle;
         *pParaStyle = *GetXFParaStyle();
-        //pOverStyle->SetStyleName(A2OUSTR(""));
+        //pOverStyle->SetStyleName("");
         this->RegisterTabStyle(pParaStyle);
         if (!m_ParentStyleName.isEmpty())
                     pParaStyle->SetParentStyleName(m_ParentStyleName);
-        m_StyleName = pXFStyleManager->AddStyle(pParaStyle)->GetStyleName();
+        m_StyleName = pXFStyleManager->AddStyle(pParaStyle).m_pStyle->GetStyleName();
     }
 
     //register master page;
@@ -777,7 +776,7 @@ void LwpPara::RegisterStyle()
     m_Fribs.SetPara(this);
     m_Fribs.RegisterStyle();
 
-    if (m_bHasDropcap == sal_True)
+    if (m_bHasDropcap)
     {
         GatherDropcapInfo();
         XFParaStyle* pStyle = new XFParaStyle;
@@ -785,7 +784,7 @@ void LwpPara::RegisterStyle()
         pStyle->SetDropCap(m_nChars-1,m_nLines);
         if (!m_ParentStyleName.isEmpty())
                     pStyle->SetParentStyleName(m_ParentStyleName);
-        m_StyleName = pXFStyleManager->AddStyle(pStyle)->GetStyleName();
+        m_StyleName = pXFStyleManager->AddStyle(pStyle).m_pStyle->GetStyleName();
     }
     // maybe useful for futer version
     // deleted because Leader of Table is not supported in this version
@@ -804,14 +803,14 @@ void LwpPara::RegisterNewSectionStyle(LwpPageLayout *pLayout)
         pSectStyle->SetColumns(pColumns);
     }
     XFStyleManager* pXFStyleManager = LwpGlobalMgr::GetInstance()->GetXFStyleManager();
-    m_SectionStyleName = pXFStyleManager->AddStyle(pSectStyle)->GetStyleName();
+    m_SectionStyleName = pXFStyleManager->AddStyle(pSectStyle).m_pStyle->GetStyleName();
 }
 
 XFSection* LwpPara::CreateXFSection()
 {
     XFSection* pXFSection = new XFSection();
     pXFSection->SetStyleName(m_SectionStyleName);
-    m_SectionStyleName = A2OUSTR("");
+    m_SectionStyleName.clear();
     return pXFSection;
 }
 
@@ -826,7 +825,7 @@ void LwpPara::RegisterTabStyle(XFParaStyle* pXFParaStyle)
     LwpTabOverride aFinaOverride;
     LwpTabOverride* pBase = NULL;
     //get the tabrack from the current layout
-    LwpStory* pStory = dynamic_cast<LwpStory*>(m_Story.obj());
+    LwpStory* pStory = dynamic_cast<LwpStory*>(m_Story.obj().get());
     LwpMiddleLayout* pLayout = pStory ? pStory->GetTabLayout() : NULL;
     if(pLayout)
     {
@@ -926,14 +925,14 @@ XFContentContainer* LwpPara::AddBulletList(XFContentContainer* pCont)
     }
 
     sal_uInt16 nLevel = m_nLevel;
-    sal_Bool bOrdered = sal_False;
+    bool bOrdered = false;
     /*LwpStory* pMyStory =*/ GetStory();
 
     pBulletStyleMgr->SetContinueFlag(m_bBullContinue);
 
     if (m_pSilverBullet->IsBulletOrdered())
     {
-        bOrdered = sal_True;
+        bOrdered = true;
     }
     if (m_pSilverBullet->HasName())
     {
@@ -962,7 +961,4 @@ void LwpNotifyListPersistent::Read(LwpObjectStream* pObjStrm)
     pObjStrm->SkipExtra();
 }
 
-void LwpPara::Release()
-{}
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
