@@ -32,10 +32,7 @@ using namespace com::sun::star::sdbc;
 OResultSetMetaData::~OResultSetMetaData()
 {
 }
-/* }}} */
 
-
-/* {{{ OResultSetMetaData::getColumnDisplaySize() -I- */
 sal_Int32 SAL_CALL OResultSetMetaData::getColumnDisplaySize(sal_Int32 column)
     throw(SQLException, RuntimeException, std::exception)
 {
@@ -50,10 +47,7 @@ sal_Int32 SAL_CALL OResultSetMetaData::getColumnDisplaySize(sal_Int32 column)
     }
     return 0; // fool compiler
 }
-/* }}} */
 
-
-/* {{{ OResultSetMetaData::getColumnType() -I- */
 sal_Int32 SAL_CALL OResultSetMetaData::getColumnType(sal_Int32 column)
     throw(SQLException, RuntimeException, std::exception)
 {
@@ -69,14 +63,12 @@ sal_Int32 SAL_CALL OResultSetMetaData::getColumnType(sal_Int32 column)
     }
     return 0; // fool compiler
 }
-/* }}} */
 
 /*
   XXX: This method doesn't throw exceptions at all.
   Should it declare that it throws ?? What if throw() is removed?
   Does it change the API, the open-close principle?
 */
-/* {{{ OResultSetMetaData::getColumnCount() -I- */
 sal_Int32 SAL_CALL OResultSetMetaData::getColumnCount()
     throw(SQLException, RuntimeException, std::exception)
 {
@@ -90,10 +82,7 @@ sal_Int32 SAL_CALL OResultSetMetaData::getColumnCount()
     }
     return 0; // fool compiler
 }
-/* }}} */
 
-
-/* {{{ OResultSetMetaData::isCaseSensitive() -I- */
 sal_Bool SAL_CALL OResultSetMetaData::isCaseSensitive(sal_Int32 column)
     throw(SQLException, RuntimeException, std::exception)
 {
@@ -109,11 +98,8 @@ sal_Bool SAL_CALL OResultSetMetaData::isCaseSensitive(sal_Int32 column)
     }
     return sal_False; // fool compiler
 }
-/* }}} */
 
-
-/* {{{ OResultSetMetaData::getSchemaName() -I- */
-OUString SAL_CALL OResultSetMetaData::getSchemaName(sal_Int32 column)
+rtl::OUString SAL_CALL OResultSetMetaData::getSchemaName(sal_Int32 column)
     throw(SQLException, RuntimeException, std::exception)
 {
     OSL_TRACE("OResultSetMetaData::getSchemaName");
@@ -126,13 +112,10 @@ OUString SAL_CALL OResultSetMetaData::getSchemaName(sal_Int32 column)
     } catch (const sql::SQLException &e) {
         mysqlc_sdbc_driver::translateAndThrow(e, *this, m_encoding);
     }
-    return OUString(); // fool compiler
+    return rtl::OUString(); // fool compiler
 }
-/* }}} */
 
-
-/* {{{ OResultSetMetaData::getColumnName() -I- */
-OUString SAL_CALL OResultSetMetaData::getColumnName(sal_Int32 column)
+rtl::OUString SAL_CALL OResultSetMetaData::getColumnName(sal_Int32 column)
     throw(SQLException, RuntimeException, std::exception)
 {
     OSL_TRACE("OResultSetMetaData::getColumnName");
@@ -145,13 +128,10 @@ OUString SAL_CALL OResultSetMetaData::getColumnName(sal_Int32 column)
     } catch (const sql::SQLException &e) {
         mysqlc_sdbc_driver::translateAndThrow(e, *this, m_encoding);
     }
-    return OUString(); // fool compiler
+    return rtl::OUString(); // fool compiler
 }
-/* }}} */
 
-
-/* {{{ OResultSetMetaData::getTableName() -I- */
-OUString SAL_CALL OResultSetMetaData::getTableName(sal_Int32 column)
+rtl::OUString SAL_CALL OResultSetMetaData::getTableName(sal_Int32 column)
     throw(SQLException, RuntimeException, std::exception)
 {
     OSL_TRACE("OResultSetMetaData::getTableName");
@@ -164,13 +144,10 @@ OUString SAL_CALL OResultSetMetaData::getTableName(sal_Int32 column)
     } catch (const sql::SQLException &e) {
         mysqlc_sdbc_driver::translateAndThrow(e, *this, m_encoding);
     }
-    return OUString(); // fool compiler
+    return rtl::OUString(); // fool compiler
 }
-/* }}} */
 
-
-/* {{{ OResultSetMetaData::getCatalogName() -I- */
-OUString SAL_CALL OResultSetMetaData::getCatalogName(sal_Int32 column)
+rtl::OUString SAL_CALL OResultSetMetaData::getCatalogName(sal_Int32 column)
     throw(SQLException, RuntimeException, std::exception)
 {
     OSL_TRACE("OResultSetMetaData::getCatalogName");
@@ -183,13 +160,10 @@ OUString SAL_CALL OResultSetMetaData::getCatalogName(sal_Int32 column)
     } catch (const sql::SQLException &e) {
         mysqlc_sdbc_driver::translateAndThrow(e, *this, m_encoding);
     }
-    return OUString(); // fool compiler
+    return rtl::OUString(); // fool compiler
 }
-/* }}} */
 
-
-/* {{{ OResultSetMetaData::getColumnTypeName() -I- */
-OUString SAL_CALL OResultSetMetaData::getColumnTypeName(sal_Int32 column)
+rtl::OUString SAL_CALL OResultSetMetaData::getColumnTypeName(sal_Int32 column)
     throw(SQLException, RuntimeException, std::exception)
 {
     OSL_TRACE("OResultSetMetaData::getColumnTypeName");
@@ -202,13 +176,10 @@ OUString SAL_CALL OResultSetMetaData::getColumnTypeName(sal_Int32 column)
     } catch (const sql::SQLException &e) {
         mysqlc_sdbc_driver::translateAndThrow(e, *this, m_encoding);
     }
-    return OUString(); // fool compiler
+    return rtl::OUString(); // fool compiler
 }
-/* }}} */
 
-
-/* {{{ OResultSetMetaData::getColumnLabel() -I- */
-OUString SAL_CALL OResultSetMetaData::getColumnLabel(sal_Int32 column)
+rtl::OUString SAL_CALL OResultSetMetaData::getColumnLabel(sal_Int32 column)
     throw(SQLException, RuntimeException, std::exception)
 {
     OSL_TRACE("OResultSetMetaData::getColumnLabel");
@@ -221,25 +192,19 @@ OUString SAL_CALL OResultSetMetaData::getColumnLabel(sal_Int32 column)
     } catch (const sql::SQLException &e) {
         mysqlc_sdbc_driver::translateAndThrow(e, *this, m_encoding);
     }
-    return OUString(); // fool compiler
+    return rtl::OUString(); // fool compiler
 }
-/* }}} */
 
-
-/* {{{ OResultSetMetaData::getColumnServiceName() -I- */
-OUString SAL_CALL OResultSetMetaData::getColumnServiceName(sal_Int32 column)
+rtl::OUString SAL_CALL OResultSetMetaData::getColumnServiceName(sal_Int32 column)
     throw(SQLException, RuntimeException, std::exception)
 {
     OSL_TRACE("OResultSetMetaData::getColumnServiceName");
     checkColumnIndex(column);
 
-    OUString aRet = OUString();
+    rtl::OUString aRet = rtl::OUString();
     return aRet;
 }
-/* }}} */
 
-
-/* {{{ OResultSetMetaData::isCurrency() -I- */
 sal_Bool SAL_CALL OResultSetMetaData::isCurrency(sal_Int32 column)
     throw(SQLException, RuntimeException, std::exception)
 {
@@ -255,10 +220,7 @@ sal_Bool SAL_CALL OResultSetMetaData::isCurrency(sal_Int32 column)
     }
     return sal_False; // fool compiler
 }
-/* }}} */
 
-
-/* {{{ OResultSetMetaData::isAutoIncrement() -I- */
 sal_Bool SAL_CALL OResultSetMetaData::isAutoIncrement(sal_Int32 column)
     throw(SQLException, RuntimeException, std::exception)
 {
@@ -274,10 +236,7 @@ sal_Bool SAL_CALL OResultSetMetaData::isAutoIncrement(sal_Int32 column)
     }
     return sal_False; // fool compiler
 }
-/* }}} */
 
-
-/* {{{ OResultSetMetaData::isSigned() -I- */
 sal_Bool SAL_CALL OResultSetMetaData::isSigned(sal_Int32 column)
     throw(SQLException, RuntimeException, std::exception)
 {
@@ -293,10 +252,7 @@ sal_Bool SAL_CALL OResultSetMetaData::isSigned(sal_Int32 column)
     }
     return sal_False; // fool compiler
 }
-/* }}} */
 
-
-/* {{{ OResultSetMetaData::getPrecision() -I- */
 sal_Int32 SAL_CALL OResultSetMetaData::getPrecision(sal_Int32 column)
     throw(SQLException, RuntimeException, std::exception)
 {
@@ -312,10 +268,7 @@ sal_Int32 SAL_CALL OResultSetMetaData::getPrecision(sal_Int32 column)
     }
     return 0; // fool compiler
 }
-/* }}} */
 
-
-/* {{{ OResultSetMetaData::getScale() -I- */
 sal_Int32 SAL_CALL OResultSetMetaData::getScale(sal_Int32 column)
     throw(::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException, std::exception)
 {
@@ -330,10 +283,7 @@ sal_Int32 SAL_CALL OResultSetMetaData::getScale(sal_Int32 column)
     }
     return 0; // fool compiler
 }
-/* }}} */
 
-
-/* {{{ OResultSetMetaData::isNullable() -I- */
 sal_Int32 SAL_CALL OResultSetMetaData::isNullable(sal_Int32 column)
     throw(SQLException, RuntimeException, std::exception)
 {
@@ -341,18 +291,15 @@ sal_Int32 SAL_CALL OResultSetMetaData::isNullable(sal_Int32 column)
     checkColumnIndex(column);
 
     try {
-        return meta->isNullable(column)? sal_True:sal_False;
+        return sal_Int32(bool(meta->isNullable(column)));
     } catch (const sql::MethodNotImplementedException &) {
         mysqlc_sdbc_driver::throwFeatureNotImplementedException("OResultSetMetaData::getMetaData", *this);
     } catch (const sql::SQLException &e) {
         mysqlc_sdbc_driver::translateAndThrow(e, *this, m_encoding);
     }
-    return sal_False; // fool compiler
+    return sal_Int32(false); // fool compiler
 }
-/* }}} */
 
-
-/* {{{ OResultSetMetaData::isSearchable() -I- */
 sal_Bool SAL_CALL OResultSetMetaData::isSearchable(sal_Int32 column)
     throw(SQLException, RuntimeException, std::exception)
 {
@@ -368,10 +315,7 @@ sal_Bool SAL_CALL OResultSetMetaData::isSearchable(sal_Int32 column)
     }
     return sal_False; // fool compiler
 }
-/* }}} */
 
-
-/* {{{ OResultSetMetaData::isReadOnly() -I- */
 sal_Bool SAL_CALL OResultSetMetaData::isReadOnly(sal_Int32 column)
     throw(SQLException, RuntimeException, std::exception)
 {
@@ -387,10 +331,7 @@ sal_Bool SAL_CALL OResultSetMetaData::isReadOnly(sal_Int32 column)
     }
     return sal_False; // fool compiler
 }
-/* }}} */
 
-
-/* {{{ OResultSetMetaData::isDefinitelyWritable() -I- */
 sal_Bool SAL_CALL OResultSetMetaData::isDefinitelyWritable(sal_Int32 column)
     throw(SQLException, RuntimeException, std::exception)
 {
@@ -406,10 +347,7 @@ sal_Bool SAL_CALL OResultSetMetaData::isDefinitelyWritable(sal_Int32 column)
     }
     return sal_False; // fool compiler
 }
-/* }}} */
 
-
-/* {{{ OResultSetMetaData::isWritable() -I- */
 sal_Bool SAL_CALL OResultSetMetaData::isWritable(sal_Int32 column)
     throw(SQLException, RuntimeException, std::exception)
 {
@@ -425,26 +363,22 @@ sal_Bool SAL_CALL OResultSetMetaData::isWritable(sal_Int32 column)
     }
     return sal_False; // fool compiler
 }
-/* }}} */
 
-
-/* {{{ OResultSetMetaData::checkColumnIndex() -I- */
 void OResultSetMetaData::checkColumnIndex(sal_Int32 columnIndex)
     throw (SQLException, RuntimeException)
 {
     OSL_TRACE("OResultSetMetaData::checkColumnIndex");
     if (columnIndex < 1 || columnIndex > (sal_Int32) meta->getColumnCount()) {
 
-        OUStringBuffer buf;
+        rtl::OUStringBuffer buf;
         buf.appendAscii( "Column index out of range (expected 1 to " );
         buf.append( sal_Int32( meta->getColumnCount() ) );
         buf.appendAscii( ", got " );
         buf.append( sal_Int32( columnIndex ) );
         buf.append( '.' );
-        throw SQLException( buf.makeStringAndClear(), *this, OUString(), 1, Any() );
+        throw SQLException( buf.makeStringAndClear(), *this, rtl::OUString(), 1, Any() );
     }
 }
-/* }}} */
 
 /*
  * Local variables:
