@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include <functional>
 #include <boost/bind.hpp>
 
@@ -26,11 +25,12 @@
 #include <com/sun/star/xml/dom/XDocument.hpp>
 #include <com/sun/star/xml/sax/XFastSAXSerializable.hpp>
 #include <rtl/ustrbuf.hxx>
+#include <osl/diagnose.h>
 #include <editeng/unoprnms.hxx>
-#include "oox/drawingml/textbody.hxx"
-#include "oox/drawingml/textparagraph.hxx"
-#include "oox/drawingml/textrun.hxx"
-#include "oox/drawingml/diagram/diagram.hxx"
+#include "drawingml/textbody.hxx"
+#include "drawingml/textparagraph.hxx"
+#include "drawingml/textrun.hxx"
+#include "drawingml/diagram/diagram.hxx"
 #include "oox/drawingml/fillproperties.hxx"
 #include "oox/ppt/pptshapegroupcontext.hxx"
 #include "oox/ppt/pptshape.hxx"
@@ -49,24 +49,20 @@ namespace dgm {
 
 void Connection::dump()
 {
-    OSL_TRACE("dgm: cnx modelId %s, srcId %s, dstId %s, parTransId %s, presId %s, sibTransId %s, srcOrd %d, dstOrd %d",
-              OUSTRING_TO_CSTR( msModelId ),
-              OUSTRING_TO_CSTR( msSourceId ),
-              OUSTRING_TO_CSTR( msDestId ),
-              OUSTRING_TO_CSTR( msParTransId ),
-              OUSTRING_TO_CSTR( msPresId ),
-              OUSTRING_TO_CSTR( msSibTransId ),
-              mnSourceOrder,
-              mnDestOrder );
+    SAL_INFO(
+        "oox.drawingml",
+        "cnx modelId " << msModelId << ", srcId " << msSourceId << ", dstId "
+            << msDestId << ", parTransId " << msParTransId << ", presId "
+            << msPresId << ", sibTransId " << msSibTransId << ", srcOrd "
+            << mnSourceOrder << ", dstOrd " << mnDestOrder);
 }
 
 void Point::dump()
 {
-    OSL_TRACE( "dgm: pt text %x, cnxId %s, modelId %s, type %d",
-               mpShape.get(),
-               OUSTRING_TO_CSTR( msCnxId ),
-               OUSTRING_TO_CSTR( msModelId ),
-               mnType );
+    SAL_INFO(
+        "oox.drawingml",
+        "pt text " << mpShape.get() << ", cnxId " << msCnxId << ", modelId "
+            << msModelId << ", type " << mnType);
 }
 
 } // dgm namespace
@@ -86,13 +82,11 @@ void DiagramData::dump()
                   boost::bind( &dgm::Point::dump, _1 ) );
 }
 
-
 void Diagram::setData( const DiagramDataPtr & pData)
 {
     mpData = pData;
 }
 
-
 void Diagram::setLayout( const DiagramLayoutPtr & pLayout)
 {
     mpLayout = pLayout;
@@ -102,7 +96,7 @@ void Diagram::setLayout( const DiagramLayoutPtr & pLayout)
 OString normalizeDotName( const OUString& rStr )
 {
     OUStringBuffer aBuf;
-    aBuf.append((sal_Unicode)'N');
+    aBuf.append('N');
 
     const sal_Int32 nLen(rStr.getLength());
     sal_Int32 nCurrIndex(0);
@@ -143,11 +137,9 @@ static sal_Int32 calcDepth( const OUString& rNodeName,
     return 0;
 }
 
-
 void Diagram::build(  )
 {
     // build name-object maps
-    // ======================
 
 #if OSL_DEBUG_LEVEL > 1
     std::ofstream output("/tmp/tree.dot");
@@ -155,8 +147,9 @@ void Diagram::build(  )
     output << "digraph datatree {" << std::endl;
 #endif
 
-    dgm::Points::iterator aCurrPoint( getData()->getPoints( ).begin() );
-    const dgm::Points::iterator aEndPoint( getData()->getPoints( ).end() );
+    dgm::Points& rPoints = getData()->getPoints();
+    dgm::Points::iterator aCurrPoint(rPoints.begin());
+    dgm::Points::iterator aEndPoint(rPoints.end());
     while( aCurrPoint != aEndPoint )
     {
 #if OSL_DEBUG_LEVEL > 1
@@ -227,8 +220,9 @@ void Diagram::build(  )
         ++aCurrPoint;
     }
 
-    dgm::Connections::const_iterator aCurrCxn( getData()->getConnections( ).begin() );
-    const dgm::Connections::const_iterator aEndCxn( getData()->getConnections( ).end() );
+    const dgm::Connections& rConnections = getData()->getConnections();
+    dgm::Connections::const_iterator aCurrCxn(rConnections.begin());
+    const dgm::Connections::const_iterator aEndCxn(rConnections.end());
     while( aCurrCxn != aEndCxn )
     {
 #if OSL_DEBUG_LEVEL > 1
@@ -298,8 +292,9 @@ void Diagram::build(  )
     }
 
     // assign outline levels
-    DiagramData::StringMap::iterator aPresOfIter=getData()->getPresOfNameMap().begin();
-    const DiagramData::StringMap::iterator aPresOfEnd=getData()->getPresOfNameMap().end();
+    DiagramData::StringMap& rStringMap = getData()->getPresOfNameMap();
+    DiagramData::StringMap::iterator aPresOfIter=rStringMap.begin();
+    const DiagramData::StringMap::iterator aPresOfEnd=rStringMap.end();
     while( aPresOfIter != aPresOfEnd )
     {
         DiagramData::StringMap::value_type::second_type::iterator aPresOfNodeIterCalcLevel=aPresOfIter->second.begin();
@@ -337,6 +332,9 @@ uno::Sequence<beans::PropertyValue> Diagram::getDomsAsPropertyValues() const
 {
     sal_Int32 length = maMainDomMap.size();
 
+    if ( 0 < maDataRelsMap.getLength() )
+        ++length;
+
     uno::Sequence<beans::PropertyValue> aValue(length);
     beans::PropertyValue* pValue = aValue.getArray();
     for (DiagramDomMap::const_iterator i = maMainDomMap.begin();
@@ -348,6 +346,13 @@ uno::Sequence<beans::PropertyValue> Diagram::getDomsAsPropertyValues() const
         ++pValue;
     }
 
+    if ( 0 < maDataRelsMap.getLength() )
+    {
+        pValue[0].Name = "OOXDiagramDataRels";
+        pValue[0].Value = uno::makeAny ( maDataRelsMap );
+        ++pValue;
+    }
+
     return aValue;
 }
 
@@ -409,6 +414,10 @@ void loadDiagram( ShapePtr& pShape,
                        "OOXData",
                        pDiagram,
                        xRefDataModel);
+
+        pDiagram->getDataRelsMap() = pShape->resolveRelationshipsOfTypeFromOfficeDoc( rFilter,
+                xRefDataModel->getFragmentPath(), "image" );
+
         // Pass the info to pShape
         for( ::std::vector<OUString>::const_iterator aIt = pData->getExtDrawings().begin(), aEnd = pData->getExtDrawings().end();
                 aIt != aEnd; ++aIt )
@@ -446,8 +455,8 @@ void loadDiagram( ShapePtr& pShape,
     } else {
         // We still want to add the XDocuments to the DiagramDomMap
         DiagramDomMap& rMainDomMap = pDiagram->getDomMap();
-        rMainDomMap[OUString::createFromAscii("OOXLayout")] = loadFragment(rFilter,rLayoutPath);
-        rMainDomMap[OUString::createFromAscii("OOXStyle")] = loadFragment(rFilter,rQStylePath);
+        rMainDomMap[OUString("OOXLayout")] = loadFragment(rFilter,rLayoutPath);
+        rMainDomMap[OUString("OOXStyle")] = loadFragment(rFilter,rQStylePath);
     }
 
     // colors
