@@ -35,8 +35,8 @@ import lib.MultiMethodTest;
 public class _XUIConfigurationManager extends MultiMethodTest {
 
     public XUIConfigurationManager oObj;
-    private String msResourceUrl = "private:resource/menubar/menubar";
-    private String msMyResourceUrl = "private:resource/menubar/mymenubar";
+    private static final String msResourceUrl = "private:resource/menubar/menubar";
+    private static final String msMyResourceUrl = "private:resource/menubar/mymenubar";
     private XIndexContainer mxSettings = null;
     private XIndexAccess mxMenuBarSettings = null;
     private XMultiServiceFactory mxMSF = null;
@@ -47,8 +47,9 @@ public class _XUIConfigurationManager extends MultiMethodTest {
      * Some stuff before the tests:
      * extract the multi service factory.
      */
+    @Override
     protected void before() {
-        mxMSF = (XMultiServiceFactory)tParam.getMSF();
+        mxMSF = tParam.getMSF();
         sShortCutManagerServiceName = (String)tEnv.getObjRelation("XConfigurationManager.ShortCutManager");
 
     }
@@ -299,7 +300,7 @@ public class _XUIConfigurationManager extends MultiMethodTest {
         prop[1].Value = sLabelName;
         prop[2] = new PropertyValue();
         prop[2].Name = "Type";
-        prop[2].Value = new Short((short)0);
+        prop[2].Value = Short.valueOf((short)0);
         prop[3] = new PropertyValue();
         prop[3].Name = "ItemDescriptorContainer";
 
@@ -336,7 +337,7 @@ public class _XUIConfigurationManager extends MultiMethodTest {
         aMenuItem[1].Value = sLabelName;
         aMenuItem[2] = new PropertyValue();
         aMenuItem[2].Name = "Type";
-        aMenuItem[2].Value = new Short((short)0);
+        aMenuItem[2].Value = Short.valueOf((short)0);
 
         try {
             xDescriptionContainer.insertByIndex(0, aMenuItem);
