@@ -651,7 +651,7 @@ void XclExpNumberCell::WriteContents( XclExpStream& rStrm )
 IMPL_FIXEDMEMPOOL_NEWDEL( XclExpBooleanCell )
 
 XclExpBooleanCell::XclExpBooleanCell(
-        const XclExpRoot rRoot, const XclAddress& rXclPos,
+        const XclExpRoot& rRoot, const XclAddress& rXclPos,
         const ScPatternAttr* pPattern, sal_uInt32 nForcedXFId, bool bValue ) :
     // #i41210# always use latin script for boolean cells
     XclExpSingleCellBase( rRoot, EXC_ID3_BOOLERR, 2, rXclPos, pPattern, ApiScriptType::LATIN, nForcedXFId ),
@@ -828,19 +828,19 @@ XclExpFormulaCell::XclExpFormulaCell(
         /*  #i8640# Don't set text format, if we have string results. */
         short nFormatType = mrScFmlaCell.GetFormatType();
         if( ((nScNumFmt % SV_COUNTRY_LANGUAGE_OFFSET) == 0) &&
-                (nFormatType != NUMBERFORMAT_LOGICAL) &&
-                (nFormatType != NUMBERFORMAT_TEXT) )
+                (nFormatType != css::util::NumberFormat::LOGICAL) &&
+                (nFormatType != css::util::NumberFormat::TEXT) )
             nAltScNumFmt = nScNumFmt;
         /*  If cell number format is Boolean and automatic formula
             format is Boolean don't write that ugly special format. */
-        else if( (nFormatType == NUMBERFORMAT_LOGICAL) &&
-                (rFormatter.GetType( nScNumFmt ) == NUMBERFORMAT_LOGICAL) )
+        else if( (nFormatType == css::util::NumberFormat::LOGICAL) &&
+                (rFormatter.GetType( nScNumFmt ) == css::util::NumberFormat::LOGICAL) )
             nAltScNumFmt = rNumFmtBfr.GetStandardFormat();
 
         // #i41420# find script type according to result type (always latin for numeric results)
         sal_Int16 nScript = ApiScriptType::LATIN;
         bool bForceLineBreak = false;
-        if( nFormatType == NUMBERFORMAT_TEXT )
+        if( nFormatType == css::util::NumberFormat::TEXT )
         {
             OUString aResult = mrScFmlaCell.GetString().getString();
             bForceLineBreak = mrScFmlaCell.IsMultilineResult();
@@ -981,14 +981,14 @@ void XclExpFormulaCell::WriteContents( XclExpStream& rStrm )
         // result of the formula
         switch( mrScFmlaCell.GetFormatType() )
         {
-            case NUMBERFORMAT_NUMBER:
+            case css::util::NumberFormat::NUMBER:
                 {
                     // either value or error code
                     rStrm << mrScFmlaCell.GetValue();
                 }
                 break;
 
-            case NUMBERFORMAT_TEXT:
+            case css::util::NumberFormat::TEXT:
                 {
                     OUString aResult = mrScFmlaCell.GetString().getString();
                     if( !aResult.isEmpty() || (rStrm.GetRoot().GetBiff() <= EXC_BIFF5) )
@@ -1002,7 +1002,7 @@ void XclExpFormulaCell::WriteContents( XclExpStream& rStrm )
                 }
                 break;
 
-            case NUMBERFORMAT_LOGICAL:
+            case css::util::NumberFormat::LOGICAL:
                 {
                     sal_uInt8 nXclValue = (mrScFmlaCell.GetValue() == 0.0) ? 0 : 1;
                     rStrm << EXC_FORMULA_RES_BOOL << sal_uInt8( 0 )
@@ -2064,11 +2064,15 @@ void XclExpRowBuffer::Finalize( XclExpDefaultRowData& rDefRowData, const ScfUInt
 
     GetProgressBar().ActivateFinalRowsSegment();
 
+#if 1
     // This is staggeringly slow, and each element operates only
     // on its own data.
-    size_t nRows = maRowMap.size();
-    size_t nThreads = std::max( std::thread::hardware_concurrency(), 1U );
-    if ( nThreads == 1 || nRows < 128 )
+    const size_t nRows = maRowMap.size();
+    const size_t nThreads = nRows < 128 ? 1 : std::max(std::thread::hardware_concurrency(), 1U);
+#else
+    const size_t nThreads = 1; // globally disable multi-threading for now.
+#endif
+    if (nThreads == 1)
     {
         RowMap::iterator itr, itrBeg = maRowMap.begin(), itrEnd = maRowMap.end();
         for (itr = itrBeg; itr != itrEnd; ++itr)
@@ -2385,7 +2389,7 @@ XclExpCellTable::XclExpCellTable( const XclExpRoot& rRoot ) :
                 if( pPattern && ((fValue == 0.0) || (fValue == 1.0)) )
                 {
                     sal_uLong nScNumFmt = GETITEMVALUE( pPattern->GetItemSet(), SfxUInt32Item, ATTR_VALUE_FORMAT, sal_uLong );
-                    if( rFormatter.GetType( nScNumFmt ) == NUMBERFORMAT_LOGICAL )
+                    if( rFormatter.GetType( nScNumFmt ) == css::util::NumberFormat::LOGICAL )
                         xCell.reset( new XclExpBooleanCell(
                             GetRoot(), aXclPos, pPattern, nMergeBaseXFId, fValue != 0.0 ) );
                 }
