@@ -19,22 +19,20 @@
 
 #include "pivotcachefragment.hxx"
 
-#include "oox/helper/attributelist.hxx"
+#include <osl/diagnose.h>
+#include <oox/helper/attributelist.hxx>
 #include "addressconverter.hxx"
 #include "biffinputstream.hxx"
+#include "formulabuffer.hxx"
 #include "pivotcachebuffer.hxx"
+#include "worksheetbuffer.hxx"
 
 namespace oox {
 namespace xls {
 
-// ============================================================================
-
 using namespace ::com::sun::star::uno;
 using namespace ::oox::core;
 
-
-// ============================================================================
-
 PivotCacheFieldContext::PivotCacheFieldContext( WorkbookFragmentBase& rFragment, PivotCacheField& rCacheField ) :
     WorkbookContextBase( rFragment ),
     mrCacheField( rCacheField )
@@ -106,8 +104,6 @@ void PivotCacheFieldContext::onStartRecord( SequenceInputStream& rStrm )
         mrCacheField.importPCDField( rStrm );
 }
 
-// ============================================================================
-
 PivotCacheDefinitionFragment::PivotCacheDefinitionFragment(
         const WorkbookHelper& rHelper, const OUString& rFragmentPath, PivotCache& rPivotCache ) :
     WorkbookFragmentBase( rHelper, rFragmentPath ),
@@ -208,8 +204,6 @@ void PivotCacheDefinitionFragment::finalizeImport()
     }
 }
 
-// ============================================================================
-
 PivotCacheRecordsFragment::PivotCacheRecordsFragment( const WorksheetHelper& rHelper,
         const OUString& rFragmentPath, const PivotCache& rPivotCache ) :
     WorksheetFragmentBase( rHelper, rFragmentPath ),
@@ -218,8 +212,12 @@ PivotCacheRecordsFragment::PivotCacheRecordsFragment( const WorksheetHelper& rHe
     mnRowIdx( 0 ),
     mbInRecord( false )
 {
+    sal_Int32 nSheetCount = rPivotCache.getWorksheets().getAllSheetCount();
+
     // prepare sheet: insert column header names into top row
     rPivotCache.writeSourceHeaderCells( *this );
+    // resize formula buffers since we've added a new dummy sheet
+    rHelper.getFormulaBuffer().SetSheetCount( nSheetCount );
 }
 
 ContextHandlerRef PivotCacheRecordsFragment::onCreateContext( sal_Int32 nElement, const AttributeList& rAttribs )
@@ -323,9 +321,6 @@ void PivotCacheRecordsFragment::importPCRecordItem( sal_Int32 nRecId, SequenceIn
     }
 }
 
-// ============================================================================
-// ============================================================================
-
 namespace {
 
 bool lclSeekToPCDField( BiffInputStream& rStrm )
@@ -340,8 +335,6 @@ bool lclSeekToPCDField( BiffInputStream& rStrm )
 
 } // namespace
 
-// ----------------------------------------------------------------------------
-
 BiffPivotCacheFragment::BiffPivotCacheFragment(
         const WorkbookHelper& rHelper, const OUString& rStrmName, PivotCache& rPivotCache ) :
     BiffWorkbookFragmentBase( rHelper, rStrmName, true ),
@@ -383,8 +376,6 @@ bool BiffPivotCacheFragment::importFragment()
     return rStrm.getRecId() == BIFF_ID_EOF;
 }
 
-// ============================================================================
-
 BiffPivotCacheRecordsContext::BiffPivotCacheRecordsContext( const WorksheetHelper& rHelper, const PivotCache& rPivotCache ) :
     BiffWorksheetContextBase( rHelper ),
     mrPivotCache( rPivotCache ),
@@ -460,8 +451,6 @@ void BiffPivotCacheRecordsContext::startNextRow()
     mbInRow = true;
 }
 
-// ============================================================================
-
 } // namespace xls
 } // namespace oox
 
