@@ -81,7 +81,7 @@ static bool lcl_isExternalRefCache(const OUString& rName, OUString& rUrl, OUStri
     // #i114504# Other schemes besides "file:" are also allowed.
     // CompareProtocolScheme is quick, only looks at the start of the string.
     INetProtocol eProt = INetURLObject::CompareProtocolScheme( rName.copy(1) );
-    if ( eProt == INET_PROT_NOT_VALID )
+    if ( eProt == INetProtocol::NotValid )
         return false;
 
     OUString aPrefix = INetURLObject::GetScheme( eProt );
@@ -135,15 +135,12 @@ ScXMLExternalTabData::ScXMLExternalTabData() :
 {
 }
 
-//------------------------------------------------------------------
-
 ScXMLTableContext::ScXMLTableContext( ScXMLImport& rImport,
                                       sal_uInt16 nPrfx,
                                       const OUString& rLName,
                                       const ::com::sun::star::uno::Reference<
                                       ::com::sun::star::xml::sax::XAttributeList>& xAttrList ) :
     SvXMLImportContext( rImport, nPrfx, rLName ),
-    pExternalRefInfo(NULL),
     nStartOffset(-1),
     bStartFormPage(false),
     bPrintEntireSheet(true)
@@ -323,7 +320,7 @@ SvXMLImportContext *ScXMLTableContext::CreateChildContext( sal_uInt16 nPrefix,
         {
             GetScImport().GetFormImport()->startPage(GetScImport().GetTables().GetCurrentXDrawPage());
             bStartFormPage = true;
-            pContext = GetScImport().GetFormImport()->createOfficeFormsContext( GetScImport(), nPrefix, rLName );
+            pContext = xmloff::OFormLayerXMLImport::createOfficeFormsContext( GetScImport(), nPrefix, rLName );
         }
         break;
     case XML_TOK_TABLE_EVENT_LISTENERS:
@@ -375,28 +372,28 @@ void ScXMLTableContext::EndElement()
     ScOutlineTable* pOutlineTable(pDoc->GetOutlineTable(nCurTab, false));
     if (pOutlineTable)
     {
-        ScOutlineArray* pColArray(pOutlineTable->GetColArray());
-        size_t nDepth = pColArray->GetDepth();
+        ScOutlineArray& rColArray(pOutlineTable->GetColArray());
+        size_t nDepth = rColArray.GetDepth();
         for (size_t i = 0; i < nDepth; ++i)
         {
-            size_t nCount = pColArray->GetCount(i);
+            size_t nCount = rColArray.GetCount(i);
             for (size_t j = 0; j < nCount; ++j)
             {
-                const ScOutlineEntry* pEntry = pColArray->GetEntry(i, j);
+                const ScOutlineEntry* pEntry = rColArray.GetEntry(i, j);
                 if (pEntry->IsHidden())
-                    pColArray->SetVisibleBelow(i, j, false);
+                    rColArray.SetVisibleBelow(i, j, false);
             }
         }
-        ScOutlineArray* pRowArray(pOutlineTable->GetRowArray());
-        nDepth = pRowArray->GetDepth();
+        ScOutlineArray& rRowArray(pOutlineTable->GetRowArray());
+        nDepth = rRowArray.GetDepth();
         for (size_t i = 0; i < nDepth; ++i)
         {
-            size_t nCount = pRowArray->GetCount(i);
+            size_t nCount = rRowArray.GetCount(i);
             for (size_t j = 0; j < nCount; ++j)
             {
-                const ScOutlineEntry* pEntry = pRowArray->GetEntry(i, j);
+                const ScOutlineEntry* pEntry = rRowArray.GetEntry(i, j);
                 if (pEntry->IsHidden())
-                    pRowArray->SetVisibleBelow(i, j, false);
+                    rRowArray.SetVisibleBelow(i, j, false);
             }
         }
     }
@@ -425,8 +422,6 @@ void ScXMLTableContext::EndElement()
     }
 }
 
-// ============================================================================
-
 ScXMLImport& ScXMLTableProtectionContext::GetScImport()
 {
     return static_cast<ScXMLImport&>(GetImport());
@@ -463,7 +458,7 @@ ScXMLTableProtectionContext::ScXMLTableProtectionContext(
                 bSelectUnprotectedCells = IsXMLToken(aValue, XML_TRUE);
             break;
             default:
-                ;
+                SAL_WARN("sc", "unknown attribute: " << aAttrName);
         }
     }
 
