@@ -57,8 +57,8 @@ static sal_Int16 lclAnovaLabels[] =
     0
 };
 
-static const OUString strWildcardRange("%RANGE%");
-static const OUString strWildcardNumber("%NUMBER%");
+static const char strWildcardRange[] = "%RANGE%";
+static const char strWildcardNumber[] = "%NUMBER%";
 
 OUString lclCreateMultiParameterFormula(
             ScRangeList&        aRangeList, const OUString& aFormulaTemplate,
@@ -96,7 +96,7 @@ void lclMakeSubRangesList(ScRangeList& rRangeList, ScRange& rInputRange, ScStati
 
 ScAnalysisOfVarianceDialog::ScAnalysisOfVarianceDialog(
                     SfxBindings* pSfxBindings, SfxChildWindow* pChildWindow,
-                    Window* pParent, ScViewData* pViewData ) :
+                    vcl::Window* pParent, ScViewData* pViewData ) :
     ScStatisticsInputOutputDialog(
             pSfxBindings, pChildWindow, pParent, pViewData,
             "AnalysisOfVarianceDialog", "modules/scalc/ui/analysisofvariancedialog.ui" ),
@@ -117,7 +117,18 @@ ScAnalysisOfVarianceDialog::ScAnalysisOfVarianceDialog(
 }
 
 ScAnalysisOfVarianceDialog::~ScAnalysisOfVarianceDialog()
-{}
+{
+    disposeOnce();
+}
+
+void ScAnalysisOfVarianceDialog::dispose()
+{
+    mpAlphaField.clear();
+    mpSingleFactorRadio.clear();
+    mpTwoFactorRadio.clear();
+    mpRowsPerSampleField.clear();
+    ScStatisticsInputOutputDialog::dispose();
+}
 
 bool ScAnalysisOfVarianceDialog::Close()
 {
@@ -190,7 +201,7 @@ void ScAnalysisOfVarianceDialog::AnovaSingleFactor(AddressWalkerWriter& output,
     output.newLine();
 
     double aAlphaValue = mpAlphaField->GetValue() / 100.0;
-    output.writeString("Alpha");
+    output.writeString(SC_STRLOAD(RID_STATISTICS_DLGS, STR_LABEL_ALPHA));
     output.nextColumn();
     output.writeValue(aAlphaValue);
     aTemplate.autoReplaceAddress("%ALPHA%", output.current());
