@@ -21,8 +21,6 @@
 #include <com/sun/star/embed/Aspects.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
 
-//------------------------------------------------------------------------
-
 #include <toolkit/helper/vclunohelper.hxx>
 #include <sot/exchange.hxx>
 #include <svl/globalnameitem.hxx>
@@ -33,10 +31,13 @@
 #include <svx/pfiledlg.hxx>
 #include <tools/urlobj.hxx>
 #include <vcl/msgbox.hxx>
+#include <vcl/syschild.hxx>
+#include <vcl/openglwin.hxx>
 #include <svl/urihelper.hxx>
 #include <unotools/moduleoptions.hxx>
 #include <svtools/insdlg.hxx>
 #include <svtools/soerr.hxx>
+#include <svtools/embedhlp.hxx>
 #include <svx/svxdlg.hxx>
 #include <comphelper/classids.hxx>
 #include <svx/svdpagv.hxx>
@@ -46,7 +47,6 @@
 #include <svx/charthelper.hxx>
 #include <scmod.hxx>
 
-// BM/IHA --
 #include <cppuhelper/component_context.hxx>
 #include <comphelper/processfactory.hxx>
 #include <comphelper/storagehelper.hxx>
@@ -56,6 +56,7 @@
 #include <com/sun/star/chart2/data/XDataProvider.hpp>
 #include <com/sun/star/chart2/data/XDataReceiver.hpp>
 #include <com/sun/star/chart2/XChartDocument.hpp>
+#include <com/sun/star/chart2/X3DChartWindowProvider.hpp>
 #include <com/sun/star/ui/dialogs/XExecutableDialog.hpp>
 #include <com/sun/star/ui/dialogs/ExecutableDialogResults.hpp>
 #include <com/sun/star/lang/XInitialization.hpp>
@@ -64,12 +65,8 @@
 #include <cppuhelper/bootstrap.hxx>
 
 using namespace ::com::sun::star;
-// BM/IHA --
 
-// erAck
 #include "chart2uno.hxx"
-// erAck
-
 #include "fuinsert.hxx"
 #include "tabvwsh.hxx"
 #include "sc.hrc"
@@ -82,6 +79,8 @@ using namespace ::com::sun::star;
 #include "globstr.hrc"
 #include "drawview.hxx"
 #include "markdata.hxx"
+#include "gridwin.hxx"
+#include <boost/scoped_ptr.hpp>
 
 namespace {
 
@@ -89,7 +88,7 @@ void lcl_ChartInit( const uno::Reference < embed::XEmbeddedObject >& xObj, ScVie
                     const OUString& rRangeParam )
 {
     ScDocShell* pDocShell = pViewData->GetDocShell();
-    ScDocument* pScDoc = pDocShell->GetDocument();
+    ScDocument& rScDoc = pDocShell->GetDocument();
 
     OUString aRangeString( rRangeParam );
     if ( aRangeString.isEmpty() )
@@ -109,13 +108,13 @@ void lcl_ChartInit( const uno::Reference < embed::XEmbeddedObject >& xObj, ScVie
         {
             PutInOrder( nCol1, nCol2 );
             PutInOrder( nRow1, nRow2 );
-            if ( nCol2>nCol1 || nRow2>nRow1 )
+            if (nCol2 >= nCol1 || nRow2 >= nRow1)
             {
                 ScDocument* pDoc = pViewData->GetDocument();
                 pDoc->LimitChartArea( nTab1, nCol1,nRow1, nCol2,nRow2 );
 
                 ScRange aRange( nCol1, nRow1, nTab1, nCol2, nRow2, nTab2 );
-                aRangeString = aRange.Format(SCR_ABS_3D, pScDoc);
+                aRangeString = aRange.Format(SCR_ABS_3D, &rScDoc);
             }
         }
     }
@@ -131,7 +130,7 @@ void lcl_ChartInit( const uno::Reference < embed::XEmbeddedObject >& xObj, ScVie
         OSL_ASSERT( xReceiver.is());
         if( xReceiver.is() )
         {
-            uno::Reference< chart2::data::XDataProvider > xDataProvider = new ScChart2DataProvider( pScDoc );
+            uno::Reference< chart2::data::XDataProvider > xDataProvider = new ScChart2DataProvider( &rScDoc );
             xReceiver->attachDataProvider( xDataProvider );
 
             uno::Reference< util::XNumberFormatsSupplier > xNumberFormatsSupplier( pDocShell->GetModel(), uno::UNO_QUERY );
@@ -144,17 +143,17 @@ void lcl_ChartInit( const uno::Reference < embed::XEmbeddedObject >& xObj, ScVie
 
             // use ScChartPositioner to auto-detect column/row headers (like ScChartArray in old version)
             ScRangeListRef aRangeListRef( new ScRangeList );
-            aRangeListRef->Parse( aRangeString, pScDoc, SCA_VALID, pScDoc->GetAddressConvention() );
+            aRangeListRef->Parse( aRangeString, &rScDoc, SCA_VALID, rScDoc.GetAddressConvention() );
             if ( !aRangeListRef->empty() )
             {
-                pScDoc->LimitChartIfAll( aRangeListRef );               // limit whole columns/rows to used area
+                rScDoc.LimitChartIfAll( aRangeListRef );               // limit whole columns/rows to used area
 
                 // update string from modified ranges.  The ranges must be in the current formula syntax.
                 OUString aTmpStr;
-                aRangeListRef->Format( aTmpStr, SCR_ABS_3D, pScDoc, pScDoc->GetAddressConvention() );
+                aRangeListRef->Format( aTmpStr, SCR_ABS_3D, &rScDoc, rScDoc.GetAddressConvention() );
                 aRangeString = aTmpStr;
 
-                ScChartPositioner aChartPositioner( pScDoc, aRangeListRef );
+                ScChartPositioner aChartPositioner( &rScDoc, aRangeListRef );
                 const ScChartPositionMap* pPositionMap( aChartPositioner.GetPositionMap() );
                 if( pPositionMap )
                 {
@@ -196,7 +195,7 @@ void lcl_ChartInit( const uno::Reference < embed::XEmbeddedObject >& xObj, ScVie
 
 }
 
-FuInsertOLE::FuInsertOLE(ScTabViewShell* pViewSh, Window* pWin, ScDrawView* pViewP,
+FuInsertOLE::FuInsertOLE(ScTabViewShell* pViewSh, vcl::Window* pWin, ScDrawView* pViewP,
            SdrModel* pDoc, SfxRequest& rReq)
     : FuPoor(pViewSh, pWin, pViewP, pDoc, rReq)
 {
@@ -207,14 +206,13 @@ FuInsertOLE::FuInsertOLE(ScTabViewShell* pViewSh, Window* pWin, ScDrawView* pVie
 
     uno::Reference < embed::XEmbeddedObject > xObj;
     uno::Reference < embed::XStorage > xStorage = comphelper::OStorageHelper::GetTemporaryStorage();
-    sal_Bool bIsFromFile = false;
+    bool bIsFromFile = false;
     OUString aName;
 
     sal_Int64 nAspect = embed::Aspects::MSOLE_CONTENT;
     OUString aIconMediaType;
     uno::Reference< io::XInputStream > xIconMetaFile;
 
-
     sal_uInt16 nSlot = rReq.GetSlot();
     SFX_REQUEST_ARG( rReq, pNameItem, SfxGlobalNameItem, SID_INSERT_OBJECT, false );
     if ( nSlot == SID_INSERT_OBJECT && pNameItem )
@@ -244,9 +242,9 @@ FuInsertOLE::FuInsertOLE(ScTabViewShell* pViewSh, Window* pWin, ScDrawView* pVie
             case SID_INSERT_FLOATINGFRAME :
             {
                 SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
-                SfxAbstractInsertObjectDialog* pDlg =
+                boost::scoped_ptr<SfxAbstractInsertObjectDialog> pDlg(
                         pFact->CreateInsertObjectDialog( pViewShell->GetWindow(), SC_MOD()->GetSlotPool()->GetSlot(nSlot)->GetCommandString(),
-                        xStorage, &aServerLst );
+                        xStorage, &aServerLst ));
                 if ( pDlg )
                 {
                     pDlg->Execute();
@@ -260,7 +258,6 @@ FuInsertOLE::FuInsertOLE(ScTabViewShell* pViewSh, Window* pWin, ScDrawView* pVie
                         pViewSh->GetObjectShell()->GetEmbeddedObjectContainer().InsertEmbeddedObject( xObj, aName );
                     // damit DrawShell eingeschaltet wird (Objekt aktivieren ist unnoetig):
                     bIsFromFile = !pDlg->IsCreateNew();
-                    DELETEZ( pDlg );
                 }
 
                 break;
@@ -276,7 +273,7 @@ FuInsertOLE::FuInsertOLE(ScTabViewShell* pViewSh, Window* pWin, ScDrawView* pVie
                 {
                     // get URL
                     INetURLObject aURL;
-                    aURL.SetSmartProtocol( INET_PROT_FILE );
+                    aURL.SetSmartProtocol( INetProtocol::File );
                     if ( aURL.SetURL( aPluginFileDialog.GetPath() ) )
                     {
                         // create a plugin object
@@ -349,22 +346,22 @@ FuInsertOLE::FuInsertOLE(ScTabViewShell* pViewSh, Window* pWin, ScDrawView* pVie
                     xObj->setVisualAreaSize( nAspect, aSz );
 
                     //  re-convert aSize to 1/100th mm to avoid rounding errors in comparison below
-                    aSize = Window::LogicToLogic( aTmp,
+                    aSize = vcl::Window::LogicToLogic( aTmp,
                                     MapMode( aMapUnit ), aMap100 );
                 }
                 else
-                    aSize = Window::LogicToLogic( aSize,
+                    aSize = vcl::Window::LogicToLogic( aSize,
                                     MapMode( aMapUnit ), aMap100 );
             }
 
             //  Chart initialisieren ?
             if ( SvtModuleOptions().IsChart() && SotExchange::IsChart( SvGlobalName( xObj->getClassID() ) ) )
-                lcl_ChartInit( xObj, pViewSh->GetViewData(), OUString() );
+                lcl_ChartInit( xObj, &pViewSh->GetViewData(), OUString() );
 
-            ScViewData* pData = pViewSh->GetViewData();
+            ScViewData& rData = pViewSh->GetViewData();
 
             Point aPnt = pViewSh->GetInsertPos();
-            if ( pData->GetDocument()->IsNegativePage( pData->GetTabNo() ) )
+            if ( rData.GetDocument()->IsNegativePage( rData.GetTabNo() ) )
                 aPnt.X() -= aSize.Width();      // move position to left edge
             Rectangle aRect (aPnt, aSize);
             SdrOle2Obj* pObj = new SdrOle2Obj( aObjRef, aName, aRect);
@@ -404,7 +401,7 @@ FuInsertOLE::FuInsertOLE(ScTabViewShell* pViewSh, Window* pWin, ScDrawView* pVie
                 }
                 else
                 {
-                    pViewShell->ActivateObject( (SdrOle2Obj*) pObj, SVVERB_SHOW );
+                    pViewShell->ActivateObject( pObj, SVVERB_SHOW );
                 }
             }
 
@@ -429,7 +426,7 @@ void FuInsertOLE::Deactivate()
     FuPoor::Deactivate();
 }
 
-FuInsertChart::FuInsertChart(ScTabViewShell* pViewSh, Window* pWin, ScDrawView* pViewP,
+FuInsertChart::FuInsertChart(ScTabViewShell* pViewSh, vcl::Window* pWin, ScDrawView* pViewP,
            SdrModel* pDoc, SfxRequest& rReq)
     : FuPoor(pViewSh, pWin, pViewP, pDoc, rReq)
 {
@@ -438,328 +435,334 @@ FuInsertChart::FuInsertChart(ScTabViewShell* pViewSh, Window* pWin, ScDrawView*
     if( ! rReq.IsAPI() )
         rReq.Done();
 
-    if( SvtModuleOptions().IsChart() )
+    if (!SvtModuleOptions().IsChart())
+        return;
+
+    // BM/IHA --
+
+    // get range
+    OUString aRangeString;
+    ScRange aPositionRange;             // cell range for chart positioning
+    ScMarkData aMark = pViewSh->GetViewData().GetMarkData();
+    if( pReqArgs )
     {
-        // ----------------------------------------
-        // BM/IHA --
+        const SfxPoolItem* pItem;
+        if( pReqArgs->HasItem( FN_PARAM_5, &pItem ) )
+            aRangeString = OUString( static_cast<const SfxStringItem*>(pItem)->GetValue());
 
-        // get range
-        OUString aRangeString;
-        ScRange aPositionRange;             // cell range for chart positioning
-        if( pReqArgs )
+        aPositionRange = pViewSh->GetViewData().GetCurPos();
+    }
+    else
+    {
+        bool bAutomaticMark = false;
+        if ( !aMark.IsMarked() && !aMark.IsMultiMarked() )
         {
-            const SfxPoolItem* pItem;
-            if( pReqArgs->HasItem( FN_PARAM_5, &pItem ) )
-                aRangeString = OUString( ((const SfxStringItem*)pItem)->GetValue());
+            pViewSh->GetViewData().GetView()->MarkDataArea( true );
+            bAutomaticMark = true;
+        }
 
-            aPositionRange = pViewSh->GetViewData()->GetCurPos();
+        ScMarkData aMultiMark( aMark );
+        aMultiMark.MarkToMulti();
+
+        ScRangeList aRanges;
+        aMultiMark.FillRangeListWithMarks( &aRanges, false );
+        OUString aStr;
+        ScDocument* pDocument = pViewSh->GetViewData().GetDocument();
+        aRanges.Format( aStr, SCR_ABS_3D, pDocument, pDocument->GetAddressConvention() );
+        aRangeString = aStr;
+
+        // get "total" range for positioning
+        if ( !aRanges.empty() )
+        {
+            aPositionRange = *aRanges[ 0 ];
+            for ( size_t i = 1, nCount = aRanges.size(); i < nCount; ++i )
+            {
+                aPositionRange.ExtendTo( *aRanges[ i ] );
+            }
+        }
+
+        if(bAutomaticMark)
+            pViewSh->GetViewData().GetView()->Unmark();
+    }
+
+    // adapted old code
+    pView->UnmarkAll();
+
+    OUString aName;
+    const sal_Int64 nAspect = embed::Aspects::MSOLE_CONTENT;
+
+    uno::Reference < embed::XEmbeddedObject > xObj =
+        pViewShell->GetObjectShell()->GetEmbeddedObjectContainer().CreateEmbeddedObject( SvGlobalName( SO3_SCH_CLASSID_60 ).GetByteSequence(), aName );
+
+    uno::Reference< ::com::sun::star::chart2::data::XDataReceiver > xReceiver;
+    uno::Reference< embed::XComponentSupplier > xCompSupp( xObj, uno::UNO_QUERY );
+    if( xCompSupp.is())
+        xReceiver.set( xCompSupp->getComponent(), uno::UNO_QUERY );
+
+    uno::Reference<chart2::XChartDocument> xChartDoc(xReceiver, uno::UNO_QUERY);
+    if (xChartDoc.is())
+        xChartDoc->createDefaultChart();
+
+    // lock the model to suppress any internal updates
+    uno::Reference< frame::XModel > xChartModel( xReceiver, uno::UNO_QUERY );
+    if( xChartModel.is() )
+        xChartModel->lockControllers();
+
+    ScRangeListRef aDummy;
+    Rectangle aMarkDest;
+    SCTAB nMarkTab;
+    bool bDrawRect = pViewShell->GetChartArea( aDummy, aMarkDest, nMarkTab );
+
+    //  Objekt-Groesse
+    awt::Size aSz = xObj->getVisualAreaSize( nAspect );
+    Size aSize( aSz.Width, aSz.Height );
+
+    MapUnit aMapUnit = VCLUnoHelper::UnoEmbed2VCLMapUnit( xObj->getMapUnit( nAspect ) );
+
+    bool bSizeCh = false;
+    if (bDrawRect && !aMarkDest.IsEmpty())
+    {
+        aSize = aMarkDest.GetSize();
+        bSizeCh = true;
+    }
+    if (aSize.Height() <= 0 || aSize.Width() <= 0)
+    {
+        aSize.Width() = 5000;
+        aSize.Height() = 5000;
+        bSizeCh = true;
+    }
+    if (bSizeCh)
+    {
+        aSize = vcl::Window::LogicToLogic( aSize, MapMode( MAP_100TH_MM ), MapMode( aMapUnit ) );
+        aSz.Width = aSize.Width();
+        aSz.Height = aSize.Height();
+        xObj->setVisualAreaSize( nAspect, aSz );
+    }
+
+    ScViewData& rData = pViewSh->GetViewData();
+    ScDocShell* pScDocSh = rData.GetDocShell();
+    ScDocument& rScDoc   = pScDocSh->GetDocument();
+    bool bUndo (rScDoc.IsUndoEnabled());
+
+    if( pReqArgs )
+    {
+        const SfxPoolItem* pItem;
+        sal_uInt16 nToTable = 0;
+
+        if( pReqArgs->HasItem( FN_PARAM_4, &pItem ) )
+        {
+            if ( pItem->ISA( SfxUInt16Item ) )
+                nToTable = static_cast<const SfxUInt16Item*>(pItem)->GetValue();
+            else if ( pItem->ISA( SfxBoolItem ) )
+            {
+                //  in der idl fuer Basic steht FN_PARAM_4 als SfxBoolItem
+                //  -> wenn gesetzt, neue Tabelle, sonst aktuelle Tabelle
+
+                if ( static_cast<const SfxBoolItem*>(pItem)->GetValue() )
+                    nToTable = static_cast<sal_uInt16>(rScDoc.GetTableCount());
+                else
+                    nToTable = static_cast<sal_uInt16>(rData.GetTabNo());
+            }
         }
         else
         {
-            ScMarkData& rMark = pViewSh->GetViewData()->GetMarkData();
-            bool bAutomaticMark = false;
-            if ( !rMark.IsMarked() && !rMark.IsMultiMarked() )
+            if (bDrawRect)
+                nToTable = static_cast<sal_uInt16>(nMarkTab);
+            rReq.AppendItem( SfxUInt16Item( FN_PARAM_4, nToTable ) );
+        }
+
+        // auf neue Tabelle ausgeben?
+        if ( nToTable == rScDoc.GetTableCount() )
+        {
+            // dann los...
+            OUString      aTabName;
+            SCTAB       nNewTab = rScDoc.GetTableCount();
+
+            rScDoc.CreateValidTabName( aTabName );
+
+            if ( rScDoc.InsertTab( nNewTab, aTabName ) )
             {
-                pViewSh->GetViewData()->GetView()->MarkDataArea( sal_True );
-                bAutomaticMark = true;
-            }
-
-            ScMarkData aMultiMark( rMark );
-            aMultiMark.MarkToMulti();
-
-            ScRangeList aRanges;
-            aMultiMark.FillRangeListWithMarks( &aRanges, false );
-            OUString aStr;
-            ScDocument* pDocument = pViewSh->GetViewData()->GetDocument();
-            aRanges.Format( aStr, SCR_ABS_3D, pDocument, pDocument->GetAddressConvention() );
-            aRangeString = aStr;
-
-            // get "total" range for positioning
-            if ( !aRanges.empty() )
-            {
-                aPositionRange = *aRanges[ 0 ];
-                for ( size_t i = 1, nCount = aRanges.size(); i < nCount; ++i )
+                if (bUndo)
                 {
-                    aPositionRange.ExtendTo( *aRanges[ i ] );
+                    bool bAppend = true;
+                    pScDocSh->GetUndoManager()->AddUndoAction(
+                        new ScUndoInsertTab( pScDocSh, nNewTab,
+                                             bAppend, aTabName ) );
                 }
-            }
 
-            if(bAutomaticMark)
-                pViewSh->GetViewData()->GetView()->Unmark();
-        }
-
-        // ----------------------------------------
-        // adapted old code
-        pView->UnmarkAll();
-
-        OUString aName;
-        const sal_Int64 nAspect = embed::Aspects::MSOLE_CONTENT;
-
-        uno::Reference < embed::XEmbeddedObject > xObj =
-            pViewShell->GetObjectShell()->GetEmbeddedObjectContainer().CreateEmbeddedObject( SvGlobalName( SO3_SCH_CLASSID_60 ).GetByteSequence(), aName );
-
-        uno::Reference< ::com::sun::star::chart2::data::XDataReceiver > xReceiver;
-        uno::Reference< embed::XComponentSupplier > xCompSupp( xObj, uno::UNO_QUERY );
-        if( xCompSupp.is())
-            xReceiver.set( xCompSupp->getComponent(), uno::UNO_QUERY );
-
-        uno::Reference<chart2::XChartDocument> xChartDoc(xReceiver, uno::UNO_QUERY);
-        if (xChartDoc.is())
-            xChartDoc->createDefaultChart();
-
-        // lock the model to suppress any internal updates
-        uno::Reference< frame::XModel > xChartModel( xReceiver, uno::UNO_QUERY );
-        if( xChartModel.is() )
-            xChartModel->lockControllers();
-
-        ScRangeListRef aDummy;
-        Rectangle aMarkDest;
-        SCTAB nMarkTab;
-        sal_Bool bDrawRect = pViewShell->GetChartArea( aDummy, aMarkDest, nMarkTab );
-
-        //  Objekt-Groesse
-        awt::Size aSz = xObj->getVisualAreaSize( nAspect );
-        Size aSize( aSz.Width, aSz.Height );
-
-        MapUnit aMapUnit = VCLUnoHelper::UnoEmbed2VCLMapUnit( xObj->getMapUnit( nAspect ) );
-
-        sal_Bool bSizeCh = false;
-        if (bDrawRect && !aMarkDest.IsEmpty())
-        {
-            aSize = aMarkDest.GetSize();
-            bSizeCh = sal_True;
-        }
-        if (aSize.Height() <= 0 || aSize.Width() <= 0)
-        {
-            aSize.Width() = 5000;
-            aSize.Height() = 5000;
-            bSizeCh = sal_True;
-        }
-        if (bSizeCh)
-        {
-            aSize = Window::LogicToLogic( aSize, MapMode( MAP_100TH_MM ), MapMode( aMapUnit ) );
-            aSz.Width = aSize.Width();
-            aSz.Height = aSize.Height();
-            xObj->setVisualAreaSize( nAspect, aSz );
-        }
-
-        ScViewData* pData = pViewSh->GetViewData();
-        ScDocShell* pScDocSh = pData->GetDocShell();
-        ScDocument* pScDoc   = pScDocSh->GetDocument();
-        sal_Bool bUndo (pScDoc->IsUndoEnabled());
-
-        if( pReqArgs )
-        {
-            const SfxPoolItem* pItem;
-            sal_uInt16 nToTable = 0;
-
-            if( pReqArgs->HasItem( FN_PARAM_4, &pItem ) )
-            {
-                if ( pItem->ISA( SfxUInt16Item ) )
-                    nToTable = ((const SfxUInt16Item*)pItem)->GetValue();
-                else if ( pItem->ISA( SfxBoolItem ) )
-                {
-                    //  in der idl fuer Basic steht FN_PARAM_4 als SfxBoolItem
-                    //  -> wenn gesetzt, neue Tabelle, sonst aktuelle Tabelle
-
-                    if ( ((const SfxBoolItem*)pItem)->GetValue() )
-                        nToTable = static_cast<sal_uInt16>(pScDoc->GetTableCount());
-                    else
-                        nToTable = static_cast<sal_uInt16>(pData->GetTabNo());
-                }
+                pScDocSh->Broadcast( ScTablesHint( SC_TAB_INSERTED, nNewTab ) );
+                pViewSh->SetTabNo( nNewTab, true );
+                pScDocSh->PostPaintExtras();            //! erst hinterher ???
             }
             else
             {
-                if (bDrawRect)
-                    nToTable = static_cast<sal_uInt16>(nMarkTab);
-                rReq.AppendItem( SfxUInt16Item( FN_PARAM_4, nToTable ) );
-            }
-
-            // auf neue Tabelle ausgeben?
-            if ( nToTable == pScDoc->GetTableCount() )
-            {
-                // dann los...
-                OUString      aTabName;
-                SCTAB       nNewTab = pScDoc->GetTableCount();
-
-                pScDoc->CreateValidTabName( aTabName );
-
-                if ( pScDoc->InsertTab( nNewTab, aTabName ) )
-                {
-                    sal_Bool bAppend = sal_True;
-
-                    if (bUndo)
-                    {
-                        pScDocSh->GetUndoManager()->AddUndoAction(
-                            new ScUndoInsertTab( pScDocSh, nNewTab,
-                                                 bAppend, aTabName ) );
-                    }
-
-                    pScDocSh->Broadcast( ScTablesHint( SC_TAB_INSERTED, nNewTab ) );
-                    pViewSh->SetTabNo( nNewTab, sal_True );
-                    pScDocSh->PostPaintExtras();            //! erst hinterher ???
-                }
-                else
-                {
-                    OSL_FAIL( "Could not create new table :-/" );
-                }
-            }
-            else if ( nToTable != pData->GetTabNo() )
-            {
-                pViewSh->SetTabNo( nToTable, sal_True );
+                OSL_FAIL( "Could not create new table :-/" );
             }
         }
-
-        lcl_ChartInit( xObj, pData, aRangeString );         // set source range, auto-detect column/row headers
-
-        //  Objekt-Position
-
-        Point aStart;
-        if ( bDrawRect )
-            aStart = aMarkDest.TopLeft();                       // marked by hand
-        else
+        else if ( nToTable != rData.GetTabNo() )
         {
-            // get chart position (from window size and data range)
-            aStart = pViewSh->GetChartInsertPos( aSize, aPositionRange );
+            pViewSh->SetTabNo( nToTable, true );
         }
+    }
 
-        Rectangle aRect (aStart, aSize);
-        SdrOle2Obj* pObj = new SdrOle2Obj( svt::EmbeddedObjectRef( xObj, nAspect ), aName, aRect);
-        SdrPageView* pPV = pView->GetSdrPageView();
+    lcl_ChartInit( xObj, &rData, aRangeString );         // set source range, auto-detect column/row headers
 
-        // #i121334# This call will change the chart's default background fill from white to transparent.
-        // Add here again if this is wanted (see task description for details)
-        // ChartHelper::AdaptDefaultsForChart( xObj );
+    //  Objekt-Position
+
+    Point aStart;
+    if ( bDrawRect )
+        aStart = aMarkDest.TopLeft();                       // marked by hand
+    else
+    {
+        // get chart position (from window size and data range)
+        aStart = pViewSh->GetChartInsertPos( aSize, aPositionRange );
+    }
+
+    Rectangle aRect (aStart, aSize);
+    SdrOle2Obj* pObj = new SdrOle2Obj( svt::EmbeddedObjectRef( xObj, nAspect ), aName, aRect);
+    SdrPageView* pPV = pView->GetSdrPageView();
+
+    // #i121334# This call will change the chart's default background fill from white to transparent.
+    // Add here again if this is wanted (see task description for details)
+    // ChartHelper::AdaptDefaultsForChart( xObj );
 
 //        pView->InsertObjectAtView(pObj, *pPV);//this call leads to an immidiate redraw and asks the chart for a visual representation
 
-        // use the page instead of the view to insert, so no undo action is created yet
-        SdrPage* pInsPage = pPV->GetPage();
-        pInsPage->InsertObject( pObj );
-        pView->UnmarkAllObj();
-        pView->MarkObj( pObj, pPV );
-        bool bAddUndo = true;               // add undo action later, unless the dialog is canceled
+    // use the page instead of the view to insert, so no undo action is created yet
+    SdrPage* pInsPage = pPV->GetPage();
+    pInsPage->InsertObject( pObj );
+    pView->UnmarkAllObj();
+    pView->MarkObj( pObj, pPV );
+    bool bAddUndo = true;               // add undo action later, unless the dialog is canceled
 
-        if (rReq.IsAPI())
+    if (rReq.IsAPI())
+    {
+        if( xChartModel.is() )
+            xChartModel->unlockControllers();
+    }
+    else
+    {
+        //the controller will be unlocked by the dialog when the dialog is told to do so
+
+        // only activate object if not called via API (e.g. macro)
+        pViewShell->ActivateObject( pObj, SVVERB_SHOW );
+
+        //open wizard
+        //@todo get context from calc if that has one
+        uno::Reference< uno::XComponentContext > xContext(
+            ::cppu::defaultBootstrap_InitialComponentContext() );
+        if(xContext.is())
         {
-            if( xChartModel.is() )
-                xChartModel->unlockControllers();
-        }
-        else
-        {
-            //the controller will be unlocked by the dialog when the dialog is told to do so
-
-            // only activate object if not called via API (e.g. macro)
-            pViewShell->ActivateObject( (SdrOle2Obj*) pObj, SVVERB_SHOW );
-
-            //open wizard
-            //@todo get context from calc if that has one
-            uno::Reference< uno::XComponentContext > xContext(
-                ::cppu::defaultBootstrap_InitialComponentContext() );
-            if(xContext.is())
+            uno::Reference< lang::XMultiComponentFactory > xMCF( xContext->getServiceManager() );
+            if(xMCF.is())
             {
-                uno::Reference< lang::XMultiComponentFactory > xMCF( xContext->getServiceManager() );
-                if(xMCF.is())
+                uno::Reference< ui::dialogs::XExecutableDialog > xDialog(
+                    xMCF->createInstanceWithContext(
+                        OUString("com.sun.star.comp.chart2.WizardDialog")
+                        , xContext), uno::UNO_QUERY);
+                uno::Reference< lang::XInitialization > xInit( xDialog, uno::UNO_QUERY );
+                if( xChartModel.is() && xInit.is() )
                 {
-                    uno::Reference< ui::dialogs::XExecutableDialog > xDialog(
-                        xMCF->createInstanceWithContext(
-                            OUString("com.sun.star.comp.chart2.WizardDialog")
-                            , xContext), uno::UNO_QUERY);
-                    uno::Reference< lang::XInitialization > xInit( xDialog, uno::UNO_QUERY );
-                    if( xChartModel.is() && xInit.is() )
+                    uno::Reference< awt::XWindow > xDialogParentWindow(0);
+                    //  initialize dialog
+                    uno::Sequence<uno::Any> aSeq(2);
+                    uno::Any* pArray = aSeq.getArray();
+                    beans::PropertyValue aParam1;
+                    aParam1.Name = "ParentWindow";
+                    aParam1.Value <<= uno::makeAny(xDialogParentWindow);
+                    beans::PropertyValue aParam2;
+                    aParam2.Name = "ChartModel";
+                    aParam2.Value <<= uno::makeAny(xChartModel);
+                    pArray[0] <<= uno::makeAny(aParam1);
+                    pArray[1] <<= uno::makeAny(aParam2);
+                    xInit->initialize( aSeq );
+
+                    // try to set the dialog's position so it doesn't hide the chart
+                    uno::Reference < beans::XPropertySet > xDialogProps( xDialog, uno::UNO_QUERY );
+                    if ( xDialogProps.is() )
                     {
-                        uno::Reference< awt::XWindow > xDialogParentWindow(0);
-                        //  initialize dialog
-                        uno::Sequence<uno::Any> aSeq(2);
-                        uno::Any* pArray = aSeq.getArray();
-                        beans::PropertyValue aParam1;
-                        aParam1.Name = "ParentWindow";
-                        aParam1.Value <<= uno::makeAny(xDialogParentWindow);
-                        beans::PropertyValue aParam2;
-                        aParam2.Name = "ChartModel";
-                        aParam2.Value <<= uno::makeAny(xChartModel);
-                        pArray[0] <<= uno::makeAny(aParam1);
-                        pArray[1] <<= uno::makeAny(aParam2);
-                        xInit->initialize( aSeq );
-
-                        // try to set the dialog's position so it doesn't hide the chart
-                        uno::Reference < beans::XPropertySet > xDialogProps( xDialog, uno::UNO_QUERY );
-                        if ( xDialogProps.is() )
+                        try
                         {
-                            try
+                            //get dialog size:
+                            awt::Size aDialogAWTSize;
+                            if( xDialogProps->getPropertyValue("Size")
+                                >>= aDialogAWTSize )
                             {
-                                //get dialog size:
-                                awt::Size aDialogAWTSize;
-                                if( xDialogProps->getPropertyValue("Size")
-                                    >>= aDialogAWTSize )
+                                Size aDialogSize( aDialogAWTSize.Width, aDialogAWTSize.Height );
+                                if ( aDialogSize.Width() > 0 && aDialogSize.Height() > 0 )
                                 {
-                                    Size aDialogSize( aDialogAWTSize.Width, aDialogAWTSize.Height );
-                                    if ( aDialogSize.Width() > 0 && aDialogSize.Height() > 0 )
-                                    {
-                                        //calculate and set new position
-                                        Point aDialogPos = pViewShell->GetChartDialogPos( aDialogSize, aRect );
-                                        xDialogProps->setPropertyValue("Position",
-                                            uno::makeAny( awt::Point(aDialogPos.getX(),aDialogPos.getY()) ) );
-                                    }
+                                    //calculate and set new position
+                                    Point aDialogPos = pViewShell->GetChartDialogPos( aDialogSize, aRect );
+                                    xDialogProps->setPropertyValue("Position",
+                                        uno::makeAny( awt::Point(aDialogPos.getX(),aDialogPos.getY()) ) );
                                 }
-                                //tell the dialog to unlock controller
-                                xDialogProps->setPropertyValue("UnlockControllersOnExecute",
-                                            uno::makeAny( sal_True ) );
-
-                            }
-                            catch( uno::Exception& )
-                            {
-                                OSL_FAIL( "Chart wizard couldn't be positioned automatically\n" );
                             }
+                            //tell the dialog to unlock controller
+                            xDialogProps->setPropertyValue("UnlockControllersOnExecute",
+                                        uno::makeAny( sal_True ) );
+
                         }
-
-                        sal_Int16 nDialogRet = xDialog->execute();
-                        if( nDialogRet == ui::dialogs::ExecutableDialogResults::CANCEL )
+                        catch( uno::Exception& )
                         {
-                            // leave OLE inplace mode and unmark
-                            OSL_ASSERT( pViewShell );
-                            OSL_ASSERT( pView );
-                            pViewShell->DeactivateOle();
-                            pView->UnmarkAll();
-
-                            // old page view pointer is invalid after switching sheets
-                            pPV = pView->GetSdrPageView();
-
-                            // remove the chart
-                            OSL_ASSERT( pPV );
-                            SdrPage * pPage( pPV->GetPage());
-                            OSL_ASSERT( pPage );
-                            OSL_ASSERT( pObj );
-                            if( pPage )
-                                pPage->RemoveObject( pObj->GetOrdNum());
-
-                            bAddUndo = false;       // don't create the undo action for inserting
-
-                            // leave the draw shell
-                            pViewShell->SetDrawShell( false );
-                        }
-                        else
-                        {
-                            OSL_ASSERT( nDialogRet == ui::dialogs::ExecutableDialogResults::OK );
-                            //@todo maybe move chart to different table
+                            OSL_FAIL( "Chart wizard couldn't be positioned automatically\n" );
                         }
                     }
-                    uno::Reference< lang::XComponent > xComponent( xDialog, uno::UNO_QUERY );
-                    if( xComponent.is())
-                        xComponent->dispose();
+
+                    sal_Int16 nDialogRet = xDialog->execute();
+                    if( nDialogRet == ui::dialogs::ExecutableDialogResults::CANCEL )
+                    {
+                        // leave OLE inplace mode and unmark
+                        OSL_ASSERT( pViewShell );
+                        OSL_ASSERT( pView );
+                        pViewShell->DeactivateOle();
+                        pView->UnmarkAll();
+
+                        // old page view pointer is invalid after switching sheets
+                        pPV = pView->GetSdrPageView();
+
+                        // remove the chart
+                        OSL_ASSERT( pPV );
+                        SdrPage * pPage( pPV->GetPage());
+                        OSL_ASSERT( pPage );
+                        OSL_ASSERT( pObj );
+                        if( pPage )
+                        {
+                            // Remove the OLE2 object from the sdr page.
+                            SdrObject* pRemoved = pPage->RemoveObject(pObj->GetOrdNum());
+                            OSL_ASSERT(pRemoved == pObj);
+                            SdrObject::Free(pRemoved); // Don't forget to free it.
+                        }
+
+                        bAddUndo = false;       // don't create the undo action for inserting
+
+                        // leave the draw shell
+                        pViewShell->SetDrawShell( false );
+
+                        // reset marked cell area
+
+                        pViewSh->GetViewData().GetViewShell()->SetMarkData(aMark);
+                    }
+                    else
+                    {
+                        OSL_ASSERT( nDialogRet == ui::dialogs::ExecutableDialogResults::OK );
+                        //@todo maybe move chart to different table
+                    }
                 }
+                uno::Reference< lang::XComponent > xComponent( xDialog, uno::UNO_QUERY );
+                if( xComponent.is())
+                    xComponent->dispose();
             }
         }
-
-        if ( bAddUndo )
-        {
-            // add undo action the same way as in SdrEditView::InsertObjectAtView
-            // (using UndoActionHdl etc.)
-            pView->AddUndo(pDoc->GetSdrUndoFactory().CreateUndoNewObject(*pObj));
-        }
-
-        // BM/IHA --
     }
+
+    if ( bAddUndo )
+    {
+        // add undo action the same way as in SdrEditView::InsertObjectAtView
+        // (using UndoActionHdl etc.)
+        pView->AddUndo(new SdrUndoNewObj(*pObj));
+    }
+
+    // BM/IHA --
 }
 
 void FuInsertChart::Activate()
@@ -772,7 +775,7 @@ void FuInsertChart::Deactivate()
     FuPoor::Deactivate();
 }
 
-FuInsertChartFromFile::FuInsertChartFromFile( ScTabViewShell* pViewSh, Window* pWin, ScDrawView* pViewP,
+FuInsertChartFromFile::FuInsertChartFromFile( ScTabViewShell* pViewSh, vcl::Window* pWin, ScDrawView* pViewP,
            SdrModel* pDoc, SfxRequest& rReq, const OUString& rURL):
     FuPoor(pViewSh, pWin, pViewP, pDoc, rReq)
 {
@@ -789,7 +792,7 @@ FuInsertChartFromFile::FuInsertChartFromFile( ScTabViewShell* pViewSh, Window* p
     awt::Size aSz = xObj->getVisualAreaSize( nAspect );
     Size aSize( aSz.Width, aSz.Height );
 
-    ScRange aPositionRange = pViewSh->GetViewData()->GetCurPos();
+    ScRange aPositionRange = pViewSh->GetViewData().GetCurPos();
     Point aStart = pViewSh->GetChartInsertPos( aSize, aPositionRange );
     Rectangle aRect (aStart, aSize);
     SdrOle2Obj* pObj = new SdrOle2Obj( svt::EmbeddedObjectRef( xObj, nAspect ), aName, aRect);
@@ -802,7 +805,7 @@ FuInsertChartFromFile::FuInsertChartFromFile( ScTabViewShell* pViewSh, Window* p
     pView->UnmarkAllObj();
     pView->MarkObj( pObj, pPV );
 
-    pViewShell->ActivateObject( (SdrOle2Obj*) pObj, SVVERB_SHOW );
+    pViewShell->ActivateObject( pObj, SVVERB_SHOW );
 }
 
 void FuInsertChartFromFile::Activate()
@@ -815,5 +818,4 @@ void FuInsertChartFromFile::Deactivate()
     FuPoor::Deactivate();
 }
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
