@@ -18,6 +18,7 @@
  */
 
 #include "privsplt.hxx"
+#include <vcl/settings.hxx>
 
 /*************************************************************************
 #*  Member:     ScPrivatSplit
@@ -33,9 +34,11 @@
 #*
 #************************************************************************/
 
-ScPrivatSplit::ScPrivatSplit( Window* pParent, const ResId& rResId,
-                             SC_SPLIT_DIRECTION eSplit):
-                        Control( pParent, rResId )
+ScPrivatSplit::ScPrivatSplit(vcl::Window* pParent, const ResId& rResId,
+                             SC_SPLIT_DIRECTION eSplit)
+    : Control(pParent, rResId)
+    , nDeltaX(0)
+    , nDeltaY(0)
 {
     Point aPos=GetPosPixel();
     nOldX=(short)aPos.X();
@@ -53,16 +56,15 @@ ScPrivatSplit::ScPrivatSplit( Window* pParent, const ResId& rResId,
     aMovingFlag=false;
     if(eScSplit==SC_SPLIT_HORZ)
     {
-        aWinPointer=Pointer(POINTER_HSPLIT);
+        aWinPointer=Pointer(PointerStyle::HSplit);
     }
     else
     {
-        aWinPointer=Pointer(POINTER_VSPLIT);
+        aWinPointer=Pointer(PointerStyle::VSplit);
     }
     SetPointer(aWinPointer);
 }
 
-
 /*************************************************************************
 #*  Member:     MouseButtonDown
 #*------------------------------------------------------------------------
@@ -233,8 +235,6 @@ void ScPrivatSplit::SetYRange(Range cRgeY)
     aYMovingRange=cRgeY;
 }
 
-
-
 /*************************************************************************
 #*  Member:     GetDeltaY
 #*------------------------------------------------------------------------
@@ -335,14 +335,13 @@ void ScPrivatSplit::MoveSplitTo(Point aPos)
     CtrModified();
 }
 
-
-void ScPrivatSplit::ImplInitSettings( sal_Bool bFont, sal_Bool bForeground, sal_Bool bBackground )
+void ScPrivatSplit::ImplInitSettings( bool bFont, bool bForeground, bool bBackground )
 {
     const StyleSettings& rStyleSettings = GetSettings().GetStyleSettings();
 
     if ( bFont )
     {
-        Font aFont = rStyleSettings.GetAppFont();
+        vcl::Font aFont = rStyleSettings.GetAppFont();
         if ( IsControlFont() )
             aFont.Merge( GetControlFont() );
         SetFont( aFont );
@@ -368,43 +367,38 @@ void ScPrivatSplit::ImplInitSettings( sal_Bool bFont, sal_Bool bForeground, sal_
     Invalidate();
 }
 
-// -----------------------------------------------------------------------
-
 void ScPrivatSplit::StateChanged( StateChangedType nType )
 {
-    if ( (nType == STATE_CHANGE_ZOOM) ||
-         (nType == STATE_CHANGE_CONTROLFONT) )
+    if ( (nType == StateChangedType::Zoom) ||
+         (nType == StateChangedType::ControlFont) )
     {
-        ImplInitSettings( sal_True, false, false );
+        ImplInitSettings( true, false, false );
         Invalidate();
     }
-    if ( nType == STATE_CHANGE_CONTROLFOREGROUND )
+    if ( nType == StateChangedType::ControlForeground )
     {
-        ImplInitSettings( false, sal_True, false );
+        ImplInitSettings( false, true, false );
         Invalidate();
     }
-    else if ( nType == STATE_CHANGE_CONTROLBACKGROUND )
+    else if ( nType == StateChangedType::ControlBackground )
     {
-        ImplInitSettings( false, false, sal_True );
+        ImplInitSettings( false, false, true );
         Invalidate();
     }
 
     Control::StateChanged( nType );
 }
 
-// -----------------------------------------------------------------------
-
 void ScPrivatSplit::DataChanged( const DataChangedEvent& rDCEvt )
 {
-    if ( (rDCEvt.GetType() == DATACHANGED_SETTINGS) &&
-         (rDCEvt.GetFlags() & SETTINGS_STYLE) )
+    if ( (rDCEvt.GetType() == DataChangedEventType::SETTINGS) &&
+         (rDCEvt.GetFlags() & AllSettingsFlags::STYLE) )
     {
-        ImplInitSettings( sal_True, sal_True, sal_True );
+        ImplInitSettings( true, true, true );
         Invalidate();
     }
     else
         Window::DataChanged( rDCEvt );
 }
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
