@@ -72,36 +72,38 @@ public:
     void      SetDoubleValue( double fNew ) { mbIsDouble = true; mfDoubleValue = fNew; }
     void      SetIntValue( sal_Int32 nNew ) { mbIsDouble = false; mnIntValue = nNew; }
 
-    virtual void Paint(const Point& rPos, SvTreeListBox& rDev, const SvViewDataEntry* pView, const SvTreeListEntry* pEntry) SAL_OVERRIDE;
+    virtual void Paint(const Point& rPos, SvTreeListBox& rDev, vcl::RenderContext& rRenderContext,
+                       const SvViewDataEntry* pView, const SvTreeListEntry* pEntry) SAL_OVERRIDE;
 };
 
-void ScSolverOptionsString::Paint( const Point& rPos, SvTreeListBox& rDev, const SvViewDataEntry* /*pView*/, const SvTreeListEntry* /*pEntry*/)
+void ScSolverOptionsString::Paint(const Point& rPos, SvTreeListBox& /*rDev*/, vcl::RenderContext& rRenderContext,
+                                  const SvViewDataEntry* /*pView*/, const SvTreeListEntry* /*pEntry*/)
 {
     //! move position? (SvxLinguTabPage: aPos.X() += 20)
-    OUString aNormalStr( GetText() );
+    OUString aNormalStr(GetText());
     aNormalStr += ":";
-    rDev.DrawText( rPos, aNormalStr );
+    rRenderContext.DrawText(rPos, aNormalStr);
 
-    Point aNewPos( rPos );
-    aNewPos.X() += rDev.GetTextWidth( aNormalStr );
-    Font aOldFont( rDev.GetFont() );
-    Font aFont( aOldFont );
-    aFont.SetWeight( WEIGHT_BOLD );
+    Point aNewPos(rPos);
+    aNewPos.X() += rRenderContext.GetTextWidth(aNormalStr);
+    vcl::Font aOldFont(rRenderContext.GetFont());
+    vcl::Font aFont(aOldFont);
+    aFont.SetWeight(WEIGHT_BOLD);
 
-    OUString sTxt( ' ' );
-    if ( mbIsDouble )
-        sTxt += rtl::math::doubleToUString( mfDoubleValue,
+    OUString sTxt(' ');
+    if (mbIsDouble)
+        sTxt += rtl::math::doubleToUString(mfDoubleValue,
             rtl_math_StringFormat_Automatic, rtl_math_DecimalPlaces_Max,
             ScGlobal::GetpLocaleData()->getNumDecimalSep()[0], true );
     else
         sTxt += OUString::number(mnIntValue);
-    rDev.SetFont( aFont );
-    rDev.DrawText( aNewPos, sTxt );
+    rRenderContext.SetFont(aFont);
+    rRenderContext.DrawText(aNewPos, sTxt);
 
-    rDev.SetFont( aOldFont );
+    rRenderContext.SetFont(aOldFont);
 }
 
-ScSolverOptionsDialog::ScSolverOptionsDialog( Window* pParent,
+ScSolverOptionsDialog::ScSolverOptionsDialog( vcl::Window* pParent,
                         const uno::Sequence<OUString>& rImplNames,
                         const uno::Sequence<OUString>& rDescriptions,
                         const OUString& rEngine,
@@ -146,7 +148,7 @@ ScSolverOptionsDialog::ScSolverOptionsDialog( Window* pParent,
             nSelect = 0;
         }
         else
-            maEngine = "";
+            maEngine.clear();
         maProperties.realloc(0);        // don't use options from different engine
     }
     if ( nSelect >= 0 )                 // select in list box
@@ -159,12 +161,16 @@ ScSolverOptionsDialog::ScSolverOptionsDialog( Window* pParent,
 
 ScSolverOptionsDialog::~ScSolverOptionsDialog()
 {
-    delete mpCheckButtonData;
+    disposeOnce();
 }
 
-const OUString& ScSolverOptionsDialog::GetEngine() const
+void ScSolverOptionsDialog::dispose()
 {
-    return maEngine;    // already updated in selection handler
+    delete mpCheckButtonData;
+    m_pLbEngine.clear();
+    m_pLbSettings.clear();
+    m_pBtnEdit.clear();
+    ModalDialog::dispose();
 }
 
 const uno::Sequence<beans::PropertyValue>& ScSolverOptionsDialog::GetProperties()
@@ -313,23 +319,23 @@ void ScSolverOptionsDialog::EditOption()
             {
                 if ( pStringItem->IsDouble() )
                 {
-                    ScSolverValueDialog aValDialog( this );
-                    aValDialog.SetOptionName( pStringItem->GetText() );
-                    aValDialog.SetValue( pStringItem->GetDoubleValue() );
-                    if ( aValDialog.Execute() == RET_OK )
+                    ScopedVclPtrInstance< ScSolverValueDialog > aValDialog( this );
+                    aValDialog->SetOptionName( pStringItem->GetText() );
+                    aValDialog->SetValue( pStringItem->GetDoubleValue() );
+                    if ( aValDialog->Execute() == RET_OK )
                     {
-                        pStringItem->SetDoubleValue( aValDialog.GetValue() );
+                        pStringItem->SetDoubleValue( aValDialog->GetValue() );
                         m_pLbSettings->InvalidateEntry( pEntry );
                     }
                 }
                 else
                 {
-                    ScSolverIntegerDialog aIntDialog( this );
-                    aIntDialog.SetOptionName( pStringItem->GetText() );
-                    aIntDialog.SetValue( pStringItem->GetIntValue() );
-                    if ( aIntDialog.Execute() == RET_OK )
+                    ScopedVclPtrInstance< ScSolverIntegerDialog > aIntDialog( this );
+                    aIntDialog->SetOptionName( pStringItem->GetText() );
+                    aIntDialog->SetValue( pStringItem->GetIntValue() );
+                    if ( aIntDialog->Execute() == RET_OK )
                     {
-                        pStringItem->SetIntValue( aIntDialog.GetValue() );
+                        pStringItem->SetIntValue( aIntDialog->GetValue() );
                         m_pLbSettings->InvalidateEntry( pEntry );
                     }
                 }
@@ -385,7 +391,7 @@ IMPL_LINK_NOARG(ScSolverOptionsDialog, SettingsSelHdl)
     return 0;
 }
 
-ScSolverIntegerDialog::ScSolverIntegerDialog(Window * pParent)
+ScSolverIntegerDialog::ScSolverIntegerDialog(vcl::Window * pParent)
     : ModalDialog( pParent, "IntegerDialog",
         "modules/scalc/ui/integerdialog.ui" )
 {
@@ -393,6 +399,18 @@ ScSolverIntegerDialog::ScSolverIntegerDialog(Window * pParent)
     get(m_pNfValue, "value");
 }
 
+ScSolverIntegerDialog::~ScSolverIntegerDialog()
+{
+    disposeOnce();
+}
+
+void ScSolverIntegerDialog::dispose()
+{
+    m_pFrame.clear();
+    m_pNfValue.clear();
+    ModalDialog::dispose();
+}
+
 void ScSolverIntegerDialog::SetOptionName( const OUString& rName )
 {
     m_pFrame->set_label(rName);
@@ -413,7 +431,7 @@ sal_Int32 ScSolverIntegerDialog::GetValue() const
     return (sal_Int32) nValue;
 }
 
-ScSolverValueDialog::ScSolverValueDialog( Window * pParent )
+ScSolverValueDialog::ScSolverValueDialog( vcl::Window * pParent )
     : ModalDialog( pParent, "DoubleDialog",
         "modules/scalc/ui/doubledialog.ui" )
 {
@@ -421,6 +439,18 @@ ScSolverValueDialog::ScSolverValueDialog( Window * pParent )
     get(m_pEdValue, "value");
 }
 
+ScSolverValueDialog::~ScSolverValueDialog()
+{
+    disposeOnce();
+}
+
+void ScSolverValueDialog::dispose()
+{
+    m_pFrame.clear();
+    m_pEdValue.clear();
+    ModalDialog::dispose();
+}
+
 void ScSolverValueDialog::SetOptionName( const OUString& rName )
 {
     m_pFrame->set_label(rName);
