@@ -17,14 +17,8 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #undef SC_DLLIMPLEMENTATION
 
-
-
-//------------------------------------------------------------------
-
-#define _TPHFEDIT_CXX
 #include "scitems.hxx"
 #include <editeng/eeitem.hxx>
 
@@ -36,6 +30,8 @@
 #include <sfx2/objsh.hxx>
 #include <vcl/msgbox.hxx>
 #include <vcl/svapp.hxx>
+#include <vcl/settings.hxx>
+
 #include <unotools/useroptions.hxx>
 
 #include "editutil.hxx"
@@ -51,21 +47,19 @@
 #include "AccessibleEditObject.hxx"
 
 #include "scuitphfedit.hxx"
-#include <memory>
+#include <boost/scoped_ptr.hpp>
 
 // STATIC DATA -----------------------------------------------------------
 
-static ScEditWindow* pActiveEdWnd = NULL;
+static VclPtr<ScEditWindow> pActiveEdWnd = NULL;
 
-//========================================================================
 // class ScHFEditPage
-//
 
-ScHFEditPage::ScHFEditPage( Window*             pParent,
+ScHFEditPage::ScHFEditPage( vcl::Window*             pParent,
                             const SfxItemSet&   rCoreAttrs,
                             sal_uInt16          nWhichId,
                             bool                bHeader  )
-    : SfxTabPage( pParent, "HeaderFooterContent", "modules/scalc/ui/headerfootercontent.ui", rCoreAttrs )
+    : SfxTabPage( pParent, "HeaderFooterContent", "modules/scalc/ui/headerfootercontent.ui", &rCoreAttrs )
     , nWhich( nWhichId )
 {
     get(m_pWndLeft,"textviewWND_LEFT");
@@ -94,7 +88,6 @@ ScHFEditPage::ScHFEditPage( Window*             pParent,
     get(m_pFtCreatedBy,"labelSTR_HF_CREATED_BY");
     get(m_pFtCustomized,"labelSTR_HF_CUSTOMIZED");
 
-
     //! use default style from current document?
     //! if font color is used, header/footer background color must be set
 
@@ -118,11 +111,11 @@ ScHFEditPage::ScHFEditPage( Window*             pParent,
     m_pFtDefinedHF->Show();
     m_pFtCustomHF->Show();
 
-    //swap left/right areas and their lables in RTL mode
-    if( Application::GetSettings().GetLayoutRTL() )
+    //swap left/right areas and their labels in RTL mode
+    if( AllSettings::GetLayoutRTL() )
     {
-        Window *pLeft = get<Window>("labelFT_LEFT");
-        Window *pRight = get<Window>("labelFT_RIGHT");
+        vcl::Window *pLeft = get<vcl::Window>("labelFT_LEFT");
+        vcl::Window *pRight = get<vcl::Window>("labelFT_RIGHT");
         sal_Int32 nOldLeftAttach = pLeft->get_grid_left_attach();
         sal_Int32 nOldRightAttach = pRight->get_grid_left_attach();
         pLeft->set_grid_left_attach(nOldRightAttach);
@@ -139,6 +132,15 @@ ScHFEditPage::ScHFEditPage( Window*             pParent,
     m_pWndCenter->SetFont( aPatAttr );
     m_pWndRight->SetFont( aPatAttr );
 
+    // Set size request of 1 widget, the other two will follow as they are
+    // in the same grid
+    Size aSize = LogicToPixel(Size(80, 120), MAP_APPFONT);
+    m_pWndLeft->set_width_request(aSize.Width());
+    m_pWndLeft->set_height_request(aSize.Height());
+
+    m_pWndLeft->SetObjectSelectHdl( LINK(this,ScHFEditPage,ObjectSelectHdl) );
+    m_pWndCenter->SetObjectSelectHdl( LINK(this,ScHFEditPage,ObjectSelectHdl) );
+    m_pWndRight->SetObjectSelectHdl( LINK(this,ScHFEditPage,ObjectSelectHdl) );
     FillCmdArr();
 
     m_pWndLeft->GrabFocus();
@@ -147,10 +149,41 @@ ScHFEditPage::ScHFEditPage( Window*             pParent,
 
 }
 
-// -----------------------------------------------------------------------
+IMPL_LINK( ScHFEditPage, ObjectSelectHdl, ScEditWindow*, pEdit )
+{
+    (void)pEdit;
+    m_pBtnText->GrabFocus();
+    return 0;
+}
 
 ScHFEditPage::~ScHFEditPage()
 {
+    disposeOnce();
+}
+
+void ScHFEditPage::dispose()
+{
+    m_pWndLeft.clear();
+    m_pWndCenter.clear();
+    m_pWndRight.clear();
+    m_pFtDefinedHF.clear();
+    m_pLbDefined.clear();
+    m_pFtCustomHF.clear();
+    m_pBtnText.clear();
+    m_pBtnFile.clear();
+    m_pBtnTable.clear();
+    m_pBtnPage.clear();
+    m_pBtnLastPage.clear();
+    m_pBtnDate.clear();
+    m_pBtnTime.clear();
+    m_pFtConfidential.clear();
+    m_pFtPage.clear();
+    m_pFtOfQuestion.clear();
+    m_pFtOf.clear();
+    m_pFtNone.clear();
+    m_pFtCreatedBy.clear();
+    m_pFtCustomized.clear();
+    SfxTabPage::dispose();
 }
 
 void ScHFEditPage::SetNumType(SvxNumType eNumType)
@@ -160,10 +193,10 @@ void ScHFEditPage::SetNumType(SvxNumType eNumType)
     m_pWndRight->SetNumType(eNumType);
 }
 
-void ScHFEditPage::Reset( const SfxItemSet& rCoreSet )
+void ScHFEditPage::Reset( const SfxItemSet* rCoreSet )
 {
     const SfxPoolItem* pItem = NULL;
-    if ( rCoreSet.HasItem(nWhich, &pItem) )
+    if ( rCoreSet->HasItem(nWhich, &pItem) )
     {
         const ScPageHFItem& rItem = static_cast<const ScPageHFItem&>(*pItem);
 
@@ -178,7 +211,7 @@ void ScHFEditPage::Reset( const SfxItemSet& rCoreSet )
     }
 }
 
-sal_Bool ScHFEditPage::FillItemSet( SfxItemSet& rCoreSet )
+bool ScHFEditPage::FillItemSet( SfxItemSet* rCoreSet )
 {
     ScPageHFItem    aItem( nWhich );
     EditTextObject* pLeft   = m_pWndLeft->CreateTextObject();
@@ -192,21 +225,17 @@ sal_Bool ScHFEditPage::FillItemSet( SfxItemSet& rCoreSet )
     delete pCenter;
     delete pRight;
 
-    rCoreSet.Put( aItem );
+    rCoreSet->Put( aItem );
 
-    return sal_True;
+    return true;
 }
 
-// -----------------------------------------------------------------------
-
 #define SET_CMD(i,id) \
     aCmd  = aDel;                           \
     aCmd += ScGlobal::GetRscString( id );   \
     aCmd += aDel;                           \
     aCmdArr[i] = aCmd;
 
-// -----------------------------------------------------------------------
-
 void ScHFEditPage::FillCmdArr()
 {
     OUString aDel( ScGlobal::GetRscString( STR_HFCMD_DELIMITER ) );
@@ -298,11 +327,9 @@ void ScHFEditPage::SetSelectDefinedList()
     // default to customized
     ScHFEntryId eSelectEntry = eEntryCount;
 
-    SAL_WNODEPRECATED_DECLARATIONS_PUSH
-    ::std::auto_ptr< EditTextObject > pLeftObj;
-    ::std::auto_ptr< EditTextObject > pCenterObj;
-    ::std::auto_ptr< EditTextObject > pRightObj;
-    SAL_WNODEPRECATED_DECLARATIONS_POP
+    boost::scoped_ptr< EditTextObject > pLeftObj;
+    boost::scoped_ptr< EditTextObject > pCenterObj;
+    boost::scoped_ptr< EditTextObject > pRightObj;
 
     OUString aLeftEntry;
     OUString aCenterEntry;
@@ -349,7 +376,6 @@ void ScHFEditPage::SetSelectDefinedList()
             }
             break;
 
-
             //TODO
             case ePagesEntry:
             {
@@ -488,7 +514,7 @@ bool ScHFEditPage::IsPageEntry(EditEngine*pEngine, EditTextObject* pTextObj)
 
     if(!pTextObj->IsFieldObject())
     {
-        std::vector<sal_uInt16> aPosList;
+        std::vector<sal_Int32> aPosList;
         pEngine->GetPortions(0,aPosList);
         if(aPosList.size() == 2)
         {
@@ -499,9 +525,7 @@ bool ScHFEditPage::IsPageEntry(EditEngine*pEngine, EditTextObject* pTextObj)
             {
                 aSel.nStartPos = aSel.nEndPos;
                 aSel.nEndPos++;
-                SAL_WNODEPRECATED_DECLARATIONS_PUSH
-                ::std::auto_ptr< EditTextObject > pPageObj;
-                SAL_WNODEPRECATED_DECLARATIONS_POP
+                boost::scoped_ptr< EditTextObject > pPageObj;
                 pPageObj.reset(pEngine->CreateTextObject(aSel));
                 if(pPageObj.get() && pPageObj->IsFieldObject() )
                 {
@@ -559,9 +583,7 @@ bool ScHFEditPage::IsExtFileNameEntry(EditTextObject* pTextObj)
 void ScHFEditPage::ProcessDefinedListSel(ScHFEntryId eSel, bool bTravelling)
 {
     SvtUserOptions aUserOpt;
-    SAL_WNODEPRECATED_DECLARATIONS_PUSH
-    ::std::auto_ptr< EditTextObject > pTextObj;
-    SAL_WNODEPRECATED_DECLARATIONS_POP
+    boost::scoped_ptr< EditTextObject > pTextObj;
 
     switch(eSel)
     {
@@ -594,7 +616,7 @@ void ScHFEditPage::ProcessDefinedListSel(ScHFEntryId eSel, bool bTravelling)
 
             OUString aPageOfEntry(" " + m_pFtOf->GetText() + " ");
             m_pWndCenter->GetEditEngine()->QuickInsertText(aPageOfEntry,ESelection(aSel.nEndPara,aSel.nEndPos, aSel.nEndPara, aSel.nEndPos));
-            aSel.nEndPos = sal::static_int_cast<xub_StrLen>( aSel.nEndPos + aPageOfEntry.getLength() );
+            aSel.nEndPos = aSel.nEndPos + aPageOfEntry.getLength();
             m_pWndCenter->GetEditEngine()->QuickInsertField(SvxFieldItem(SvxPagesField(), EE_FEATURE_FIELD), ESelection(aSel.nEndPara,aSel.nEndPos, aSel.nEndPara, aSel.nEndPos));
             pTextObj.reset(m_pWndCenter->GetEditEngine()->CreateTextObject());
             m_pWndCenter->SetText(*pTextObj);
@@ -634,7 +656,7 @@ void ScHFEditPage::ProcessDefinedListSel(ScHFEntryId eSel, bool bTravelling)
             OUString aPageEntry(", " + m_pFtPage->GetText() + " ");
             m_pWndCenter->GetEditEngine()->QuickInsertText(aPageEntry, ESelection(aSel.nEndPara,aSel.nEndPos, aSel.nEndPara, aSel.nEndPos));
             aSel.nStartPos = aSel.nEndPos;
-            aSel.nEndPos = sal::static_int_cast<xub_StrLen>( aSel.nEndPos + aPageEntry.getLength() );
+            aSel.nEndPos = aSel.nEndPos + aPageEntry.getLength();
             m_pWndCenter->GetEditEngine()->QuickInsertField(SvxFieldItem(SvxPageField(), EE_FEATURE_FIELD), ESelection(aSel.nEndPara,aSel.nEndPos, aSel.nEndPara, aSel.nEndPos));
             pTextObj.reset(m_pWndCenter->GetEditEngine()->CreateTextObject());
             m_pWndCenter->SetText(*pTextObj);
@@ -663,7 +685,7 @@ void ScHFEditPage::ProcessDefinedListSel(ScHFEntryId eSel, bool bTravelling)
 
             OUString aCommaSpace(", ");
             m_pWndCenter->GetEditEngine()->QuickInsertText(aCommaSpace,ESelection(aSel.nEndPara, aSel.nEndPos, aSel.nEndPara, aSel.nEndPos));
-            aSel.nEndPos = sal::static_int_cast<xub_StrLen>( aSel.nEndPos + aCommaSpace.getLength() );
+            aSel.nEndPos = aSel.nEndPos + aCommaSpace.getLength();
             m_pWndCenter->GetEditEngine()->QuickInsertField( SvxFieldItem(SvxTableField(), EE_FEATURE_FIELD), ESelection(aSel.nEndPara, aSel.nEndPos, aSel.nEndPara, aSel.nEndPos));
             pTextObj.reset(m_pWndCenter->GetEditEngine()->CreateTextObject());
             m_pWndCenter->SetText(*pTextObj);
@@ -683,7 +705,7 @@ void ScHFEditPage::ProcessDefinedListSel(ScHFEntryId eSel, bool bTravelling)
             ++aSel.nEndPos;
             OUString aCommaSpace(", ");
             m_pWndCenter->GetEditEngine()->QuickInsertText(aCommaSpace,ESelection(aSel.nEndPara, aSel.nEndPos, aSel.nEndPara, aSel.nEndPos));
-            aSel.nEndPos = sal::static_int_cast<xub_StrLen>( aSel.nEndPos + aCommaSpace.getLength() );
+            aSel.nEndPos = aSel.nEndPos + aCommaSpace.getLength();
             m_pWndCenter->GetEditEngine()->QuickInsertField( SvxFieldItem(SvxFileField(), EE_FEATURE_FIELD), ESelection(aSel.nEndPara, aSel.nEndPos, aSel.nEndPara, aSel.nEndPos));
             pTextObj.reset(m_pWndCenter->GetEditEngine()->CreateTextObject());
             m_pWndCenter->SetText(*pTextObj);
@@ -750,9 +772,7 @@ void ScHFEditPage::ClearTextAreas()
     m_pWndRight->Invalidate();
 }
 
-//-----------------------------------------------------------------------
 // Handler:
-//-----------------------------------------------------------------------
 
 IMPL_LINK( ScHFEditPage, ListHdl_Impl, ListBox*, pList )
 {
@@ -783,7 +803,7 @@ IMPL_LINK( ScHFEditPage, ClickHdl, PushButton*, pBtn )
 
     if ( pBtn == m_pBtnText )
     {
-        pActiveEdWnd->SetCharAttriutes();
+        pActiveEdWnd->SetCharAttributes();
     }
     else
     {
@@ -808,7 +828,7 @@ IMPL_LINK( ScHFEditPage, ClickHdl, PushButton*, pBtn )
     return 0;
 }
 
-IMPL_LINK( ScHFEditPage, MenuHdl, ScExtIButton*, pBtn )
+IMPL_STATIC_LINK( ScHFEditPage, MenuHdl, ScExtIButton*, pBtn )
 {
     pActiveEdWnd = ::GetScEditWindow();
     if ( !pActiveEdWnd )
@@ -816,7 +836,7 @@ IMPL_LINK( ScHFEditPage, MenuHdl, ScExtIButton*, pBtn )
 
     if(pBtn!=NULL)
     {
-        OSL_ENSURE( true, pBtn->GetSelected());
+        SAL_WARN_IF(pBtn->GetSelected() == 0, "sc.ui", "nothing selected");
         OString sSelectedId = pBtn->GetSelectedIdent();
 
         if (sSelectedId == "title")
@@ -837,68 +857,60 @@ IMPL_LINK( ScHFEditPage, MenuHdl, ScExtIButton*, pBtn )
     return 0;
 }
 
-//========================================================================
 // class ScRightHeaderEditPage
-//========================================================================
 
-ScRightHeaderEditPage::ScRightHeaderEditPage( Window* pParent, const SfxItemSet& rCoreSet )
+ScRightHeaderEditPage::ScRightHeaderEditPage( vcl::Window* pParent, const SfxItemSet& rCoreSet )
     : ScHFEditPage( pParent,
                     rCoreSet,
                     rCoreSet.GetPool()->GetWhich(SID_SCATTR_PAGE_HEADERRIGHT ),
                     true )
     {}
 
-// -----------------------------------------------------------------------
+VclPtr<SfxTabPage> ScRightHeaderEditPage::Create( vcl::Window* pParent, const SfxItemSet* rCoreSet )
+{
+    return VclPtr<ScRightHeaderEditPage>::Create( pParent, *rCoreSet );
+}
 
-SfxTabPage* ScRightHeaderEditPage::Create( Window* pParent, const SfxItemSet& rCoreSet )
-    { return ( new ScRightHeaderEditPage( pParent, rCoreSet ) ); };
-
-//========================================================================
 // class ScLeftHeaderEditPage
-//========================================================================
 
-ScLeftHeaderEditPage::ScLeftHeaderEditPage( Window* pParent, const SfxItemSet& rCoreSet )
+ScLeftHeaderEditPage::ScLeftHeaderEditPage( vcl::Window* pParent, const SfxItemSet& rCoreSet )
     : ScHFEditPage( pParent,
                     rCoreSet,
                     rCoreSet.GetPool()->GetWhich(SID_SCATTR_PAGE_HEADERLEFT ),
                     true )
     {}
 
-// -----------------------------------------------------------------------
+VclPtr<SfxTabPage> ScLeftHeaderEditPage::Create( vcl::Window* pParent, const SfxItemSet* rCoreSet )
+{
+    return VclPtr<ScLeftHeaderEditPage>::Create( pParent, *rCoreSet );
+}
 
-SfxTabPage* ScLeftHeaderEditPage::Create( Window* pParent, const SfxItemSet& rCoreSet )
-    { return ( new ScLeftHeaderEditPage( pParent, rCoreSet ) ); };
-
-//========================================================================
 // class ScRightFooterEditPage
-//========================================================================
 
-ScRightFooterEditPage::ScRightFooterEditPage( Window* pParent, const SfxItemSet& rCoreSet )
+ScRightFooterEditPage::ScRightFooterEditPage( vcl::Window* pParent, const SfxItemSet& rCoreSet )
     : ScHFEditPage( pParent,
                     rCoreSet,
                     rCoreSet.GetPool()->GetWhich(SID_SCATTR_PAGE_FOOTERRIGHT ),
                     false )
     {}
 
-// -----------------------------------------------------------------------
+VclPtr<SfxTabPage> ScRightFooterEditPage::Create( vcl::Window* pParent, const SfxItemSet* rCoreSet )
+{
+    return VclPtr<ScRightFooterEditPage>::Create( pParent, *rCoreSet );
+}
 
-SfxTabPage* ScRightFooterEditPage::Create( Window* pParent, const SfxItemSet& rCoreSet )
-    { return ( new ScRightFooterEditPage( pParent, rCoreSet ) ); };
-
-//========================================================================
 // class ScLeftFooterEditPage
-//========================================================================
 
-ScLeftFooterEditPage::ScLeftFooterEditPage( Window* pParent, const SfxItemSet& rCoreSet )
+ScLeftFooterEditPage::ScLeftFooterEditPage( vcl::Window* pParent, const SfxItemSet& rCoreSet )
     : ScHFEditPage( pParent,
                     rCoreSet,
                     rCoreSet.GetPool()->GetWhich(SID_SCATTR_PAGE_FOOTERLEFT ),
                     false )
     {}
 
-// -----------------------------------------------------------------------
-
-SfxTabPage* ScLeftFooterEditPage::Create( Window* pParent, const SfxItemSet& rCoreSet )
-    { return ( new ScLeftFooterEditPage( pParent, rCoreSet ) ); };
+VclPtr<SfxTabPage> ScLeftFooterEditPage::Create( vcl::Window* pParent, const SfxItemSet* rCoreSet )
+{
+    return VclPtr<ScLeftFooterEditPage>::Create( pParent, *rCoreSet );
+};
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
