@@ -39,6 +39,7 @@
 #include "scmod.hxx"
 #include "globstr.hrc"
 #include "chartarr.hxx"
+#include <gridwin.hxx>
 
 #include <com/sun/star/embed/NoVisualAreaSizeException.hpp>
 #include <com/sun/star/embed/Aspects.hpp>
@@ -54,20 +55,18 @@ using namespace com::sun::star;
 
 Point aDragStartDiff;
 
-// -----------------------------------------------------------------------
-
-void ScDrawView::CheckOle( const SdrMarkList& rMarkList, sal_Bool& rAnyOle, sal_Bool& rOneOle )
+void ScDrawView::CheckOle( const SdrMarkList& rMarkList, bool& rAnyOle, bool& rOneOle )
 {
     rAnyOle = rOneOle = false;
-    sal_uLong nCount = rMarkList.GetMarkCount();
-    for (sal_uLong i=0; i<nCount; i++)
+    const size_t nCount = rMarkList.GetMarkCount();
+    for (size_t i=0; i<nCount; ++i)
     {
         SdrMark* pMark = rMarkList.GetMark(i);
         SdrObject* pObj = pMark->GetMarkedSdrObj();
         sal_uInt16 nSdrObjKind = pObj->GetObjIdentifier();
         if (nSdrObjKind == OBJ_OLE2)
         {
-            rAnyOle = sal_True;
+            rAnyOle = true;
             rOneOle = (nCount == 1);
             break;
         }
@@ -79,7 +78,7 @@ void ScDrawView::CheckOle( const SdrMarkList& rMarkList, sal_Bool& rAnyOle, sal_
             {
                 if ( pSubObj->GetObjIdentifier() == OBJ_OLE2 )
                 {
-                    rAnyOle = sal_True;
+                    rAnyOle = true;
                     // rOneOle remains sal_False - a group isn't treated like a single OLE object
                     return;
                 }
@@ -89,20 +88,20 @@ void ScDrawView::CheckOle( const SdrMarkList& rMarkList, sal_Bool& rAnyOle, sal_
     }
 }
 
-sal_Bool ScDrawView::BeginDrag( Window* pWindow, const Point& rStartPos )
+bool ScDrawView::BeginDrag( vcl::Window* pWindow, const Point& rStartPos )
 {
-    sal_Bool bReturn = false;
+    bool bReturn = false;
 
     if ( AreObjectsMarked() )
     {
         BrkAction();
 
         Rectangle aMarkedRect = GetAllMarkedRect();
-        Region aRegion( aMarkedRect );
+        vcl::Region aRegion( aMarkedRect );
 
         aDragStartDiff = rStartPos - aMarkedRect.TopLeft();
 
-        sal_Bool bAnyOle, bOneOle;
+        bool bAnyOle, bOneOle;
         const SdrMarkList& rMarkList = GetMarkedObjectList();
         CheckOle( rMarkList, bAnyOle, bOneOle );
 
@@ -165,10 +164,9 @@ void getRangeFromDataSource( uno::Reference< chart2::data::XDataSource > xDataSo
     }
 }
 
-
-void getRangeFromErrorBar(const uno::Reference< chart2::XChartDocument > xChartDoc, std::vector<OUString>& rRangeRep)
+void getRangeFromErrorBar(const uno::Reference< chart2::XChartDocument >& rChartDoc, std::vector<OUString>& rRangeRep)
 {
-    uno::Reference <chart2::XDiagram > xDiagram = xChartDoc->getFirstDiagram();
+    uno::Reference <chart2::XDiagram > xDiagram = rChartDoc->getFirstDiagram();
     if(!xDiagram.is())
         return;
 
@@ -372,8 +370,8 @@ void ScDrawView::DoCopy()
         // Copy data referenced by the chart objects to the draw clip
         // document. We need to do this before GetMarkedObjModel() below.
         ScDocShellRef xDocSh = *ScGlobal::pDrawClipDocShellRef;
-        ScDocument* pClipDoc = xDocSh->GetDocument();
-        copyChartRefDataToClipDoc(pDoc, pClipDoc, aRanges);
+        ScDocument& rClipDoc = xDocSh->GetDocument();
+        copyChartRefDataToClipDoc(pDoc, &rClipDoc, aRanges);
     }
     SdrModel* pModel = GetMarkedObjModel();
     ScDrawLayer::SetGlobalDrawPersist(NULL);
@@ -404,7 +402,7 @@ void ScDrawView::DoCopy()
 
 uno::Reference<datatransfer::XTransferable> ScDrawView::CopyToTransferable()
 {
-    sal_Bool bAnyOle, bOneOle;
+    bool bAnyOle, bOneOle;
     const SdrMarkList& rMarkList = GetMarkedObjectList();
     CheckOle( rMarkList, bAnyOle, bOneOle );
 
@@ -466,38 +464,38 @@ void ScDrawView::SetMarkedOriginalSize()
 
     const SdrMarkList& rMarkList = GetMarkedObjectList();
     long nDone = 0;
-    sal_uLong nCount = rMarkList.GetMarkCount();
-    for (sal_uLong i=0; i<nCount; i++)
+    const size_t nCount = rMarkList.GetMarkCount();
+    for (size_t i=0; i<nCount; ++i)
     {
         SdrObject* pObj = rMarkList.GetMark(i)->GetMarkedSdrObj();
         sal_uInt16 nIdent = pObj->GetObjIdentifier();
-        sal_Bool bDo = false;
+        bool bDo = false;
         Size aOriginalSize;
         if (nIdent == OBJ_OLE2)
         {
             // TODO/LEAN: working with visual area can switch object to running state
-            uno::Reference < embed::XEmbeddedObject > xObj( ((SdrOle2Obj*)pObj)->GetObjRef(), uno::UNO_QUERY );
+             uno::Reference < embed::XEmbeddedObject > xObj( static_cast<SdrOle2Obj*>(pObj)->GetObjRef(), uno::UNO_QUERY );
             if ( xObj.is() )    // NULL for an invalid object that couldn't be loaded
             {
-                sal_Int64 nAspect = ((SdrOle2Obj*)pObj)->GetAspect();
+                sal_Int64 nAspect = static_cast<SdrOle2Obj*>(pObj)->GetAspect();
 
                 if ( nAspect == embed::Aspects::MSOLE_ICON )
                 {
                     MapMode aMapMode( MAP_100TH_MM );
-                    aOriginalSize = ((SdrOle2Obj*)pObj)->GetOrigObjSize( &aMapMode );
-                    bDo = sal_True;
+                    aOriginalSize = static_cast<SdrOle2Obj*>(pObj)->GetOrigObjSize( &aMapMode );
+                    bDo = true;
                 }
                 else
                 {
-                    MapUnit aUnit = VCLUnoHelper::UnoEmbed2VCLMapUnit( xObj->getMapUnit( ((SdrOle2Obj*)pObj)->GetAspect() ) );
+                    MapUnit aUnit = VCLUnoHelper::UnoEmbed2VCLMapUnit( xObj->getMapUnit( static_cast<SdrOle2Obj*>(pObj)->GetAspect() ) );
                     awt::Size aSz;
                     try
                     {
-                        aSz = xObj->getVisualAreaSize( ((SdrOle2Obj*)pObj)->GetAspect() );
+                        aSz = xObj->getVisualAreaSize( static_cast<SdrOle2Obj*>(pObj)->GetAspect() );
                         aOriginalSize = OutputDevice::LogicToLogic(
                                             Size( aSz.Width, aSz.Height ),
                                             aUnit, MAP_100TH_MM );
-                        bDo = sal_True;
+                        bDo = true;
                     } catch( embed::NoVisualAreaSizeException& )
                     {
                         OSL_ENSURE( false, "Can't get the original size of the object!" );
@@ -507,7 +505,7 @@ void ScDrawView::SetMarkedOriginalSize()
         }
         else if (nIdent == OBJ_GRAF)
         {
-            const Graphic& rGraphic = ((SdrGrafObj*)pObj)->GetGraphic();
+            const Graphic& rGraphic = static_cast<SdrGrafObj*>(pObj)->GetGraphic();
 
             MapMode aSourceMap = rGraphic.GetPrefMapMode();
             MapMode aDestMap( MAP_100TH_MM );
@@ -522,12 +520,12 @@ void ScDrawView::SetMarkedOriginalSize()
             }
             if (pViewData)
             {
-                Window* pActWin = pViewData->GetActiveWin();
+                vcl::Window* pActWin = pViewData->GetActiveWin();
                 if (pActWin)
                 {
                     aOriginalSize = pActWin->LogicToLogic(
                                     rGraphic.GetPrefSize(), &aSourceMap, &aDestMap );
-                    bDo = sal_True;
+                    bDo = true;
                 }
             }
         }
@@ -543,7 +541,7 @@ void ScDrawView::SetMarkedOriginalSize()
         }
     }
 
-    if (nDone)
+    if (nDone && pViewData)
     {
         pUndoGroup->SetComment(ScGlobal::GetRscString( STR_UNDO_ORIGINALSIZE ));
         ScDocShell* pDocSh = pViewData->GetDocShell();
@@ -554,5 +552,4 @@ void ScDrawView::SetMarkedOriginalSize()
         delete pUndoGroup;
 }
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
