@@ -34,6 +34,7 @@
 #include <sfx2/bindings.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <svx/sdrundomanager.hxx>
+#include <svx/xbtmpit.hxx>
 
 #include "drawview.hxx"
 #include "global.hxx"
@@ -57,12 +58,8 @@
 
 using namespace com::sun::star;
 
-// -----------------------------------------------------------------------
-
 #define SC_HANDLESIZE_BIG       9
 
-// -----------------------------------------------------------------------
-
 void ScDrawView::Construct()
 {
     EnableExtendedKeyInputDispatcher(false);
@@ -79,8 +76,8 @@ void ScDrawView::Construct()
         SCTAB nViewTab = pViewData->GetTabNo();
         ShowSdrPage(GetModel()->GetPage(nViewTab));
 
-        sal_Bool bEx = pViewData->GetViewShell()->IsDrawSelMode();
-        sal_Bool bProt = pDoc->IsTabProtected( nViewTab ) ||
+        bool bEx = pViewData->GetViewShell()->IsDrawSelMode();
+        bool bProt = pDoc->IsTabProtected( nViewTab ) ||
                      pViewData->GetSfxDocShell()->IsReadOnly();
 
         SdrLayer* pLayer;
@@ -90,7 +87,7 @@ void ScDrawView::Construct()
             SetLayerLocked( pLayer->GetName(), bProt || !bEx );
         pLayer = rAdmin.GetLayerPerID(SC_LAYER_INTERN);
         if (pLayer)
-            SetLayerLocked( pLayer->GetName(), sal_True );
+            SetLayerLocked( pLayer->GetName(), true );
         pLayer = rAdmin.GetLayerPerID(SC_LAYER_FRONT);
         if (pLayer)
         {
@@ -107,7 +104,7 @@ void ScDrawView::Construct()
             SetLayerVisible( pLayer->GetName(), false);
         }
 
-        SetSwapAsynchron(sal_True);
+        SetSwapAsynchron(true);
     }
     else
     {
@@ -138,14 +135,14 @@ ScDrawView::~ScDrawView()
 void ScDrawView::AddCustomHdl()
 {
     const SdrMarkList &rMrkList = GetMarkedObjectList();
-    sal_uInt32 nCount = rMrkList.GetMarkCount();
-    for(sal_uInt32 nPos=0; nPos<nCount; nPos++ )
+    const size_t nCount = rMrkList.GetMarkCount();
+    for(size_t nPos=0; nPos<nCount; ++nPos )
     {
         SdrObject* pObj = rMrkList.GetMark(nPos)->GetMarkedSdrObj();
         if (ScDrawObjData *pAnchor = ScDrawLayer::GetObjDataTab(pObj, nTab))
         {
             if (ScTabView* pView = pViewData->GetView())
-                pView->CreateAnchorHandles(aHdl, pAnchor->maStart);
+                pView->CreateAnchorHandles(maHdlList, pAnchor->maStart);
         }
     }
 }
@@ -198,6 +195,9 @@ void ScDrawView::InvalidateDrawTextAttrs()
     rBindings.Invalidate( SID_TEXTDIRECTION_TOP_TO_BOTTOM );
     rBindings.Invalidate( SID_ATTR_PARA_LEFT_TO_RIGHT );
     rBindings.Invalidate( SID_ATTR_PARA_RIGHT_TO_LEFT );
+    rBindings.Invalidate( SID_TABLE_VERT_NONE );
+    rBindings.Invalidate( SID_TABLE_VERT_CENTER );
+    rBindings.Invalidate( SID_TABLE_VERT_BOTTOM );
     // pseudo slots for Format menu
     rBindings.Invalidate( SID_ALIGN_ANY_LEFT );
     rBindings.Invalidate( SID_ALIGN_ANY_HCENTER );
@@ -214,8 +214,8 @@ void ScDrawView::SetMarkedToLayer( sal_uInt8 nLayerNo )
         BegUndo( ScGlobal::GetRscString( STR_UNDO_SELATTR ) );
 
         const SdrMarkList& rMark = GetMarkedObjectList();
-        sal_uLong nCount = rMark.GetMarkCount();
-        for (sal_uLong i=0; i<nCount; i++)
+        const size_t nCount = rMark.GetMarkCount();
+        for (size_t i=0; i<nCount; ++i)
         {
             SdrObject* pObj = rMark.GetMark(i)->GetMarkedSdrObj();
             if ( !pObj->ISA(SdrUnoObj) && (pObj->GetLayer() != SC_LAYER_INTERN) )
@@ -330,8 +330,8 @@ void ScDrawView::RecalcScale()
     {
         if ( SdrPage* pPage = pPV->GetPage() )
         {
-            sal_uLong nCount = pPage->GetObjCount();
-            for ( sal_uLong i = 0; i < nCount; i++ )
+            const size_t nCount = pPage->GetObjCount();
+            for ( size_t i = 0; i < nCount; ++i )
             {
                 SdrObject* pObj = pPage->GetObj( i );
                 // Align objects to nearset grid position
@@ -351,8 +351,6 @@ void ScDrawView::MarkListHasChanged()
 {
     FmFormView::MarkListHasChanged();
 
-    UpdateBrowser();
-
     ScTabViewShell* pViewSh = pViewData->GetViewShell();
 
     // #i110829# remove the cell selection only if drawing objects are selected
@@ -369,7 +367,7 @@ void ScDrawView::MarkListHasChanged()
     ScModule* pScMod = SC_MOD();
     bool bUnoRefDialog = pScMod->IsRefDialogOpen() && pScMod->GetCurRefDlgId() == WID_SIMPLE_REF;
 
-    ScClient* pClient = (ScClient*) pViewSh->GetIPClient();
+    ScClient* pClient = static_cast<ScClient*>( pViewSh->GetIPClient() );
     if ( pClient && pClient->IsObjectInPlaceActive() && !bUnoRefDialog )
     {
         //  beim ViewShell::Activate aus dem Reset2Open nicht die Handles anzeigen
@@ -383,7 +381,7 @@ void ScDrawView::MarkListHasChanged()
     SdrGrafObj* pGrafObj = NULL;
 
     const SdrMarkList& rMarkList = GetMarkedObjectList();
-    sal_uLong nMarkCount = rMarkList.GetMarkCount();
+    const size_t nMarkCount = rMarkList.GetMarkCount();
 
     if ( nMarkCount == 0 && !pViewData->GetViewShell()->IsDrawSelMode() && !bInConstruct )
     {
@@ -392,24 +390,24 @@ void ScDrawView::MarkListHasChanged()
         LockInternalLayer();
     }
 
-    sal_Bool bSubShellSet = false;
+    bool bSubShellSet = false;
     if (nMarkCount == 1)
     {
         SdrObject* pObj = rMarkList.GetMark(0)->GetMarkedSdrObj();
         if (pObj->GetObjIdentifier() == OBJ_OLE2)
         {
-            pOle2Obj = (SdrOle2Obj*) pObj;
-            if (!pDoc->IsChart(pObj) )
-                pViewSh->SetOleObjectShell(sal_True);
+            pOle2Obj = static_cast<SdrOle2Obj*>(pObj);
+            if (!ScDocument::IsChart(pObj) )
+                pViewSh->SetOleObjectShell(true);
             else
-                pViewSh->SetChartShell(sal_True);
-            bSubShellSet = sal_True;
+                pViewSh->SetChartShell(true);
+            bSubShellSet = true;
         }
         else if (pObj->GetObjIdentifier() == OBJ_GRAF)
         {
-            pGrafObj = (SdrGrafObj*) pObj;
-            pViewSh->SetGraphicShell(sal_True);
-            bSubShellSet = sal_True;
+            pGrafObj = static_cast<SdrGrafObj*>(pObj);
+            pViewSh->SetGraphicShell(true);
+            bSubShellSet = true;
         }
         else if (pObj->GetObjIdentifier() == OBJ_MEDIA)
         {
@@ -419,21 +417,21 @@ void ScDrawView::MarkListHasChanged()
         else if (pObj->GetObjIdentifier() != OBJ_TEXT   // Verhindern, das beim Anlegen
                     || !pViewSh->IsDrawTextShell())     // eines TextObjekts auf die
         {                                               // DrawShell umgeschaltet wird.
-            pViewSh->SetDrawShell(sal_True);                //@#70206#
+            pViewSh->SetDrawShell(true);                //@#70206#
         }
     }
 
     if ( nMarkCount && !bSubShellSet )
     {
-        sal_Bool bOnlyControls = sal_True;
-        sal_Bool bOnlyGraf     = sal_True;
-        for (sal_uLong i=0; i<nMarkCount; i++)
+        bool bOnlyControls = true;
+        bool bOnlyGraf     = true;
+        for (size_t i=0; i<nMarkCount; ++i)
         {
             SdrObject* pObj = rMarkList.GetMark(i)->GetMarkedSdrObj();
             if ( pObj->ISA( SdrObjGroup ) )
             {
-                const SdrObjList *pLst = ((SdrObjGroup*)pObj)->GetSubList();
-                sal_uLong nListCount = pLst->GetObjCount();
+                const SdrObjList *pLst = static_cast<SdrObjGroup*>(pObj)->GetSubList();
+                const size_t nListCount = pLst->GetObjCount();
                 if ( nListCount == 0 )
                 {
                     //  An empty group (may occur during Undo) is no control or graphics object.
@@ -441,7 +439,7 @@ void ScDrawView::MarkListHasChanged()
                     bOnlyControls = false;
                     bOnlyGraf = false;
                 }
-                for ( sal_uInt16 j = 0; j < nListCount; ++j )
+                for ( size_t j = 0; j < nListCount; ++j )
                 {
                     SdrObject *pSubObj = pLst->GetObj( j );
 
@@ -466,24 +464,22 @@ void ScDrawView::MarkListHasChanged()
 
         if(bOnlyControls)
         {
-            pViewSh->SetDrawFormShell(sal_True);            // jetzt UNO-Controls
+            pViewSh->SetDrawFormShell(true);            // jetzt UNO-Controls
         }
         else if(bOnlyGraf)
         {
-            pViewSh->SetGraphicShell(sal_True);
+            pViewSh->SetGraphicShell(true);
         }
         else if(nMarkCount>1)
         {
-            pViewSh->SetDrawShell(sal_True);
+            pViewSh->SetDrawShell(true);
         }
     }
 
-
-
     //  Verben anpassen
 
     SfxViewFrame* pViewFrame = pViewSh->GetViewFrame();
-    sal_Bool bOle = pViewSh->GetViewFrame()->GetFrame().IsInPlace();
+    bool bOle = pViewSh->GetViewFrame()->GetFrame().IsInPlace();
     uno::Sequence< embed::VerbDescriptor > aVerbs;
     if ( pOle2Obj && !bOle )
     {
@@ -511,7 +507,7 @@ void ScDrawView::MarkListHasChanged()
 
         if(OUTDEV_WINDOW == rOutDev.GetOutDevType())
         {
-            ((Window&)rOutDev).Update();
+            static_cast<vcl::Window&>(rOutDev).Update();
         }
     }
 
@@ -536,18 +532,18 @@ void ScDrawView::MarkListHasChanged()
 
 }
 
-sal_Bool ScDrawView::SdrBeginTextEdit(
+bool ScDrawView::SdrBeginTextEdit(
     SdrObject* pObj,
     SdrPageView* pPV,
-    ::Window* pWinL,
-    sal_Bool bIsNewObj,
+    vcl::Window* pWinL,
+    bool bIsNewObj,
     SdrOutliner* pGivenOutliner,
     OutlinerView* pGivenOutlinerView,
-    sal_Bool bDontDeleteOutliner,
-    sal_Bool bOnlyOneView,
-    sal_Bool bGrabFocus )
+    bool bDontDeleteOutliner,
+    bool bOnlyOneView,
+    bool bGrabFocus )
 {
-    const sal_Bool bRet = FmFormView::SdrBeginTextEdit(
+    const bool bRet = FmFormView::SdrBeginTextEdit(
         pObj, pPV, pWinL, bIsNewObj,
         pGivenOutliner, pGivenOutlinerView, bDontDeleteOutliner,
         bOnlyOneView, bGrabFocus );
@@ -568,8 +564,7 @@ sal_Bool ScDrawView::SdrBeginTextEdit(
     return bRet;
 }
 
-
-SdrEndTextEditKind ScDrawView::SdrEndTextEdit( sal_Bool bDontDeleteReally )
+SdrEndTextEditKind ScDrawView::SdrEndTextEdit( bool bDontDeleteReally )
 {
     const SdrEndTextEditKind eRet = FmFormView::SdrEndTextEdit( bDontDeleteReally );
 
@@ -589,7 +584,6 @@ SdrEndTextEditKind ScDrawView::SdrEndTextEdit( sal_Bool bDontDeleteReally )
     return eRet;
 }
 
-
 void ScDrawView::ModelHasChanged()
 {
     SdrObject* pEditObj = GetTextEditObject();
@@ -618,17 +612,101 @@ void ScDrawView::UpdateUserViewOptions()
         SetSnapEnabled( rGrid.GetUseGridSnap() );
         SetGridSnap( rGrid.GetUseGridSnap() );
 
-        Fraction aFractX( rGrid.GetFldDrawX(), rGrid.GetFldDivisionX() + 1 );
-        Fraction aFractY( rGrid.GetFldDrawY(), rGrid.GetFldDivisionY() + 1 );
+        Fraction aFractX( rGrid.GetFieldDrawX(), rGrid.GetFieldDivisionX() + 1 );
+        Fraction aFractY( rGrid.GetFieldDrawY(), rGrid.GetFieldDivisionY() + 1 );
         SetSnapGridWidth( aFractX, aFractY );
 
-        SetGridCoarse( Size( rGrid.GetFldDrawX(), rGrid.GetFldDrawY() ) );
-        SetGridFine( Size( rGrid.GetFldDrawX() / (rGrid.GetFldDivisionX() + 1),
-                           rGrid.GetFldDrawY() / (rGrid.GetFldDivisionY() + 1) ) );
+        SetGridCoarse( Size( rGrid.GetFieldDrawX(), rGrid.GetFieldDrawY() ) );
+        SetGridFine( Size( rGrid.GetFieldDrawX() / (rGrid.GetFieldDivisionX() + 1),
+                           rGrid.GetFieldDrawY() / (rGrid.GetFieldDivisionY() + 1) ) );
     }
 }
 
-sal_Bool ScDrawView::SelectObject( const OUString& rName )
+SdrObject* ScDrawView::GetObjectByName(const OUString& rName)
+{
+    SfxObjectShell* pShell = pDoc->GetDocumentShell();
+    if (pShell)
+    {
+        SdrModel* pDrawLayer = GetModel();
+        sal_uInt16 nTabCount = pDoc->GetTableCount();
+        for (sal_uInt16 i=0; i<nTabCount; i++)
+        {
+            SdrPage* pPage = pDrawLayer->GetPage(i);
+            DBG_ASSERT(pPage,"Page ?");
+            if (pPage)
+            {
+                SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+                SdrObject* pObject = aIter.Next();
+                while (pObject)
+                {
+                    if ( ScDrawLayer::GetVisibleName( pObject ) == rName )
+                    {
+                        return pObject;
+                    }
+                    pObject = aIter.Next();
+                }
+            }
+        }
+    }
+    return 0;
+}
+
+//realize multi-selection of objects
+
+bool ScDrawView::SelectCurrentViewObject( const OUString& rName )
+{
+    sal_uInt16 nObjectTab = 0;
+    SdrObject* pFound = NULL;
+    bool bUnMark = false;
+    SfxObjectShell* pShell = pDoc->GetDocumentShell();
+    if (pShell)
+    {
+        SdrModel* pDrawLayer = GetModel();
+        sal_uInt16 nTabCount = pDoc->GetTableCount();
+        for (sal_uInt16 i=0; i<nTabCount && !pFound; i++)
+        {
+            SdrPage* pPage = pDrawLayer->GetPage(i);
+            DBG_ASSERT(pPage,"Page ?");
+            if (pPage)
+            {
+                SdrObjListIter aIter( *pPage, IM_DEEPWITHGROUPS );
+                SdrObject* pObject = aIter.Next();
+                while (pObject && !pFound)
+                {
+                    if ( ScDrawLayer::GetVisibleName( pObject ) == rName )
+                    {
+                        pFound = pObject;
+                        nObjectTab = i;
+                    }
+                    pObject = aIter.Next();
+                }
+            }
+        }
+    }
+    if ( pFound )
+    {
+        ScTabView* pView = pViewData->GetView();
+        if ( nObjectTab != nTab )                               // Tabelle umschalten
+            pView->SetTabNo( nObjectTab );
+        DBG_ASSERT( nTab == nObjectTab, "Tabellen umschalten hat nicht geklappt" );
+        pView->ScrollToObject( pFound );
+        if ( pFound->GetLayer() == SC_LAYER_BACK &&
+                !pViewData->GetViewShell()->IsDrawSelMode() &&
+                !pDoc->IsTabProtected( nTab ) &&
+                !pViewData->GetSfxDocShell()->IsReadOnly() )
+        {
+            SdrLayer* pLayer = GetModel()->GetLayerAdmin().GetLayerPerID(SC_LAYER_BACK);
+            if (pLayer)
+                SetLayerLocked( pLayer->GetName(), false );
+        }
+        SdrPageView* pPV = GetSdrPageView();
+              bUnMark = IsObjMarked(pFound);
+           MarkObj( pFound, pPV, bUnMark);
+    }
+    return bUnMark;
+}
+
+bool ScDrawView::SelectObject( const OUString& rName )
 {
     UnmarkAll();
 
@@ -689,8 +767,18 @@ sal_Bool ScDrawView::SelectObject( const OUString& rName )
     return ( pFound != NULL );
 }
 
+//If  object  is marked , return true , else return false .
+bool ScDrawView::GetObjectIsMarked(  SdrObject* pObject  )
+{
+    bool bisMarked = false;
+    if (pObject )
+    {
+        bisMarked = IsObjMarked(pObject);
+    }
+    return  bisMarked;
+}
 
-bool ScDrawView::InsertObjectSafe(SdrObject* pObj, SdrPageView& rPV, sal_uLong nOptions)
+bool ScDrawView::InsertObjectSafe(SdrObject* pObj, SdrPageView& rPV, SdrInsertFlags nOptions)
 {
     //  Markierung nicht aendern, wenn Ole-Objekt aktiv
     //  (bei Drop aus Ole-Objekt wuerde sonst mitten im ExecuteDrag deaktiviert!)
@@ -699,7 +787,7 @@ bool ScDrawView::InsertObjectSafe(SdrObject* pObj, SdrPageView& rPV, sal_uLong n
     {
         SfxInPlaceClient* pClient = pViewData->GetViewShell()->GetIPClient();
         if ( pClient && pClient->IsObjectInPlaceActive() )
-            nOptions |= SDRINSERT_DONTMARK;
+            nOptions |= SdrInsertFlags::DONTMARK;
     }
 
     return InsertObjectAtView( pObj, rPV, nOptions );
@@ -727,7 +815,7 @@ void ScDrawView::LockCalcLayer( SdrLayerID nLayer, bool bLock )
         SetLayerLocked( pLockLayer->GetName(), bLock );
 }
 
-void ScDrawView::MakeVisible( const Rectangle& rRect, Window& rWin )
+void ScDrawView::MakeVisible( const Rectangle& rRect, vcl::Window& rWin )
 {
     //! rWin richtig auswerten
     //! ggf Zoom aendern
@@ -777,7 +865,7 @@ void ScDrawView::DeleteMarked()
 
 SdrEndTextEditKind ScDrawView::ScEndTextEdit()
 {
-    sal_Bool bIsTextEdit = IsTextEdit();
+    bool bIsTextEdit = IsTextEdit();
     SdrEndTextEditKind eKind = SdrEndTextEdit();
 
     if ( bIsTextEdit && pViewData )
@@ -811,18 +899,18 @@ void ScDrawView::SyncForGrid( SdrObject* pObj )
     // process members of a group shape separately
     if ( pObj->ISA( SdrObjGroup ) )
     {
-        SdrObjList *pLst = ((SdrObjGroup*)pObj)->GetSubList();
-        for ( sal_uLong i = 0, nCount = pLst->GetObjCount(); i < nCount; ++i )
+        SdrObjList *pLst = static_cast<SdrObjGroup*>(pObj)->GetSubList();
+        for ( size_t i = 0, nCount = pLst->GetObjCount(); i < nCount; ++i )
             SyncForGrid( pLst->GetObj( i ) );
     }
 
     ScSplitPos eWhich = pViewData->GetActivePart();
-    ScGridWindow* pGridWin = (ScGridWindow*)pViewData->GetActiveWin();
+    ScGridWindow* pGridWin = pViewData->GetActiveWin();
     ScDrawObjData* pData = ScDrawLayer::GetObjData( pObj );
     if ( pGridWin )
     {
         ScAddress aOldStt;
-        if( pData )
+        if( pData && pData->maStart.IsValid())
         {
             aOldStt = pData->maStart;
         }
@@ -841,7 +929,7 @@ void ScDrawView::SyncForGrid( SdrObject* pObj )
         aOldPos.X() = sc::TwipsToHMM( aOldPos.X() );
         aOldPos.Y() = sc::TwipsToHMM( aOldPos.Y() );
         // find position of same point on the screen ( e.g. grid )
-        Point aCurPos =  pViewData->GetScrPos(  aOldStt.Col(), aOldStt.Row(), eWhich, sal_True );
+        Point aCurPos =  pViewData->GetScrPos(  aOldStt.Col(), aOldStt.Row(), eWhich, true );
         Point aCurPosHmm = pGridWin->PixelToLogic(aCurPos, aDrawMode );
         Point aGridOff = ( aCurPosHmm - aOldPos );
         // fdo#63878 Fix the X position for RTL Sheet
@@ -857,4 +945,41 @@ SdrUndoManager* ScDrawView::getSdrUndoManagerForEnhancedTextEdit() const
     return pDoc ? dynamic_cast< SdrUndoManager* >(pDoc->GetUndoManager()) : 0;
 }
 
+// #i123922# helper to apply a Graphic to an existing SdrObject
+SdrObject* ScDrawView::ApplyGraphicToObject(
+    SdrObject& rHitObject,
+    const Graphic& rGraphic,
+    const OUString& rBeginUndoText,
+    const OUString& rFile,
+    const OUString& rFilter)
+{
+    if(dynamic_cast< SdrGrafObj* >(&rHitObject))
+    {
+        SdrGrafObj* pNewGrafObj = static_cast<SdrGrafObj*>(rHitObject.Clone());
+
+        pNewGrafObj->SetGraphic(rGraphic);
+        BegUndo(rBeginUndoText);
+        ReplaceObjectAtView(&rHitObject, *GetSdrPageView(), pNewGrafObj);
+
+        // set in all cases - the Clone() will have copied an existing link (!)
+        pNewGrafObj->SetGraphicLink( rFile, ""/*TODO?*/, rFilter );
+
+        EndUndo();
+        return pNewGrafObj;
+    }
+    else if(rHitObject.IsClosedObj() && !dynamic_cast< SdrOle2Obj* >(&rHitObject))
+    {
+        AddUndo(new SdrUndoAttrObj(rHitObject));
+
+        SfxItemSet aSet(GetModel()->GetItemPool(), XATTR_FILLSTYLE, XATTR_FILLBITMAP);
+
+        aSet.Put(XFillStyleItem(drawing::FillStyle_BITMAP));
+        aSet.Put(XFillBitmapItem(OUString(), rGraphic));
+        rHitObject.SetMergedItemSetAndBroadcast(aSet);
+        return &rHitObject;
+    }
+
+    return NULL;
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
