@@ -69,7 +69,6 @@ PPTExCharSheet::PPTExCharSheet( int nInstance )
     }
 }
 
-
 void PPTExCharSheet::SetStyleSheet( const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > & rXPropSet,
                                     FontCollection& rFontCollection, int nLevel )
 {
@@ -90,7 +89,7 @@ void PPTExCharSheet::SetStyleSheet( const ::com::sun::star::uno::Reference< ::co
     rLev.mnFlags = aPortionObj.mnCharAttr;
 }
 
-void PPTExCharSheet::Write( SvStream& rSt, PptEscherEx*, sal_uInt16 nLev, sal_Bool, sal_Bool bSimpleText,
+void PPTExCharSheet::Write( SvStream& rSt, PptEscherEx*, sal_uInt16 nLev, bool, bool bSimpleText,
     const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > & rPagePropSet )
 {
     const PPTExCharLevel& rLev = maCharLevel[ nLev ];
@@ -99,16 +98,16 @@ void PPTExCharSheet::Write( SvStream& rSt, PptEscherEx*, sal_uInt16 nLev, sal_Bo
     if ( bSimpleText )
         nCharFlags = 0x7ffff;
 
-    rSt << nCharFlags
-        << rLev.mnFlags
-        << rLev.mnFont;
+    rSt.WriteUInt32( nCharFlags )
+       .WriteUInt16( rLev.mnFlags )
+       .WriteUInt16( rLev.mnFont );
 
     sal_uInt32 nFontColor = rLev.mnFontColor;
     if ( nFontColor == COL_AUTO )
     {
-        sal_Bool bIsDark = sal_False;
+        bool bIsDark = false;
         ::com::sun::star::uno::Any aAny;
-        if ( PropValue::GetPropertyValue( aAny, rPagePropSet, OUString( "IsBackgroundDark" ), sal_True ) )
+        if ( PropValue::GetPropertyValue( aAny, rPagePropSet, OUString( "IsBackgroundDark" ), true ) )
             aAny >>= bIsDark;
         nFontColor = bIsDark ? 0xffffff : 0x000000;
     }
@@ -116,25 +115,25 @@ void PPTExCharSheet::Write( SvStream& rSt, PptEscherEx*, sal_uInt16 nLev, sal_Bo
     nFontColor |= 0xfe000000;
     if ( bSimpleText )
     {
-        rSt << rLev.mnFontHeight
-            << nFontColor;
+        rSt.WriteUInt16( rLev.mnFontHeight )
+           .WriteUInt32( nFontColor );
     }
     else
     {
-        rSt << rLev.mnAsianOrComplexFont
-            << (sal_uInt16)0xffff       // unknown
-            << (sal_uInt16)0xffff       // unknown
-            << rLev.mnFontHeight
-            << nFontColor
-            << rLev.mnEscapement;
+        rSt.WriteUInt16( rLev.mnAsianOrComplexFont )
+           .WriteUInt16( 0xffff )       // unknown
+           .WriteUInt16( 0xffff )       // unknown
+           .WriteUInt16( rLev.mnFontHeight )
+           .WriteUInt32( nFontColor )
+           .WriteUInt16( rLev.mnEscapement );
     }
 }
 
-PPTExParaSheet::PPTExParaSheet( int nInstance, sal_uInt16 nDefaultTab, PPTExBulletProvider& rProv ) :
-    rBuProv     ( rProv ),
+PPTExParaSheet::PPTExParaSheet( int nInstance, sal_uInt16 nDefaultTab, PPTExBulletProvider* pProv ) :
+    pBuProv     ( pProv ),
     mnInstance  ( nInstance )
 {
-    sal_Bool bHasBullet = sal_False;
+    bool bHasBullet = false;
 
     sal_uInt16 nUpperDist = 0;
     sal_uInt16 nBulletChar = 0x2022;
@@ -154,7 +153,7 @@ PPTExParaSheet::PPTExParaSheet( int nInstance, sal_uInt16 nDefaultTab, PPTExBull
             case EPP_TEXTTYPE_HalfBody :
             case EPP_TEXTTYPE_QuarterBody :
             {
-                bHasBullet = sal_True;
+                bHasBullet = true;
                 nUpperDist = 0x14;
             }
             break;
@@ -216,7 +215,7 @@ PPTExParaSheet::PPTExParaSheet( int nInstance, sal_uInt16 nDefaultTab, PPTExBull
         rLev.mnAsianSettings = 2;
         rLev.mnBiDi = 0;
 
-        rLev.mbExtendedBulletsUsed = sal_False;
+        rLev.mbExtendedBulletsUsed = false;
         rLev.mnBulletId = 0xffff;
         rLev.mnBulletStart = 0;
         rLev.mnMappedNumType = 0;
@@ -227,7 +226,7 @@ PPTExParaSheet::PPTExParaSheet( int nInstance, sal_uInt16 nDefaultTab, PPTExBull
 void PPTExParaSheet::SetStyleSheet( const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > & rXPropSet,
                                         FontCollection& rFontCollection, int nLevel, const PPTExCharLevel& rCharLevel )
 {
-    ParagraphObj aParagraphObj( rXPropSet, rBuProv );
+    ParagraphObj aParagraphObj( rXPropSet, pBuProv );
     aParagraphObj.CalculateGraphicBulletSize( rCharLevel.mnFontHeight );
     PPTExParaLevel& rLev = maParaLevel[ nLevel ];
 
@@ -238,7 +237,7 @@ void PPTExParaSheet::SetStyleSheet( const ::com::sun::star::uno::Reference< ::co
         sal_Int16 nLineSpacing = aParagraphObj.mnLineSpacing;
         if ( nLineSpacing > 0 ) // if nLinespacing is < 0 the linespacing is an absolute spacing
         {
-            sal_Bool bFixedLineSpacing = sal_False;
+            bool bFixedLineSpacing = false;
             uno::Any aAny = rXPropSet->getPropertyValue("FontIndependentLineSpacing");
             if( !(aAny >>= bFixedLineSpacing) || !bFixedLineSpacing )
             {
@@ -293,7 +292,7 @@ void PPTExParaSheet::SetStyleSheet( const ::com::sun::star::uno::Reference< ::co
             {
                 PPTExParaLevel& rLevel = maParaLevel[ i ];
                 if ( i )
-                    aParagraphObj.ImplGetNumberingLevel( rBuProv, i, sal_False );
+                    aParagraphObj.ImplGetNumberingLevel( pBuProv, i, false );
                 rLevel.mnTextOfs = aParagraphObj.nTextOfs;
                 rLevel.mnBulletOfs = (sal_uInt16)aParagraphObj.nBulletOfs;
                 rLevel.mnBulletChar = aParagraphObj.cBulletId;
@@ -313,7 +312,7 @@ void PPTExParaSheet::SetStyleSheet( const ::com::sun::star::uno::Reference< ::co
     }
 }
 
-void PPTExParaSheet::Write( SvStream& rSt, PptEscherEx*, sal_uInt16 nLev, sal_Bool, sal_Bool bSimpleText,
+void PPTExParaSheet::Write( SvStream& rSt, PptEscherEx*, sal_uInt16 nLev, bool, bool bSimpleText,
     const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet > & rPagePropSet )
 {
     const PPTExParaLevel& rLev = maParaLevel[ nLev ];
@@ -322,21 +321,21 @@ void PPTExParaSheet::Write( SvStream& rSt, PptEscherEx*, sal_uInt16 nLev, sal_Bo
             maParaLevel[ 2 ].mbExtendedBulletsUsed || maParaLevel[ 3 ].mbExtendedBulletsUsed ||
                 maParaLevel[ 4 ].mbExtendedBulletsUsed )
     {
-        SvStream& rOut = rBuProv.aBuExMasterStream;
+        SvStream& rOut = pBuProv->aBuExMasterStream;
         if ( !nLev )
         {
-            rOut << (sal_uInt32)( ( EPP_PST_ExtendedParagraphMasterAtom << 16 ) | ( mnInstance << 4 ) )
-                 << (sal_uInt32)( 5 * 16 + 2 )
-                 << (sal_uInt16)5;              // depth
+            rOut.WriteUInt32( ( EPP_PST_ExtendedParagraphMasterAtom << 16 ) | ( mnInstance << 4 ) )
+                .WriteUInt32( 5 * 16 + 2 )
+                .WriteUInt16( 5 );              // depth
         }
         sal_uInt16 nBulletId = rLev.mnBulletId;
         if ( rLev.mnNumberingType != SVX_NUM_BITMAP )
             nBulletId = 0xffff;
-        rOut << (sal_uInt32)0x03800000
-             << (sal_uInt16)nBulletId
-             << (sal_uInt32)rLev.mnMappedNumType
-             << (sal_uInt16)rLev.mnBulletStart
-             << (sal_uInt32)0;
+        rOut.WriteUInt32( 0x03800000 )
+            .WriteUInt16( nBulletId )
+            .WriteUInt32( rLev.mnMappedNumType )
+            .WriteUInt16( rLev.mnBulletStart )
+            .WriteUInt32( 0 );
     }
 
     sal_uInt32 nParaFlags = 0x3ffdff;
@@ -349,48 +348,47 @@ void PPTExParaSheet::Write( SvStream& rSt, PptEscherEx*, sal_uInt16 nLev, sal_Bo
     sal_uInt32 nBulletColor = rLev.mnBulletColor;
     if ( nBulletColor == COL_AUTO )
     {
-        sal_Bool bIsDark = sal_False;
+        bool bIsDark = false;
         ::com::sun::star::uno::Any aAny;
-        if ( PropValue::GetPropertyValue( aAny, rPagePropSet, OUString( "IsBackgroundDark" ), sal_True ) )
+        if ( PropValue::GetPropertyValue( aAny, rPagePropSet, OUString( "IsBackgroundDark" ), true ) )
             aAny >>= bIsDark;
         nBulletColor = bIsDark ? 0xffffff : 0x000000;
     }
     nBulletColor &= 0xffffff;
     nBulletColor |= 0xfe000000;
-    rSt << nParaFlags
-        << nBulletFlags
-        << rLev.mnBulletChar
-        << rLev.mnBulletFont
-        << rLev.mnBulletHeight
-        << nBulletColor
-        << rLev.mnAdjust
-        << rLev.mnLineFeed
-        << rLev.mnUpperDist
-        << rLev.mnLowerDist
-        << rLev.mnTextOfs
-        << rLev.mnBulletOfs;
+    rSt.WriteUInt32( nParaFlags )
+       .WriteUInt16( nBulletFlags )
+       .WriteUInt16( rLev.mnBulletChar )
+       .WriteUInt16( rLev.mnBulletFont )
+       .WriteUInt16( rLev.mnBulletHeight )
+       .WriteUInt32( nBulletColor )
+       .WriteUInt16( rLev.mnAdjust )
+       .WriteUInt16( rLev.mnLineFeed )
+       .WriteUInt16( rLev.mnUpperDist )
+       .WriteUInt16( rLev.mnLowerDist )
+       .WriteUInt16( rLev.mnTextOfs )
+       .WriteUInt16( rLev.mnBulletOfs );
 
     if ( bSimpleText || nLev )
     {
         if ( nParaFlags & 0x200000 )
-            rSt << rLev.mnBiDi;
+            rSt.WriteUInt16( rLev.mnBiDi );
     }
     else
     {
-        rSt << rLev.mnDefaultTab
-            << (sal_uInt16)0
-            << (sal_uInt16)0
-            << rLev.mnAsianSettings
-            << rLev.mnBiDi;
+        rSt.WriteUInt16( rLev.mnDefaultTab )
+           .WriteUInt16( 0 )
+           .WriteUInt16( 0 )
+           .WriteUInt16( rLev.mnAsianSettings )
+           .WriteUInt16( rLev.mnBiDi );
     }
 }
 
-
-PPTExStyleSheet::PPTExStyleSheet( sal_uInt16 nDefaultTab, PPTExBulletProvider& rBuProv )
+PPTExStyleSheet::PPTExStyleSheet( sal_uInt16 nDefaultTab, PPTExBulletProvider* pBuProv )
 {
     for ( int nInstance = EPP_TEXTTYPE_Title; nInstance <= EPP_TEXTTYPE_QuarterBody; nInstance++ )
     {
-        mpParaSheet[ nInstance ] = ( nInstance == EPP_TEXTTYPE_notUsed ) ? NULL : new PPTExParaSheet( nInstance, nDefaultTab, rBuProv );
+        mpParaSheet[ nInstance ] = ( nInstance == EPP_TEXTTYPE_notUsed ) ? NULL : new PPTExParaSheet( nInstance, nDefaultTab, pBuProv );
         mpCharSheet[ nInstance ] = ( nInstance == EPP_TEXTTYPE_notUsed ) ? NULL : new PPTExCharSheet( nInstance );
     }
 }
@@ -416,7 +414,7 @@ void PPTExStyleSheet::SetStyleSheet( const ::com::sun::star::uno::Reference< ::c
     mpParaSheet[ nInstance ]->SetStyleSheet( rXPropSet, rFontCollection, nLevel, mpCharSheet[ nInstance ]->maCharLevel[ nLevel ] );
 }
 
-sal_Bool PPTExStyleSheet::IsHardAttribute( sal_uInt32 nInstance, sal_uInt32 nLevel, PPTExTextAttr eAttr, sal_uInt32 nValue )
+bool PPTExStyleSheet::IsHardAttribute( sal_uInt32 nInstance, sal_uInt32 nLevel, PPTExTextAttr eAttr, sal_uInt32 nValue )
 {
     const PPTExParaLevel& rPara = mpParaSheet[ nInstance ]->maParaLevel[ nLevel ];
     const PPTExCharLevel& rChar = mpCharSheet[ nInstance ]->maCharLevel[ nLevel ];
@@ -425,7 +423,7 @@ sal_Bool PPTExStyleSheet::IsHardAttribute( sal_uInt32 nInstance, sal_uInt32 nLev
 
     switch ( eAttr )
     {
-        case ParaAttr_BulletOn : return ( rPara.mbIsBullet ) ? ( nValue ) ? sal_False : sal_True : ( nValue ) ? sal_True : sal_False;
+        case ParaAttr_BulletOn : return ( rPara.mbIsBullet ) ? nValue == 0 : nValue != 0;
         case ParaAttr_BuHardFont :
         case ParaAttr_BulletFont : return ( rPara.mnBulletFont != nValue );
         case ParaAttr_BuHardColor :
@@ -449,13 +447,13 @@ sal_Bool PPTExStyleSheet::IsHardAttribute( sal_uInt32 nInstance, sal_uInt32 nLev
         case CharAttr_Embossed : nFlag = 512; break;
         case CharAttr_Font : return ( rChar.mnFont != nValue );
         case CharAttr_AsianOrComplexFont : return ( rChar.mnAsianOrComplexFont != nValue );
-        case CharAttr_Symbol : return sal_True;
+        case CharAttr_Symbol : return true;
         case CharAttr_FontHeight : return ( rChar.mnFontHeight != nValue );
         case CharAttr_FontColor : return ( rChar.mnFontColor != nValue );
         case CharAttr_Escapement : return ( rChar.mnEscapement != nValue );
         default:
             break;
-    };
+    }
     if ( nFlag )
     {
         if ( rChar.mnFlags & nFlag )
@@ -463,12 +461,7 @@ sal_Bool PPTExStyleSheet::IsHardAttribute( sal_uInt32 nInstance, sal_uInt32 nLev
         else
             return ( ( nValue & nFlag ) != 0 );
     }
-    return sal_True;
-}
-
-sal_uInt32 PPTExStyleSheet::SizeOfTxCFStyleAtom() const
-{
-    return 24;
+    return true;
 }
 
 // the TxCFStyleAtom stores the text properties that are used
@@ -485,14 +478,14 @@ void PPTExStyleSheet::WriteTxCFStyleAtom( SvStream& rSt )
     sal_uInt32 nCharFlags = rCharStyle.mnFlags;
     nCharFlags &= CharAttr_Italic | CharAttr_Bold | CharAttr_Underline | CharAttr_Shadow;
 
-    rSt << (sal_uInt32)( EPP_TxCFStyleAtom << 16 )  // recordheader
-        << SizeOfTxCFStyleAtom() - 8
-        << (sal_uInt16)( 0x80 | nCharFlags )
-        << (sal_uInt16)nFlags
-        << (sal_uInt16)nCharFlags
-        << (sal_Int32)-1                            // ?
-        << rCharStyle.mnFontHeight
-        << rCharStyle.mnFontColor;
+    rSt.WriteUInt32( EPP_TxCFStyleAtom << 16 )  // recordheader
+       .WriteUInt32( SizeOfTxCFStyleAtom() - 8 )
+       .WriteUInt16( 0x80 | nCharFlags )
+       .WriteUInt16( nFlags )
+       .WriteUInt16( nCharFlags )
+       .WriteInt32( -1 )                            // ?
+       .WriteUInt16( rCharStyle.mnFontHeight )
+       .WriteUInt32( rCharStyle.mnFontColor );
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
