@@ -91,7 +91,7 @@ PresenterSlideShowView::PresenterSlideShowView (
     }
 }
 
-void PresenterSlideShowView::LateInit (void)
+void PresenterSlideShowView::LateInit()
 {
     mxSlideShow = Reference<presentation::XSlideShow> (
         mxSlideShowController->getSlideShow(), UNO_QUERY_THROW);
@@ -175,18 +175,18 @@ void PresenterSlideShowView::LateInit (void)
         >>= msClickToExitPresentationTitle;
 }
 
-PresenterSlideShowView::~PresenterSlideShowView (void)
+PresenterSlideShowView::~PresenterSlideShowView()
 {
 }
 
-void PresenterSlideShowView::disposing (void)
+void PresenterSlideShowView::disposing()
 {
     // Tell all listeners that we are disposed.
     lang::EventObject aEvent;
     aEvent.Source = static_cast<XWeak*>(this);
 
     ::cppu::OInterfaceContainerHelper* pIterator
-          = maBroadcaster.getContainer(getCppuType((Reference<lang::XEventListener>*)NULL));
+          = maBroadcaster.getContainer(cppu::UnoType<lang::XEventListener>::get());
     if (pIterator != NULL)
         pIterator->disposeAndClear(aEvent);
 
@@ -245,9 +245,9 @@ void PresenterSlideShowView::disposing (void)
     mxController = NULL;
     mxCanvas = NULL;
     mpBackground.reset();
-    msClickToExitPresentationText = OUString();
-    msClickToExitPresentationTitle = OUString();
-    msTitleTemplate = OUString();
+    msClickToExitPresentationText.clear();
+    msClickToExitPresentationTitle.clear();
+    msTitleTemplate.clear();
     mxCurrentSlide = NULL;
 }
 
@@ -255,7 +255,7 @@ void PresenterSlideShowView::disposing (void)
 
 void SAL_CALL PresenterSlideShowView::setCurrentPage (
     const css::uno::Reference<css::drawing::XDrawPage>& rxSlide)
-    throw (css::uno::RuntimeException)
+    throw (css::uno::RuntimeException, std::exception)
 {
     mxCurrentSlide = rxSlide;
     if (mpPresenterController.get() != NULL
@@ -290,21 +290,21 @@ void SAL_CALL PresenterSlideShowView::setCurrentPage (
         if (pDescriptor.get() != NULL)
         {
             pDescriptor->msTitleTemplate = msTitleTemplate;
-            pDescriptor->msTitle = OUString();
+            (pDescriptor->msTitle).clear();
             mpPresenterController->UpdatePaneTitles();
         }
     }
 }
 
-css::uno::Reference<css::drawing::XDrawPage> SAL_CALL PresenterSlideShowView::getCurrentPage (void)
-    throw (css::uno::RuntimeException)
+css::uno::Reference<css::drawing::XDrawPage> SAL_CALL PresenterSlideShowView::getCurrentPage()
+    throw (css::uno::RuntimeException, std::exception)
 {
     return mxCurrentSlide;
 }
 
 //----- CachablePresenterView -------------------------------------------------
 
-void PresenterSlideShowView::ReleaseView (void)
+void PresenterSlideShowView::ReleaseView()
 {
     if (mxSlideShow.is() && mbIsViewAdded)
     {
@@ -315,16 +315,16 @@ void PresenterSlideShowView::ReleaseView (void)
 
 //----- XSlideShowView --------------------------------------------------------
 
-Reference<rendering::XSpriteCanvas> SAL_CALL PresenterSlideShowView::getCanvas (void)
-    throw (RuntimeException)
+Reference<rendering::XSpriteCanvas> SAL_CALL PresenterSlideShowView::getCanvas()
+    throw (RuntimeException, std::exception)
 {
     ThrowIfDisposed();
 
     return Reference<rendering::XSpriteCanvas>(mxViewCanvas, UNO_QUERY);
 }
 
-void SAL_CALL PresenterSlideShowView::clear (void)
-    throw (RuntimeException)
+void SAL_CALL PresenterSlideShowView::clear()
+    throw (RuntimeException, std::exception)
 {
     ThrowIfDisposed();
     mbIsForcedPaintPending = false;
@@ -351,14 +351,14 @@ void SAL_CALL PresenterSlideShowView::clear (void)
     }
 }
 
-geometry::AffineMatrix2D SAL_CALL PresenterSlideShowView::getTransformation (void)
-    throw (RuntimeException)
+geometry::AffineMatrix2D SAL_CALL PresenterSlideShowView::getTransformation()
+    throw (RuntimeException, std::exception)
 {
     ThrowIfDisposed();
 
     if (mxViewWindow.is())
     {
-        // When the mbIsInModifyNotification is set then a slightly modifed
+        // When the mbIsInModifyNotification is set then a slightly modified
         // version of the transformation is returned in order to get past
         // optimizations the avoid updates when the transformation is
         // unchanged (when the window size changes then due to the constant
@@ -378,8 +378,8 @@ geometry::AffineMatrix2D SAL_CALL PresenterSlideShowView::getTransformation (voi
     }
 }
 
-geometry::IntegerSize2D SAL_CALL PresenterSlideShowView::getTranslationOffset(void)
-    throw (RuntimeException)
+geometry::IntegerSize2D SAL_CALL PresenterSlideShowView::getTranslationOffset()
+    throw (RuntimeException, std::exception)
 {
     ThrowIfDisposed();
     return geometry::IntegerSize2D(0,0);
@@ -387,86 +387,86 @@ geometry::IntegerSize2D SAL_CALL PresenterSlideShowView::getTranslationOffset(vo
 
 void SAL_CALL PresenterSlideShowView::addTransformationChangedListener(
     const Reference<util::XModifyListener>& rxListener)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     ThrowIfDisposed();
     maBroadcaster.addListener(
-        getCppuType((Reference<util::XModifyListener>*)NULL),
+        cppu::UnoType<util::XModifyListener>::get(),
         rxListener);
 }
 
 void SAL_CALL PresenterSlideShowView::removeTransformationChangedListener(
     const Reference<util::XModifyListener>& rxListener)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     ThrowIfDisposed();
     maBroadcaster.removeListener(
-        getCppuType((Reference<util::XModifyListener>*)NULL),
+        cppu::UnoType<util::XModifyListener>::get(),
         rxListener);
 }
 
 void SAL_CALL PresenterSlideShowView::addPaintListener(
     const Reference<awt::XPaintListener>& rxListener)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     ThrowIfDisposed();
     maBroadcaster.addListener(
-        getCppuType((Reference<awt::XPaintListener>*)NULL),
+        cppu::UnoType<awt::XPaintListener>::get(),
         rxListener);
 }
 
 void SAL_CALL PresenterSlideShowView::removePaintListener(
     const Reference<awt::XPaintListener>& rxListener)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     ThrowIfDisposed();
     maBroadcaster.removeListener(
-        getCppuType((Reference<awt::XPaintListener>*)NULL),
+        cppu::UnoType<awt::XPaintListener>::get(),
         rxListener);
 }
 
 void SAL_CALL PresenterSlideShowView::addMouseListener(
     const Reference<awt::XMouseListener>& rxListener)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     ThrowIfDisposed();
     maBroadcaster.addListener(
-        getCppuType((Reference<awt::XMouseListener>*)NULL),
+        cppu::UnoType<awt::XMouseListener>::get(),
         rxListener);
 }
 
 void SAL_CALL PresenterSlideShowView::removeMouseListener(
     const Reference<awt::XMouseListener>& rxListener)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     ThrowIfDisposed();
     maBroadcaster.removeListener(
-        getCppuType((Reference<awt::XMouseListener>*)NULL),
+        cppu::UnoType<awt::XMouseListener>::get(),
         rxListener);
 }
 
 void SAL_CALL PresenterSlideShowView::addMouseMotionListener(
     const Reference<awt::XMouseMotionListener>& rxListener)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     ThrowIfDisposed();
     maBroadcaster.addListener(
-        getCppuType((Reference<awt::XMouseMotionListener>*)NULL),
+        cppu::UnoType<awt::XMouseMotionListener>::get(),
         rxListener);
 }
 
 void SAL_CALL PresenterSlideShowView::removeMouseMotionListener(
     const Reference<awt::XMouseMotionListener>& rxListener)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     ThrowIfDisposed();
     maBroadcaster.removeListener(
-        getCppuType((Reference<awt::XMouseMotionListener>*)NULL),
+        cppu::UnoType<awt::XMouseMotionListener>::get(),
         rxListener);
 }
 
 void SAL_CALL PresenterSlideShowView::setMouseCursor(::sal_Int16 nPointerShape)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     ThrowIfDisposed();
 
@@ -486,7 +486,7 @@ void SAL_CALL PresenterSlideShowView::setMouseCursor(::sal_Int16 nPointerShape)
     }
 }
 
-awt::Rectangle SAL_CALL PresenterSlideShowView::getCanvasArea(  ) throw (RuntimeException)
+awt::Rectangle SAL_CALL PresenterSlideShowView::getCanvasArea(  ) throw (RuntimeException, std::exception)
 {
     if( mxViewWindow.is() && mxTopPane.is() )
         return mxPresenterHelper->getWindowExtentsRelative( mxViewWindow, mxTopPane->getWindow() );
@@ -501,7 +501,7 @@ awt::Rectangle SAL_CALL PresenterSlideShowView::getCanvasArea(  ) throw (Runtime
 //----- lang::XEventListener --------------------------------------------------
 
 void SAL_CALL PresenterSlideShowView::disposing (const lang::EventObject& rEvent)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     if (rEvent.Source == mxViewWindow)
         mxViewWindow = NULL;
@@ -512,7 +512,7 @@ void SAL_CALL PresenterSlideShowView::disposing (const lang::EventObject& rEvent
 //----- XPaintListener --------------------------------------------------------
 
 void SAL_CALL PresenterSlideShowView::windowPaint (const awt::PaintEvent& rEvent)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     // Deactivated views must not be painted.
     if ( ! mbIsPresenterViewActive)
@@ -533,12 +533,12 @@ void SAL_CALL PresenterSlideShowView::windowPaint (const awt::PaintEvent& rEvent
 //----- XMouseListener --------------------------------------------------------
 
 void SAL_CALL PresenterSlideShowView::mousePressed (const awt::MouseEvent& rEvent)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     awt::MouseEvent aEvent (rEvent);
     aEvent.Source = static_cast<XWeak*>(this);
     ::cppu::OInterfaceContainerHelper* pIterator
-        = maBroadcaster.getContainer(getCppuType((Reference<awt::XMouseListener>*)NULL));
+        = maBroadcaster.getContainer(cppu::UnoType<awt::XMouseListener>::get());
     if (pIterator != NULL)
     {
         pIterator->notifyEach(&awt::XMouseListener::mousePressed, aEvent);
@@ -553,12 +553,12 @@ void SAL_CALL PresenterSlideShowView::mousePressed (const awt::MouseEvent& rEven
 }
 
 void SAL_CALL PresenterSlideShowView::mouseReleased (const awt::MouseEvent& rEvent)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     awt::MouseEvent aEvent (rEvent);
     aEvent.Source = static_cast<XWeak*>(this);
     ::cppu::OInterfaceContainerHelper* pIterator
-        = maBroadcaster.getContainer(getCppuType((Reference<awt::XMouseListener>*)NULL));
+        = maBroadcaster.getContainer(cppu::UnoType<awt::XMouseListener>::get());
     if (pIterator != NULL)
     {
         pIterator->notifyEach(&awt::XMouseListener::mouseReleased, aEvent);
@@ -566,12 +566,12 @@ void SAL_CALL PresenterSlideShowView::mouseReleased (const awt::MouseEvent& rEve
 }
 
 void SAL_CALL PresenterSlideShowView::mouseEntered (const awt::MouseEvent& rEvent)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     awt::MouseEvent aEvent (rEvent);
     aEvent.Source = static_cast<XWeak*>(this);
     ::cppu::OInterfaceContainerHelper* pIterator
-        = maBroadcaster.getContainer(getCppuType((Reference<awt::XMouseListener>*)NULL));
+        = maBroadcaster.getContainer(cppu::UnoType<awt::XMouseListener>::get());
     if (pIterator != NULL)
     {
         pIterator->notifyEach(&awt::XMouseListener::mouseEntered, aEvent);
@@ -579,12 +579,12 @@ void SAL_CALL PresenterSlideShowView::mouseEntered (const awt::MouseEvent& rEven
 }
 
 void SAL_CALL PresenterSlideShowView::mouseExited (const awt::MouseEvent& rEvent)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     awt::MouseEvent aEvent (rEvent);
     aEvent.Source = static_cast<XWeak*>(this);
     ::cppu::OInterfaceContainerHelper* pIterator
-        = maBroadcaster.getContainer(getCppuType((Reference<awt::XMouseListener>*)NULL));
+        = maBroadcaster.getContainer(cppu::UnoType<awt::XMouseListener>::get());
     if (pIterator != NULL)
     {
         pIterator->notifyEach(&awt::XMouseListener::mouseExited, aEvent);
@@ -594,12 +594,12 @@ void SAL_CALL PresenterSlideShowView::mouseExited (const awt::MouseEvent& rEvent
 //----- XMouseMotionListener --------------------------------------------------
 
 void SAL_CALL PresenterSlideShowView::mouseDragged (const awt::MouseEvent& rEvent)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     awt::MouseEvent aEvent (rEvent);
     aEvent.Source = static_cast<XWeak*>(this);
     ::cppu::OInterfaceContainerHelper* pIterator
-        = maBroadcaster.getContainer(getCppuType((Reference<awt::XMouseMotionListener>*)NULL));
+        = maBroadcaster.getContainer(cppu::UnoType<awt::XMouseMotionListener>::get());
     if (pIterator != NULL)
     {
         pIterator->notifyEach(&awt::XMouseMotionListener::mouseDragged, aEvent);
@@ -607,12 +607,12 @@ void SAL_CALL PresenterSlideShowView::mouseDragged (const awt::MouseEvent& rEven
 }
 
 void SAL_CALL PresenterSlideShowView::mouseMoved (const awt::MouseEvent& rEvent)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     awt::MouseEvent aEvent (rEvent);
     aEvent.Source = static_cast<XWeak*>(this);
     ::cppu::OInterfaceContainerHelper* pIterator
-        = maBroadcaster.getContainer(getCppuType((Reference<awt::XMouseMotionListener>*)NULL));
+        = maBroadcaster.getContainer(cppu::UnoType<awt::XMouseMotionListener>::get());
     if (pIterator != NULL)
     {
         pIterator->notifyEach(&awt::XMouseMotionListener::mouseMoved, aEvent);
@@ -622,7 +622,7 @@ void SAL_CALL PresenterSlideShowView::mouseMoved (const awt::MouseEvent& rEvent)
 //----- XWindowListener -------------------------------------------------------
 
 void SAL_CALL PresenterSlideShowView::windowResized (const awt::WindowEvent& rEvent)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     (void)rEvent;
 
@@ -633,7 +633,7 @@ void SAL_CALL PresenterSlideShowView::windowResized (const awt::WindowEvent& rEv
 }
 
 void SAL_CALL PresenterSlideShowView::windowMoved (const awt::WindowEvent& rEvent)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     (void)rEvent;
     if ( ! mbIsPaintPending)
@@ -641,35 +641,35 @@ void SAL_CALL PresenterSlideShowView::windowMoved (const awt::WindowEvent& rEven
 }
 
 void SAL_CALL PresenterSlideShowView::windowShown (const lang::EventObject& rEvent)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     (void)rEvent;
     Resize();
 }
 
 void SAL_CALL PresenterSlideShowView::windowHidden (const lang::EventObject& rEvent)
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     (void)rEvent;
 }
 
 //----- XView -----------------------------------------------------------------
 
-Reference<XResourceId> SAL_CALL PresenterSlideShowView::getResourceId (void)
-    throw(RuntimeException)
+Reference<XResourceId> SAL_CALL PresenterSlideShowView::getResourceId()
+    throw(RuntimeException, std::exception)
 {
     return mxViewId;
 }
 
-sal_Bool SAL_CALL PresenterSlideShowView::isAnchorOnly (void)
-    throw (RuntimeException)
+sal_Bool SAL_CALL PresenterSlideShowView::isAnchorOnly()
+    throw (RuntimeException, std::exception)
 {
     return false;
 }
 
 //----- CachablePresenterView -------------------------------------------------
 
-void PresenterSlideShowView::ActivatePresenterView (void)
+void PresenterSlideShowView::ActivatePresenterView()
 {
     if (mxSlideShow.is() && ! mbIsViewAdded)
     {
@@ -678,7 +678,7 @@ void PresenterSlideShowView::ActivatePresenterView (void)
     }
 }
 
-void PresenterSlideShowView::DeactivatePresenterView (void)
+void PresenterSlideShowView::DeactivatePresenterView()
 {
     if (mxSlideShow.is() && mbIsViewAdded)
     {
@@ -687,7 +687,7 @@ void PresenterSlideShowView::DeactivatePresenterView (void)
     }
 }
 
-//-----------------------------------------------------------------------------
+
 
 void PresenterSlideShowView::PaintOuterWindow (const awt::Rectangle& rRepaintBox)
 {
@@ -811,7 +811,7 @@ void PresenterSlideShowView::PaintInnerWindow (const awt::PaintEvent& rEvent)
     awt::PaintEvent aEvent (rEvent);
     aEvent.Source = static_cast<XWeak*>(this);
     ::cppu::OInterfaceContainerHelper* pIterator
-        = maBroadcaster.getContainer(getCppuType((Reference<awt::XPaintListener>*)NULL));
+        = maBroadcaster.getContainer(cppu::UnoType<awt::XPaintListener>::get());
     if (pIterator != NULL)
     {
         pIterator->notifyEach(&awt::XPaintListener::windowPaint, aEvent);
@@ -877,7 +877,7 @@ Reference<rendering::XCanvas> PresenterSlideShowView::CreateViewCanvas (
         rxViewWindow);
 }
 
-void PresenterSlideShowView::Resize (void)
+void PresenterSlideShowView::Resize()
 {
     if ( ! mxWindow.is() || ! mxViewWindow.is())
         return;
@@ -920,7 +920,7 @@ void PresenterSlideShowView::Resize (void)
     // window has changed.
     lang::EventObject aEvent (static_cast<XWeak*>(this));
     ::cppu::OInterfaceContainerHelper* pIterator
-        = maBroadcaster.getContainer(getCppuType((Reference<util::XModifyListener>*)NULL));
+        = maBroadcaster.getContainer(cppu::UnoType<util::XModifyListener>::get());
     if (pIterator != NULL)
     {
         pIterator->notifyEach(&util::XModifyListener::modified, aEvent);
@@ -933,7 +933,7 @@ void PresenterSlideShowView::Resize (void)
         mbIsForcedPaintPending = true;
 }
 
-void PresenterSlideShowView::ForceRepaint (void)
+void PresenterSlideShowView::ForceRepaint()
 {
     if (mxSlideShow.is() && mbIsViewAdded)
     {
@@ -942,7 +942,7 @@ void PresenterSlideShowView::ForceRepaint (void)
     }
 }
 
-void PresenterSlideShowView::CreateBackgroundPolygons (void)
+void PresenterSlideShowView::CreateBackgroundPolygons()
 {
     const awt::Rectangle aWindowBox (mxWindow->getPosSize());
     const awt::Rectangle aViewWindowBox (mxViewWindow->getPosSize());
@@ -989,7 +989,7 @@ void PresenterSlideShowView::CreateBackgroundPolygons (void)
     }
 }
 
-void PresenterSlideShowView::ThrowIfDisposed (void)
+void PresenterSlideShowView::ThrowIfDisposed()
     throw (::com::sun::star::lang::DisposedException)
 {
     if (rBHelper.bDisposed || rBHelper.bInDispose)
@@ -1004,7 +1004,7 @@ void PresenterSlideShowView::impl_addAndConfigureView()
 {
     Reference<presentation::XSlideShowView> xView (this);
     mxSlideShow->addView(xView);
-    // Prevent embeded sounds being played twice at the same time by
+    // Prevent embedded sounds being played twice at the same time by
     // disabling sound for the new slide show view.
     beans::PropertyValue aProperty;
     aProperty.Name = "IsSoundEnabled";
