@@ -97,14 +97,14 @@ using namespace ::ucbhelper;
 using ::std::vector;
 using ::std::advance;
 
-//========================================================================
+
 
 #define TITLE                   "Title"
 #define TARGET_URL              "TargetURL"
 
 #define COMMAND_TRANSFER        "transfer"
 
-//========================================================================
+
 
 class RegionData_Impl;
 
@@ -114,15 +114,15 @@ class DocTempl_EntryData_Impl
 {
     RegionData_Impl*    mpParent;
 
-    // the following member must be SfxObjectShellLock since it controlls that SfxObjectShell lifetime by design
+    // the following member must be SfxObjectShellLock since it controls that SfxObjectShell lifetime by design
     // and users of this class expect it to be so.
     SfxObjectShellLock  mxObjShell;
 
     OUString            maTitle;
     OUString            maOwnURL;
     OUString            maTargetURL;
-    sal_Bool            mbIsOwner   : 1;
-    sal_Bool            mbDidConvert: 1;
+    bool            mbIsOwner   : 1;
+    bool            mbDidConvert: 1;
 
 private:
     RegionData_Impl*    GetParent() const { return mpParent; }
@@ -146,7 +146,7 @@ public:
 
 using namespace ::DocTempl;
 
-// ------------------------------------------------------------------------
+
 
 class RegionData_Impl
 {
@@ -158,7 +158,7 @@ class RegionData_Impl
 
 private:
     size_t                      GetEntryPos( const OUString& rTitle,
-                                             sal_Bool& rFound ) const;
+                                             bool& rFound ) const;
     const SfxDocTemplate_Impl*  GetParent() const { return mpParent; }
 
 public:
@@ -184,14 +184,12 @@ public:
                                   size_t *pPos = NULL );
     void                DeleteEntry( size_t nIndex );
 
-    int                 Compare( const OUString& rTitle ) const
-                            { return maTitle.compareTo( rTitle ); }
     int                 Compare( RegionData_Impl* pCompareWith ) const;
 };
 
 typedef vector< RegionData_Impl* > RegionList_Impl;
 
-// ------------------------------------------------------------------------
+
 
 class SfxDocTemplate_Impl : public SvRefBase
 {
@@ -202,7 +200,7 @@ class SfxDocTemplate_Impl : public SvRefBase
     OUString            maRootURL;
     OUString            maStandardGroup;
     RegionList_Impl     maRegions;
-    sal_Bool            mbConstructed;
+    bool            mbConstructed;
 
     uno::Reference< XAnyCompareFactory > m_rCompareFactory;
 
@@ -215,12 +213,12 @@ private:
 
 public:
                         SfxDocTemplate_Impl();
-                        ~SfxDocTemplate_Impl();
+                        virtual ~SfxDocTemplate_Impl();
 
     void                IncrementLock();
     void                DecrementLock();
 
-    sal_Bool            Construct( );
+    bool            Construct( );
     void                CreateFromHierarchy( Content &rTemplRoot );
     void                ReInitFromComponent();
     void                AddRegion( const OUString& rTitle,
@@ -235,14 +233,14 @@ public:
     RegionData_Impl*    GetRegion( const OUString& rName ) const;
     RegionData_Impl*    GetRegion( size_t nIndex ) const;
 
-    sal_Bool            GetTitleFromURL( const OUString& rURL, OUString& aTitle );
-    sal_Bool            InsertRegion( RegionData_Impl *pData, size_t nPos = size_t(-1) );
+    bool            GetTitleFromURL( const OUString& rURL, OUString& aTitle );
+    bool            InsertRegion( RegionData_Impl *pData, size_t nPos = size_t(-1) );
     OUString            GetRootURL() const { return maRootURL; }
 
     uno::Reference< XDocumentTemplates >     getDocTemplates() { return mxTemplates; }
 };
 
-// ------------------------------------------------------------------------
+
 
 class DocTemplLocker_Impl
 {
@@ -260,37 +258,33 @@ public:
     }
 };
 
-// ------------------------------------------------------------------------
+
 
 #ifndef SFX_DECL_DOCTEMPLATES_DEFINED
 #define SFX_DECL_DOCTEMPLATES_DEFINED
-SV_DECL_REF(SfxDocTemplate_Impl)
+typedef tools::SvRef<SfxDocTemplate_Impl> SfxDocTemplate_ImplRef;
 #endif
 
-SV_IMPL_REF(SfxDocTemplate_Impl)
-
-// ------------------------------------------------------------------------
-
 SfxDocTemplate_Impl *gpTemplateData = 0;
 
-// -----------------------------------------------------------------------
 
-static sal_Bool getTextProperty_Impl( Content& rContent,
+
+static bool getTextProperty_Impl( Content& rContent,
                                       const OUString& rPropName,
                                       OUString& rPropValue );
 
-//========================================================================
+
 
 OUString SfxDocumentTemplates::GetFullRegionName
 (
-    sal_uInt16 nIdx                     // Region Index
+    sal_uInt16 nIdx                     // vcl::Region Index
 )   const
 
 /*  [Description]
 
     Returns the logical name of a region and its path
 
-    [Return value]                 Reference to the Region name
+    [Return value]                 Reference to the vcl::Region name
 
 */
 
@@ -315,11 +309,11 @@ OUString SfxDocumentTemplates::GetFullRegionName
     return aName;
 }
 
-//------------------------------------------------------------------------
+
 
 const OUString& SfxDocumentTemplates::GetRegionName
 (
-    sal_uInt16 nIdx                 // Region Index
+    sal_uInt16 nIdx                 // vcl::Region Index
 )   const
 
 /*  [Description]
@@ -328,7 +322,7 @@ const OUString& SfxDocumentTemplates::GetRegionName
 
     [Return value]
 
-    const String&                   Reference to the Region name
+    const String&                   Reference to the vcl::Region name
 
 */
 {
@@ -343,15 +337,15 @@ const OUString& SfxDocumentTemplates::GetRegionName
         if ( pData )
             maTmpString = pData->GetTitle();
         else
-            maTmpString = "";
+            maTmpString.clear();
     }
     else
-        maTmpString = "";
+        maTmpString.clear();
 
     return maTmpString;
 }
 
-//------------------------------------------------------------------------
+
 
 sal_uInt16 SfxDocumentTemplates::GetRegionCount() const
 
@@ -374,11 +368,11 @@ sal_uInt16 SfxDocumentTemplates::GetRegionCount() const
     return (sal_uInt16) nCount;
 }
 
-//------------------------------------------------------------------------
+
 
 sal_uInt16 SfxDocumentTemplates::GetCount
 (
-    sal_uInt16 nRegion              /* Region index whose number is
+    sal_uInt16 nRegion              /* vcl::Region index whose number is
                                    to be determined */
 
 )   const
@@ -405,11 +399,11 @@ sal_uInt16 SfxDocumentTemplates::GetCount
     return (sal_uInt16) nCount;
 }
 
-//------------------------------------------------------------------------
+
 
 const OUString& SfxDocumentTemplates::GetName
 (
-    sal_uInt16 nRegion,     //  Region Index, in which the entry lies
+    sal_uInt16 nRegion,     //  vcl::Region Index, in which the entry lies
     sal_uInt16 nIdx         //  Index of the entry
 )   const
 
@@ -438,19 +432,19 @@ const OUString& SfxDocumentTemplates::GetName
         if ( pEntry )
             maTmpString = pEntry->GetTitle();
         else
-            maTmpString = "";
+            maTmpString.clear();
     }
     else
-        maTmpString = "";
+        maTmpString.clear();
 
     return maTmpString;
 }
 
-//------------------------------------------------------------------------
+
 
 OUString SfxDocumentTemplates::GetPath
 (
-    sal_uInt16  nRegion,    //  Region Index, in which the entry lies
+    sal_uInt16  nRegion,    //  vcl::Region Index, in which the entry lies
     sal_uInt16  nIdx        //  Index of the entry
 )   const
 
@@ -480,7 +474,7 @@ OUString SfxDocumentTemplates::GetPath
         return OUString();
 }
 
-//------------------------------------------------------------------------
+
 
 OUString SfxDocumentTemplates::GetTemplateTargetURLFromComponent( const OUString& aGroupName,
                                                                          const OUString& aTitle )
@@ -511,7 +505,7 @@ OUString SfxDocumentTemplates::GetTemplateTargetURLFromComponent( const OUString
     return aResult;
 }
 
-//------------------------------------------------------------------------
+
 
 /** Convert a resource string - a template name - to its localised pair if it exists.
     @param nSourceResIds
@@ -536,15 +530,15 @@ OUString SfxDocumentTemplates::ConvertResourceString (
     return rString;
 }
 
-//------------------------------------------------------------------------
 
-sal_Bool SfxDocumentTemplates::CopyOrMove
+
+bool SfxDocumentTemplates::CopyOrMove
 (
-    sal_uInt16  nTargetRegion,      //  Target Region Index
+    sal_uInt16  nTargetRegion,      //  Target vcl::Region Index
     sal_uInt16  nTargetIdx,         //  Target position Index
-    sal_uInt16  nSourceRegion,      //  Source Region Index
+    sal_uInt16  nSourceRegion,      //  Source vcl::Region Index
     sal_uInt16  nSourceIdx,         /*  Index to be copied / to moved template */
-    sal_Bool    bMove           //  Copy / Move
+    bool        bMove               //  Copy / Move
 )
 
 /*  [Description]
@@ -575,29 +569,29 @@ sal_Bool SfxDocumentTemplates::CopyOrMove
     DocTemplLocker_Impl aLocker( *pImp );
 
     if ( !pImp->Construct() )
-        return sal_False;
+        return false;
 
     // Don't copy or move any folders
     if( nSourceIdx == USHRT_MAX )
-        return sal_False ;
+        return false ;
 
     if ( nSourceRegion == nTargetRegion )
     {
         SAL_WARN( "sfx.doc", "Don't know, what to do!" );
-        return sal_False;
+        return false;
     }
 
     RegionData_Impl *pSourceRgn = pImp->GetRegion( nSourceRegion );
     if ( !pSourceRgn )
-        return sal_False;
+        return false;
 
     DocTempl_EntryData_Impl *pSource = pSourceRgn->GetEntry( nSourceIdx );
     if ( !pSource )
-        return sal_False;
+        return false;
 
     RegionData_Impl *pTargetRgn = pImp->GetRegion( nTargetRegion );
     if ( !pTargetRgn )
-        return sal_False;
+        return false;
 
     OUString aTitle = pSource->GetTitle();
 
@@ -609,19 +603,19 @@ sal_Bool SfxDocumentTemplates::CopyOrMove
     {
         OUString aNewTargetURL = GetTemplateTargetURLFromComponent( pTargetRgn->GetTitle(), aTitle );
         if ( aNewTargetURL.isEmpty() )
-            return sal_False;
+            return false;
 
         if ( bMove )
         {
             // --**-- delete the original file
-            sal_Bool bDeleted = xTemplates->removeTemplate( pSourceRgn->GetTitle(),
+            bool bDeleted = xTemplates->removeTemplate( pSourceRgn->GetTitle(),
                                                             pSource->GetTitle() );
             if ( bDeleted )
                 pSourceRgn->DeleteEntry( nSourceIdx );
             else
             {
                 if ( xTemplates->removeTemplate( pTargetRgn->GetTitle(), aTitle ) )
-                    return sal_False; // will trigger tetry with copy instead of move
+                    return false; // will trigger tetry with copy instead of move
 
                 // if it is not possible to remove just created template ( must be possible! )
                 // it is better to report success here, since at least the copy has succeeded
@@ -633,22 +627,22 @@ sal_Bool SfxDocumentTemplates::CopyOrMove
         size_t temp_nTargetIdx = nTargetIdx;
         pTargetRgn->AddEntry( aTitle, aNewTargetURL, &temp_nTargetIdx );
 
-        return sal_True;
+        return true;
     }
 
     // --**-- if the current file is opened,
     // it must be re-opened afterwards.
 
-    return sal_False;
+    return false;
 }
 
-//------------------------------------------------------------------------
 
-sal_Bool SfxDocumentTemplates::Move
+
+bool SfxDocumentTemplates::Move
 (
-    sal_uInt16 nTargetRegion,       //  Target Region Index
+    sal_uInt16 nTargetRegion,       //  Target vcl::Region Index
     sal_uInt16 nTargetIdx,          //  Target position Index
-    sal_uInt16 nSourceRegion,       //  Source Region Index
+    sal_uInt16 nSourceRegion,       //  Source vcl::Region Index
     sal_uInt16 nSourceIdx           /*  Index to be copied / to moved template */
 )
 
@@ -669,16 +663,16 @@ sal_Bool SfxDocumentTemplates::Move
     DocTemplLocker_Impl aLocker( *pImp );
 
     return CopyOrMove( nTargetRegion, nTargetIdx,
-                       nSourceRegion, nSourceIdx, sal_True );
+                       nSourceRegion, nSourceIdx, true );
 }
 
-//------------------------------------------------------------------------
 
-sal_Bool SfxDocumentTemplates::Copy
+
+bool SfxDocumentTemplates::Copy
 (
-    sal_uInt16 nTargetRegion,       //  Target Region Index
+    sal_uInt16 nTargetRegion,       //  Target vcl::Region Index
     sal_uInt16 nTargetIdx,          //  Target position Index
-    sal_uInt16 nSourceRegion,       //  Source Region Index
+    sal_uInt16 nSourceRegion,       //  Source vcl::Region Index
     sal_uInt16 nSourceIdx           /*  Index to be copied / to moved template */
 )
 
@@ -700,14 +694,14 @@ sal_Bool SfxDocumentTemplates::Copy
     DocTemplLocker_Impl aLocker( *pImp );
 
     return CopyOrMove( nTargetRegion, nTargetIdx,
-                       nSourceRegion, nSourceIdx, sal_False );
+                       nSourceRegion, nSourceIdx, false );
 }
 
-//------------------------------------------------------------------------
 
-sal_Bool SfxDocumentTemplates::CopyTo
+
+bool SfxDocumentTemplates::CopyTo
 (
-    sal_uInt16          nRegion,    //  Region of the template to be exported
+    sal_uInt16          nRegion,    //  vcl::Region of the template to be exported
     sal_uInt16          nIdx,       //  Index of the template to be exported
     const OUString&     rName       /*  File name under which the template is to
                                     be created */
@@ -731,15 +725,15 @@ sal_Bool SfxDocumentTemplates::CopyTo
     DocTemplLocker_Impl aLocker( *pImp );
 
     if ( ! pImp->Construct() )
-        return sal_False;
+        return false;
 
     RegionData_Impl *pSourceRgn = pImp->GetRegion( nRegion );
     if ( !pSourceRgn )
-        return sal_False;
+        return false;
 
     DocTempl_EntryData_Impl *pSource = pSourceRgn->GetEntry( nIdx );
     if ( !pSource )
-        return sal_False;
+        return false;
 
     INetURLObject aTargetURL( rName );
 
@@ -768,18 +762,18 @@ sal_Bool SfxDocumentTemplates::CopyTo
         aTarget.executeCommand( aCmd, aArg );
     }
     catch ( ContentCreationException& )
-    { return sal_False; }
+    { return false; }
     catch ( Exception& )
-    { return sal_False; }
+    { return false; }
 
-    return sal_True;
+    return true;
 }
 
-//------------------------------------------------------------------------
 
-sal_Bool SfxDocumentTemplates::CopyFrom
+
+bool SfxDocumentTemplates::CopyFrom
 (
-    sal_uInt16      nRegion,        /*  Region in which the template is to be
+    sal_uInt16      nRegion,        /*  vcl::Region in which the template is to be
                                     imported */
     sal_uInt16      nIdx,           //  Index of the new template in this Region
     OUString&       rName           /*  File name of the template to be imported
@@ -792,7 +786,7 @@ sal_Bool SfxDocumentTemplates::CopyFrom
 
     Import a template from the file system
 
-    [Return value]                 Sucess (sal_True) or serfpTargetDirectory->GetContent());
+    [Return value]                 Success (sal_True) or serfpTargetDirectory->GetContent());
 
     sal_Bool            sal_True,   Action could be performed
                         sal_False,  Action could not be performed
@@ -806,19 +800,19 @@ sal_Bool SfxDocumentTemplates::CopyFrom
     DocTemplLocker_Impl aLocker( *pImp );
 
     if ( ! pImp->Construct() )
-        return sal_False;
+        return false;
 
     RegionData_Impl *pTargetRgn = pImp->GetRegion( nRegion );
 
     if ( !pTargetRgn )
-        return sal_False;
+        return false;
 
     uno::Reference< XDocumentTemplates > xTemplates = pImp->getDocTemplates();
     if ( !xTemplates.is() )
-        return sal_False;
+        return false;
 
     OUString aTitle;
-    sal_Bool bTemplateAdded = sal_False;
+    bool bTemplateAdded = false;
 
     if( pImp->GetTitleFromURL( rName, aTitle ) )
     {
@@ -904,27 +898,27 @@ sal_Bool SfxDocumentTemplates::CopyFrom
                 size_t temp_nIdx = nIdx;
                 pTargetRgn->AddEntry( aTitle, aTemplName, &temp_nIdx );
                 rName = aTitle;
-                return sal_True;
+                return true;
             }
             else
             {
-                DBG_ASSERT( sal_False, "CopyFrom(): The content should contain target URL!" );
+                DBG_ASSERT( false, "CopyFrom(): The content should contain target URL!" );
             }
         }
         else
         {
-            DBG_ASSERT( sal_False, "CopyFrom(): The content just was created!" );
+            DBG_ASSERT( false, "CopyFrom(): The content just was created!" );
         }
     }
 
-    return sal_False;
+    return false;
 }
 
-//------------------------------------------------------------------------
 
-sal_Bool SfxDocumentTemplates::Delete
+
+bool SfxDocumentTemplates::Delete
 (
-    sal_uInt16 nRegion,             //  Region Index
+    sal_uInt16 nRegion,             //  vcl::Region Index
     sal_uInt16 nIdx                 /*  Index of the entry or USHRT_MAX,
                                     if a directory is meant. */
 )
@@ -952,14 +946,14 @@ sal_Bool SfxDocumentTemplates::Delete
        Then remove the data from the lists
     */
     if ( ! pImp->Construct() )
-        return sal_False;
+        return false;
 
     RegionData_Impl *pRegion = pImp->GetRegion( nRegion );
 
     if ( !pRegion )
-        return sal_False;
+        return false;
 
-    sal_Bool bRet;
+    bool bRet;
     uno::Reference< XDocumentTemplates > xTemplates = pImp->getDocTemplates();
 
     if ( nIdx == USHRT_MAX )
@@ -973,7 +967,7 @@ sal_Bool SfxDocumentTemplates::Delete
         DocTempl_EntryData_Impl *pEntry = pRegion->GetEntry( nIdx );
 
         if ( !pEntry )
-            return sal_False;
+            return false;
 
         bRet = xTemplates->removeTemplate( pRegion->GetTitle(),
                                            pEntry->GetTitle() );
@@ -984,12 +978,12 @@ sal_Bool SfxDocumentTemplates::Delete
     return bRet;
 }
 
-//------------------------------------------------------------------------
 
-sal_Bool SfxDocumentTemplates::InsertDir
+
+bool SfxDocumentTemplates::InsertDir
 (
     const OUString&     rText,      //  the logical name of the new Region
-    sal_uInt16          nRegion     //  Region Index
+    sal_uInt16          nRegion     //  vcl::Region Index
 )
 
 /*  [Description]
@@ -1009,12 +1003,12 @@ sal_Bool SfxDocumentTemplates::InsertDir
     DocTemplLocker_Impl aLocker( *pImp );
 
     if ( ! pImp->Construct() )
-        return sal_False;
+        return false;
 
     RegionData_Impl *pRegion = pImp->GetRegion( rText );
 
     if ( pRegion )
-        return sal_False;
+        return false;
 
     uno::Reference< XDocumentTemplates > xTemplates = pImp->getDocTemplates();
 
@@ -1025,44 +1019,44 @@ sal_Bool SfxDocumentTemplates::InsertDir
         if ( ! pImp->InsertRegion( pNewRegion, nRegion ) )
         {
             delete pNewRegion;
-            return sal_False;
+            return false;
         }
-        return sal_True;
+        return true;
     }
 
-    return sal_False;
+    return false;
 }
 
-sal_Bool SfxDocumentTemplates::InsertTemplate(sal_uInt16 nSourceRegion, sal_uInt16 nIdx, const OUString &rName, const OUString &rPath)
+bool SfxDocumentTemplates::InsertTemplate(sal_uInt16 nSourceRegion, sal_uInt16 nIdx, const OUString &rName, const OUString &rPath)
 {
     DocTemplLocker_Impl aLocker( *pImp );
 
     if ( ! pImp->Construct() )
-        return sal_False;
+        return false;
 
     RegionData_Impl *pRegion = pImp->GetRegion( nSourceRegion );
 
     if ( !pRegion )
-        return sal_False;
+        return false;
 
     size_t pos = nIdx;
     pRegion->AddEntry( rName, rPath, &pos );
 
-    return sal_True;
+    return true;
 }
 
-sal_Bool SfxDocumentTemplates::SetName( const OUString& rName, sal_uInt16 nRegion, sal_uInt16 nIdx )
+bool SfxDocumentTemplates::SetName( const OUString& rName, sal_uInt16 nRegion, sal_uInt16 nIdx )
 
 {
     DocTemplLocker_Impl aLocker( *pImp );
 
     if ( ! pImp->Construct() )
-        return sal_False;
+        return false;
 
     RegionData_Impl *pRegion = pImp->GetRegion( nRegion );
 
     if ( !pRegion )
-        return sal_False;
+        return false;
 
     uno::Reference< XDocumentTemplates > xTemplates = pImp->getDocTemplates();
     OUString aEmpty;
@@ -1070,7 +1064,7 @@ sal_Bool SfxDocumentTemplates::SetName( const OUString& rName, sal_uInt16 nRegio
     if ( nIdx == USHRT_MAX )
     {
         if ( pRegion->GetTitle() == rName )
-            return sal_True;
+            return true;
 
         // we have to rename a region
         if ( xTemplates->renameGroup( pRegion->GetTitle(), rName ) )
@@ -1078,7 +1072,7 @@ sal_Bool SfxDocumentTemplates::SetName( const OUString& rName, sal_uInt16 nRegio
             pRegion->SetTitle( rName );
             pRegion->SetTargetURL( aEmpty );
             pRegion->SetHierarchyURL( aEmpty );
-            return sal_True;
+            return true;
         }
     }
     else
@@ -1086,10 +1080,10 @@ sal_Bool SfxDocumentTemplates::SetName( const OUString& rName, sal_uInt16 nRegio
         DocTempl_EntryData_Impl *pEntry = pRegion->GetEntry( nIdx );
 
         if ( !pEntry )
-            return sal_False;
+            return false;
 
         if ( pEntry->GetTitle() == rName )
-            return sal_True;
+            return true;
 
         if ( xTemplates->renameTemplate( pRegion->GetTitle(),
                                          pEntry->GetTitle(),
@@ -1098,18 +1092,18 @@ sal_Bool SfxDocumentTemplates::SetName( const OUString& rName, sal_uInt16 nRegio
             pEntry->SetTitle( rName );
             pEntry->SetTargetURL( aEmpty );
             pEntry->SetHierarchyURL( aEmpty );
-            return sal_True;
+            return true;
         }
     }
 
-    return sal_False;
+    return false;
 }
 
-//------------------------------------------------------------------------
 
-sal_Bool SfxDocumentTemplates::GetFull
+
+bool SfxDocumentTemplates::GetFull
 (
-    const OUString &rRegion,      // Region Name
+    const OUString &rRegion,      // vcl::Region Name
     const OUString &rName,        // Template Name
     OUString &rPath               // Out: Path + File name
 )
@@ -1133,10 +1127,10 @@ sal_Bool SfxDocumentTemplates::GetFull
 
     // We don't search for empty names!
     if ( rName.isEmpty() )
-        return sal_False;
+        return false;
 
     if ( ! pImp->Construct() )
-        return sal_False;
+        return false;
 
     DocTempl_EntryData_Impl* pEntry = NULL;
     const sal_uInt16 nCount = GetRegionCount();
@@ -1161,12 +1155,12 @@ sal_Bool SfxDocumentTemplates::GetFull
     return ( pEntry != NULL );
 }
 
-//------------------------------------------------------------------------
 
-sal_Bool SfxDocumentTemplates::GetLogicNames
+
+bool SfxDocumentTemplates::GetLogicNames
 (
     const OUString &rPath,            // Full Path to the template
-    OUString &rRegion,                // Out: Region name
+    OUString &rRegion,                // Out: vcl::Region name
     OUString &rName                   // Out: Template name
 ) const
 
@@ -1188,17 +1182,17 @@ sal_Bool SfxDocumentTemplates::GetLogicNames
     DocTemplLocker_Impl aLocker( *pImp );
 
     if ( ! pImp->Construct() )
-        return sal_False;
+        return false;
 
     INetURLObject aFullPath;
 
-    aFullPath.SetSmartProtocol( INET_PROT_FILE );
+    aFullPath.SetSmartProtocol( INetProtocol::File );
     aFullPath.SetURL( rPath );
     OUString aPath( aFullPath.GetMainURL( INetURLObject::NO_DECODE ) );
 
     RegionData_Impl *pData = NULL;
     DocTempl_EntryData_Impl  *pEntry = NULL;
-    sal_Bool         bFound = sal_False;
+    bool         bFound = false;
 
     sal_uIntPtr nCount = GetRegionCount();
 
@@ -1212,9 +1206,9 @@ sal_Bool SfxDocumentTemplates::GetLogicNames
             for ( sal_uIntPtr j=0; !bFound && (j<nChildCount); j++ )
             {
                 pEntry = pData->GetEntry( j );
-                if ( pEntry->GetTargetURL() == aPath )
+                if ( pEntry && pEntry->GetTargetURL() == aPath )
                 {
-                    bFound = sal_True;
+                    bFound = true;
                 }
             }
         }
@@ -1229,7 +1223,7 @@ sal_Bool SfxDocumentTemplates::GetLogicNames
     return bFound;
 }
 
-//------------------------------------------------------------------------
+
 
 SfxDocumentTemplates::SfxDocumentTemplates()
 
@@ -1244,16 +1238,7 @@ SfxDocumentTemplates::SfxDocumentTemplates()
     pImp = gpTemplateData;
 }
 
-//-------------------------------------------------------------------------
 
-void SfxDocumentTemplates::Construct()
-
-//  Delayed build-up of administrative data
-
-{
-}
-
-//------------------------------------------------------------------------
 
 SfxDocumentTemplates::~SfxDocumentTemplates()
 
@@ -1267,10 +1252,10 @@ SfxDocumentTemplates::~SfxDocumentTemplates()
     pImp = NULL;
 }
 
-void SfxDocumentTemplates::Update( sal_Bool _bSmart )
+void SfxDocumentTemplates::Update( bool _bSmart )
 {
     if  (   !_bSmart                                                // don't be smart
-        ||  ::svt::TemplateFolderCache( sal_True ).needsUpdate()    // update is really necessary
+        ||  ::svt::TemplateFolderCache( true ).needsUpdate()    // update is really necessary
         )
     {
         if ( pImp->Construct() )
@@ -1283,24 +1268,24 @@ void SfxDocumentTemplates::ReInitFromComponent()
     pImp->ReInitFromComponent();
 }
 
-// -----------------------------------------------------------------------
+
 DocTempl_EntryData_Impl::DocTempl_EntryData_Impl( RegionData_Impl* pParent,
                                 const OUString& rTitle )
 {
     mpParent    = pParent;
     maTitle     = SfxDocumentTemplates::ConvertResourceString(
                   STR_TEMPLATE_NAME1_DEF, STR_TEMPLATE_NAME1, NUM_TEMPLATE_NAMES, rTitle );
-    mbIsOwner   = sal_False;
-    mbDidConvert= sal_False;
+    mbIsOwner   = false;
+    mbDidConvert= false;
 }
 
-// -----------------------------------------------------------------------
+
 int DocTempl_EntryData_Impl::Compare( const OUString& rTitle ) const
 {
     return maTitle.compareTo( rTitle );
 }
 
-// -----------------------------------------------------------------------
+
 const OUString& DocTempl_EntryData_Impl::GetHierarchyURL()
 {
     if ( maOwnURL.isEmpty() )
@@ -1318,7 +1303,7 @@ const OUString& DocTempl_EntryData_Impl::GetHierarchyURL()
     return maOwnURL;
 }
 
-// -----------------------------------------------------------------------
+
 const OUString& DocTempl_EntryData_Impl::GetTargetURL()
 {
     if ( maTargetURL.isEmpty() )
@@ -1341,7 +1326,7 @@ const OUString& DocTempl_EntryData_Impl::GetTargetURL()
     return maTargetURL;
 }
 
-// -----------------------------------------------------------------------
+
 RegionData_Impl::RegionData_Impl( const SfxDocTemplate_Impl* pParent,
                                   const OUString& rTitle )
 {
@@ -1349,7 +1334,7 @@ RegionData_Impl::RegionData_Impl( const SfxDocTemplate_Impl* pParent,
     mpParent    = pParent;
 }
 
-// -----------------------------------------------------------------------
+
 RegionData_Impl::~RegionData_Impl()
 {
     for ( size_t i = 0, n = maEntries.size(); i < n; ++i )
@@ -1357,8 +1342,8 @@ RegionData_Impl::~RegionData_Impl()
     maEntries.clear();
 }
 
-// -----------------------------------------------------------------------
-size_t RegionData_Impl::GetEntryPos( const OUString& rTitle, sal_Bool& rFound ) const
+
+size_t RegionData_Impl::GetEntryPos( const OUString& rTitle, bool& rFound ) const
 {
 #if 1   // Don't use binary search today
     size_t i;
@@ -1370,12 +1355,12 @@ size_t RegionData_Impl::GetEntryPos( const OUString& rTitle, sal_Bool& rFound )
 
         if ( pData->Compare( rTitle ) == 0 )
         {
-            rFound = sal_True;
+            rFound = true;
             return i;
         }
     }
 
-    rFound = sal_False;
+    rFound = false;
     return i;
 
 #else
@@ -1418,7 +1403,7 @@ size_t RegionData_Impl::GetEntryPos( const OUString& rTitle, sal_Bool& rFound )
 #endif
 }
 
-// -----------------------------------------------------------------------
+
 void RegionData_Impl::AddEntry( const OUString& rTitle,
                                 const OUString& rTargetURL,
                                 size_t *pPos )
@@ -1430,7 +1415,7 @@ void RegionData_Impl::AddEntry( const OUString& rTitle,
     OUString aLinkURL = aLinkObj.GetMainURL( INetURLObject::NO_DECODE );
 
     DocTempl_EntryData_Impl* pEntry;
-    sal_Bool        bFound = sal_False;
+    bool        bFound = false;
     size_t          nPos = GetEntryPos( rTitle, bFound );
 
     if ( bFound )
@@ -1455,13 +1440,13 @@ void RegionData_Impl::AddEntry( const OUString& rTitle,
     }
 }
 
-// -----------------------------------------------------------------------
+
 size_t RegionData_Impl::GetCount() const
 {
     return maEntries.size();
 }
 
-// -----------------------------------------------------------------------
+
 const OUString& RegionData_Impl::GetHierarchyURL()
 {
     if ( maOwnURL.isEmpty() )
@@ -1479,10 +1464,10 @@ const OUString& RegionData_Impl::GetHierarchyURL()
     return maOwnURL;
 }
 
-// -----------------------------------------------------------------------
+
 DocTempl_EntryData_Impl* RegionData_Impl::GetEntry( const OUString& rName ) const
 {
-    sal_Bool    bFound = sal_False;
+    bool    bFound = false;
     long        nPos = GetEntryPos( rName, bFound );
 
     if ( bFound )
@@ -1491,7 +1476,7 @@ DocTempl_EntryData_Impl* RegionData_Impl::GetEntry( const OUString& rName ) cons
         return NULL;
 }
 
-// -----------------------------------------------------------------------
+
 DocTempl_EntryData_Impl* RegionData_Impl::GetEntry( size_t nIndex ) const
 {
     if ( nIndex < maEntries.size() )
@@ -1499,7 +1484,7 @@ DocTempl_EntryData_Impl* RegionData_Impl::GetEntry( size_t nIndex ) const
     return NULL;
 }
 
-// -----------------------------------------------------------------------
+
 void RegionData_Impl::DeleteEntry( size_t nIndex )
 {
     if ( nIndex < maEntries.size() )
@@ -1511,7 +1496,7 @@ void RegionData_Impl::DeleteEntry( size_t nIndex )
     }
 }
 
-// -----------------------------------------------------------------------
+
 int RegionData_Impl::Compare( RegionData_Impl* pCompare ) const
 {
     int nCompare = maTitle.compareTo( pCompare->maTitle );
@@ -1519,15 +1504,15 @@ int RegionData_Impl::Compare( RegionData_Impl* pCompare ) const
     return nCompare;
 }
 
-// -----------------------------------------------------------------------
+
 
 SfxDocTemplate_Impl::SfxDocTemplate_Impl()
-: mbConstructed( sal_False )
+: mbConstructed( false )
 , mnLockCounter( 0 )
 {
 }
 
-// -----------------------------------------------------------------------
+
 SfxDocTemplate_Impl::~SfxDocTemplate_Impl()
 {
     Clear();
@@ -1535,14 +1520,14 @@ SfxDocTemplate_Impl::~SfxDocTemplate_Impl()
     gpTemplateData = NULL;
 }
 
-// -----------------------------------------------------------------------
+
 void SfxDocTemplate_Impl::IncrementLock()
 {
     ::osl::MutexGuard aGuard( maMutex );
     mnLockCounter++;
 }
 
-// -----------------------------------------------------------------------
+
 void SfxDocTemplate_Impl::DecrementLock()
 {
     ::osl::MutexGuard aGuard( maMutex );
@@ -1550,7 +1535,7 @@ void SfxDocTemplate_Impl::DecrementLock()
         mnLockCounter--;
 }
 
-// -----------------------------------------------------------------------
+
 RegionData_Impl* SfxDocTemplate_Impl::GetRegion( size_t nIndex ) const
 {
     if ( nIndex < maRegions.size() )
@@ -1558,7 +1543,7 @@ RegionData_Impl* SfxDocTemplate_Impl::GetRegion( size_t nIndex ) const
     return NULL;
 }
 
-// -----------------------------------------------------------------------
+
 RegionData_Impl* SfxDocTemplate_Impl::GetRegion( const OUString& rName )
     const
 {
@@ -1571,7 +1556,7 @@ RegionData_Impl* SfxDocTemplate_Impl::GetRegion( const OUString& rName )
     return NULL;
 }
 
-// -----------------------------------------------------------------------
+
 void SfxDocTemplate_Impl::DeleteRegion( size_t nIndex )
 {
     if ( nIndex < maRegions.size() )
@@ -1583,8 +1568,8 @@ void SfxDocTemplate_Impl::DeleteRegion( size_t nIndex )
     }
 }
 
-// -----------------------------------------------------------------------
-/*  AddRegion adds a Region to the RegionList
+
+/*  AddRegion adds a vcl::Region to the RegionList
 */
 void SfxDocTemplate_Impl::AddRegion( const OUString& rTitle,
                                      Content& rContent )
@@ -1633,7 +1618,7 @@ void SfxDocTemplate_Impl::AddRegion( const OUString& rTitle,
     }
 }
 
-// -----------------------------------------------------------------------
+
 void SfxDocTemplate_Impl::CreateFromHierarchy( Content &rTemplRoot )
 {
     uno::Reference< XResultSet > xResultSet;
@@ -1672,13 +1657,13 @@ void SfxDocTemplate_Impl::CreateFromHierarchy( Content &rTemplRoot )
     }
 }
 
-// ------------------------------------------------------------------------
-sal_Bool SfxDocTemplate_Impl::Construct( )
+
+bool SfxDocTemplate_Impl::Construct( )
 {
     ::osl::MutexGuard aGuard( maMutex );
 
     if ( mbConstructed )
-        return sal_True;
+        return true;
 
     uno::Reference< XComponentContext > xContext = ::comphelper::getProcessComponentContext();
 
@@ -1695,9 +1680,9 @@ sal_Bool SfxDocTemplate_Impl::Construct( )
     uno::Reference < XCommandEnvironment > aCmdEnv;
 
     if ( ! aRootContent.is() )
-        return sal_False;
+        return false;
 
-    mbConstructed = sal_True;
+    mbConstructed = true;
     maRootURL = aRootContent->getIdentifier()->getContentIdentifier();
 
     ResStringArray  aLongNames( SfxResId( TEMPLATE_LONG_NAMES_ARY ) );
@@ -1708,10 +1693,10 @@ sal_Bool SfxDocTemplate_Impl::Construct( )
     Content aTemplRoot( aRootContent, aCmdEnv, xContext );
     CreateFromHierarchy( aTemplRoot );
 
-    return sal_True;
+    return true;
 }
 
-// -----------------------------------------------------------------------
+
 void SfxDocTemplate_Impl::ReInitFromComponent()
 {
     uno::Reference< XDocumentTemplates > xTemplates = getDocTemplates();
@@ -1725,15 +1710,15 @@ void SfxDocTemplate_Impl::ReInitFromComponent()
     }
 }
 
-// -----------------------------------------------------------------------
-sal_Bool SfxDocTemplate_Impl::InsertRegion( RegionData_Impl *pNew, size_t nPos )
+
+bool SfxDocTemplate_Impl::InsertRegion( RegionData_Impl *pNew, size_t nPos )
 {
     ::osl::MutexGuard   aGuard( maMutex );
 
     // return false (not inserted) if the entry already exists
     for ( size_t i = 0, n = maRegions.size(); i < n; ++i )
         if ( maRegions[ i ]->Compare( pNew ) == 0 )
-            return sal_False;
+            return false;
 
     size_t newPos = nPos;
     if ( pNew->GetTitle() == maStandardGroup )
@@ -1748,10 +1733,10 @@ sal_Bool SfxDocTemplate_Impl::InsertRegion( RegionData_Impl *pNew, size_t nPos )
     else
         maRegions.push_back( pNew );
 
-    return sal_True;
+    return true;
 }
 
-// -----------------------------------------------------------------------
+
 void SfxDocTemplate_Impl::Rescan()
 {
     Clear();
@@ -1777,8 +1762,8 @@ void SfxDocTemplate_Impl::Rescan()
     }
 }
 
-// -----------------------------------------------------------------------
-sal_Bool SfxDocTemplate_Impl::GetTitleFromURL( const OUString& rURL,
+
+bool SfxDocTemplate_Impl::GetTitleFromURL( const OUString& rURL,
                                            OUString& aTitle )
 {
     if ( mxInfo.is() )
@@ -1790,7 +1775,7 @@ sal_Bool SfxDocTemplate_Impl::GetTitleFromURL( const OUString& rURL,
         catch ( Exception& )
         {
             // the document is not a StarOffice document
-            return sal_False;
+            return false;
         }
 
 
@@ -1817,11 +1802,11 @@ sal_Bool SfxDocTemplate_Impl::GetTitleFromURL( const OUString& rURL,
                                INetURLObject::DECODE_WITH_CHARSET );
     }
 
-    return sal_True;
+    return true;
 }
 
 
-// -----------------------------------------------------------------------
+
 void SfxDocTemplate_Impl::Clear()
 {
     ::osl::MutexGuard   aGuard( maMutex );
@@ -1833,12 +1818,12 @@ void SfxDocTemplate_Impl::Clear()
     maRegions.clear();
 }
 
-// -----------------------------------------------------------------------
-sal_Bool getTextProperty_Impl( Content& rContent,
+
+bool getTextProperty_Impl( Content& rContent,
                                const OUString& rPropName,
                                OUString& rPropValue )
 {
-    sal_Bool bGotProperty = sal_False;
+    bool bGotProperty = false;
 
     // Get the property
     try
@@ -1848,7 +1833,7 @@ sal_Bool getTextProperty_Impl( Content& rContent,
         // check, whether or not the property exists
         if ( !aPropInfo.is() || !aPropInfo->hasPropertyByName( rPropName ) )
         {
-            return sal_False;
+            return false;
         }
 
         // now get the property
@@ -1863,7 +1848,7 @@ sal_Bool getTextProperty_Impl( Content& rContent,
             aRelocImpl.makeAbsoluteURL( rPropValue );
         }
 
-        bGotProperty = sal_True;
+        bGotProperty = true;
     }
     catch ( RuntimeException& ) {}
     catch ( Exception& ) {}
