@@ -75,11 +75,11 @@ namespace slideshow
 {
     namespace internal
     {
-        //////////////////////////////////////////////////////////////////////
-        //
+
+
         // Private methods
-        //
-        //////////////////////////////////////////////////////////////////////
+
+
 
         GDIMetaFileSharedPtr DrawShape::forceScrollTextMetaFile()
         {
@@ -168,6 +168,7 @@ namespace slideshow
             }
 
             // redraw all view shapes, by calling their update() method
+            ViewShape::RenderArgs renderArgs( getViewRenderArgs() );
             if( ::std::count_if( maViewShapes.begin(),
                                  maViewShapes.end(),
                                  ::boost::bind<bool>(
@@ -178,8 +179,7 @@ namespace slideshow
                                                                              // the extra mem_fn. WTF.
                                      _1,
                                      ::boost::cref( mpCurrMtf ),
-                                     ::boost::cref(
-                                         getViewRenderArgs() ),
+                                     ::boost::cref( renderArgs ),
                                      nUpdateFlags,
                                      isVisible() ) )
                 != static_cast<ViewShapeVector::difference_type>(maViewShapes.size()) )
@@ -207,7 +207,7 @@ namespace slideshow
 
 
             // determine what has to be updated
-            // --------------------------------
+
 
             // do we have an attribute layer?
             if( mpAttributeLayer )
@@ -327,7 +327,7 @@ namespace slideshow
 
 
                         // retrieve bounds for subset of whole metafile
-                        // --------------------------------------------
+
 
                         ::basegfx::B2DRange aTotalBounds;
 
@@ -523,11 +523,11 @@ namespace slideshow
             //           issue for this #i72828#
         }
 
-        //////////////////////////////////////////////////////////////////////
-        //
+
+
         // Public methods
-        //
-        //////////////////////////////////////////////////////////////////////
+
+
 
         DrawShapeSharedPtr DrawShape::create(
             const uno::Reference< drawing::XShape >&    xShape,
@@ -632,16 +632,14 @@ namespace slideshow
         void DrawShape::addViewLayer( const ViewLayerSharedPtr& rNewLayer,
                                       bool                      bRedrawLayer )
         {
-            ViewShapeVector::iterator aEnd( maViewShapes.end() );
-
             // already added?
-            if( ::std::find_if( maViewShapes.begin(),
-                                aEnd,
-                                ::boost::bind<bool>(
+            if( ::std::any_of( maViewShapes.begin(),
+                               maViewShapes.end(),
+                               ::boost::bind<bool>(
                                     ::std::equal_to< ViewLayerSharedPtr >(),
                                     ::boost::bind( &ViewShape::getViewLayer,
                                                    _1 ),
-                                    ::boost::cref( rNewLayer ) ) ) != aEnd )
+                                    ::boost::cref( rNewLayer ) ) ))
             {
                 // yes, nothing to do
                 return;
@@ -731,8 +729,7 @@ namespace slideshow
 
         bool DrawShape::isContentChanged() const
         {
-            return mbForceUpdate ?
-                true :
+            return mbForceUpdate ||
                 getUpdateFlags() != ViewShape::NONE;
         }
 
@@ -912,12 +909,11 @@ namespace slideshow
             for ( MetaAction * pCurrAct = mpCurrMtf->FirstAction();
                   pCurrAct != 0; pCurrAct = mpCurrMtf->NextAction() )
             {
-                if (pCurrAct->GetType() == META_COMMENT_ACTION) {
+                if (pCurrAct->GetType() == MetaActionType::COMMENT) {
                     MetaCommentAction * pAct =
                         static_cast<MetaCommentAction *>(pCurrAct);
                     // skip comment if not a special XTEXT comment
-                    if (pAct->GetComment().equalsIgnoreAsciiCaseL(
-                            RTL_CONSTASCII_STRINGPARAM("FIELD_SEQ_BEGIN") ) &&
+                    if (pAct->GetComment().equalsIgnoreAsciiCase("FIELD_SEQ_BEGIN") &&
                         // e.g. date field doesn't have data!
                         // currently assuming that only url field, this is
                         // somehow fragile! xxx todo if possible
@@ -942,8 +938,7 @@ namespace slideshow
                                     pAct->GetDataSize() / sizeof(sal_Unicode) )
                                 ) );
                     }
-                    else if (pAct->GetComment().equalsIgnoreAsciiCaseL(
-                                 RTL_CONSTASCII_STRINGPARAM("FIELD_SEQ_END")) &&
+                    else if (pAct->GetComment().equalsIgnoreAsciiCase("FIELD_SEQ_END") &&
                              // pending end is expected:
                              !maHyperlinkIndices.empty() &&
                              maHyperlinkIndices.back().second == -1)
@@ -1055,7 +1050,7 @@ namespace slideshow
 
 
         // AnimatableShape methods
-        // ======================================================
+
 
         void DrawShape::enterAnimationMode()
         {
@@ -1093,7 +1088,7 @@ namespace slideshow
 
 
         // AttributableShape methods
-        // ======================================================
+
 
         ShapeAttributeLayerSharedPtr DrawShape::createAttributeLayer()
         {
