@@ -17,8 +17,8 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <config_features.h>
 
-// must be first
 #include <canvas/debug.hxx>
 #include <tools/diagnose_ex.h>
 #include <canvas/verbosetrace.hxx>
@@ -30,6 +30,7 @@
 
 #include <vcl/canvastools.hxx>
 #include <vcl/syschild.hxx>
+#include <vcl/sysdata.hxx>
 #include <vcl/window.hxx>
 #include <vcl/graph.hxx>
 
@@ -45,6 +46,9 @@
 #include <cppcanvas/vclfactory.hxx>
 #include <cppcanvas/basegfxfactory.hxx>
 #include <avmedia/mediawindow.hxx>
+#include <avmedia/modeltools.hxx>
+
+#include <vcl/opengl/OpenGLContext.hxx>
 
 #include <com/sun/star/media/XManager.hpp>
 #include <com/sun/star/media/XPlayer.hpp>
@@ -71,7 +75,7 @@ namespace slideshow
                                         const uno::Reference< drawing::XShape >&        rxShape,
                                         const uno::Reference< uno::XComponentContext >& rxContext ) :
             mpViewLayer( rViewLayer ),
-            mpMediaWindow(),
+            mpEventHandlerParent(0),
             maWindowOffset( 0, 0 ),
             maBounds(),
             mxShape( rxShape ),
@@ -92,7 +96,7 @@ namespace slideshow
             }
         }
 
-        // ---------------------------------------------------------------------
+
 
         ViewMediaShape::~ViewMediaShape()
         {
@@ -109,27 +113,27 @@ namespace slideshow
             }
         }
 
-        // ---------------------------------------------------------------------
+
 
         ViewLayerSharedPtr ViewMediaShape::getViewLayer() const
         {
             return mpViewLayer;
         }
 
-        // ---------------------------------------------------------------------
+
 
         bool ViewMediaShape::startMedia()
         {
             if( !mxPlayer.is() )
                 implInitialize( maBounds );
 
-            if( mxPlayer.is() && ( mxPlayer->getDuration() > 0.0 ) )
+            if (mxPlayer.is())
                 mxPlayer->start();
 
             return true;
         }
 
-        // ---------------------------------------------------------------------
+
 
         void ViewMediaShape::endMedia()
         {
@@ -144,7 +148,8 @@ namespace slideshow
                 mxPlayerWindow.clear();
             }
 
-            mpMediaWindow.reset();
+            mpMediaWindow.disposeAndClear();
+            mpEventHandlerParent.disposeAndClear();
 
             // shutdown player
             if( mxPlayer.is() )
@@ -160,26 +165,29 @@ namespace slideshow
             }
         }
 
-        // ---------------------------------------------------------------------
+
 
         void ViewMediaShape::pauseMedia()
         {
-            if( mxPlayer.is() && ( mxPlayer->getDuration() > 0.0 ) )
+            if (mxPlayer.is())
                 mxPlayer->stop();
         }
 
-        // ---------------------------------------------------------------------
+
 
         void ViewMediaShape::setMediaTime(double fTime)
         {
-            if( mxPlayer.is() && ( mxPlayer->getDuration() > 0.0 ) )
+            if (mxPlayer.is())
                 mxPlayer->setMediaTime(fTime);
         }
 
-        // ---------------------------------------------------------------------
+
 
         bool ViewMediaShape::render( const ::basegfx::B2DRectangle& rBounds ) const
         {
+#if !HAVE_FEATURE_AVMEDIA
+            (void) rBounds;
+#else
             ::cppcanvas::CanvasSharedPtr pCanvas = mpViewLayer->getCanvas();
 
             if( !pCanvas )
@@ -187,12 +195,14 @@ namespace slideshow
 
             if( !mpMediaWindow.get() && !mxPlayerWindow.is() )
             {
-                OUString sURL;
+                uno::Reference< graphic::XGraphic > xGraphic;
                 uno::Reference< beans::XPropertySet > xPropSet( mxShape, uno::UNO_QUERY );
                 if (xPropSet.is())
-                    xPropSet->getPropertyValue("PrivateTempFileURL") >>= sURL;
+                {
+                    xPropSet->getPropertyValue("FallbackGraphic") >>= xGraphic;
+                }
 
-                const Graphic aGraphic(avmedia::MediaWindow::grabFrame(sURL,"", true));
+                Graphic aGraphic(xGraphic);
                 const BitmapEx aBmp = aGraphic.GetBitmapEx();
 
                 uno::Reference< rendering::XBitmap > xBitmap(vcl::unotools::xBitmapFromBitmapEx(
@@ -216,7 +226,7 @@ namespace slideshow
                                                      aViewState,
                                                      aRenderState );
             }
-
+#endif
             return true;
         }
 
@@ -266,7 +276,15 @@ namespace slideshow
 
             if( mpMediaWindow.get() )
             {
-                mpMediaWindow->SetPosSizePixel( aPosPixel, aSizePixel );
+                if( mpEventHandlerParent )
+                {
+                    mpEventHandlerParent->SetPosSizePixel( aPosPixel, aSizePixel );
+                    mpMediaWindow->SetPosSizePixel( Point(0,0), aSizePixel );
+                }
+                else
+                {
+                    mpMediaWindow->SetPosSizePixel( aPosPixel, aSizePixel );
+                }
                 mxPlayerWindow->setPosSize( 0, 0,
                                             aSizePixel.Width(), aSizePixel.Height(),
                                             0 );
@@ -281,39 +299,40 @@ namespace slideshow
             return true;
         }
 
-        // ---------------------------------------------------------------------
+
 
         bool ViewMediaShape::implInitialize( const ::basegfx::B2DRectangle& rBounds )
         {
             if( !mxPlayer.is() && mxShape.is() )
             {
                 ENSURE_OR_RETURN_FALSE( mpViewLayer->getCanvas(),
-                                   "ViewMediaShape::update(): Invalid layer canvas" );
+                                   "ViewMediaShape::implInitialize(): Invalid layer canvas" );
 
                 uno::Reference< rendering::XCanvas > xCanvas( mpViewLayer->getCanvas()->getUNOCanvas() );
 
                 if( xCanvas.is() )
                 {
                     uno::Reference< beans::XPropertySet >   xPropSet;
-                    OUString                         aURL;
-
                     try
                     {
                         xPropSet.set( mxShape, uno::UNO_QUERY );
+                        OUString sMimeType;
 
                         // create Player
                         if (xPropSet.is())
                         {
+                            OUString aURL;
+                            xPropSet->getPropertyValue("MediaMimeType") >>= sMimeType;
                             if ((xPropSet->getPropertyValue(
                                   OUString( "PrivateTempFileURL")) >>= aURL)
                                 && !aURL.isEmpty())
                             {
-                                implInitializeMediaPlayer( aURL );
+                                implInitializeMediaPlayer( aURL, sMimeType );
                             }
                             else if (xPropSet->getPropertyValue(
                                   OUString( "MediaURL")) >>= aURL)
                             {
-                                implInitializeMediaPlayer( aURL );
+                                implInitializeMediaPlayer( aURL, sMimeType );
                             }
                         }
 
@@ -322,23 +341,7 @@ namespace slideshow
 
                         if( ::canvas::tools::getDeviceInfo( xCanvas, aDeviceParams ).getLength() > 1 )
                         {
-                            OUString aImplName;
-
-                            aDeviceParams[ 0 ] >>= aImplName;
-
-                            if( aImplName.endsWithIgnoreAsciiCaseAsciiL(
-                                    RTL_CONSTASCII_STRINGPARAM("VCL") ) || aImplName.endsWithIgnoreAsciiCaseAsciiL(
-                                    RTL_CONSTASCII_STRINGPARAM("Cairo") ) )
-                            {
-                                implInitializeVCLBasedPlayerWindow( rBounds, aDeviceParams );
-                            }
-                            else if( aImplName.endsWithIgnoreAsciiCaseAsciiL(
-                                         RTL_CONSTASCII_STRINGPARAM("DX")) ||
-                                     aImplName.endsWithIgnoreAsciiCaseAsciiL(
-                                         RTL_CONSTASCII_STRINGPARAM("DX9")))
-                            {
-                                implInitializeDXBasedPlayerWindow( rBounds, aDeviceParams );
-                            }
+                            implInitializePlayerWindow( rBounds, aDeviceParams, sMimeType );
                         }
 
                         // set player properties
@@ -360,7 +363,7 @@ namespace slideshow
             return mxPlayer.is() || mxPlayerWindow.is();
         }
 
-        // ---------------------------------------------------------------------
+
 
         void ViewMediaShape::implSetMediaProperties( const uno::Reference< beans::XPropertySet >& rxProps )
         {
@@ -370,13 +373,13 @@ namespace slideshow
 
                 if( rxProps.is() )
                 {
-                    sal_Bool bLoop( false );
+                    bool bLoop( false );
                     getPropertyValue( bLoop,
                                       rxProps,
                                       OUString( "Loop" ));
                     mxPlayer->setPlaybackLoop( bLoop );
 
-                    sal_Bool bMute( false );
+                    bool bMute( false );
                     getPropertyValue( bMute,
                                       rxProps,
                                       OUString( "Mute" ));
@@ -400,17 +403,21 @@ namespace slideshow
             }
         }
 
-        // ---------------------------------------------------------------------
 
-        void ViewMediaShape::implInitializeMediaPlayer( const OUString& rMediaURL )
+
+        void ViewMediaShape::implInitializeMediaPlayer( const OUString& rMediaURL, const OUString& rMimeType )
         {
+#if !HAVE_FEATURE_AVMEDIA
+            (void) rMediaURL;
+            (void) rMimeType;
+#else
             if( !mxPlayer.is() )
             {
                 try
                 {
                     if( !rMediaURL.isEmpty() )
                     {
-                        mxPlayer.set( avmedia::MediaWindow::createPlayer( rMediaURL, ""/*TODO!*/ ),
+                        mxPlayer.set( avmedia::MediaWindow::createPlayer( rMediaURL, ""/*TODO!*/, &rMimeType ),
                             uno::UNO_QUERY );
                     }
                 }
@@ -420,19 +427,19 @@ namespace slideshow
                 }
                 catch( const uno::Exception& )
                 {
-                    throw lang::NoSupportException(
-                        OUString( "No video support for " ) + rMediaURL,
-                        uno::Reference<uno::XInterface>() );
+                    throw lang::NoSupportException( "No video support for " + rMediaURL );
                 }
             }
+#endif
         }
 
-        // ---------------------------------------------------------------------
 
-        bool ViewMediaShape::implInitializeVCLBasedPlayerWindow( const ::basegfx::B2DRectangle&   rBounds,
-                                                                 const uno::Sequence< uno::Any >& rVCLDeviceParams)
+
+        bool ViewMediaShape::implInitializePlayerWindow( const ::basegfx::B2DRectangle&   rBounds,
+                                                                 const uno::Sequence< uno::Any >& rVCLDeviceParams,
+                                                                 const OUString& rMimeType )
         {
-                    OSL_TRACE( "ViewMediaShape::implInitializeVCLBasedPlayerWindow" );
+            OSL_TRACE( "ViewMediaShape::implInitializePlayerWindow" );
             if( !mpMediaWindow.get() && !rBounds.isEmpty() )
             {
                 try
@@ -441,7 +448,7 @@ namespace slideshow
 
                     rVCLDeviceParams[ 1 ] >>= aVal;
 
-                    Window* pWindow = reinterpret_cast< Window* >( aVal );
+                    vcl::Window* pWindow = reinterpret_cast< vcl::Window* >( aVal );
 
                     if( pWindow )
                     {
@@ -459,17 +466,37 @@ namespace slideshow
                                                                   rRangePix.getMinY(),
                                                                     rRangePix.getMaxX() - rRangePix.getMinX(),
                                                                     rRangePix.getMaxY() - rRangePix.getMinY() );
-
-                            mpMediaWindow.reset( new
-                                                SystemChildWindow( pWindow, WB_CLIPCHILDREN ) );
-                            mpMediaWindow->SetBackground( Color( COL_BLACK ) );
-                            mpMediaWindow->SetPosSizePixel( Point( aAWTRect.X, aAWTRect.Y ),
+#if !HAVE_FEATURE_GLTF
+                            (void)rMimeType;
+#else
+                            if( avmedia::IsModel(rMimeType) )
+                            {
+                                mpMediaWindow.disposeAndClear();
+                                mpEventHandlerParent.disposeAndClear();
+                                mpEventHandlerParent = VclPtr<vcl::Window>::Create(pWindow, WB_NOBORDER|WB_NODIALOGCONTROL);
+                                mpEventHandlerParent->SetPosSizePixel( Point( aAWTRect.X, aAWTRect.Y ),
                                                            Size( aAWTRect.Width, aAWTRect.Height ) );
+                                mpEventHandlerParent->EnablePaint(false);
+                                mpEventHandlerParent->Show();
+                                SystemWindowData aWinData = OpenGLContext::generateWinData(mpEventHandlerParent.get(), false);
+                                mpMediaWindow = VclPtr<SystemChildWindow>::Create(mpEventHandlerParent.get(), 0, &aWinData);
+                                mpMediaWindow->SetPosSizePixel( Point( 0, 0 ),
+                                                           Size( aAWTRect.Width, aAWTRect.Height ) );
+                            }
+                            else
+#endif
+                            {
+                                mpMediaWindow.disposeAndClear();
+                                mpMediaWindow = VclPtr<SystemChildWindow>::Create( pWindow, WB_CLIPCHILDREN );
+                                mpMediaWindow->SetPosSizePixel( Point( aAWTRect.X, aAWTRect.Y ),
+                                                           Size( aAWTRect.Width, aAWTRect.Height ) );
+                            }
+                            mpMediaWindow->SetBackground( Color( COL_BLACK ) );
                             mpMediaWindow->SetParentClipMode( PARENTCLIPMODE_NOCLIP );
-                            mpMediaWindow->EnableEraseBackground( sal_False );
-                            mpMediaWindow->EnablePaint( sal_False );
-                            mpMediaWindow->SetForwardKey( sal_True );
-                            mpMediaWindow->SetMouseTransparent( sal_True );
+                            mpMediaWindow->EnableEraseBackground( false );
+                            mpMediaWindow->EnablePaint( false );
+                            mpMediaWindow->SetForwardKey( true );
+                            mpMediaWindow->SetMouseTransparent( true );
                             mpMediaWindow->Show();
 
                             if( mxPlayer.is() )
@@ -479,7 +506,6 @@ namespace slideshow
 
                                 aAWTRect.X = aAWTRect.Y = 0;
                                 aArgs[ 1 ] = uno::makeAny( aAWTRect );
-
                                 aArgs[ 2 ] = uno::makeAny( reinterpret_cast< sal_IntPtr >( mpMediaWindow.get() ) );
 
                                 mxPlayerWindow.set( mxPlayer->createPlayerWindow( aArgs ) );
@@ -495,65 +521,8 @@ namespace slideshow
                             {
                                 //if there was no playerwindow, then clear the mpMediaWindow too
                                 //so that we can draw a placeholder instead in that space
-                                mpMediaWindow.reset();
-                            }
-                        }
-                    }
-                }
-                catch( uno::RuntimeException& )
-                {
-                    throw;
-                }
-                catch( uno::Exception& )
-                {
-                    OSL_FAIL( OUStringToOString(
-                                    comphelper::anyToString( cppu::getCaughtException() ),
-                                    RTL_TEXTENCODING_UTF8 ).getStr() );
-                }
-            }
-
-            return mxPlayerWindow.is();
-        }
-
-        // ---------------------------------------------------------------------
-
-        bool ViewMediaShape::implInitializeDXBasedPlayerWindow( const ::basegfx::B2DRectangle&   rBounds,
-                                                                const uno::Sequence< uno::Any >& rDXDeviceParams )
-        {
-            if( !mxPlayerWindow.is() )
-            {
-                try
-                {
-                    if( rDXDeviceParams.getLength() == 2 )
-                    {
-                        sal_Int64 aWNDVal=0;
-
-                        rDXDeviceParams[ 1 ] >>= aWNDVal;
-
-                        if( aWNDVal )
-                        {
-                            ::basegfx::B2DRange aTmpRange;
-                            ::canvas::tools::calcTransformedRectBounds( aTmpRange,
-                                                                        rBounds,
-                                                                        mpViewLayer->getTransformation() );
-                            const ::basegfx::B2IRange& rRangePix(
-                                ::basegfx::unotools::b2ISurroundingRangeFromB2DRange( aTmpRange ));
-
-                            if( !rRangePix.isEmpty() )
-                            {
-                                uno::Sequence< uno::Any >   aArgs( 2 );
-                                awt::Rectangle              aAWTRect( rRangePix.getMinX() + maWindowOffset.X,
-                                                                      rRangePix.getMinY() + maWindowOffset.Y,
-                                                                      rRangePix.getMaxX() - rRangePix.getMinX(),
-                                                                      rRangePix.getMaxY() - rRangePix.getMinY() );
-
-                                if( mxPlayer.is() )
-                                {
-                                    aArgs[ 0 ] = uno::makeAny( sal::static_int_cast< sal_Int32 >( aWNDVal) );
-                                    aArgs[ 1 ] = uno::makeAny( aAWTRect );
-
-                                    mxPlayerWindow.set( mxPlayer->createPlayerWindow( aArgs ) );
-                                }
+                                mpMediaWindow.disposeAndClear();
+                                mpEventHandlerParent.disposeAndClear();
                             }
                         }
                     }
