@@ -19,125 +19,119 @@
 
 #include <typelib/typedescription.h>
 #include <uno/data.h>
+#include <cppuhelper/queryinterface.hxx>
 
 #include "base.hxx"
 
+using namespace css::lang;
+using namespace css::reflection;
+using namespace css::uno;
 
 namespace stoc_corefl
 {
 
 // XInterface
-//__________________________________________________________________________________________________
+
 Any ArrayIdlClassImpl::queryInterface( const Type & rType )
-    throw(::com::sun::star::uno::RuntimeException)
+    throw(css::uno::RuntimeException, std::exception)
 {
     Any aRet( ::cppu::queryInterface( rType, static_cast< XIdlArray * >( this ) ) );
     return (aRet.hasValue() ? aRet : IdlClassImpl::queryInterface( rType ));
 }
-//__________________________________________________________________________________________________
+
 void ArrayIdlClassImpl::acquire() throw()
 {
     IdlClassImpl::acquire();
 }
-//__________________________________________________________________________________________________
+
 void ArrayIdlClassImpl::release() throw()
 {
     IdlClassImpl::release();
 }
 
 // XTypeProvider
-//__________________________________________________________________________________________________
+
 Sequence< Type > ArrayIdlClassImpl::getTypes()
-    throw (::com::sun::star::uno::RuntimeException)
+    throw (css::uno::RuntimeException, std::exception)
 {
-    static OTypeCollection * s_pTypes = 0;
+    static ::cppu::OTypeCollection * s_pTypes = 0;
     if (! s_pTypes)
     {
-        MutexGuard aGuard( getMutexAccess() );
+        ::osl::MutexGuard aGuard( getMutexAccess() );
         if (! s_pTypes)
         {
-            static OTypeCollection s_aTypes(
-                ::getCppuType( (const Reference< XIdlArray > *)0 ),
+            static ::cppu::OTypeCollection s_aTypes(
+                cppu::UnoType<XIdlArray>::get(),
                 IdlClassImpl::getTypes() );
             s_pTypes = &s_aTypes;
         }
     }
     return s_pTypes->getTypes();
 }
-//__________________________________________________________________________________________________
+
 Sequence< sal_Int8 > ArrayIdlClassImpl::getImplementationId()
-    throw (::com::sun::star::uno::RuntimeException)
+    throw (css::uno::RuntimeException, std::exception)
 {
-    static OImplementationId * s_pId = 0;
-    if (! s_pId)
-    {
-        MutexGuard aGuard( getMutexAccess() );
-        if (! s_pId)
-        {
-            static OImplementationId s_aId;
-            s_pId = &s_aId;
-        }
-    }
-    return s_pId->getImplementationId();
+    return css::uno::Sequence<sal_Int8>();
 }
 
 // XIdlArray
-//__________________________________________________________________________________________________
+
 void ArrayIdlClassImpl::realloc( Any & rArray, sal_Int32 nLen )
-    throw(::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException)
+    throw(css::lang::IllegalArgumentException, css::uno::RuntimeException, std::exception)
 {
     TypeClass eTC = rArray.getValueTypeClass();
-    if (eTC != TypeClass_SEQUENCE && eTC != TypeClass_ARRAY)
+    if (eTC != TypeClass_SEQUENCE)
     {
         throw IllegalArgumentException(
-            OUString("no sequence given!"),
+            "no sequence given!",
             (XWeak *)(OWeakObject *)this, 0 );
     }
     if (nLen < 0)
     {
         throw IllegalArgumentException(
-            OUString("illegal length given!"),
+            "illegal length given!",
             (XWeak *)(OWeakObject *)this, 1 );
     }
 
-    uno_Sequence ** ppSeq = (uno_Sequence **)rArray.getValue();
-    uno_sequence_realloc( ppSeq, (typelib_TypeDescription *)getTypeDescr(),
+    uno_Sequence ** ppSeq = const_cast<uno_Sequence **>(static_cast<uno_Sequence * const *>(rArray.getValue()));
+    uno_sequence_realloc( ppSeq, &getTypeDescr()->aBase,
                           nLen,
                           reinterpret_cast< uno_AcquireFunc >(cpp_acquire),
                           reinterpret_cast< uno_ReleaseFunc >(cpp_release) );
     rArray.pData = ppSeq;
 }
-//__________________________________________________________________________________________________
+
 sal_Int32 ArrayIdlClassImpl::getLen( const Any & rArray )
-    throw(::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::uno::RuntimeException)
+    throw(css::lang::IllegalArgumentException, css::uno::RuntimeException, std::exception)
 {
     TypeClass eTC = rArray.getValueTypeClass();
-    if (eTC != TypeClass_SEQUENCE && eTC != TypeClass_ARRAY)
+    if (eTC != TypeClass_SEQUENCE)
     {
         throw IllegalArgumentException(
-            OUString("no sequence given!"),
+            "no sequence given!",
             (XWeak *)(OWeakObject *)this, 0 );
     }
 
-    return (*(uno_Sequence **)rArray.getValue())->nElements;
+    return (*static_cast<uno_Sequence * const *>(rArray.getValue()))->nElements;
 }
-//__________________________________________________________________________________________________
+
 Any ArrayIdlClassImpl::get( const Any & rArray, sal_Int32 nIndex )
-    throw(::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::lang::ArrayIndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException)
+    throw(css::lang::IllegalArgumentException, css::lang::ArrayIndexOutOfBoundsException, css::uno::RuntimeException, std::exception)
 {
     TypeClass eTC = rArray.getValueTypeClass();
-    if (eTC != TypeClass_SEQUENCE && eTC != TypeClass_ARRAY)
+    if (eTC != TypeClass_SEQUENCE)
     {
         throw IllegalArgumentException(
-            OUString("no sequence given!"),
+            "no sequence given!",
             (XWeak *)(OWeakObject *)this, 0 );
     }
 
-    uno_Sequence * pSeq = *(uno_Sequence **)rArray.getValue();
+    uno_Sequence * pSeq = *static_cast<uno_Sequence * const *>(rArray.getValue());
     if (pSeq->nElements <= nIndex)
     {
         throw ArrayIndexOutOfBoundsException(
-            OUString("illegal index given!"),
+            "illegal index given!",
             (XWeak *)(OWeakObject *)this );
     }
 
@@ -152,29 +146,29 @@ Any ArrayIdlClassImpl::get( const Any & rArray, sal_Int32 nIndex )
     return aRet;
 }
 
-//__________________________________________________________________________________________________
+
 void ArrayIdlClassImpl::set( Any & rArray, sal_Int32 nIndex, const Any & rNewValue )
-    throw(::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::lang::ArrayIndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException)
+    throw(css::lang::IllegalArgumentException, css::lang::ArrayIndexOutOfBoundsException, css::uno::RuntimeException, std::exception)
 {
     TypeClass eTC = rArray.getValueTypeClass();
-    if (eTC != TypeClass_SEQUENCE && eTC != TypeClass_ARRAY)
+    if (eTC != TypeClass_SEQUENCE)
     {
         throw IllegalArgumentException(
-            OUString("no sequence given!"),
+            "no sequence given!",
             (XWeak *)(OWeakObject *)this, 0 );
     }
 
-    uno_Sequence * pSeq = *(uno_Sequence **)rArray.getValue();
+    uno_Sequence * pSeq = *static_cast<uno_Sequence * const *>(rArray.getValue());
     if (pSeq->nElements <= nIndex)
     {
         throw ArrayIndexOutOfBoundsException(
-            OUString("illegal index given!"),
+            "illegal index given!",
             (XWeak *)(OWeakObject *)this );
     }
 
-    uno_Sequence ** ppSeq = (uno_Sequence **)rArray.getValue();
+    uno_Sequence ** ppSeq = const_cast<uno_Sequence **>(static_cast<uno_Sequence * const *>(rArray.getValue()));
     uno_sequence_reference2One(
-        ppSeq, (typelib_TypeDescription *)getTypeDescr(),
+        ppSeq, &getTypeDescr()->aBase,
         reinterpret_cast< uno_AcquireFunc >(cpp_acquire),
         reinterpret_cast< uno_ReleaseFunc >(cpp_release) );
     rArray.pData = ppSeq;
@@ -188,31 +182,31 @@ void ArrayIdlClassImpl::set( Any & rArray, sal_Int32 nIndex, const Any & rNewVal
     {
         TYPELIB_DANGER_RELEASE( pElemTypeDescr );
         throw IllegalArgumentException(
-            OUString("sequence element is not assignable by given value!"),
+            "sequence element is not assignable by given value!",
             (XWeak *)(OWeakObject *)this, 2 );
     }
     TYPELIB_DANGER_RELEASE( pElemTypeDescr );
 }
 
 // ArrayIdlClassImpl
-//__________________________________________________________________________________________________
+
 sal_Bool ArrayIdlClassImpl::isAssignableFrom( const Reference< XIdlClass > & xType )
-    throw(::com::sun::star::uno::RuntimeException)
+    throw(css::uno::RuntimeException, std::exception)
 {
     return (xType.is() &&
             (equals( xType ) ||
              (xType->getTypeClass() == getTypeClass() && // must be sequence|array
               getComponentType()->isAssignableFrom( xType->getComponentType() ))));
 }
-//__________________________________________________________________________________________________
+
 Reference< XIdlClass > ArrayIdlClassImpl::getComponentType()
-    throw(::com::sun::star::uno::RuntimeException)
+    throw(css::uno::RuntimeException, std::exception)
 {
     return getReflection()->forType( getTypeDescr()->pType );
 }
-//__________________________________________________________________________________________________
+
 Reference< XIdlArray > ArrayIdlClassImpl::getArray()
-    throw(::com::sun::star::uno::RuntimeException)
+    throw(css::uno::RuntimeException, std::exception)
 {
     return this;
 }
