@@ -26,18 +26,18 @@
 #include <cppuhelper/typeprovider.hxx>
 #include <cppuhelper/implbase2.hxx>
 
-#include <com/sun/star/uno/DeploymentException.hpp>
 #include <com/sun/star/script/FailReason.hpp>
 #include <com/sun/star/script/XTypeConverter.hpp>
 #include <com/sun/star/script/XInvocation.hpp>
 #include <com/sun/star/script/XInvocation2.hpp>
 #include <com/sun/star/reflection/XIdlReflection.hpp>
+#include <com/sun/star/reflection/theCoreReflection.hpp>
 #include <com/sun/star/container/XNameContainer.hpp>
 #include <com/sun/star/container/XIndexContainer.hpp>
 #include <com/sun/star/container/XEnumerationAccess.hpp>
 #include <com/sun/star/beans/XExactName.hpp>
 #include <com/sun/star/beans/XMaterialHolder.hpp>
-#include <com/sun/star/beans/Introspection.hpp>
+#include <com/sun/star/beans/theIntrospection.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 #include <com/sun/star/beans/MethodConcept.hpp>
@@ -55,13 +55,13 @@
 #define SERVICENAME "com.sun.star.script.Invocation"
 #define IMPLNAME     "com.sun.star.comp.stoc.Invocation"
 
-using namespace com::sun::star::uno;
-using namespace com::sun::star::lang;
-using namespace com::sun::star::script;
-using namespace com::sun::star::reflection;
-using namespace com::sun::star::beans;
-using namespace com::sun::star::registry;
-using namespace com::sun::star::container;
+using namespace css::uno;
+using namespace css::lang;
+using namespace css::script;
+using namespace css::reflection;
+using namespace css::beans;
+using namespace css::registry;
+using namespace css::container;
 using namespace cppu;
 using namespace osl;
 
@@ -86,7 +86,7 @@ inline Reference<XIdlClass> TypeToIdlClass( const Type& rType, const Reference<
 }
 
 
-//==================================================================================================
+
 class Invocation_Impl
     : public OWeakObject
     , public XInvocation2
@@ -104,109 +104,108 @@ public:
     virtual ~Invocation_Impl();
 
     // XInterface
-    virtual Any         SAL_CALL queryInterface( const Type & aType) throw( RuntimeException );
-    virtual void        SAL_CALL acquire() throw() { OWeakObject::acquire(); }
-    virtual void        SAL_CALL release() throw() { OWeakObject::release(); }
+    virtual Any         SAL_CALL queryInterface( const Type & aType) throw( RuntimeException, std::exception ) SAL_OVERRIDE;
+    virtual void        SAL_CALL acquire() throw() SAL_OVERRIDE { OWeakObject::acquire(); }
+    virtual void        SAL_CALL release() throw() SAL_OVERRIDE { OWeakObject::release(); }
 
 
     // XTypeProvider
-    virtual Sequence< ::com::sun::star::uno::Type > SAL_CALL getTypes(  )
-       throw(RuntimeException);
+    virtual Sequence< css::uno::Type > SAL_CALL getTypes(  )
+       throw(RuntimeException, std::exception) SAL_OVERRIDE;
     virtual Sequence< sal_Int8 > SAL_CALL getImplementationId(  )
-       throw( RuntimeException);
+       throw( RuntimeException, std::exception) SAL_OVERRIDE;
 
     // Methoden von XMaterialHolder
-    virtual Any         SAL_CALL getMaterial(void) throw(RuntimeException);
-
-    // ? XTool
-    virtual void        SAL_CALL setMaterial( const Any& rMaterial );
+    virtual Any         SAL_CALL getMaterial() throw(RuntimeException, std::exception) SAL_OVERRIDE;
 
     // XInvocation
-    virtual Reference<XIntrospectionAccess> SAL_CALL getIntrospection(void) throw( RuntimeException );
+    virtual Reference<XIntrospectionAccess> SAL_CALL getIntrospection() throw( RuntimeException, std::exception ) SAL_OVERRIDE;
     virtual Any SAL_CALL invoke(const OUString& FunctionName, const Sequence< Any >& Params, Sequence< sal_Int16 >& OutParamIndex, Sequence< Any >& OutParam)
-        throw( IllegalArgumentException, CannotConvertException, InvocationTargetException, RuntimeException );
+        throw( IllegalArgumentException, CannotConvertException, InvocationTargetException, RuntimeException, std::exception ) SAL_OVERRIDE;
     virtual void SAL_CALL setValue(const OUString& PropertyName, const Any& Value)
-        throw( UnknownPropertyException, CannotConvertException, InvocationTargetException, RuntimeException );
+        throw( UnknownPropertyException, CannotConvertException, InvocationTargetException, RuntimeException, std::exception ) SAL_OVERRIDE;
     virtual Any SAL_CALL getValue(const OUString& PropertyName)
-        throw( UnknownPropertyException, RuntimeException );
-    virtual sal_Bool SAL_CALL hasMethod(const OUString& Name) throw( RuntimeException );
-    virtual sal_Bool SAL_CALL hasProperty(const OUString& Name) throw( RuntimeException );
+        throw( UnknownPropertyException, RuntimeException, std::exception ) SAL_OVERRIDE;
+    virtual sal_Bool SAL_CALL hasMethod(const OUString& Name) throw( RuntimeException, std::exception ) SAL_OVERRIDE;
+    virtual sal_Bool SAL_CALL hasProperty(const OUString& Name) throw( RuntimeException, std::exception ) SAL_OVERRIDE;
 
     // XInvocation2
     virtual Sequence< OUString > SAL_CALL getMemberNames(  )
-        throw( RuntimeException );
+        throw( RuntimeException, std::exception ) SAL_OVERRIDE;
     virtual Sequence< InvocationInfo > SAL_CALL getInfo(  )
-        throw( RuntimeException );
+        throw( RuntimeException, std::exception ) SAL_OVERRIDE;
     virtual InvocationInfo SAL_CALL getInfoForName( const OUString& aName, sal_Bool bExact )
-        throw( IllegalArgumentException, RuntimeException );
+        throw( IllegalArgumentException, RuntimeException, std::exception ) SAL_OVERRIDE;
 
     // All Access and Container methods are not thread save
     // XElementAccess
-    virtual Type SAL_CALL getElementType(void) throw( RuntimeException )
+    virtual Type SAL_CALL getElementType() throw( RuntimeException, std::exception ) SAL_OVERRIDE
         { return _xElementAccess->getElementType(); }
 
-    virtual sal_Bool SAL_CALL hasElements(void) throw( RuntimeException )
+    virtual sal_Bool SAL_CALL hasElements() throw( RuntimeException, std::exception ) SAL_OVERRIDE
         { return _xElementAccess->hasElements(); }
 
     // XNameContainer
     virtual void SAL_CALL insertByName( const OUString& Name, const Any& Element )
-        throw( IllegalArgumentException, ElementExistException, WrappedTargetException, RuntimeException )
+        throw( IllegalArgumentException, ElementExistException, WrappedTargetException, RuntimeException, std::exception ) SAL_OVERRIDE
         { _xNameContainer->insertByName( Name, Element ); }
 
     virtual void SAL_CALL replaceByName( const OUString& Name, const Any& Element )
-        throw( IllegalArgumentException, NoSuchElementException, WrappedTargetException, RuntimeException )
+        throw( IllegalArgumentException, NoSuchElementException, WrappedTargetException, RuntimeException, std::exception ) SAL_OVERRIDE
         { _xNameContainer->replaceByName( Name, Element ); }
 
     virtual void SAL_CALL removeByName( const OUString& Name )
-        throw( NoSuchElementException, WrappedTargetException, RuntimeException )
+        throw( NoSuchElementException, WrappedTargetException, RuntimeException, std::exception ) SAL_OVERRIDE
         { _xNameContainer->removeByName( Name ); }
 
     // XNameAccess
     virtual Any SAL_CALL getByName( const OUString& Name )
-        throw( NoSuchElementException, WrappedTargetException, RuntimeException )
+        throw( NoSuchElementException, WrappedTargetException, RuntimeException, std::exception ) SAL_OVERRIDE
         { return _xNameAccess->getByName( Name ); }
 
-    virtual Sequence<OUString> SAL_CALL getElementNames(void) throw( RuntimeException )
+    virtual Sequence<OUString> SAL_CALL getElementNames() throw( RuntimeException, std::exception ) SAL_OVERRIDE
         { return _xNameAccess->getElementNames(); }
 
-    virtual sal_Bool SAL_CALL hasByName( const OUString& Name ) throw( RuntimeException )
+    virtual sal_Bool SAL_CALL hasByName( const OUString& Name ) throw( RuntimeException, std::exception ) SAL_OVERRIDE
         { return _xNameAccess->hasByName( Name ); }
 
     // XIndexContainer
     virtual void SAL_CALL insertByIndex( sal_Int32 Index, const Any& Element )
-        throw( IllegalArgumentException, IndexOutOfBoundsException, WrappedTargetException, RuntimeException )
+        throw( IllegalArgumentException, IndexOutOfBoundsException, WrappedTargetException, RuntimeException, std::exception ) SAL_OVERRIDE
         { _xIndexContainer->insertByIndex( Index, Element ); }
 
     virtual void SAL_CALL replaceByIndex( sal_Int32 Index, const Any& Element )
-        throw( IllegalArgumentException, IndexOutOfBoundsException, WrappedTargetException, RuntimeException )
+        throw( IllegalArgumentException, IndexOutOfBoundsException, WrappedTargetException, RuntimeException, std::exception ) SAL_OVERRIDE
         { _xIndexContainer->replaceByIndex( Index, Element ); }
 
     virtual void SAL_CALL removeByIndex( sal_Int32 Index )
-        throw( IndexOutOfBoundsException, WrappedTargetException, RuntimeException )
+        throw( IndexOutOfBoundsException, WrappedTargetException, RuntimeException, std::exception ) SAL_OVERRIDE
         { _xIndexContainer->removeByIndex( Index ); }
 
     // XIndexAccess
-    virtual sal_Int32 SAL_CALL getCount(void) throw( RuntimeException )
+    virtual sal_Int32 SAL_CALL getCount() throw( RuntimeException, std::exception ) SAL_OVERRIDE
         { return _xIndexAccess->getCount(); }
 
     virtual Any SAL_CALL getByIndex( sal_Int32 Index )
-        throw( IndexOutOfBoundsException, WrappedTargetException, RuntimeException )
+        throw( IndexOutOfBoundsException, WrappedTargetException, RuntimeException, std::exception ) SAL_OVERRIDE
         { return _xIndexAccess->getByIndex( Index ); }
 
     // XEnumerationAccess
-    virtual Reference<XEnumeration> SAL_CALL createEnumeration(void) throw( RuntimeException )
+    virtual Reference<XEnumeration> SAL_CALL createEnumeration() throw( RuntimeException, std::exception ) SAL_OVERRIDE
         { return _xEnumerationAccess->createEnumeration(); }
 
     // XExactName
-    virtual OUString SAL_CALL getExactName( const OUString& rApproximateName ) throw( RuntimeException );
+    virtual OUString SAL_CALL getExactName( const OUString& rApproximateName ) throw( RuntimeException, std::exception ) SAL_OVERRIDE;
+
 
 
-    //=====================================================================================================
 private:
+    void setMaterial( const Any& rMaterial );
+
     void getInfoSequenceImpl( Sequence< OUString >* pStringSeq, Sequence< InvocationInfo >* pInfoSeq );
     void fillInfoForNameAccess( InvocationInfo& rInfo, const OUString& aName );
-    void fillInfoForProperty( InvocationInfo& rInfo, const Property& rProp );
-    void fillInfoForMethod( InvocationInfo& rInfo, const Reference< XIdlMethod > xMethod );
+    static void fillInfoForProperty( InvocationInfo& rInfo, const Property& rProp );
+    static void fillInfoForMethod( InvocationInfo& rInfo, const Reference< XIdlMethod > xMethod );
 
     Reference<XTypeConverter>           xTypeConverter;
     Reference<XIntrospection>           xIntrospection;
@@ -227,16 +226,16 @@ private:
     Reference<XEnumerationAccess>       _xEnumerationAccess;
     Reference<XElementAccess>           _xElementAccess;
 
-    //
+
     Reference<XExactName>               _xENDirect, _xENIntrospection, _xENNameAccess;
 };
 
 
-//==================================================================================================
-//==================================================================================================
-//==================================================================================================
 
-//--------------------------------------------------------------------------------------------------
+
+
+
+
 Invocation_Impl::Invocation_Impl
 (
     const Any & rAdapted,
@@ -253,13 +252,13 @@ Invocation_Impl::Invocation_Impl
 
 Invocation_Impl::~Invocation_Impl() {}
 
-//##################################################################################################
+
 //### INTERFACE IMPLEMENTATIONS ####################################################################
-//##################################################################################################
+
 
 
 Any SAL_CALL Invocation_Impl::queryInterface( const Type & aType )
-    throw( RuntimeException )
+    throw( RuntimeException, std::exception )
 {
     // PropertySet-Implementation
     Any a = ::cppu::queryInterface( aType,
@@ -271,7 +270,7 @@ Any SAL_CALL Invocation_Impl::queryInterface( const Type & aType )
         return a;
     }
 
-    if( aType  == getCppuType( (Reference<XExactName>*) NULL ) )
+    if( aType  == cppu::UnoType<XExactName>::get())
     {
         // Ivocation does not support XExactName, if direct object supports
         // XInvocation, but not XExactName.
@@ -281,32 +280,32 @@ Any SAL_CALL Invocation_Impl::queryInterface( const Type & aType )
             return makeAny( Reference< XExactName >( (static_cast< XExactName* >(this)) ) );
         }
     }
-    else if ( aType == getCppuType( (Reference<XNameContainer>*) NULL ) )
+    else if ( aType == cppu::UnoType<XNameContainer>::get())
     {
         if( _xNameContainer.is() )
             return makeAny( Reference< XNameContainer >( (static_cast< XNameContainer* >(this)) ) );
     }
-    else if ( aType == getCppuType( (Reference<XNameAccess>*) NULL ) )
+    else if ( aType == cppu::UnoType<XNameAccess>::get())
     {
         if( _xNameAccess.is() )
             return makeAny( Reference< XNameAccess >( (static_cast< XNameAccess* >(this)) ) );
     }
-    else if ( aType == getCppuType( (Reference<XIndexContainer>*) NULL ) )
+    else if ( aType == cppu::UnoType<XIndexContainer>::get())
     {
         if (_xIndexContainer.is())
             return makeAny( Reference< XIndexContainer >( (static_cast< XIndexContainer* >(this)) ) );
     }
-    else if ( aType == getCppuType( (Reference<XIndexAccess>*) NULL ) )
+    else if ( aType == cppu::UnoType<XIndexAccess>::get())
     {
         if (_xIndexAccess.is())
             return makeAny( Reference< XIndexAccess >( (static_cast< XIndexAccess* >(this)) ) );
     }
-    else if ( aType == getCppuType( (Reference<XEnumerationAccess>*) NULL ) )
+    else if ( aType == cppu::UnoType<XEnumerationAccess>::get())
     {
         if (_xEnumerationAccess.is())
             return makeAny( Reference< XEnumerationAccess >( (static_cast< XEnumerationAccess* >(this)) ) );
     }
-    else if ( aType == getCppuType( (Reference<XElementAccess>*) NULL ) )
+    else if ( aType == cppu::UnoType<XElementAccess>::get())
     {
         if (_xElementAccess.is())
         {
@@ -314,7 +313,7 @@ Any SAL_CALL Invocation_Impl::queryInterface( const Type & aType )
                 (static_cast< XElementAccess* >((static_cast< XNameContainer* >(this))) ) ) );
         }
     }
-    else if ( aType == getCppuType( (Reference<XInvocation2>*) NULL ) )
+    else if ( aType == cppu::UnoType<XInvocation2>::get())
     {
         // Invocation does not support XInvocation2, if direct object supports
         // XInvocation, but not XInvocation2.
@@ -329,8 +328,8 @@ Any SAL_CALL Invocation_Impl::queryInterface( const Type & aType )
 }
 
 
-//--------------------------------------------------------------------------------------------------
-Any Invocation_Impl::getMaterial(void) throw(RuntimeException)
+
+Any Invocation_Impl::getMaterial() throw(RuntimeException, std::exception)
 {
     // AB, 12.2.1999  Sicherstellen, dass das Material wenn moeglich
     // aus der direkten Invocation bzw. von der Introspection geholt
@@ -353,14 +352,14 @@ Any Invocation_Impl::getMaterial(void) throw(RuntimeException)
     return _aMaterial;
 }
 
-//--------------------------------------------------------------------------------------------------
+
 void Invocation_Impl::setMaterial( const Any& rMaterial )
 {
     // set the material first and only once
     Reference<XInterface> xObj;
 
     if (rMaterial.getValueType().getTypeClass() == TypeClass_INTERFACE)
-        xObj = *(Reference<XInterface>*)rMaterial.getValue();
+        xObj = *static_cast<Reference<XInterface> const *>(rMaterial.getValue());
     _aMaterial = rMaterial;
 
     // Ersteinmal alles ausserhalb des guards machen
@@ -393,31 +392,31 @@ void Invocation_Impl::setMaterial( const Any& rMaterial )
 
                 _xElementAccess = Reference<XElementAccess>::query(
                       _xIntrospectionAccess->queryAdapter(
-                                 getCppuType( (Reference<XElementAccess>*) NULL ) ) );
+                                 cppu::UnoType<XElementAccess>::get()) );
 
                 _xEnumerationAccess = Reference<XEnumerationAccess>::query(
                            _xIntrospectionAccess->queryAdapter(
-                                getCppuType( (Reference<XEnumerationAccess>*) NULL )) );
+                                cppu::UnoType<XEnumerationAccess>::get()) );
 
                 _xIndexAccess = Reference<XIndexAccess>::query(
                        _xIntrospectionAccess->queryAdapter(
-                                getCppuType( (Reference<XIndexAccess>*) NULL ) ) );
+                                cppu::UnoType<XIndexAccess>::get()) );
 
                 _xIndexContainer = Reference<XIndexContainer>::query(
                      _xIntrospectionAccess->queryAdapter(
-                                getCppuType( (Reference<XIndexContainer>*) NULL ) ) );
+                                cppu::UnoType<XIndexContainer>::get()) );
 
                 _xNameAccess = Reference<XNameAccess>::query(
                      _xIntrospectionAccess->queryAdapter(
-                                getCppuType( (Reference<XNameAccess>*) NULL ) ) );
+                                cppu::UnoType<XNameAccess>::get()) );
 
                 _xNameContainer = Reference<XNameContainer>::query(
                            _xIntrospectionAccess->queryAdapter(
-                               getCppuType( (Reference<XNameContainer>*) NULL ) ) );
+                               cppu::UnoType<XNameContainer>::get()) );
 
                 _xPropertySet = Reference<XPropertySet>::query(
                            _xIntrospectionAccess->queryAdapter(
-                               getCppuType( (Reference<XPropertySet>*) NULL )) );
+                               cppu::UnoType<XPropertySet>::get()) );
 
                 _xENIntrospection = Reference<XExactName>::query( _xIntrospectionAccess );
                 if (_xNameAccess.is())
@@ -441,9 +440,9 @@ void Invocation_Impl::setMaterial( const Any& rMaterial )
     }
 }
 
-//--------------------------------------------------------------------------------------------------
+
 OUString Invocation_Impl::getExactName( const OUString& rApproximateName )
-    throw( RuntimeException )
+    throw( RuntimeException, std::exception )
 {
     if (_xENDirect.is())
         return _xENDirect->getExactName( rApproximateName );
@@ -456,9 +455,9 @@ OUString Invocation_Impl::getExactName( const OUString& rApproximateName )
     return aRet;
 }
 
-//--------------------------------------------------------------------------------------------------
-Reference<XIntrospectionAccess> Invocation_Impl::getIntrospection(void)
-    throw( RuntimeException )
+
+Reference<XIntrospectionAccess> Invocation_Impl::getIntrospection()
+    throw( RuntimeException, std::exception )
 {
     if( _xDirect.is() )
         return _xDirect->getIntrospection();
@@ -466,9 +465,9 @@ Reference<XIntrospectionAccess> Invocation_Impl::getIntrospection(void)
         return _xIntrospectionAccess;
 }
 
-//--------------------------------------------------------------------------------------------------
+
 sal_Bool Invocation_Impl::hasMethod( const OUString& Name )
-    throw( RuntimeException )
+    throw( RuntimeException, std::exception )
 {
     if (_xDirect.is())
         return _xDirect->hasMethod( Name );
@@ -477,9 +476,9 @@ sal_Bool Invocation_Impl::hasMethod( const OUString& Name )
     return sal_False;
 }
 
-//--------------------------------------------------------------------------------------------------
+
 sal_Bool Invocation_Impl::hasProperty( const OUString& Name )
-    throw( RuntimeException )
+    throw( RuntimeException, std::exception )
 {
     if (_xDirect.is())
         return _xDirect->hasProperty( Name );
@@ -493,9 +492,9 @@ sal_Bool Invocation_Impl::hasProperty( const OUString& Name )
     return sal_False;
 }
 
-//--------------------------------------------------------------------------------------------------
+
 Any Invocation_Impl::getValue( const OUString& PropertyName )
-    throw( UnknownPropertyException, RuntimeException )
+    throw( UnknownPropertyException, RuntimeException, std::exception )
 {
     if (_xDirect.is())
         return _xDirect->getValue( PropertyName );
@@ -524,14 +523,12 @@ Any Invocation_Impl::getValue( const OUString& PropertyName )
     {
     }
 
-    throw UnknownPropertyException(
-        OUString("cannot get value ") + PropertyName,
-        Reference< XInterface >() );
+    throw UnknownPropertyException( "cannot get value " + PropertyName );
 }
 
-//--------------------------------------------------------------------------------------------------
+
 void Invocation_Impl::setValue( const OUString& PropertyName, const Any& Value )
-    throw( UnknownPropertyException, CannotConvertException, InvocationTargetException, RuntimeException )
+    throw( UnknownPropertyException, CannotConvertException, InvocationTargetException, RuntimeException, std::exception )
 {
     if (_xDirect.is())
         _xDirect->setValue( PropertyName, Value );
@@ -553,9 +550,7 @@ void Invocation_Impl::setValue( const OUString& PropertyName, const Any& Value )
                     _xPropertySet->setPropertyValue(
                         PropertyName, xTypeConverter->convertTo( Value, aProp.Type ) );
                 else
-                    throw RuntimeException(
-                        OUString("no type converter service!"),
-                        Reference< XInterface >() );
+                    throw RuntimeException( "no type converter service!" );
             }
             // NameContainer
             else if( _xNameContainer.is() )
@@ -568,9 +563,7 @@ void Invocation_Impl::setValue( const OUString& PropertyName, const Any& Value )
                 else if( xTypeConverter.is() )
                     aConv = xTypeConverter->convertTo( Value, _xNameContainer->getElementType() );
                 else
-                    throw RuntimeException(
-                        OUString("no type converter service!"),
-                        Reference< XInterface >() );
+                    throw RuntimeException( "no type converter service!" );
 
                 // bei Vorhandensein ersetzen, ansonsten einfuegen
                 if (_xNameContainer->hasByName( PropertyName ))
@@ -579,9 +572,7 @@ void Invocation_Impl::setValue( const OUString& PropertyName, const Any& Value )
                     _xNameContainer->insertByName( PropertyName, aConv );
             }
             else
-                throw UnknownPropertyException(
-                    OUString("no introspection nor name container!"),
-                    Reference< XInterface >() );
+                throw UnknownPropertyException( "no introspection nor name container!" );
         }
         catch (UnknownPropertyException &)
         {
@@ -602,16 +593,16 @@ void Invocation_Impl::setValue( const OUString& PropertyName, const Any& Value )
         catch (const Exception & exc)
         {
             throw InvocationTargetException(
-                OUString( "exception occurred in setValue(): " ) +
-                exc.Message, Reference< XInterface >(), makeAny( exc /* though sliced */ ) );
+                "exception occurred in setValue(): " + exc.Message,
+                Reference< XInterface >(), makeAny( exc /* though sliced */ ) );
         }
     }
 }
 
-//--------------------------------------------------------------------------------------------------
+
 Any Invocation_Impl::invoke( const OUString& FunctionName, const Sequence<Any>& InParams,
                                 Sequence<sal_Int16>& OutIndices, Sequence<Any>& OutParams )
-    throw( IllegalArgumentException, CannotConvertException, InvocationTargetException, RuntimeException )
+    throw( IllegalArgumentException, CannotConvertException, InvocationTargetException, RuntimeException, std::exception )
 {
     if (_xDirect.is())
         return _xDirect->invoke( FunctionName, InParams, OutIndices, OutParams );
@@ -629,7 +620,7 @@ Any Invocation_Impl::invoke( const OUString& FunctionName, const Sequence<Any>&
         if (nFParamsLen != InParams.getLength())
         {
             throw IllegalArgumentException(
-                OUString("incorrect number of parameters passed invoking function ") + FunctionName,
+                "incorrect number of parameters passed invoking function " + FunctionName,
                 (OWeakObject *) this, (sal_Int16) 1 );
         }
 
@@ -712,7 +703,7 @@ Any Invocation_Impl::invoke( const OUString& FunctionName, const Sequence<Any>&
     throw aExc;
 }
 
-//--------------------------------------------------------------------------------------------------
+
 
 // Struct to optimize sorting
 struct MemberItem
@@ -846,7 +837,7 @@ void Invocation_Impl::getInfoSequenceImpl
 
 // XInvocation2
 Sequence< OUString > SAL_CALL Invocation_Impl::getMemberNames(  )
-    throw( RuntimeException )
+    throw( RuntimeException, std::exception )
 {
     if( _xDirect2.is() )
     {
@@ -858,7 +849,7 @@ Sequence< OUString > SAL_CALL Invocation_Impl::getMemberNames(  )
 }
 
 Sequence< InvocationInfo > SAL_CALL Invocation_Impl::getInfo(  )
-    throw( RuntimeException )
+    throw( RuntimeException, std::exception )
 {
     if( _xDirect2.is() )
     {
@@ -870,7 +861,7 @@ Sequence< InvocationInfo > SAL_CALL Invocation_Impl::getInfo(  )
 }
 
 InvocationInfo SAL_CALL Invocation_Impl::getInfoForName( const OUString& aName, sal_Bool bExact )
-    throw( IllegalArgumentException, RuntimeException )
+    throw( IllegalArgumentException, RuntimeException, std::exception )
 {
     if( _xDirect2.is() )
     {
@@ -982,7 +973,7 @@ void Invocation_Impl::fillInfoForMethod
 
 
 // XTypeProvider
-Sequence< Type > SAL_CALL Invocation_Impl::getTypes(void) throw( RuntimeException )
+Sequence< Type > SAL_CALL Invocation_Impl::getTypes() throw( RuntimeException, std::exception )
 {
     static Sequence< Type > const * s_pTypes = 0;
     if (! s_pTypes)
@@ -991,48 +982,48 @@ Sequence< Type > SAL_CALL Invocation_Impl::getTypes(void) throw( RuntimeExceptio
         Type * pTypes = types.getArray();
         sal_Int32 n = 0;
 
-        pTypes[ n++ ] = ::getCppuType( (Reference< XTypeProvider > const *)0 );
-        pTypes[ n++ ] = ::getCppuType( (Reference< XWeak > const *)0 );
-        pTypes[ n++ ] = ::getCppuType( (Reference< XInvocation > const *)0 );
-        pTypes[ n++ ] = ::getCppuType( (Reference< XMaterialHolder > const *)0 );
+        pTypes[ n++ ] = cppu::UnoType<XTypeProvider>::get();
+        pTypes[ n++ ] = cppu::UnoType<XWeak>::get();
+        pTypes[ n++ ] = cppu::UnoType<XInvocation>::get();
+        pTypes[ n++ ] = cppu::UnoType<XMaterialHolder>::get();
 
         // Ivocation does not support XExactName, if direct object supports
         // XInvocation, but not XExactName.
         if ((_xDirect.is() && _xENDirect.is()) ||
             (!_xDirect.is() && (_xENIntrospection.is() || _xENNameAccess.is())))
         {
-            pTypes[ n++ ] = ::getCppuType( (Reference< XExactName > const *)0 );
+            pTypes[ n++ ] = cppu::UnoType<XExactName>::get();
         }
         if( _xNameContainer.is() )
         {
-            pTypes[ n++ ] = ::getCppuType( (Reference< XNameContainer > const *)0 );
+            pTypes[ n++ ] = cppu::UnoType<XNameContainer>::get();
         }
         if( _xNameAccess.is() )
         {
-            pTypes[ n++ ] = ::getCppuType( (Reference< XNameAccess > const *)0 );
+            pTypes[ n++ ] = cppu::UnoType<XNameAccess>::get();
         }
         if (_xIndexContainer.is())
         {
-            pTypes[ n++ ] = ::getCppuType( (Reference< XIndexContainer > const *)0 );
+            pTypes[ n++ ] = cppu::UnoType<XIndexContainer>::get();
         }
         if (_xIndexAccess.is())
         {
-            pTypes[ n++ ] = ::getCppuType( (Reference< XIndexAccess > const *)0 );
+            pTypes[ n++ ] = cppu::UnoType<XIndexAccess>::get();
         }
         if (_xEnumerationAccess.is())
         {
-            pTypes[ n++ ] = ::getCppuType( (Reference< XEnumerationAccess > const *)0 );
+            pTypes[ n++ ] = cppu::UnoType<XEnumerationAccess>::get();
         }
         if (_xElementAccess.is())
         {
-            pTypes[ n++ ] = ::getCppuType( (Reference< XElementAccess > const *)0 );
+            pTypes[ n++ ] = cppu::UnoType<XElementAccess>::get();
         }
         // Invocation does not support XInvocation2, if direct object supports
         // XInvocation, but not XInvocation2.
         if ( ( _xDirect.is() && _xDirect2.is()) ||
              (!_xDirect.is() && _xIntrospectionAccess.is() ) )
         {
-            pTypes[ n++ ] = ::getCppuType( (Reference< XInvocation2 > const *)0 );
+            pTypes[ n++ ] = cppu::UnoType<XInvocation2>::get();
         }
 
         types.realloc( n );
@@ -1048,24 +1039,14 @@ Sequence< Type > SAL_CALL Invocation_Impl::getTypes(void) throw( RuntimeExceptio
     return *s_pTypes;
 }
 
-Sequence< sal_Int8 > SAL_CALL Invocation_Impl::getImplementationId(  ) throw( RuntimeException)
+Sequence< sal_Int8 > SAL_CALL Invocation_Impl::getImplementationId(  ) throw( RuntimeException, std::exception)
 {
-    static OImplementationId *pId = 0;
-    if( ! pId )
-    {
-        MutexGuard guard( Mutex::getGlobalMutex() );
-        if( ! pId )
-        {
-            static OImplementationId id( sal_False );
-            pId = &id;
-        }
-    }
-    return pId->getImplementationId();
+    return css::uno::Sequence<sal_Int8>();
 }
 
-//==================================================================================================
-//==================================================================================================
-//==================================================================================================
+
+
+
 class InvocationService
     : public WeakImplHelper2< XSingleServiceFactory, XServiceInfo >
 {
@@ -1074,14 +1055,14 @@ public:
     virtual ~InvocationService();
 
     // XServiceInfo
-    OUString                    SAL_CALL getImplementationName() throw( RuntimeException );
-    sal_Bool                        SAL_CALL supportsService(const OUString& ServiceName) throw( RuntimeException );
-    Sequence< OUString >        SAL_CALL getSupportedServiceNames(void) throw( RuntimeException );
+    OUString                    SAL_CALL getImplementationName() throw( RuntimeException, std::exception ) SAL_OVERRIDE;
+    sal_Bool                        SAL_CALL supportsService(const OUString& ServiceName) throw( RuntimeException, std::exception ) SAL_OVERRIDE;
+    Sequence< OUString >        SAL_CALL getSupportedServiceNames() throw( RuntimeException, std::exception ) SAL_OVERRIDE;
 
     // XSingleServiceFactory
-    Reference<XInterface>       SAL_CALL createInstance(void) throw( Exception, RuntimeException );
+    Reference<XInterface>       SAL_CALL createInstance() throw( Exception, RuntimeException, std::exception ) SAL_OVERRIDE;
     Reference<XInterface>       SAL_CALL createInstanceWithArguments(
-        const Sequence<Any>& rArguments ) throw( Exception, RuntimeException );
+        const Sequence<Any>& rArguments ) throw( Exception, RuntimeException, std::exception ) SAL_OVERRIDE;
 private:
     Reference<XComponentContext> mxCtx;
     Reference<XMultiComponentFactory> mxSMgr;
@@ -1093,60 +1074,46 @@ private:
 InvocationService::InvocationService( const Reference<XComponentContext> & xCtx )
     : mxCtx( xCtx )
     , mxSMgr( xCtx->getServiceManager() )
+    , xCoreReflection( css::reflection::theCoreReflection::get(mxCtx) )
 {
     xTypeConverter = Reference<XTypeConverter>(
         mxSMgr->createInstanceWithContext(
             OUString("com.sun.star.script.Converter"),
             xCtx ),
         UNO_QUERY );
-    xIntrospection = Introspection::create(xCtx);
-    mxCtx->getValueByName(
-        OUString("/singletons/com.sun.star.reflection.theCoreReflection") )
-                >>= xCoreReflection;
-    OSL_ENSURE( xCoreReflection.is(), "### CoreReflection singleton not accessible!?" );
-    if (! xCoreReflection.is())
-    {
-        throw DeploymentException(
-            OUString("/singletons/com.sun.star.reflection.theCoreReflection singleton not accessible"),
-            Reference< XInterface >() );
-    }
-//         xCoreReflection = Reference<XIdlReflection>(
-//      mxSMgr->createInstanceWithContext(
-//          OUString("com.sun.star.reflection.CoreReflection"),
-//          xCtx),
-//      UNO_QUERY);
+    xIntrospection = theIntrospection::get(xCtx);
 }
 
 InvocationService::~InvocationService() {}
 
 // XServiceInfo
-OUString InvocationService::getImplementationName() throw( RuntimeException )
+OUString InvocationService::getImplementationName() throw( RuntimeException, std::exception )
 {
     return inv_getImplementationName();
 }
 
 // XServiceInfo
-sal_Bool InvocationService::supportsService(const OUString& ServiceName) throw( RuntimeException )
+sal_Bool InvocationService::supportsService(const OUString& ServiceName) throw( RuntimeException, std::exception )
 {
     return cppu::supportsService(this, ServiceName);
 }
 
 // XServiceInfo
-Sequence< OUString > InvocationService::getSupportedServiceNames(void) throw( RuntimeException )
+Sequence< OUString > InvocationService::getSupportedServiceNames() throw( RuntimeException, std::exception )
 {
     return inv_getSupportedServiceNames();
 }
 
-//--------------------------------------------------------------------------------------------------
-Reference<XInterface> InvocationService::createInstance(void) throw( Exception, RuntimeException )
+
+Reference<XInterface> InvocationService::createInstance() throw( Exception, RuntimeException, std::exception )
 {
     //TODO:throw( Exception("no default construction of invocation adapter possible!", *this) );
     return Reference<XInterface>(); // dummy
 }
 
-//--------------------------------------------------------------------------------------------------
+
 Reference<XInterface> InvocationService::createInstanceWithArguments(
-    const Sequence<Any>& rArguments ) throw( Exception, RuntimeException )
+    const Sequence<Any>& rArguments ) throw( Exception, RuntimeException, std::exception )
 {
     if (rArguments.getLength() == 1)
     {
@@ -1162,7 +1129,7 @@ Reference<XInterface> InvocationService::createInstanceWithArguments(
 }
 
 
-//*************************************************************************
+
 Reference<XInterface> SAL_CALL InvocationService_CreateInstance( const Reference<XComponentContext> & xCtx )
     throw( RuntimeException )
 {
