@@ -17,9 +17,13 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <svl/style.hxx>
+
 #include <com/sun/star/lang/XComponent.hpp>
 
+#include <sal/log.hxx>
 #include <tools/tenccvt.hxx>
+#include <osl/diagnose.h>
 #include <comphelper/processfactory.hxx>
 #include <unotools/intlwrapper.hxx>
 #include <svl/smplhint.hxx>
@@ -28,13 +32,10 @@
 #include <svl/itempool.hxx>
 #include <svl/IndexedStyleSheets.hxx>
 #include <svl/itemiter.hxx>
-#include <svl/style.hxx>
 #include <unotools/syslocale.hxx>
 #include <algorithm>
 #include <comphelper/servicehelper.hxx>
 
-#include <boost/numeric/conversion/cast.hpp>
-
 #include <string.h>
 
 #ifdef DBG_UTIL
@@ -44,7 +45,10 @@ public:
     DbgStyleSheetReferences() : mnStyles(0), mnPools(0) {}
     ~DbgStyleSheetReferences()
     {
-        OSL_TRACE("DbgStyleSheetReferences\nSfxStyleSheetBase left %ld\nSfxStyleSheetBasePool left %ld", mnStyles, mnPools );
+        SAL_WARN_IF(
+            mnStyles != 0 || mnPools != 0, "svl.items",
+            "SfxStyleSheetBase left " << mnStyles
+                << "; SfxStyleSheetBasePool left " << mnPools);
     }
 
     sal_uInt32 mnStyles;
@@ -58,15 +62,11 @@ TYPEINIT0(SfxStyleSheetBase)
 
 TYPEINIT3(SfxStyleSheet, SfxStyleSheetBase, SfxListener, SfxBroadcaster)
 
-TYPEINIT1(SfxStyleSheetHint, SfxHint);
-TYPEINIT1(SfxStyleSheetHintExtended, SfxStyleSheetHint);
-TYPEINIT1(SfxStyleSheetPoolHint, SfxHint);
-
 SfxStyleSheetHintExtended::SfxStyleSheetHintExtended
 (
-    sal_uInt16          nAction,        // SFX_STYLESHEET_... (s.o.)
+    sal_uInt16          nAction,        // SfxStyleSheetHintId::... (see above)
     const OUString&     rOldName,
-    SfxStyleSheetBase&  rStyleSheet     // geh"ort weiterhin dem Aufrufer
+    SfxStyleSheetBase&  rStyleSheet     // Remains with the caller
 )
 :   SfxStyleSheetHint( nAction, rStyleSheet ),
     aName( rOldName )
@@ -75,8 +75,8 @@ SfxStyleSheetHintExtended::SfxStyleSheetHintExtended
 
 SfxStyleSheetHint::SfxStyleSheetHint
 (
-    sal_uInt16              nAction,        // SFX_STYLESHEET_... (s.o.)
-    SfxStyleSheetBase&  rStyleSheet     // geh"ort weiterhin dem Aufrufer
+    sal_uInt16              nAction,    // SfxStyleSheetHintId::... (see above)
+    SfxStyleSheetBase&  rStyleSheet     // Remains with the caller
 )
 :   pStyleSh( &rStyleSheet ),
     nHint( nAction )
@@ -85,8 +85,22 @@ SfxStyleSheetHint::SfxStyleSheetHint
 
 class SfxStyleSheetBasePool_Impl
 {
+private:
+    SfxStyleSheetBasePool_Impl(const SfxStyleSheetBasePool_Impl&) SAL_DELETED_FUNCTION;
+    SfxStyleSheetBasePool_Impl& operator=(const SfxStyleSheetBasePool_Impl&) SAL_DELETED_FUNCTION;
 public:
     SfxStyleSheetIteratorPtr pIter;
+
+    /** This member holds the indexed style sheets.
+     *
+     * @internal
+     * This member is private and not protected in order to have more control which style sheets are added
+     * where. Ideally, all calls which add/remove/change style sheets are done in the base class.
+     */
+    std::shared_ptr<svl::IndexedStyleSheets> mxIndexedStyleSheets;
+
+    SfxStyleSheetBasePool_Impl() :
+        mxIndexedStyleSheets(new svl::IndexedStyleSheets) {}
 };
 
 
@@ -142,13 +156,7 @@ SfxStyleSheetBase::~SfxStyleSheetBase()
     }
 }
 
-sal_uInt16 SfxStyleSheetBase::GetVersion() const
-{
-    return 0x0000;
-}
-
 // Change name
-
 const OUString& SfxStyleSheetBase::GetName() const
 {
     return aName;
@@ -181,7 +189,7 @@ bool SfxStyleSheetBase::SetName(const OUString& rName, bool bReIndexNow)
             pPool->Reindex();
         pPool->SetSearchMask(eTmpFam, nTmpMask);
         pPool->Broadcast( SfxStyleSheetHintExtended(
-            SFX_STYLESHEET_MODIFIED, aOldName, *this ) );
+            SfxStyleSheetHintId::MODIFIED, aOldName, *this ) );
     }
     return true;
 }
@@ -198,13 +206,7 @@ OUString SfxStyleSheetBase::GetDisplayName() const
     }
 }
 
-void SfxStyleSheetBase::SetDisplayName( const OUString& rDisplayName )
-{
-    maDisplayName = rDisplayName;
-}
-
 // Change Parent
-
 const OUString& SfxStyleSheetBase::GetParent() const
 {
     return aParent;
@@ -235,18 +237,19 @@ bool SfxStyleSheetBase::SetParent( const OUString& rName )
         }
         aParent = rName;
     }
-    pPool->Broadcast( SfxStyleSheetHint( SFX_STYLESHEET_MODIFIED, *this ) );
+    pPool->Broadcast( SfxStyleSheetHint( SfxStyleSheetHintId::MODIFIED, *this ) );
     return true;
 }
 
 void SfxStyleSheetBase::SetHidden( bool hidden )
 {
     bHidden = hidden;
-    pPool->Broadcast( SfxStyleSheetHint( SFX_STYLESHEET_MODIFIED, *this ) );
+    pPool->Broadcast( SfxStyleSheetHint( SfxStyleSheetHintId::MODIFIED, *this ) );
 }
 
-// Change follow
-
+/**
+ * Change follow
+ */
 const OUString& SfxStyleSheetBase::GetFollow() const
 {
     return aFollow;
@@ -263,12 +266,14 @@ bool SfxStyleSheetBase::SetFollow( const OUString& rName )
         }
         aFollow = rName;
     }
-    pPool->Broadcast( SfxStyleSheetHint( SFX_STYLESHEET_MODIFIED, *this ) );
+    pPool->Broadcast( SfxStyleSheetHint( SfxStyleSheetHintId::MODIFIED, *this ) );
     return true;
 }
 
-// Set Itemset. The default implementation creates a new set
-
+/**
+ * Set Itemset
+ * The default implementation creates a new set
+ */
 SfxItemSet& SfxStyleSheetBase::GetItemSet()
 {
     if( !pSet )
@@ -279,8 +284,9 @@ SfxItemSet& SfxStyleSheetBase::GetItemSet()
     return *pSet;
 }
 
-// Hilfe-Datei und -ID setzen und abfragen
-
+/**
+ * Set help file and ID and return it
+ */
 sal_uLong SfxStyleSheetBase::GetHelpId( OUString& rFile )
 {
     rFile = aHelpFile;
@@ -293,43 +299,52 @@ void SfxStyleSheetBase::SetHelpId( const OUString& rFile, sal_uLong nId )
     nHelpId = nId;
 }
 
-// Next style possible? Default: Yes
-
+/**
+ * Next style possible?
+ * Default: Yes
+ */
 bool SfxStyleSheetBase::HasFollowSupport() const
 {
     return true;
 }
 
-// Basisvorlage m"oglich? Default: Ja
-
+/**
+ * Base template possible?
+ * Default: Yes
+ */
 bool SfxStyleSheetBase::HasParentSupport() const
 {
     return true;
 }
 
-// Basisvorlage uf NULL setzen m"oglich? Default: Nein
-
+/**
+ * Setting base template to NULL possible?
+ * Default: No
+ */
 bool SfxStyleSheetBase::HasClearParentSupport() const
 {
     return false;
 }
 
-// Defaultmaessig sind alle StyleSheets Used
-
+/**
+ * By default all stylesheets are set to used
+ */
 bool SfxStyleSheetBase::IsUsed() const
 {
     return true;
 }
 
-// eingestellte Attribute ausgeben
-
+/**
+ * Return set attributes
+ */
 OUString SfxStyleSheetBase::GetDescription()
 {
     return GetDescription( SFX_MAPUNIT_CM );
 }
 
-// eingestellte Attribute ausgeben
-
+/**
+ * Return set attributes
+ */
 OUString SfxStyleSheetBase::GetDescription( SfxMapUnit eMetric )
 {
     SfxItemIter aIter( GetItemSet() );
@@ -343,8 +358,7 @@ OUString SfxStyleSheetBase::GetDescription( SfxMapUnit eMetric )
 
         if ( !IsInvalidItem( pItem ) &&
              pPool->GetPool().GetPresentation(
-                *pItem, SFX_ITEM_PRESENTATION_COMPLETE,
-                eMetric, aItemPresentation, &aIntlWrapper ) )
+                *pItem, eMetric, aItemPresentation, &aIntlWrapper ) )
         {
             if ( !aDesc.isEmpty() && !aItemPresentation.isEmpty() )
                 aDesc += " + ";
@@ -424,12 +438,16 @@ sal_uInt16 SfxStyleSheetIterator::Count()
     sal_uInt16 n = 0;
     if( IsTrivialSearch())
     {
-        n = (sal_uInt16) pBasePool->mIndexedStyleSheets->GetNumberOfStyleSheets();
+        n = (sal_uInt16) pBasePool->pImp->mxIndexedStyleSheets->GetNumberOfStyleSheets();
+    }
+    else if(nMask == SFXSTYLEBIT_ALL)
+    {
+        n = static_cast<sal_uInt16>(pBasePool->pImp->mxIndexedStyleSheets->GetStyleSheetPositionsByFamily(nSearchFamily).size());
     }
     else
     {
         DoesStyleMatchStyleSheetPredicate predicate(this);
-        n = pBasePool->mIndexedStyleSheets->GetNumberOfStyleSheetsWithPredicate(predicate);
+        n = pBasePool->pImp->mxIndexedStyleSheets->GetNumberOfStyleSheetsWithPredicate(predicate);
     }
     return n;
 }
@@ -439,17 +457,26 @@ SfxStyleSheetBase* SfxStyleSheetIterator::operator[](sal_uInt16 nIdx)
     SfxStyleSheetBase* retval = NULL;
     if( IsTrivialSearch())
     {
-        retval = pBasePool->mIndexedStyleSheets->GetStyleSheetByPosition(nIdx).get();
+        retval = pBasePool->pImp->mxIndexedStyleSheets->GetStyleSheetByPosition(nIdx).get();
+        nAktPosition = nIdx;
+    }
+    else if(nMask == SFXSTYLEBIT_ALL)
+    {
+        rtl::Reference< SfxStyleSheetBase > ref =
+        pBasePool->pImp->mxIndexedStyleSheets->GetStyleSheetByPosition(
+                pBasePool->pImp->mxIndexedStyleSheets->GetStyleSheetPositionsByFamily(nSearchFamily).at(nIdx))
+                ;
+        retval = ref.get();
         nAktPosition = nIdx;
     }
     else
     {
         DoesStyleMatchStyleSheetPredicate predicate(this);
         rtl::Reference< SfxStyleSheetBase > ref =
-                pBasePool->mIndexedStyleSheets->GetNthStyleSheetThatMatchesPredicate(nIdx, predicate);
+                pBasePool->pImp->mxIndexedStyleSheets->GetNthStyleSheetThatMatchesPredicate(nIdx, predicate);
         if (ref.get() != NULL)
         {
-            nAktPosition = pBasePool->mIndexedStyleSheets->FindStyleSheetPosition(*ref);
+            nAktPosition = pBasePool->pImp->mxIndexedStyleSheets->FindStyleSheetPosition(*ref);
             retval = ref.get();
         }
     }
@@ -464,7 +491,12 @@ SfxStyleSheetBase* SfxStyleSheetIterator::operator[](sal_uInt16 nIdx)
 
 SfxStyleSheetBase* SfxStyleSheetIterator::First()
 {
-    return operator[](0);
+    if (Count() != 0) {
+        return operator[](0);
+    }
+    else {
+        return NULL;
+    }
 }
 
 
@@ -474,23 +506,35 @@ SfxStyleSheetBase* SfxStyleSheetIterator::Next()
 
     if ( IsTrivialSearch() )
     {
-        unsigned nStyleSheets = pBasePool->mIndexedStyleSheets->GetNumberOfStyleSheets();
+        unsigned nStyleSheets = pBasePool->pImp->mxIndexedStyleSheets->GetNumberOfStyleSheets();
         unsigned newPosition = nAktPosition +1;
         if (nStyleSheets > newPosition)
         {
             nAktPosition = newPosition;
-            retval = pBasePool->mIndexedStyleSheets->GetStyleSheetByPosition(nAktPosition).get();
+            retval = pBasePool->pImp->mxIndexedStyleSheets->GetStyleSheetByPosition(nAktPosition).get();
+        }
+    }
+    else if(nMask == SFXSTYLEBIT_ALL)
+    {
+        unsigned newPosition = nAktPosition +1;
+        const std::vector<unsigned>& familyVector =
+            pBasePool->pImp->mxIndexedStyleSheets->GetStyleSheetPositionsByFamily(nSearchFamily);
+        if (familyVector.size() > newPosition)
+        {
+            nAktPosition = newPosition;
+            unsigned stylePosition = familyVector.at(newPosition);
+            retval = pBasePool->pImp->mxIndexedStyleSheets->GetStyleSheetByPosition(stylePosition).get();
         }
     }
     else
     {
         DoesStyleMatchStyleSheetPredicate predicate(this);
         rtl::Reference< SfxStyleSheetBase > ref =
-                pBasePool->mIndexedStyleSheets->GetNthStyleSheetThatMatchesPredicate(
+                pBasePool->pImp->mxIndexedStyleSheets->GetNthStyleSheetThatMatchesPredicate(
                         0, predicate, nAktPosition+1);
         retval = ref.get();
         if (retval != NULL) {
-            nAktPosition = pBasePool->mIndexedStyleSheets->FindStyleSheetPosition(*ref);
+            nAktPosition = pBasePool->pImp->mxIndexedStyleSheets->FindStyleSheetPosition(*ref);
         }
     }
     pAktStyle = retval;
@@ -502,13 +546,14 @@ SfxStyleSheetBase* SfxStyleSheetIterator::Find(const OUString& rStr)
     DoesStyleMatchStyleSheetPredicate predicate(this);
 
     std::vector<unsigned> positions =
-            pBasePool->mIndexedStyleSheets->FindPositionsByNameAndPredicate(rStr, predicate);
+            pBasePool->pImp->mxIndexedStyleSheets->FindPositionsByNameAndPredicate(rStr, predicate,
+                    svl::IndexedStyleSheets::RETURN_FIRST);
     if (positions.empty()) {
         return NULL;
     }
 
     unsigned pos = positions.front();
-    SfxStyleSheetBase* pStyle = pBasePool->mIndexedStyleSheets->GetStyleSheetByPosition(pos).get();
+    SfxStyleSheetBase* pStyle = pBasePool->pImp->mxIndexedStyleSheets->GetStyleSheetByPosition(pos).get();
     nAktPosition = pos;
     pAktStyle = pStyle;
     return pAktStyle;
@@ -544,34 +589,31 @@ SfxStyleSheetIterator& SfxStyleSheetBasePool::GetIterator_Impl()
     return *pImp->pIter;
 }
 
-SfxStyleSheetBasePool::SfxStyleSheetBasePool( SfxItemPool& r )
-    : aAppName(r.GetName())
-    , rPool(r)
-    , nSearchFamily(SFX_STYLE_FAMILY_PARA)
-    , nMask(SFXSTYLEBIT_ALL)
-    , mIndexedStyleSheets(new svl::IndexedStyleSheets)
+SfxStyleSheetBasePool::SfxStyleSheetBasePool( SfxItemPool& r ) :
+    pImp(new SfxStyleSheetBasePool_Impl),
+    aAppName(r.GetName()),
+    rPool(r),
+    nSearchFamily(SFX_STYLE_FAMILY_PARA),
+    nMask(SFXSTYLEBIT_ALL)
 {
 #ifdef DBG_UTIL
     aDbgStyleSheetReferences.mnPools++;
 #endif
-
-    pImp = new SfxStyleSheetBasePool_Impl;
 }
 
-SfxStyleSheetBasePool::SfxStyleSheetBasePool( const SfxStyleSheetBasePool& r )
-    : SfxBroadcaster( r )
-    , comphelper::OWeakTypeObject()
-    , aAppName(r.aAppName)
-    , rPool(r.rPool)
-    , nSearchFamily(r.nSearchFamily)
-    , nMask( r.nMask )
-    , mIndexedStyleSheets(new svl::IndexedStyleSheets)
+SfxStyleSheetBasePool::SfxStyleSheetBasePool( const SfxStyleSheetBasePool& r ) :
+    SfxBroadcaster( r ),
+    comphelper::OWeakTypeObject(),
+    pImp(new SfxStyleSheetBasePool_Impl),
+    aAppName(r.aAppName),
+    rPool(r.rPool),
+    nSearchFamily(r.nSearchFamily),
+    nMask( r.nMask )
 {
 #ifdef DBG_UTIL
     aDbgStyleSheetReferences.mnPools++;
 #endif
 
-    pImp = new SfxStyleSheetBasePool_Impl;
     *this += r;
 }
 
@@ -603,10 +645,6 @@ void SfxStyleSheetBasePool::SetSearchMask(SfxStyleFamily eFam, sal_uInt16 n)
     nSearchFamily = eFam; nMask = n;
 }
 
-sal_uInt16 SfxStyleSheetBasePool::GetSearchMask() const
-{
-    return nMask;
-}
 
 SfxStyleSheetIteratorPtr SfxStyleSheetBasePool::CreateIterator
 (
@@ -644,15 +682,15 @@ SfxStyleSheetBase& SfxStyleSheetBasePool::Make( const OUString& rName, SfxStyleF
     {
         xStyle = Create( rName, eFam, mask );
         StoreStyleSheet(xStyle);
-        Broadcast( SfxStyleSheetHint( SFX_STYLESHEET_CREATED, *xStyle.get() ) );
+        Broadcast( SfxStyleSheetHint( SfxStyleSheetHintId::CREATED, *xStyle.get() ) );
     }
     return *xStyle.get();
 }
 
-// Hilfsroutine: Falls eine Vorlage dieses Namens existiert, wird
-// sie neu erzeugt. Alle Vorlagen, die diese Vorlage zum Parent haben,
-// werden umgehaengt.
-
+/**
+ * Helper function: If a template with this name exists it is created
+ * anew. All templates that have this template as a parent are reconnected.
+ */
 SfxStyleSheetBase& SfxStyleSheetBasePool::Add( const SfxStyleSheetBase& rSheet )
 {
     SfxStyleSheetIterator aIter(this, rSheet.GetFamily(), nMask);
@@ -661,8 +699,8 @@ SfxStyleSheetBase& SfxStyleSheetBasePool::Add( const SfxStyleSheetBase& rSheet )
         Remove( pOld );
     }
     rtl::Reference< SfxStyleSheetBase > xNew( Create( rSheet ) );
-    mIndexedStyleSheets->AddStyleSheet(xNew);
-    Broadcast( SfxStyleSheetHint( SFX_STYLESHEET_CHANGED, *xNew.get() ) );
+    pImp->mxIndexedStyleSheets->AddStyleSheet(xNew);
+    Broadcast( SfxStyleSheetHint( SfxStyleSheetHintId::CHANGED, *xNew.get() ) );
     return *xNew.get();
 }
 
@@ -696,7 +734,7 @@ SfxStyleSheetBasePool& SfxStyleSheetBasePool::operator+=( const SfxStyleSheetBas
     if( &r != this )
     {
         AddStyleSheetCallback callback(this);
-        mIndexedStyleSheets->ApplyToAllStyleSheets(callback);
+        pImp->mxIndexedStyleSheets->ApplyToAllStyleSheets(callback);
     }
     return *this;
 }
@@ -735,7 +773,7 @@ void SfxStyleSheetBasePool::Remove( SfxStyleSheetBase* p )
     {
         // Reference to keep p alive until after Broadcast call!
         rtl::Reference<SfxStyleSheetBase> xP(p);
-        bool bWasRemoved = mIndexedStyleSheets->RemoveStyleSheet(xP);
+        bool bWasRemoved = pImp->mxIndexedStyleSheets->RemoveStyleSheet(xP);
         if( bWasRemoved )
         {
             // Adapt all styles which have this style as parant
@@ -754,7 +792,7 @@ void SfxStyleSheetBasePool::Remove( SfxStyleSheetBase* p )
             // catch( com::sun::star::uno::Exception& )
             // {
             // }
-            Broadcast( SfxStyleSheetHint( SFX_STYLESHEET_ERASED, *p ) );
+            Broadcast( SfxStyleSheetHint( SfxStyleSheetHintId::ERASED, *p ) );
         }
     }
 }
@@ -774,7 +812,7 @@ void SfxStyleSheetBasePool::Insert( SfxStyleSheetBase* p )
     }
 #endif
     StoreStyleSheet(rtl::Reference< SfxStyleSheetBase >( p ) );
-    Broadcast( SfxStyleSheetHint( SFX_STYLESHEET_CREATED, *p ) );
+    Broadcast( SfxStyleSheetHint( SfxStyleSheetHintId::CREATED, *p ) );
 }
 
 namespace
@@ -798,7 +836,7 @@ struct StyleSheetDisposerFunctor SAL_FINAL : public svl::StyleSheetDisposer
         catch( com::sun::star::uno::Exception& )
         {
         }
-        mPool->Broadcast( SfxStyleSheetHint( SFX_STYLESHEET_ERASED, *styleSheet.get() ) );
+        mPool->Broadcast( SfxStyleSheetHint( SfxStyleSheetHintId::ERASED, *styleSheet.get() ) );
     }
 
     SfxStyleSheetBasePool* mPool;
@@ -809,7 +847,7 @@ struct StyleSheetDisposerFunctor SAL_FINAL : public svl::StyleSheetDisposer
 void SfxStyleSheetBasePool::Clear()
 {
     StyleSheetDisposerFunctor cleanup(this);
-    mIndexedStyleSheets->Clear(cleanup);
+    pImp->mxIndexedStyleSheets->Clear(cleanup);
 }
 
 void SfxStyleSheetBasePool::ChangeParent(const OUString& rOld,
@@ -839,17 +877,6 @@ void SfxStyleSheetBase::Store( SvStream& )
 {
 }
 
-SfxItemPool& SfxStyleSheetBasePool::GetPool()
-{
-    return rPool;
-}
-
-const SfxItemPool& SfxStyleSheetBasePool::GetPool() const
-{
-    return rPool;
-}
-
-
 SfxStyleSheet::SfxStyleSheet(const OUString &rName,
                              const SfxStyleSheetBasePool& r_Pool,
                              SfxStyleFamily eFam,
@@ -868,7 +895,7 @@ SfxStyleSheet::SfxStyleSheet(const SfxStyleSheet& rStyle)
 
 SfxStyleSheet::~SfxStyleSheet()
 {
-    Broadcast( SfxStyleSheetHint( SFX_STYLESHEET_INDESTRUCTION, *this ) );
+    Broadcast( SfxStyleSheetHint( SfxStyleSheetHintId::INDESTRUCTION, *this ) );
 }
 
 
@@ -879,19 +906,17 @@ bool SfxStyleSheet::SetParent( const OUString& rName )
     const OUString aOldParent(aParent);
     if(SfxStyleSheetBase::SetParent(rName))
     {
-            // aus der Benachrichtigungskette des alten
-            // Parents gfs. austragen
+        // Remove from notification chain of the old parent if applicable
         if(!aOldParent.isEmpty())
         {
-            SfxStyleSheet *pParent = (SfxStyleSheet *)pPool->Find(aOldParent, nFamily, SFXSTYLEBIT_ALL);
+            SfxStyleSheet *pParent = static_cast<SfxStyleSheet *>(pPool->Find(aOldParent, nFamily, SFXSTYLEBIT_ALL));
             if(pParent)
                 EndListening(*pParent);
         }
-            // in die Benachrichtigungskette des neuen
-            // Parents eintragen
+        // Add to the notification chain of the new parent
         if(!aParent.isEmpty())
         {
-            SfxStyleSheet *pParent = (SfxStyleSheet *)pPool->Find(aParent, nFamily, SFXSTYLEBIT_ALL);
+            SfxStyleSheet *pParent = static_cast<SfxStyleSheet *>(pPool->Find(aParent, nFamily, SFXSTYLEBIT_ALL));
             if(pParent)
                 StartListening(*pParent);
         }
@@ -900,7 +925,9 @@ bool SfxStyleSheet::SetParent( const OUString& rName )
     return false;
 }
 
-// Notify all listeners
+/**
+ * Notify all listeners
+ */
 void SfxStyleSheet::Notify(SfxBroadcaster& rBC, const SfxHint& rHint )
 {
     Forward(rBC, rHint);
@@ -923,12 +950,6 @@ SfxStyleSheetBase* SfxStyleSheetPool::Create( const OUString& rName,
     return new SfxStyleSheet( rName, *this, eFam, mask );
 }
 
-SfxStyleSheetBase* SfxStyleSheetPool::Create( const SfxStyleSheet& r )
-{
-    return new SfxStyleSheet( r );
-}
-
-// class SfxUnoStyleSheet
 SfxUnoStyleSheet::SfxUnoStyleSheet( const OUString& _rName, const SfxStyleSheetBasePool& _rPool, SfxStyleFamily _eFamily, sal_uInt16 _nMaske )
 : ::cppu::ImplInheritanceHelper2< SfxStyleSheet, ::com::sun::star::style::XStyle, ::com::sun::star::lang::XUnoTunnel >( _rName, _rPool, _eFamily, _nMaske )
 {
@@ -946,7 +967,9 @@ SfxUnoStyleSheet* SfxUnoStyleSheet::getUnoStyleSheet( const ::com::sun::star::un
     return pRet;
 }
 
-// XUnoTunnel
+/**
+ * XUnoTunnel
+ */
 ::sal_Int64 SAL_CALL SfxUnoStyleSheet::getSomething( const ::com::sun::star::uno::Sequence< ::sal_Int8 >& rId ) throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     if( rId.getLength() == 16 && 0 == memcmp( getIdentifier().getConstArray(), rId.getConstArray(), 16 ) )
@@ -962,7 +985,7 @@ SfxUnoStyleSheet* SfxUnoStyleSheet::getUnoStyleSheet( const ::com::sun::star::un
 void
 SfxStyleSheetBasePool::StoreStyleSheet(rtl::Reference< SfxStyleSheetBase > xStyle)
 {
-    mIndexedStyleSheets->AddStyleSheet(xStyle);
+    pImp->mxIndexedStyleSheets->AddStyleSheet(xStyle);
 }
 
 namespace
@@ -978,19 +1001,19 @@ const ::com::sun::star::uno::Sequence< ::sal_Int8 >& SfxUnoStyleSheet::getIdenti
 void
 SfxStyleSheetBasePool::Reindex()
 {
-    mIndexedStyleSheets->Reindex();
+    pImp->mxIndexedStyleSheets->Reindex();
 }
 
 const svl::IndexedStyleSheets&
 SfxStyleSheetBasePool::GetIndexedStyleSheets() const
 {
-    return *mIndexedStyleSheets;
+    return *pImp->mxIndexedStyleSheets;
 }
 
 rtl::Reference<SfxStyleSheetBase>
 SfxStyleSheetBasePool::GetStyleSheetByPositionInIndex(unsigned pos)
 {
-    return mIndexedStyleSheets->GetStyleSheetByPosition(pos);
+    return pImp->mxIndexedStyleSheets->GetStyleSheetByPosition(pos);
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
