@@ -49,7 +49,7 @@ struct SvtFontSubstConfig_Impl
 
 SvtFontSubstConfig::SvtFontSubstConfig() :
     ConfigItem(OUString("Office.Common/Font/Substitution")),
-    bIsEnabled(sal_False),
+    bIsEnabled(false),
     pImpl(new SvtFontSubstConfig_Impl)
 {
     Sequence<OUString> aNames(1);
@@ -57,7 +57,7 @@ SvtFontSubstConfig::SvtFontSubstConfig() :
     Sequence<Any> aValues = GetProperties(aNames);
     DBG_ASSERT(aValues.getConstArray()[0].hasValue(), "no value available");
     if(aValues.getConstArray()[0].hasValue())
-        bIsEnabled = *(sal_Bool*)aValues.getConstArray()[0].getValue();
+        bIsEnabled = *static_cast<sal_Bool const *>(aValues.getConstArray()[0].getValue());
 
     OUString sPropPrefix(cFontPairs);
     Sequence<OUString> aNodeNames = GetNodeNames(sPropPrefix, CONFIG_NAME_LOCAL_PATH);
@@ -83,8 +83,8 @@ SvtFontSubstConfig::SvtFontSubstConfig() :
         SubstitutionStruct* pInsert = new SubstitutionStruct;
         pNodeValues[nName++] >>= pInsert->sFont;
         pNodeValues[nName++] >>= pInsert->sReplaceBy;
-        pInsert->bReplaceAlways = *(sal_Bool*)pNodeValues[nName++].getValue();
-        pInsert->bReplaceOnScreenOnly = *(sal_Bool*)pNodeValues[nName++].getValue();
+        pInsert->bReplaceAlways = *static_cast<sal_Bool const *>(pNodeValues[nName++].getValue());
+        pInsert->bReplaceOnScreenOnly = *static_cast<sal_Bool const *>(pNodeValues[nName++].getValue());
         pImpl->aSubstArr.push_back(pInsert);
     }
 }
@@ -98,12 +98,12 @@ void SvtFontSubstConfig::Notify( const com::sun::star::uno::Sequence< OUString >
 {
 }
 
-void SvtFontSubstConfig::Commit()
+void SvtFontSubstConfig::ImplCommit()
 {
     Sequence<OUString> aNames(1);
     aNames.getArray()[0] = cReplacement;
     Sequence<Any> aValues(1);
-    aValues.getArray()[0].setValue(&bIsEnabled, ::getBooleanCppuType());
+    aValues.getArray()[0].setValue(&bIsEnabled, cppu::UnoType<bool>::get());
     PutProperties(aNames, aValues);
 
     OUString sNode(cFontPairs);
@@ -120,7 +120,7 @@ void SvtFontSubstConfig::Commit()
         const OUString sAlways(cAlways);
         const OUString sOnScreenOnly(cOnScreenOnly);
 
-        const uno::Type& rBoolType = ::getBooleanCppuType();
+        const uno::Type& rBoolType = cppu::UnoType<bool>::get();
         for(size_t i = 0; i < pImpl->aSubstArr.size(); i++)
         {
             OUString sPrefix = sNode + "/_" + OUString::number(i) + "/";
@@ -178,12 +178,12 @@ void SvtFontSubstConfig::Apply()
 
     for (sal_Int32  i = 0; i < nCount; i++)
     {
-        sal_uInt16 nFlags = 0;
+        AddFontSubstituteFlags nFlags = AddFontSubstituteFlags::NONE;
         const SubstitutionStruct* pSubs = GetSubstitution(i);
         if(pSubs->bReplaceAlways)
-            nFlags |= FONT_SUBSTITUTE_ALWAYS;
+            nFlags |= AddFontSubstituteFlags::ALWAYS;
         if(pSubs->bReplaceOnScreenOnly)
-            nFlags |= FONT_SUBSTITUTE_SCREENONLY;
+            nFlags |= AddFontSubstituteFlags::ScreenOnly;
         OutputDevice::AddFontSubstitute( pSubs->sFont, pSubs->sReplaceBy, nFlags );
     }
 
