@@ -25,7 +25,7 @@
 #include <ctype.h>
 #include <stdlib.h>
 
-// die Tabelle muss noch sortiert werden
+// the table is still to be sorted
 struct RTF_TokenEntry
 {
     union{
@@ -35,8 +35,8 @@ struct RTF_TokenEntry
     int nToken;
 };
 
-// Flag: RTF-Token Tabelle wurde schon sortiert
-static int bSortKeyWords = sal_False;
+// Flag: RTF-token table has been sorted
+static bool bSortKeyWords = false;
 
 static RTF_TokenEntry aRTFTokenTab[] = {
 {{OOO_STRING_SVTOOLS_RTF_IGNORE},        RTF_IGNOREFLAG},
@@ -1000,6 +1000,7 @@ static RTF_TokenEntry aRTFTokenTab[] = {
 {{OOO_STRING_SVTOOLS_RTF_SHPFBLWTXT},   RTF_SHPFBLWTXT},
 {{OOO_STRING_SVTOOLS_RTF_SHPFHDR},      RTF_SHPFHDR},
 {{OOO_STRING_SVTOOLS_RTF_SHPGRP},       RTF_SHPGRP},
+{{OOO_STRING_SVTOOLS_RTF_SHPINST},      RTF_SHPINST},
 {{OOO_STRING_SVTOOLS_RTF_SHPLEFT},      RTF_SHPLEFT},
 {{OOO_STRING_SVTOOLS_RTF_SHPLID},       RTF_SHPLID},
 {{OOO_STRING_SVTOOLS_RTF_SHPLOCKANCHOR},    RTF_SHPLOCKANCHOR},
@@ -1077,7 +1078,7 @@ static RTF_TokenEntry aRTFTokenTab[] = {
         {{OOO_STRING_SVTOOLS_RTF_NOOVERFLOW},    RTF_NOOVERFLOW},
         {{OOO_STRING_SVTOOLS_RTF_ASPALPHA},      RTF_ASPALPHA},
 
-// SWG spezifische Attribute
+// SWG specific attributes
         {{OOO_STRING_SVTOOLS_RTF_GRFALIGNV},     RTF_GRF_ALIGNV},
         {{OOO_STRING_SVTOOLS_RTF_GRFALIGNH},     RTF_GRF_ALIGNH},
         {{OOO_STRING_SVTOOLS_RTF_GRFMIRROR},     RTF_GRF_MIRROR},
@@ -1094,7 +1095,7 @@ static RTF_TokenEntry aRTFTokenTab[] = {
         {{OOO_STRING_SVTOOLS_RTF_PRTDATA},       RTF_SWG_PRTDATA},
         {{OOO_STRING_SVTOOLS_RTF_BKMKKEY},       RTF_BKMK_KEY},
 
-// Attribute fuer die freifliegenden Rahmen
+// Attributes for fly frames
         {{OOO_STRING_SVTOOLS_RTF_FLYPRINT},      RTF_FLYPRINT},
         {{OOO_STRING_SVTOOLS_RTF_FLYOPAQUE},     RTF_FLYOPAQUE},
         {{OOO_STRING_SVTOOLS_RTF_FLYPRTCTD},     RTF_FLYPRTCTD},
@@ -1178,25 +1179,25 @@ extern "C" {
 static int SAL_CALL RTFKeyCompare( const void *pFirst, const void *pSecond)
 {
     int nRet = 0;
-    if( -1 == ((RTF_TokenEntry*)pFirst)->nToken )
+    if( -1 == static_cast<RTF_TokenEntry const *>(pFirst)->nToken )
     {
-        if( -1 == ((RTF_TokenEntry*)pSecond)->nToken )
-            nRet = ((RTF_TokenEntry*)pFirst)->pUToken->compareTo(
-                            *((RTF_TokenEntry*)pSecond)->pUToken );
+        if( -1 == static_cast<RTF_TokenEntry const *>(pSecond)->nToken )
+            nRet = static_cast<RTF_TokenEntry const *>(pFirst)->pUToken->compareTo(
+                            *static_cast<RTF_TokenEntry const *>(pSecond)->pUToken );
         else
         {
-            nRet = ((RTF_TokenEntry*)pFirst)->pUToken->compareToIgnoreAsciiCaseAscii(
-                            ((RTF_TokenEntry*)pSecond)->sToken );
+            nRet = static_cast<RTF_TokenEntry const *>(pFirst)->pUToken->compareToIgnoreAsciiCaseAscii(
+                            static_cast<RTF_TokenEntry const *>(pSecond)->sToken );
         }
     }
     else
     {
-        if( -1 == ((RTF_TokenEntry*)pSecond)->nToken )
-            nRet = -1 * ((RTF_TokenEntry*)pSecond)->pUToken->compareToIgnoreAsciiCaseAscii(
-                            ((RTF_TokenEntry*)pFirst)->sToken );
+        if( -1 == static_cast<RTF_TokenEntry const *>(pSecond)->nToken )
+            nRet = -1 * static_cast<RTF_TokenEntry const *>(pSecond)->pUToken->compareToIgnoreAsciiCaseAscii(
+                            static_cast<RTF_TokenEntry const *>(pFirst)->sToken );
         else
-            nRet = strcmp( ((RTF_TokenEntry*)pFirst)->sToken,
-                            ((RTF_TokenEntry*)pSecond)->sToken );
+            nRet = strcmp( static_cast<RTF_TokenEntry const *>(pFirst)->sToken,
+                            static_cast<RTF_TokenEntry const *>(pSecond)->sToken );
     }
 
     return nRet;
@@ -1212,7 +1213,7 @@ int GetRTFToken( const OUString& rSearch )
                 sizeof( aRTFTokenTab ) / sizeof( RTF_TokenEntry ),
                 sizeof( RTF_TokenEntry ),
                 RTFKeyCompare );
-        bSortKeyWords = sal_True;
+        bSortKeyWords = true;
     }
 
     int nRet = 0;
@@ -1221,12 +1222,13 @@ int GetRTFToken( const OUString& rSearch )
     aSrch.pUToken = &rSearch;
     aSrch.nToken = -1;
 
-    if( 0 != ( pFound = bsearch( (char *) &aSrch,
+    if( 0 != ( pFound = bsearch( &aSrch,
                         (void*) aRTFTokenTab,
                         sizeof( aRTFTokenTab ) / sizeof( RTF_TokenEntry ),
                         sizeof( RTF_TokenEntry ),
                         RTFKeyCompare )))
-        nRet = ((RTF_TokenEntry*)pFound)->nToken;
+        nRet = static_cast<RTF_TokenEntry*>(pFound)->nToken;
+
     return nRet;
 }
 
