@@ -17,6 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
+
+#include <cstdlib>
+
 #include <svx/framelink.hxx>
 
 #include <math.h>
@@ -38,13 +42,13 @@ using namespace editeng;
 namespace svx {
 namespace frame {
 
-// ============================================================================
+
 
 namespace {
 
 typedef std::vector< Point > PointVec;
 
-// ----------------------------------------------------------------------------
+
 // Link result structs for horizontal and vertical lines and borders.
 
 /** Result struct used by the horizontal/vertical frame link functions.
@@ -128,7 +132,7 @@ struct BorderResult
     BorderEndResult     maEnd;      /// Result for end of border line (right or bottom end).
 };
 
-// ----------------------------------------------------------------------------
+
 // Link result structs for diagonal lines and borders.
 
 /** Result struct used by the diagonal frame link functions.
@@ -166,7 +170,7 @@ struct DiagBordersResult
     DiagBorderResult    maBLTR;     /// Result for bottom-left to top-right frame border.
 };
 
-// ----------------------------------------------------------------------------
+
 
 /** A helper struct containing two points of a line.
  */
@@ -182,7 +186,7 @@ struct LinePoints
                             maEnd( bTLBR ? rRect.BottomRight() : rRect.BottomLeft() ) {}
 };
 
-// ============================================================================
+
 
 /** Rounds and casts a double value to a long value. */
 inline long lclD2L( double fValue )
@@ -196,7 +200,7 @@ double lclScaleValue( double nValue, double fScale, sal_uInt16 nMaxWidth )
     return std::min<double>(nValue * fScale, nMaxWidth);
 }
 
-// ----------------------------------------------------------------------------
+
 // Line width offset calculation.
 
 /** Returns the start offset of the single/primary line across the frame border.
@@ -336,11 +340,11 @@ inline long lclGetBeforeBeg( const Style& rBorder )
 inline long lclGetBehindEnd( const Style& rBorder )
 { return rBorder.Prim() ? (lclGetEnd( rBorder ) + 256) : 0; }
 
-// ============================================================================
-// Linking functions
-// ============================================================================
 
-// ----------------------------------------------------------------------------
+// Linking functions
+
+
+
 // Linking of single horizontal line ends.
 
 /** Calculates X offsets for the left end of a single horizontal frame border.
@@ -505,7 +509,7 @@ void lclLinkLeftEnd_Gap(
 
     rResult.mnOffs2 = rResult.mnOffs1;
 }
-// ----------------------------------------------------------------------------
+
 // Linking of horizontal frame border ends.
 
 /** Calculates X offsets for the left end of a horizontal frame border.
@@ -557,7 +561,7 @@ void lclLinkRightEnd(
     rResult.Negate();
 }
 
-// ----------------------------------------------------------------------------
+
 // Linking of horizontal and vertical frame borders.
 
 /** Calculates X offsets for all line ends of a horizontal frame border.
@@ -607,9 +611,9 @@ void lclLinkVerFrameBorder(
         rBFromTL.Mirror(), rBFromL, rBFromB, rBFromR, rBFromTR );
 }
 
-// ============================================================================
 
-// ----------------------------------------------------------------------------
+
+
 // Linking of diagonal frame borders.
 
 /** Calculates clipping offsets for a top-left to bottom-right frame border.
@@ -689,11 +693,11 @@ void lclLinkDiagFrameBorders(
     lclLinkBLTRFrameBorder( rResult.maBLTR, rBLTR, rBLFromT, rBLFromR, rTRFromB, rTRFromL );
 }
 
-// ============================================================================
-// Drawing functions
-// ============================================================================
 
-// ----------------------------------------------------------------------------
+// Drawing functions
+
+
+
 // Simple helper functions
 
 /** Converts sub units to OutputDevice map units. */
@@ -715,7 +719,7 @@ inline Polygon lclCreatePolygon( const PointVec& rPoints )
 }
 
 /** Returns a polygon constructed from the five passed points. */
-Region lclCreatePolygon( const Point& rP1, const Point& rP2, const Point& rP3, const Point& rP4, const Point& rP5 )
+vcl::Region lclCreatePolygon( const Point& rP1, const Point& rP2, const Point& rP3, const Point& rP4, const Point& rP5 )
 {
     PointVec aPoints;
     aPoints.reserve( 5 );
@@ -724,7 +728,7 @@ Region lclCreatePolygon( const Point& rP1, const Point& rP2, const Point& rP3, c
     aPoints.push_back( rP3 );
     aPoints.push_back( rP4 );
     aPoints.push_back( rP5 );
-    return Region(lclCreatePolygon(aPoints));
+    return vcl::Region(lclCreatePolygon(aPoints));
 }
 
 /** Sets the color of the passed frame style to the output device.
@@ -742,13 +746,13 @@ Region lclCreatePolygon( const Point& rP1, const Point& rP2, const Point& rP3, c
  */
 void lclSetColorToOutDev( OutputDevice& rDev, const Color& rColor, const Color* pForceColor )
 {
-    rDev.Push( PUSH_LINECOLOR | PUSH_FILLCOLOR );
+    rDev.Push( PushFlags::LINECOLOR | PushFlags::FILLCOLOR );
     rDev.SetLineColor( pForceColor ? *pForceColor : rColor );
     rDev.SetFillColor( pForceColor ? *pForceColor : rColor );
 }
 
-// ----------------------------------------------------------------------------
-// ============================================================================
+
+
 // Drawing of horizontal frame borders.
 
 /** Draws a horizontal thin or thick line into the passed output device.
@@ -765,9 +769,9 @@ void lclDrawHorLine(
     LinePoints aTPoints( rLPos + lclToMapUnit( rLRes.mnOffs1, nTOffs ), rRPos + lclToMapUnit( rRRes.mnOffs1, nTOffs ) );
     LinePoints aBPoints( rLPos + lclToMapUnit( rLRes.mnOffs2, nBOffs ), rRPos + lclToMapUnit( rRRes.mnOffs2, nBOffs ) );
 
-    sal_uInt32 nWidth = lclToMapUnit( abs( nTOffs ) ) + lclToMapUnit( abs( nBOffs ) );
+    sal_uInt32 nWidth = lclToMapUnit( std::abs( nTOffs ) ) + lclToMapUnit( std::abs( nBOffs ) );
     if ( ( nTOffs >= 0 && nBOffs >= 0 ) || ( nTOffs <= 0 && nBOffs <= 0 ) )
-        nWidth = abs( lclToMapUnit( nTOffs ) - lclToMapUnit( nBOffs ) ) + 1;
+        nWidth = std::abs( lclToMapUnit( nTOffs ) - lclToMapUnit( nBOffs ) ) + 1;
     Point rLMid = ( aTPoints.maBeg + aBPoints.maBeg ) / 2;
     Point rRMid = ( aTPoints.maEnd + aBPoints.maEnd ) / 2;
 
@@ -818,7 +822,7 @@ void lclDrawHorFrameBorder(
     }
 }
 
-// ----------------------------------------------------------------------------
+
 // Drawing of vertical frame borders.
 
 /** Draws a vertical thin or thick line into the passed output device.
@@ -835,9 +839,9 @@ void lclDrawVerLine(
     LinePoints aLPoints( rTPos + lclToMapUnit( nLOffs, rTRes.mnOffs1 ), rBPos + lclToMapUnit( nLOffs, rBRes.mnOffs1 ) );
     LinePoints aRPoints( rTPos + lclToMapUnit( nROffs, rTRes.mnOffs2 ), rBPos + lclToMapUnit( nROffs, rBRes.mnOffs2 ) );
 
-    sal_uInt32 nWidth = lclToMapUnit( abs( nLOffs ) ) + lclToMapUnit( abs( nROffs ) );
+    sal_uInt32 nWidth = lclToMapUnit( std::abs( nLOffs ) ) + lclToMapUnit( std::abs( nROffs ) );
     if ( ( nLOffs >= 0 && nROffs >= 0 ) || ( nLOffs <= 0 && nROffs <= 0 ) )
-        nWidth = abs( lclToMapUnit( nLOffs ) - lclToMapUnit( nROffs ) ) + 1;
+        nWidth = std::abs( lclToMapUnit( nLOffs ) - lclToMapUnit( nROffs ) ) + 1;
     Point rTMid = ( aLPoints.maBeg + aRPoints.maBeg ) / 2;
     Point rBMid = ( aLPoints.maEnd + aRPoints.maEnd ) / 2;
 
@@ -887,7 +891,7 @@ void lclDrawVerFrameBorder(
     }
 }
 
-// ============================================================================
+
 // Drawing of diagonal frame borders, incudes clipping functions.
 
 /** Returns the drawing coordinates for a diagonal thin line.
@@ -922,7 +926,7 @@ LinePoints lclGetDiagLineEnds( const Rectangle& rRect, bool bTLBR, long nDiagOff
     return aPoints;
 }
 
-// ----------------------------------------------------------------------------
+
 // Clipping functions for diagonal frame borders.
 
 /** Limits the clipping region to the inner area of a rectange.
@@ -954,7 +958,7 @@ void lclPushDiagClipRect( OutputDevice& rDev, const Rectangle& rRect, const Diag
     if( (aClipRect.GetWidth() < 1) ||(aClipRect.GetHeight() < 1) )
         aClipRect.SetEmpty();
 
-    rDev.Push( PUSH_CLIPREGION );
+    rDev.Push( PushFlags::CLIPREGION );
     rDev.IntersectClipRegion( aClipRect );
 }
 
@@ -985,7 +989,7 @@ void lclPushCrossingClipRegion( OutputDevice& rDev, const Rectangle& rRect, bool
     LinePoints aLPoints( lclGetDiagLineEnds( rRect, !bTLBR, lclGetPrimEnd( rCrossStyle ) ) );
     LinePoints aRPoints( lclGetDiagLineEnds( rRect, !bTLBR, lclGetSecnBeg( rCrossStyle ) ) );
 
-    Region aClipReg;
+    vcl::Region aClipReg;
     if( bTLBR )
     {
         aClipReg = lclCreatePolygon(
@@ -1001,11 +1005,11 @@ void lclPushCrossingClipRegion( OutputDevice& rDev, const Rectangle& rRect, bool
             aRPoints.maBeg, aRPoints.maEnd, rRect.BottomLeft(), rRect.BottomRight(), rRect.TopRight() ) );
     }
 
-    rDev.Push( PUSH_CLIPREGION );
+    rDev.Push( PushFlags::CLIPREGION );
     rDev.IntersectClipRegion( aClipReg );
 }
 
-// ----------------------------------------------------------------------------
+
 // Drawing functions for diagonal frame borders.
 
 /** Draws a diagonal thin or thick line into the passed output device.
@@ -1023,9 +1027,9 @@ void lclDrawDiagLine(
     Point aSMid( ( aLPoints.maBeg + aL2Points.maBeg ) / 2 );
     Point aEMid( ( aLPoints.maEnd + aL2Points.maEnd ) / 2 );
 
-    sal_uInt32 nWidth = lclToMapUnit( abs( nDiagOffs1 ) ) + lclToMapUnit( abs( nDiagOffs2 ) );
+    sal_uInt32 nWidth = lclToMapUnit( std::abs( nDiagOffs1 ) ) + lclToMapUnit( std::abs( nDiagOffs2 ) );
     if ( ( nDiagOffs1 <= 0 && nDiagOffs2 <= 0 ) || ( nDiagOffs1 >=0 && nDiagOffs2 >=0 ) )
-        nWidth = lclToMapUnit( abs( nDiagOffs1 - nDiagOffs2 ) );
+        nWidth = lclToMapUnit( std::abs( nDiagOffs1 - nDiagOffs2 ) );
 
     svtools::DrawLine( rDev, aSMid, aEMid, nWidth, nDashing );
     rDev.Pop(); // clipping region
@@ -1114,13 +1118,13 @@ void lclDrawDiagFrameBorders(
     }
 }
 
-// ============================================================================
+
 
 } // namespace
 
-// ============================================================================
+
 // Classes
-// ============================================================================
+
 
 #define SCALEVALUE( value ) lclScaleValue( value, fScale, nMaxWidth )
 
@@ -1150,13 +1154,6 @@ Style::Style( const Color& rColorPrim, const Color& rColorSecn, const Color& rCo
     Set( rColorPrim, rColorSecn, rColorGap, bUseGapColor, nP, nD, nS );
 }
 
-Style::Style( const editeng::SvxBorderLine& rBorder, double fScale, sal_uInt16 nMaxWidth ) :
-    meRefMode(REFMODE_CENTERED),
-    mfPatternScale(fScale)
-{
-    Set( rBorder, fScale, nMaxWidth );
-}
-
 Style::Style( const editeng::SvxBorderLine* pBorder, double fScale, sal_uInt16 nMaxWidth ) :
     meRefMode(REFMODE_CENTERED),
     mfPatternScale(fScale)
@@ -1164,10 +1161,6 @@ Style::Style( const editeng::SvxBorderLine* pBorder, double fScale, sal_uInt16 n
     Set( pBorder, fScale, nMaxWidth );
 }
 
-double Style::PatternScale() const
-{
-    return mfPatternScale;
-}
 
 void Style::SetPatternScale( double fScale )
 {
@@ -1181,7 +1174,7 @@ void Style::Clear()
 
 void Style::Set( double nP, double nD, double nS )
 {
-    /*  nP  nD  nS  ->  mnPrim  mnDist  mnSecn
+    /*  nP  nD  nS  ->  mfPrim  mfDist  mfSecn
         --------------------------------------
         any any 0       nP      0       0
         0   any >0      nS      0       0
@@ -1229,12 +1222,12 @@ void Style::Set( const SvxBorderLine& rBorder, double fScale, sal_uInt16 nMaxWid
         while( GetWidth() > nMaxWidth )
         {
             // First decrease space between lines.
-            if( mfDist )
+            if (mfDist)
                 --mfDist;
             // Still too thick? Decrease the line widths.
             if( GetWidth() > nMaxWidth )
             {
-                if( rtl::math::approxEqual(mfPrim, 0.0) && rtl::math::approxEqual(mfPrim, mfSecn) )
+                if (!rtl::math::approxEqual(mfPrim, 0.0) && rtl::math::approxEqual(mfPrim, mfSecn))
                 {
                     // Both lines equal - decrease both to keep symmetry.
                     --mfPrim;
@@ -1243,9 +1236,9 @@ void Style::Set( const SvxBorderLine& rBorder, double fScale, sal_uInt16 nMaxWid
                 else
                 {
                     // Decrease each line for itself
-                    if( mfPrim )
+                    if (mfPrim)
                         --mfPrim;
-                    if( (GetWidth() > nMaxWidth) && !rtl::math::approxEqual(mfSecn, 0.0) )
+                    if ((GetWidth() > nMaxWidth) && !rtl::math::approxEqual(mfSecn, 0.0))
                         --mfSecn;
                 }
             }
@@ -1266,7 +1259,7 @@ void Style::Set( const SvxBorderLine* pBorder, double fScale, sal_uInt16 nMaxWid
 
 Style& Style::MirrorSelf()
 {
-    if( mfSecn )
+    if (mfSecn)
         std::swap( mfPrim, mfSecn );
     if( meRefMode != REFMODE_CENTERED )
         meRefMode = (meRefMode == REFMODE_BEGIN) ? REFMODE_END : REFMODE_BEGIN;
@@ -1308,16 +1301,16 @@ bool operator<( const Style& rL, const Style& rR )
 
 #undef SCALEVALUE
 
-// ============================================================================
+
 // Various helper functions
-// ============================================================================
+
 
 double GetHorDiagAngle( long nWidth, long nHeight )
 {
     return atan2( static_cast< double >( std::abs( nHeight ) ), static_cast< double >( std::abs( nWidth ) ) );
 }
 
-// ============================================================================
+
 
 long GetTLDiagOffset( long nVerOffs, long nDiagOffs, double fAngle )
 {
@@ -1339,7 +1332,7 @@ long GetTRDiagOffset( long nVerOffs, long nDiagOffs, double fAngle )
     return -lclD2L( nVerOffs / tan( fAngle ) - nDiagOffs / sin( fAngle ) );
 }
 
-// ============================================================================
+
 
 bool CheckFrameBorderConnectable( const Style& rLBorder, const Style& rRBorder,
         const Style& rTFromTL, const Style& rTFromT, const Style& rTFromTR,
@@ -1364,19 +1357,19 @@ bool CheckFrameBorderConnectable( const Style& rLBorder, const Style& rRBorder,
         );
 }
 
-// ============================================================================
+
 // Drawing functions
-// ============================================================================
+
 
 double lcl_GetExtent( const Style& rBorder, const Style& rSide, const Style& rOpposite,
                       long nAngleSide = 9000, long nAngleOpposite = 9000 )
 {
-    Style aOtherBorder = const_cast< Style& >( rSide );
+    Style aOtherBorder = rSide;
     long nOtherAngle = nAngleSide;
     if ( rSide.GetWidth() == 0 && rOpposite.GetWidth() > 0 )
     {
         nOtherAngle = nAngleOpposite;
-        aOtherBorder = const_cast< Style& >( rOpposite );
+        aOtherBorder = rOpposite;
     }
     else if ( rSide.GetWidth() == 0 && rOpposite.GetWidth() == 0 )
     {
@@ -1402,14 +1395,14 @@ double lcl_GetExtent( const Style& rBorder, const Style& rSide, const Style& rOp
     double nCut = 0.0;
     basegfx::tools::findCut(
             aBasePoint, aBaseVector, aOtherPoint, aOtherVector,
-            CUTFLAG_ALL, &nCut );
+            CutFlagValue::ALL, &nCut );
 
     return nCut;
 }
 
-basegfx::B2DPoint lcl_PointToB2DPoint( const Point aPoint )
+basegfx::B2DPoint lcl_PointToB2DPoint( const Point& rPoint )
 {
-    return basegfx::B2DPoint( aPoint.getX(), aPoint.getY() );
+    return basegfx::B2DPoint(rPoint.getX(), rPoint.getY());
 }
 
 drawinglayer::primitive2d::Primitive2DSequence CreateClippedBorderPrimitives (
@@ -1495,7 +1488,7 @@ void DrawHorFrameBorder( OutputDevice& rDev,
     }
 }
 
-// ----------------------------------------------------------------------------
+
 
 void DrawVerFrameBorder( OutputDevice& rDev,
         const Point& rTPos, const Point& rBPos, const Style& rBorder,
@@ -1513,7 +1506,7 @@ void DrawVerFrameBorder( OutputDevice& rDev,
     }
 }
 
-// ============================================================================
+
 
 void DrawDiagFrameBorders(
         OutputDevice& rDev, const Rectangle& rRect, const Style& rTLBR, const Style& rBLTR,
@@ -1530,9 +1523,9 @@ void DrawDiagFrameBorders(
     }
 }
 
-// ============================================================================
 
-} // namespace frame
-} // namespace svx
+
+}
+}
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
