@@ -7,39 +7,60 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
+#include <com/sun/star/frame/XDispatchProvider.hpp>
+#include <com/sun/star/util/URL.hpp>
+#include <com/sun/star/util/URLTransformer.hpp>
+#include <comphelper/processfactory.hxx>
+#include <sfx2/sidebar/Theme.hxx>
 #include <svx/sidebar/PanelLayout.hxx>
 #include <vcl/layout.hxx>
 
-PanelLayout::PanelLayout(Window* pParent, const OString& rID, const OUString& rUIXMLDescription, const com::sun::star::uno::Reference<com::sun::star::frame::XFrame> &rFrame)
+using namespace sfx2::sidebar;
+
+PanelLayout::PanelLayout(vcl::Window* pParent, const OString& rID, const OUString& rUIXMLDescription, const com::sun::star::uno::Reference<com::sun::star::frame::XFrame> &rFrame)
     : Control(pParent)
     , m_bInClose(false)
 {
     SetStyle(GetStyle() | WB_DIALOGCONTROL);
     m_pUIBuilder = new VclBuilder(this, getUIRootDir(), rUIXMLDescription, rID, rFrame);
-    m_aPanelLayoutTimer.SetTimeout(50);
-    m_aPanelLayoutTimer.SetTimeoutHdl( LINK( this, PanelLayout, ImplHandlePanelLayoutTimerHdl ) );
+    m_aPanelLayoutIdle.SetPriority(SchedulerPriority::RESIZE);
+    m_aPanelLayoutIdle.SetIdleHdl( LINK( this, PanelLayout, ImplHandlePanelLayoutTimerHdl ) );
 }
 
 PanelLayout::~PanelLayout()
+{
+    disposeOnce();
+}
+
+void PanelLayout::dispose()
 {
     m_bInClose = true;
-    m_aPanelLayoutTimer.Stop();
+    m_aPanelLayoutIdle.Stop();
+    disposeBuilder();
+    Control::dispose();
 }
 
 Size PanelLayout::GetOptimalSize() const
 {
     if (isLayoutEnabled(this))
-        return VclContainer::getLayoutRequisition(*GetWindow(WINDOW_FIRSTCHILD));
+    {
+        Size aSize = VclContainer::getLayoutRequisition(*GetWindow(GetWindowType::FirstChild));
+        sal_Int32 nTabBarWidth = Theme::GetInteger(Theme::Int_TabItemWidth)
+            + Theme::GetInteger(Theme::Int_TabBarLeftPadding)
+            + Theme::GetInteger(Theme::Int_TabBarRightPadding);
+        aSize.Width() = std::min<long>(aSize.Width(), (400 - nTabBarWidth) * GetDPIScaleFactor());
+        return aSize;
+    }
 
     return Control::GetOptimalSize();
 }
 
 bool PanelLayout::hasPanelPendingLayout() const
 {
-    return m_aPanelLayoutTimer.IsActive();
+    return m_aPanelLayoutIdle.IsActive();
 }
 
-void PanelLayout::queue_resize()
+void PanelLayout::queue_resize(StateChangedType /*eReason*/)
 {
     if (m_bInClose)
         return;
@@ -47,24 +68,24 @@ void PanelLayout::queue_resize()
         return;
     if (!isLayoutEnabled(this))
         return;
-    m_aPanelLayoutTimer.Start();
+    InvalidateSizeCache();
+    m_aPanelLayoutIdle.Start();
 }
 
-IMPL_LINK( PanelLayout, ImplHandlePanelLayoutTimerHdl, void*, EMPTYARG )
+IMPL_LINK_NOARG_TYPED( PanelLayout, ImplHandlePanelLayoutTimerHdl, Idle*, void )
 {
-    Window *pChild = GetWindow(WINDOW_FIRSTCHILD);
+    vcl::Window *pChild = GetWindow(GetWindowType::FirstChild);
     assert(pChild);
     VclContainer::setLayoutAllocation(*pChild, Point(0, 0), GetSizePixel());
-    return 0;
 }
 
-void PanelLayout::setPosSizePixel(long nX, long nY, long nWidth, long nHeight, sal_uInt16 nFlags)
+void PanelLayout::setPosSizePixel(long nX, long nY, long nWidth, long nHeight, PosSizeFlags nFlags)
 {
     bool bCanHandleSmallerWidth = false;
     bool bCanHandleSmallerHeight = false;
 
     bool bIsLayoutEnabled = isLayoutEnabled(this);
-    Window *pChild = GetWindow(WINDOW_FIRSTCHILD);
+    vcl::Window *pChild = GetWindow(GetWindowType::FirstChild);
 
     if (bIsLayoutEnabled && pChild->GetType() == WINDOW_SCROLLWINDOW)
     {
@@ -83,7 +104,7 @@ void PanelLayout::setPosSizePixel(long nX, long nY, long nWidth, long nHeight, s
 
     Control::setPosSizePixel(nX, nY, nWidth, nHeight, nFlags);
 
-    if (bIsLayoutEnabled && (nFlags & WINDOW_POSSIZE_SIZE))
+    if (bIsLayoutEnabled && (nFlags & PosSizeFlags::Size))
         VclContainer::setLayoutAllocation(*pChild, Point(0, 0), Size(nWidth, nHeight));
 }
 
