@@ -17,6 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
+
+#include <memory>
+#include <utility>
 
 #include <accessiblecell.hxx>
 
@@ -28,12 +32,12 @@
 #include <vcl/svapp.hxx>
 
 #include <unotools/accessiblestatesethelper.hxx>
-
+#include <comphelper/string.hxx>
 #include <editeng/outlobj.hxx>
 #include <svx/unoshtxt.hxx>
 #include <svx/svdotext.hxx>
 
-using namespace ::sdr::table;
+using namespace sdr::table;
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::accessibility;
@@ -42,10 +46,6 @@ using namespace ::com::sun::star::container;
 
 namespace accessibility {
 
-// --------------------------------------------------------------------
-// AccessibleCell
-// --------------------------------------------------------------------
-
 AccessibleCell::AccessibleCell( const ::com::sun::star::uno::Reference< ::com::sun::star::accessibility::XAccessible>& rxParent, const sdr::table::CellRef& rCell, sal_Int32 nIndex, const AccessibleShapeTreeInfo& rShapeTreeInfo )
 : AccessibleCellBase( rxParent, AccessibleRole::TABLE_CELL )
 , maShapeTreeInfo( rShapeTreeInfo )
@@ -53,21 +53,23 @@ AccessibleCell::AccessibleCell( const ::com::sun::star::uno::Reference< ::com::s
 , mpText( NULL )
 , mxCell( rCell )
 {
+    //Init the pAccTable var
+    pAccTable = dynamic_cast <AccessibleTableShape *> (rxParent.get());
 }
 
-// --------------------------------------------------------------------
 
-AccessibleCell::~AccessibleCell (void)
+
+AccessibleCell::~AccessibleCell()
 {
     DBG_ASSERT( mpText == 0, "svx::AccessibleCell::~AccessibleCell(), not disposed!?" );
 }
 
-// --------------------------------------------------------------------
 
-void AccessibleCell::Init (void)
+
+void AccessibleCell::Init()
 {
     SdrView* pView = maShapeTreeInfo.GetSdrView();
-    const Window* pWindow = maShapeTreeInfo.GetWindow ();
+    const vcl::Window* pWindow = maShapeTreeInfo.GetWindow ();
     if( (pView != NULL) && (pWindow != NULL) && mxCell.is())
     {
         OutlinerParaObject* pOutlinerParaObject = mxCell->GetEditOutlinerParaObject(); // Get the OutlinerParaObject if text edit is active
@@ -81,10 +83,8 @@ void AccessibleCell::Init (void)
         if( pOutlinerParaObject )
         {
             // non-empty text -> use full-fledged edit source right away
-            SAL_WNODEPRECATED_DECLARATIONS_PUSH
-            ::std::auto_ptr<SvxEditSource> pEditSource( new SvxTextEditSource( mxCell->GetObject(), mxCell.get(), *pView, *pWindow) );
-            SAL_WNODEPRECATED_DECLARATIONS_POP
-            mpText = new AccessibleTextHelper( pEditSource );
+            ::std::unique_ptr<SvxEditSource> pEditSource( new SvxTextEditSource( mxCell->GetObject(), mxCell.get(), *pView, *pWindow) );
+            mpText = new AccessibleTextHelper( std::move(pEditSource) );
             mpText->SetEventSource(this);
         }
 
@@ -93,18 +93,18 @@ void AccessibleCell::Init (void)
     }
 }
 
-// --------------------------------------------------------------------
 
-sal_Bool AccessibleCell::SetState (sal_Int16 aState)
+
+bool AccessibleCell::SetState (sal_Int16 aState)
 {
-    sal_Bool bStateHasChanged = sal_False;
+    bool bStateHasChanged = false;
 
     if (aState == AccessibleStateType::FOCUSED && mpText != NULL)
     {
         // Offer FOCUSED state to edit engine and detect whether the state
         // changes.
-        sal_Bool bIsFocused = mpText->HaveFocus ();
-        mpText->SetFocus (sal_True);
+        bool bIsFocused = mpText->HaveFocus ();
+        mpText->SetFocus (true);
         bStateHasChanged = (bIsFocused != mpText->HaveFocus ());
     }
     else
@@ -113,18 +113,18 @@ sal_Bool AccessibleCell::SetState (sal_Int16 aState)
     return bStateHasChanged;
 }
 
-// --------------------------------------------------------------------
 
-sal_Bool AccessibleCell::ResetState (sal_Int16 aState)
+
+bool AccessibleCell::ResetState (sal_Int16 aState)
 {
-    sal_Bool bStateHasChanged = sal_False;
+    bool bStateHasChanged = false;
 
     if (aState == AccessibleStateType::FOCUSED && mpText != NULL)
     {
         // Try to remove FOCUSED state from the edit engine and detect
         // whether the state changes.
-        sal_Bool bIsFocused = mpText->HaveFocus ();
-        mpText->SetFocus (sal_False);
+        bool bIsFocused = mpText->HaveFocus ();
+        mpText->SetFocus (false);
         bStateHasChanged = (bIsFocused != mpText->HaveFocus ());
     }
     else
@@ -133,55 +133,55 @@ sal_Bool AccessibleCell::ResetState (sal_Int16 aState)
     return bStateHasChanged;
 }
 
-//-----------------------------------------------------------------------------
+
 
 bool AccessibleCell::operator== (const AccessibleCell& rAccessibleCell)
 {
     return this == &rAccessibleCell;
 }
 
-//-----------------------------------------------------------------------------
-// XInterface
-//-----------------------------------------------------------------------------
 
-Any SAL_CALL AccessibleCell::queryInterface( const Type& aType ) throw (RuntimeException)
+// XInterface
+
+
+Any SAL_CALL AccessibleCell::queryInterface( const Type& aType ) throw (RuntimeException, std::exception)
 {
     return AccessibleCellBase::queryInterface( aType );
 }
 
-//-----------------------------------------------------------------------------
+
 
 void SAL_CALL AccessibleCell::acquire(  ) throw ()
 {
     AccessibleCellBase::acquire();
 }
 
-//-----------------------------------------------------------------------------
+
 
 void SAL_CALL AccessibleCell::release(  ) throw ()
 {
     AccessibleCellBase::release();
 }
 
-// --------------------------------------------------------------------
+
 // XAccessibleContext
-// --------------------------------------------------------------------
+
 
 /** The children of this cell come from the paragraphs of text.
 */
-sal_Int32 SAL_CALL AccessibleCell::getAccessibleChildCount() throw (::com::sun::star::uno::RuntimeException)
+sal_Int32 SAL_CALL AccessibleCell::getAccessibleChildCount() throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aSolarGuard;
     ThrowIfDisposed ();
     return mpText != NULL ? mpText->GetChildCount () : 0;
 }
 
-// --------------------------------------------------------------------
+
 
 /** Forward the request to the shape.  Return the requested shape or throw
     an exception for a wrong index.
 */
-Reference<XAccessible> SAL_CALL AccessibleCell::getAccessibleChild (sal_Int32 nIndex) throw (IndexOutOfBoundsException, RuntimeException)
+Reference<XAccessible> SAL_CALL AccessibleCell::getAccessibleChild (sal_Int32 nIndex) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
 {
     SolarMutexGuard aSolarGuard;
     ThrowIfDisposed ();
@@ -190,7 +190,7 @@ Reference<XAccessible> SAL_CALL AccessibleCell::getAccessibleChild (sal_Int32 nI
     return mpText->GetChild (nIndex);
 }
 
-// --------------------------------------------------------------------
+
 
 /** Return a copy of the state set.
     Possible states are:
@@ -198,7 +198,7 @@ Reference<XAccessible> SAL_CALL AccessibleCell::getAccessibleChild (sal_Int32 nI
         SHOWING
         VISIBLE
 */
-Reference<XAccessibleStateSet> SAL_CALL AccessibleCell::getAccessibleStateSet (void) throw (RuntimeException)
+Reference<XAccessibleStateSet> SAL_CALL AccessibleCell::getAccessibleStateSet() throw (RuntimeException, std::exception)
 {
     SolarMutexGuard aSolarGuard;
     ::osl::MutexGuard aGuard (maMutex);
@@ -223,7 +223,39 @@ Reference<XAccessibleStateSet> SAL_CALL AccessibleCell::getAccessibleStateSet (v
                 else
                     pStateSet->RemoveState (AccessibleStateType::FOCUSED);
             }
+            // Set the invisible state for merged cell
+            if (mxCell.is() && mxCell->isMerged())
+                pStateSet->RemoveState(AccessibleStateType::VISIBLE);
+            else
+                pStateSet->AddState(AccessibleStateType::VISIBLE);
 
+
+            //Just when the parent table is not read-only,set states EDITABLE,RESIZABLE,MOVEABLE
+            ::com::sun::star::uno::Reference<XAccessible> xTempAcc = getAccessibleParent();
+            if( xTempAcc.is() )
+            {
+                ::com::sun::star::uno::Reference<XAccessibleContext>
+                                        xTempAccContext = xTempAcc->getAccessibleContext();
+                if( xTempAccContext.is() )
+                {
+                    ::com::sun::star::uno::Reference<XAccessibleStateSet> rState =
+                        xTempAccContext->getAccessibleStateSet();
+                    if( rState.is() )           {
+                        com::sun::star::uno::Sequence<short> pStates = rState->getStates();
+                        int count = pStates.getLength();
+                        for( int iIndex = 0;iIndex < count;iIndex++ )
+                        {
+                            if( pStates[iIndex] == AccessibleStateType::EDITABLE )
+                            {
+                                pStateSet->AddState (AccessibleStateType::EDITABLE);
+                                pStateSet->AddState (AccessibleStateType::RESIZABLE);
+                                pStateSet->AddState (AccessibleStateType::MOVEABLE);
+                                break;
+                            }
+                        }
+                    }
+                }
+            }
             // Create a copy of the state set that may be modified by the
             // caller without affecting the current state set.
             xStateSet = Reference<XAccessibleStateSet>(new ::utl::AccessibleStateSetHelper (*pStateSet));
@@ -233,11 +265,11 @@ Reference<XAccessibleStateSet> SAL_CALL AccessibleCell::getAccessibleStateSet (v
     return xStateSet;
 }
 
-// --------------------------------------------------------------------
-// XAccessibleComponent
-// --------------------------------------------------------------------
 
-sal_Bool SAL_CALL AccessibleCell::containsPoint( const ::com::sun::star::awt::Point& aPoint) throw (::com::sun::star::uno::RuntimeException)
+// XAccessibleComponent
+
+
+sal_Bool SAL_CALL AccessibleCell::containsPoint( const ::com::sun::star::awt::Point& aPoint) throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     return AccessibleComponentBase::containsPoint( aPoint );
 }
@@ -250,7 +282,7 @@ sal_Bool SAL_CALL AccessibleCell::containsPoint( const ::com::sun::star::awt::Po
     the already instantiated children and only if no match is found
     instantiate the remaining ones.
 */
-Reference<XAccessible > SAL_CALL  AccessibleCell::getAccessibleAtPoint ( const ::com::sun::star::awt::Point& aPoint) throw(RuntimeException)
+Reference<XAccessible > SAL_CALL  AccessibleCell::getAccessibleAtPoint ( const ::com::sun::star::awt::Point& aPoint) throw(RuntimeException, std::exception)
 {
     SolarMutexGuard aSolarGuard;
     ::osl::MutexGuard aGuard (maMutex);
@@ -279,9 +311,9 @@ Reference<XAccessible > SAL_CALL  AccessibleCell::getAccessibleAtPoint ( const :
     return uno::Reference<XAccessible>();
 }
 
-// --------------------------------------------------------------------
 
-::com::sun::star::awt::Rectangle SAL_CALL AccessibleCell::getBounds(void) throw(RuntimeException)
+
+::com::sun::star::awt::Rectangle SAL_CALL AccessibleCell::getBounds() throw(RuntimeException, std::exception)
 {
     SolarMutexGuard aSolarGuard;
     ::osl::MutexGuard aGuard (maMutex);
@@ -326,18 +358,18 @@ Reference<XAccessible > SAL_CALL  AccessibleCell::getAccessibleAtPoint ( const :
     return aBoundingBox;
 }
 
-// --------------------------------------------------------------------
 
-::com::sun::star::awt::Point SAL_CALL AccessibleCell::getLocation(void) throw (RuntimeException)
+
+::com::sun::star::awt::Point SAL_CALL AccessibleCell::getLocation() throw (RuntimeException, std::exception)
 {
     ThrowIfDisposed ();
     ::com::sun::star::awt::Rectangle aBoundingBox(getBounds());
     return ::com::sun::star::awt::Point(aBoundingBox.X, aBoundingBox.Y);
 }
 
-// --------------------------------------------------------------------
 
-::com::sun::star::awt::Point SAL_CALL AccessibleCell::getLocationOnScreen(void) throw(RuntimeException)
+
+::com::sun::star::awt::Point SAL_CALL AccessibleCell::getLocationOnScreen() throw(RuntimeException, std::exception)
 {
     ThrowIfDisposed ();
 
@@ -360,39 +392,39 @@ Reference<XAccessible > SAL_CALL  AccessibleCell::getAccessibleAtPoint ( const :
     return aLocation;
 }
 
-// --------------------------------------------------------------------
 
-awt::Size SAL_CALL AccessibleCell::getSize (void) throw (RuntimeException)
+
+awt::Size SAL_CALL AccessibleCell::getSize() throw (RuntimeException, std::exception)
 {
     ThrowIfDisposed ();
     awt::Rectangle aBoundingBox (getBounds());
     return awt::Size (aBoundingBox.Width, aBoundingBox.Height);
 }
 
-// --------------------------------------------------------------------
+
 
 void SAL_CALL AccessibleCell::addFocusListener ( const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XFocusListener >& xListener) throw (::com::sun::star::uno::RuntimeException)
 {
     AccessibleComponentBase::addFocusListener( xListener );
 }
 
-// --------------------------------------------------------------------
+
 
 void SAL_CALL AccessibleCell::removeFocusListener (const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XFocusListener >& xListener ) throw (::com::sun::star::uno::RuntimeException)
 {
     AccessibleComponentBase::removeFocusListener( xListener );
 }
 
-// --------------------------------------------------------------------
 
-void SAL_CALL AccessibleCell::grabFocus (void) throw (::com::sun::star::uno::RuntimeException)
+
+void SAL_CALL AccessibleCell::grabFocus() throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     AccessibleComponentBase::grabFocus();
 }
 
-// --------------------------------------------------------------------
 
-sal_Int32 SAL_CALL AccessibleCell::getForeground(void) throw (RuntimeException)
+
+sal_Int32 SAL_CALL AccessibleCell::getForeground() throw (RuntimeException, std::exception)
 {
     ThrowIfDisposed ();
     sal_Int32 nColor (0x0ffffffL);
@@ -401,9 +433,9 @@ sal_Int32 SAL_CALL AccessibleCell::getForeground(void) throw (RuntimeException)
     return nColor;
 }
 
-// --------------------------------------------------------------------
 
-sal_Int32 SAL_CALL AccessibleCell::getBackground (void) throw (RuntimeException)
+
+sal_Int32 SAL_CALL AccessibleCell::getBackground() throw (RuntimeException, std::exception)
 {
     ThrowIfDisposed ();
     sal_Int32 nColor (0L);
@@ -412,35 +444,35 @@ sal_Int32 SAL_CALL AccessibleCell::getBackground (void) throw (RuntimeException)
     return nColor;
 }
 
-// --------------------------------------------------------------------
-// XAccessibleExtendedComponent
-// --------------------------------------------------------------------
 
-::com::sun::star::uno::Reference< ::com::sun::star::awt::XFont > SAL_CALL AccessibleCell::getFont (void) throw (::com::sun::star::uno::RuntimeException)
+// XAccessibleExtendedComponent
+
+
+::com::sun::star::uno::Reference< ::com::sun::star::awt::XFont > SAL_CALL AccessibleCell::getFont() throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
 //todo
     return AccessibleComponentBase::getFont();
 }
 
-// --------------------------------------------------------------------
 
-OUString SAL_CALL AccessibleCell::getTitledBorderText (void) throw (::com::sun::star::uno::RuntimeException)
+
+OUString SAL_CALL AccessibleCell::getTitledBorderText() throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     return AccessibleComponentBase::getTitledBorderText();
 }
 
-// --------------------------------------------------------------------
 
-OUString SAL_CALL AccessibleCell::getToolTipText (void) throw (::com::sun::star::uno::RuntimeException)
+
+OUString SAL_CALL AccessibleCell::getToolTipText() throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     return AccessibleComponentBase::getToolTipText();
 }
 
-// --------------------------------------------------------------------
-// XAccessibleEventBroadcaster
-// --------------------------------------------------------------------
 
-void SAL_CALL AccessibleCell::addAccessibleEventListener( const Reference<XAccessibleEventListener >& rxListener)  throw (RuntimeException)
+// XAccessibleEventBroadcaster
+
+
+void SAL_CALL AccessibleCell::addAccessibleEventListener( const Reference<XAccessibleEventListener >& rxListener)  throw (RuntimeException, std::exception)
 {
     SolarMutexGuard aSolarGuard;
     ::osl::MutexGuard aGuard (maMutex);
@@ -458,9 +490,9 @@ void SAL_CALL AccessibleCell::addAccessibleEventListener( const Reference<XAcces
     }
 }
 
-// --------------------------------------------------------------------
 
-void SAL_CALL AccessibleCell::removeAccessibleEventListener( const Reference<XAccessibleEventListener >& rxListener) throw (RuntimeException)
+
+void SAL_CALL AccessibleCell::removeAccessibleEventListener( const Reference<XAccessibleEventListener >& rxListener) throw (RuntimeException, std::exception)
 {
     SolarMutexGuard aSolarGuard;
     AccessibleContextBase::removeAccessibleEventListener(rxListener);
@@ -468,18 +500,18 @@ void SAL_CALL AccessibleCell::removeAccessibleEventListener( const Reference<XAc
         mpText->RemoveEventListener (rxListener);
 }
 
-// --------------------------------------------------------------------
-// XServiceInfo
-// --------------------------------------------------------------------
 
-OUString SAL_CALL AccessibleCell::getImplementationName(void) throw (RuntimeException)
+// XServiceInfo
+
+
+OUString SAL_CALL AccessibleCell::getImplementationName() throw (RuntimeException, std::exception)
 {
     return OUString("AccessibleCell");
 }
 
-// --------------------------------------------------------------------
 
-Sequence<OUString> SAL_CALL AccessibleCell::getSupportedServiceNames(void) throw (RuntimeException)
+
+Sequence<OUString> SAL_CALL AccessibleCell::getSupportedServiceNames() throw (RuntimeException, std::exception)
 {
     ThrowIfDisposed ();
 
@@ -489,15 +521,14 @@ Sequence<OUString> SAL_CALL AccessibleCell::getSupportedServiceNames(void) throw
 
     // ...and add additional names.
     aServiceNames.realloc (nCount + 1);
-    static const OUString sAdditionalServiceName ("com.sun.star.drawing.AccessibleCell");
-    aServiceNames[nCount] = sAdditionalServiceName;
+    aServiceNames[nCount] = "com.sun.star.drawing.AccessibleCell";
 
     return aServiceNames;
 }
 
-// --------------------------------------------------------------------
+
 // IAccessibleViewForwarderListener
-// --------------------------------------------------------------------
+
 
 void AccessibleCell::ViewForwarderChanged (ChangeType /*aChangeType*/, const IAccessibleViewForwarder* /*pViewForwarder*/)
 {
@@ -510,16 +541,16 @@ void AccessibleCell::ViewForwarderChanged (ChangeType /*aChangeType*/, const IAc
         mpText->UpdateChildren();
 }
 
-// --------------------------------------------------------------------
-// protected
-// --------------------------------------------------------------------
 
-void AccessibleCell::disposing (void)
+// protected
+
+
+void AccessibleCell::disposing()
 {
     SolarMutexGuard aSolarGuard;
     ::osl::MutexGuard aGuard (maMutex);
 
-    // Make sure to send an event that this object looses the focus in the
+    // Make sure to send an event that this object loses the focus in the
     // case that it has the focus.
     ::utl::AccessibleStateSetHelper* pStateSet = static_cast< ::utl::AccessibleStateSetHelper*>(mxStateSet.get());
     if (pStateSet != NULL)
@@ -541,13 +572,81 @@ void AccessibleCell::disposing (void)
     AccessibleContextBase::dispose ();
 }
 
-sal_Int32 SAL_CALL AccessibleCell::getAccessibleIndexInParent (void) throw (RuntimeException)
+sal_Int32 SAL_CALL AccessibleCell::getAccessibleIndexInParent() throw (RuntimeException, std::exception)
 {
     ThrowIfDisposed ();
     return mnIndexInParent;
 }
 
-OUString SAL_CALL AccessibleCell::getAccessibleName (void) throw (::com::sun::star::uno::RuntimeException)
+
+OUString AccessibleCell::getCellName( sal_Int32 nCol, sal_Int32 nRow )
+{
+    OUStringBuffer aBuf;
+
+    if (nCol < 26*26)
+    {
+        if (nCol < 26)
+            aBuf.append( static_cast<sal_Unicode>( 'A' +
+                        static_cast<sal_uInt16>(nCol)));
+        else
+        {
+            aBuf.append( static_cast<sal_Unicode>( 'A' +
+                        (static_cast<sal_uInt16>(nCol) / 26) - 1));
+            aBuf.append( static_cast<sal_Unicode>( 'A' +
+                        (static_cast<sal_uInt16>(nCol) % 26)));
+        }
+    }
+    else
+    {
+        OUStringBuffer aStr;
+        while (nCol >= 26)
+        {
+            sal_Int32 nC = nCol % 26;
+            aStr.append(static_cast<sal_Unicode>( 'A' +
+                    static_cast<sal_uInt16>(nC)));
+            nCol = nCol - nC;
+            nCol = nCol / 26 - 1;
+        }
+        aStr.append(static_cast<sal_Unicode>( 'A' +
+                static_cast<sal_uInt16>(nCol)));
+        aBuf.append(comphelper::string::reverseString(aStr.makeStringAndClear()));
+    }
+    aBuf.append( OUString::number(nRow+1) );
+    return aBuf.makeStringAndClear();
+}
+
+OUString SAL_CALL AccessibleCell::getAccessibleName() throw (::com::sun::star::uno::RuntimeException, std::exception)
+{
+    ThrowIfDisposed ();
+    SolarMutexGuard aSolarGuard;
+
+    if( pAccTable )
+    {
+        try
+        {
+            sal_Int32 nRow = 0, nCol = 0;
+            pAccTable->getColumnAndRow(mnIndexInParent, nCol, nRow);
+            return getCellName( nCol, nRow );
+        }
+        catch(const Exception&)
+        {
+        }
+    }
+
+    return AccessibleCellBase::getAccessibleName();
+}
+
+void AccessibleCell::UpdateChildren()
+{
+    if (mpText)
+        mpText->UpdateChildren();
+}
+
+/* MT: Above getAccessibleName was introduced with IA2 CWS, while below was introduce in 3.3 meanwhile. Check which one is correct
++If this is correct, we also don't need  sdr::table::CellRef getCellRef(), UpdateChildren(), getCellName( sal_Int32 nCol, sal_Int32 nRow ) above
++
+
+OUString SAL_CALL AccessibleCell::getAccessibleName() throw (::com::sun::star::uno::RuntimeException)
 {
     ThrowIfDisposed ();
     SolarMutexGuard aSolarGuard;
@@ -557,6 +656,7 @@ OUString SAL_CALL AccessibleCell::getAccessibleName (void) throw (::com::sun::st
 
     return AccessibleCellBase::getAccessibleName();
 }
+*/
 
 } // end of namespace accessibility
 
