@@ -34,42 +34,35 @@
 #include <svx/itemwin.hxx>
 #include <svx/dialmgr.hxx>
 #include <svx/unoapi.hxx>
+#include <boost/scoped_ptr.hpp>
 
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::beans;
 using namespace ::com::sun::star::util;
 using namespace ::com::sun::star::frame;
 using namespace ::com::sun::star::lang;
+using namespace ::com::sun::star;
 
 // For End Line Controlleer
 #define MAX_LINES 12
 
-// STATIC DATA -----------------------------------------------------------
-
 SFX_IMPL_TOOLBOX_CONTROL( SvxLineStyleToolBoxControl, XLineStyleItem );
 SFX_IMPL_TOOLBOX_CONTROL( SvxLineWidthToolBoxControl, XLineWidthItem );
-SFX_IMPL_TOOLBOX_CONTROL( SvxLineColorToolBoxControl, XLineColorItem );
 SFX_IMPL_TOOLBOX_CONTROL( SvxLineEndToolBoxControl,   SfxBoolItem );
 
-/*************************************************************************
-|*
-|* SvxLineStyleToolBoxControl
-|*
-\************************************************************************/
-
 SvxLineStyleToolBoxControl::SvxLineStyleToolBoxControl( sal_uInt16 nSlotId,
                                                         sal_uInt16 nId,
                                                         ToolBox& rTbx ) :
     SfxToolBoxControl( nSlotId, nId, rTbx ),
     pStyleItem      ( NULL ),
     pDashItem       ( NULL ),
-    bUpdate         ( sal_False )
+    bUpdate         ( false )
 {
     addStatusListener( OUString( ".uno:LineDash" ));
     addStatusListener( OUString( ".uno:DashListState" ));
 }
 
-//========================================================================
+
 
 SvxLineStyleToolBoxControl::~SvxLineStyleToolBoxControl()
 {
@@ -77,17 +70,17 @@ SvxLineStyleToolBoxControl::~SvxLineStyleToolBoxControl()
     delete pDashItem;
 }
 
-//========================================================================
+
 
 void SvxLineStyleToolBoxControl::StateChanged (
 
     sal_uInt16 nSID, SfxItemState eState, const SfxPoolItem* pState )
 
 {
-    SvxLineBox* pBox = (SvxLineBox*)GetToolBox().GetItemWindow( GetId() );
+    SvxLineBox* pBox = static_cast<SvxLineBox*>( GetToolBox().GetItemWindow( GetId() ) );
     DBG_ASSERT( pBox, "Window not found!" );
 
-    if( eState == SFX_ITEM_DISABLED )
+    if( eState == SfxItemState::DISABLED )
     {
         pBox->Disable();
         pBox->SetNoSelection();
@@ -96,20 +89,20 @@ void SvxLineStyleToolBoxControl::StateChanged (
     {
         pBox->Enable();
 
-        if ( eState == SFX_ITEM_AVAILABLE )
+        if ( eState == SfxItemState::DEFAULT )
         {
             if( nSID == SID_ATTR_LINE_STYLE )
             {
                 delete pStyleItem;
-                pStyleItem = (XLineStyleItem*)pState->Clone();
+                pStyleItem = static_cast<XLineStyleItem*>(pState->Clone());
             }
             else if( nSID == SID_ATTR_LINE_DASH )
             {
                 delete pDashItem;
-                pDashItem = (XLineDashItem*)pState->Clone();
+                pDashItem = static_cast<XLineDashItem*>(pState->Clone());
             }
 
-            bUpdate = sal_True;
+            bUpdate = true;
             Update( pState );
         }
         else if ( nSID != SID_DASH_LIST )
@@ -120,15 +113,15 @@ void SvxLineStyleToolBoxControl::StateChanged (
     }
 }
 
-//========================================================================
+
 
 void SvxLineStyleToolBoxControl::Update( const SfxPoolItem* pState )
 {
     if ( pState && bUpdate )
     {
-        bUpdate = sal_False;
+        bUpdate = false;
 
-        SvxLineBox* pBox = (SvxLineBox*)GetToolBox().GetItemWindow( GetId() );
+        SvxLineBox* pBox = static_cast<SvxLineBox*>(GetToolBox().GetItemWindow( GetId() ));
         DBG_ASSERT( pBox, "Window not found!" );
 
         // Since the timer can strike unexpectedly, it may happen that
@@ -137,24 +130,24 @@ void SvxLineStyleToolBoxControl::Update( const SfxPoolItem* pState )
         if( pBox->GetEntryCount() == 0 )
             pBox->FillControl();
 
-        XLineStyle eXLS;
+        drawing::LineStyle eXLS;
 
         if ( pStyleItem )
-            eXLS = ( XLineStyle )pStyleItem->GetValue();
+            eXLS = ( drawing::LineStyle )pStyleItem->GetValue();
         else
-            eXLS = XLINE_NONE;
+            eXLS = drawing::LineStyle_NONE;
 
         switch( eXLS )
         {
-            case XLINE_NONE:
+            case drawing::LineStyle_NONE:
                 pBox->SelectEntryPos( 0 );
                 break;
 
-            case XLINE_SOLID:
+            case drawing::LineStyle_SOLID:
                 pBox->SelectEntryPos( 1 );
                 break;
 
-            case XLINE_DASH:
+            case drawing::LineStyle_DASH:
             {
                 if( pDashItem )
                 {
@@ -176,31 +169,25 @@ void SvxLineStyleToolBoxControl::Update( const SfxPoolItem* pState )
     if ( pState && ( pState->ISA( SvxDashListItem ) ) )
     {
         // The list of line styles has changed
-        SvxLineBox* pBox = (SvxLineBox*)GetToolBox().GetItemWindow( GetId() );
+        SvxLineBox* pBox = static_cast<SvxLineBox*>(GetToolBox().GetItemWindow( GetId() ));
         DBG_ASSERT( pBox, "Window not found!" );
 
         OUString aString( pBox->GetSelectEntry() );
         pBox->Clear();
         pBox->InsertEntry( SVX_RESSTR(RID_SVXSTR_INVISIBLE) );
         pBox->InsertEntry( SVX_RESSTR(RID_SVXSTR_SOLID) );
-        pBox->Fill( ((SvxDashListItem*)pState )->GetDashList() );
+        pBox->Fill( static_cast<const SvxDashListItem*>(pState)->GetDashList() );
         pBox->SelectEntry( aString );
     }
 }
 
-//========================================================================
 
-Window* SvxLineStyleToolBoxControl::CreateItemWindow( Window *pParent )
+
+VclPtr<vcl::Window> SvxLineStyleToolBoxControl::CreateItemWindow( vcl::Window *pParent )
 {
-    return new SvxLineBox( pParent, m_xFrame );
+    return VclPtr<SvxLineBox>::Create( pParent, m_xFrame ).get();
 }
 
-/*************************************************************************
-|*
-|* SvxLineWidthToolBoxControl
-|*
-\************************************************************************/
-
 SvxLineWidthToolBoxControl::SvxLineWidthToolBoxControl(
     sal_uInt16 nSlotId, sal_uInt16 nId, ToolBox& rTbx ) :
     SfxToolBoxControl( nSlotId, nId, rTbx )
@@ -208,19 +195,19 @@ SvxLineWidthToolBoxControl::SvxLineWidthToolBoxControl(
     addStatusListener( OUString( ".uno:MetricUnit" ));
 }
 
-//========================================================================
+
 
 SvxLineWidthToolBoxControl::~SvxLineWidthToolBoxControl()
 {
 }
 
-//========================================================================
+
 
 void SvxLineWidthToolBoxControl::StateChanged(
     sal_uInt16 nSID, SfxItemState eState, const SfxPoolItem* pState )
 {
-    SvxMetricField* pFld = (SvxMetricField*)
-                           GetToolBox().GetItemWindow( GetId() );
+    SvxMetricField* pFld = static_cast<SvxMetricField*>(
+                           GetToolBox().GetItemWindow( GetId() ));
     DBG_ASSERT( pFld, "Window not found" );
 
     if ( nSID == SID_ATTR_METRIC )
@@ -229,7 +216,7 @@ void SvxLineWidthToolBoxControl::StateChanged(
     }
     else
     {
-        if ( eState == SFX_ITEM_DISABLED )
+        if ( eState == SfxItemState::DISABLED )
         {
             pFld->Disable();
             pFld->SetText( "" );
@@ -238,7 +225,7 @@ void SvxLineWidthToolBoxControl::StateChanged(
         {
             pFld->Enable();
 
-            if ( eState == SFX_ITEM_AVAILABLE )
+            if ( eState == SfxItemState::DEFAULT )
             {
                 DBG_ASSERT( pState->ISA(XLineWidthItem), "wrong ItemType" );
 
@@ -247,7 +234,7 @@ void SvxLineWidthToolBoxControl::StateChanged(
                 SfxMapUnit eUnit = SFX_MAPUNIT_100TH_MM; // CD!!! GetCoreMetric();
                 pFld->SetCoreUnit( eUnit );
 
-                pFld->Update( (const XLineWidthItem*)pState );
+                pFld->Update( static_cast<const XLineWidthItem*>(pState) );
             }
             else
                 pFld->Update( NULL );
@@ -255,97 +242,13 @@ void SvxLineWidthToolBoxControl::StateChanged(
     }
 }
 
-//========================================================================
 
-Window* SvxLineWidthToolBoxControl::CreateItemWindow( Window *pParent )
+
+VclPtr<vcl::Window> SvxLineWidthToolBoxControl::CreateItemWindow( vcl::Window *pParent )
 {
-    return( new SvxMetricField( pParent, m_xFrame ) );
+    return VclPtr<SvxMetricField>::Create( pParent, m_xFrame ).get();
 }
 
-/*************************************************************************
-|*
-|* SvxLineColorToolBoxControl
-|*
-\************************************************************************/
-
-SvxLineColorToolBoxControl::SvxLineColorToolBoxControl(
-    sal_uInt16 nSlotId, sal_uInt16 nId, ToolBox& rTbx ) :
-    SfxToolBoxControl( nSlotId, nId, rTbx )
-{
-    addStatusListener( OUString( ".uno:ColorTableState" ));
-}
-
-//========================================================================
-
-SvxLineColorToolBoxControl::~SvxLineColorToolBoxControl()
-{
-}
-
-//========================================================================
-
-void SvxLineColorToolBoxControl::StateChanged(
-
-    sal_uInt16 nSID, SfxItemState eState, const SfxPoolItem* pState )
-
-{
-    SvxColorBox* pBox = (SvxColorBox*)GetToolBox().GetItemWindow( GetId() );
-    DBG_ASSERT( pBox, "Window not found" );
-
-    if ( nSID != SID_COLOR_TABLE )
-    {
-        if ( eState == SFX_ITEM_DISABLED )
-        {
-            pBox->Disable();
-            pBox->SetNoSelection();
-        }
-        else
-        {
-            pBox->Enable();
-
-            if ( eState == SFX_ITEM_AVAILABLE )
-            {
-                DBG_ASSERT( pState->ISA(XLineColorItem), "wrong ItemType" );
-                pBox->Update( (const XLineColorItem*) pState );
-            }
-            else
-                pBox->Update( NULL );
-        }
-    }
-    else
-        Update( pState );
-}
-
-//========================================================================
-
-void SvxLineColorToolBoxControl::Update( const SfxPoolItem* pState )
-{
-    if ( pState && ( pState->ISA( SvxColorListItem ) ) )
-    {
-        SvxColorBox* pBox = (SvxColorBox*)GetToolBox().GetItemWindow( GetId() );
-
-        DBG_ASSERT( pBox, "Window not found" );
-
-        // The list of colors (ColorTable) has changed:
-        ::Color aTmpColor( pBox->GetSelectEntryColor() );
-        pBox->Clear();
-        pBox->Fill( ( (SvxColorListItem*)pState )->GetColorList() );
-        pBox->SelectEntry( aTmpColor );
-    }
-}
-
-//========================================================================
-
-Window* SvxLineColorToolBoxControl::CreateItemWindow( Window *pParent )
-{
-    return new SvxColorBox( pParent, m_aCommandURL, m_xFrame );
-}
-
-/*************************************************************************
-|*
-|* SvxLineEndWindow
-|*
-\************************************************************************/
-
 SvxLineEndWindow::SvxLineEndWindow(
     sal_uInt16 nSlotId,
     const Reference< XFrame >& rFrame,
@@ -353,11 +256,11 @@ SvxLineEndWindow::SvxLineEndWindow(
     SfxPopupWindow( nSlotId,
                     rFrame,
                     WinBits( WB_STDPOPUP | WB_OWNERDRAWDECORATION ) ),
-    aLineEndSet     ( this, WinBits( WB_ITEMBORDER | WB_3DLOOK | WB_NO_DIRECTSELECT ) ),
+    aLineEndSet     ( VclPtr<ValueSet>::Create(this, WinBits( WB_ITEMBORDER | WB_3DLOOK | WB_NO_DIRECTSELECT )) ),
     nCols           ( 2 ),
     nLines          ( 12 ),
     nLineEndWidth   ( 400 ),
-    bPopupMode      ( sal_True ),
+    bPopupMode      ( true ),
     mbInResize      ( false ),
     mxFrame         ( rFrame )
 {
@@ -368,17 +271,17 @@ SvxLineEndWindow::SvxLineEndWindow(
 SvxLineEndWindow::SvxLineEndWindow(
     sal_uInt16 nSlotId,
     const Reference< XFrame >& rFrame,
-    Window* pParentWindow,
+    vcl::Window* pParentWindow,
     const OUString& rWndTitle ) :
     SfxPopupWindow( nSlotId,
                     rFrame,
                     pParentWindow,
                     WinBits( WB_STDPOPUP | WB_OWNERDRAWDECORATION ) ),
-    aLineEndSet     ( this, WinBits( WB_ITEMBORDER | WB_3DLOOK | WB_NO_DIRECTSELECT ) ),
+    aLineEndSet     ( VclPtr<ValueSet>::Create(this, WinBits( WB_ITEMBORDER | WB_3DLOOK | WB_NO_DIRECTSELECT ) )),
     nCols           ( 2 ),
     nLines          ( 12 ),
     nLineEndWidth   ( 400 ),
-    bPopupMode      ( sal_True ),
+    bPopupMode      ( true ),
     mbInResize      ( false ),
     mxFrame         ( rFrame )
 {
@@ -389,25 +292,24 @@ SvxLineEndWindow::SvxLineEndWindow(
 void SvxLineEndWindow::implInit()
 {
     SfxObjectShell*     pDocSh  = SfxObjectShell::Current();
-    const SfxPoolItem*  pItem   = NULL;
 
     SetHelpId( HID_POPUP_LINEEND );
-    aLineEndSet.SetHelpId( HID_POPUP_LINEEND_CTRL );
+    aLineEndSet->SetHelpId( HID_POPUP_LINEEND_CTRL );
 
     if ( pDocSh )
     {
-        pItem = pDocSh->GetItem( SID_LINEEND_LIST );
+        const SfxPoolItem*  pItem = pDocSh->GetItem( SID_LINEEND_LIST );
         if( pItem )
-            pLineEndList = ( (SvxLineEndListItem*) pItem )->GetLineEndList();
+            pLineEndList = static_cast<const SvxLineEndListItem*>( pItem )->GetLineEndList();
 
         pItem = pDocSh->GetItem( SID_ATTR_LINEEND_WIDTH_DEFAULT );
         if( pItem )
-            nLineEndWidth = ( (SfxUInt16Item*) pItem )->GetValue();
+            nLineEndWidth = static_cast<const SfxUInt16Item*>( pItem )->GetValue();
     }
     DBG_ASSERT( pLineEndList.is(), "LineEndList not found" );
 
-    aLineEndSet.SetSelectHdl( LINK( this, SvxLineEndWindow, SelectHdl ) );
-    aLineEndSet.SetColCount( nCols );
+    aLineEndSet->SetSelectHdl( LINK( this, SvxLineEndWindow, SelectHdl ) );
+    aLineEndSet->SetColCount( nCols );
 
     // ValueSet fill with entries of LineEndList
     FillValueSet();
@@ -415,45 +317,50 @@ void SvxLineEndWindow::implInit()
     AddStatusListener( OUString( ".uno:LineEndListState" ));
 
     //ChangeHelpId( HID_POPUP_LINEENDSTYLE );
-    aLineEndSet.Show();
+    aLineEndSet->Show();
 }
 
-SfxPopupWindow* SvxLineEndWindow::Clone() const
+VclPtr<SfxPopupWindow> SvxLineEndWindow::Clone() const
 {
-    return new SvxLineEndWindow( GetId(), mxFrame, GetText() );
+    return VclPtr<SvxLineEndWindow>::Create( GetId(), mxFrame, GetText() );
 }
 
-// -----------------------------------------------------------------------
+
 
 SvxLineEndWindow::~SvxLineEndWindow()
 {
+    disposeOnce();
 }
 
-// -----------------------------------------------------------------------
+void SvxLineEndWindow::dispose()
+{
+    aLineEndSet.disposeAndClear();
+    SfxPopupWindow::dispose();
+}
 
 IMPL_LINK_NOARG(SvxLineEndWindow, SelectHdl)
 {
-    XLineEndItem*           pLineEndItem = NULL;
-    XLineStartItem*         pLineStartItem = NULL;
-    sal_uInt16                  nId = aLineEndSet.GetSelectItemId();
+    boost::scoped_ptr<XLineEndItem> pLineEndItem;
+    boost::scoped_ptr<XLineStartItem> pLineStartItem;
+    sal_uInt16                  nId = aLineEndSet->GetSelectItemId();
 
     if( nId == 1 )
     {
-        pLineStartItem  = new XLineStartItem();
+        pLineStartItem.reset(new XLineStartItem());
     }
     else if( nId == 2 )
     {
-        pLineEndItem    = new XLineEndItem();
+        pLineEndItem.reset(new XLineEndItem());
     }
     else if( nId % 2 ) // beginning of line
     {
         XLineEndEntry* pEntry = pLineEndList->GetLineEnd( ( nId - 1 ) / 2 - 1 );
-        pLineStartItem  = new XLineStartItem( pEntry->GetName(), pEntry->GetLineEnd() );
+        pLineStartItem.reset(new XLineStartItem( pEntry->GetName(), pEntry->GetLineEnd() ));
     }
     else // end of line
     {
         XLineEndEntry* pEntry = pLineEndList->GetLineEnd( nId / 2 - 2 );
-        pLineEndItem    = new XLineEndItem( pEntry->GetName(), pEntry->GetLineEnd() );
+        pLineEndItem.reset(new XLineEndItem( pEntry->GetName(), pEntry->GetLineEnd() ));
     }
 
     if ( IsInPopupMode() )
@@ -478,26 +385,23 @@ IMPL_LINK_NOARG(SvxLineEndWindow, SelectHdl)
     /*  #i33380# DR 2004-09-03 Moved the following line above the Dispatch() call.
         This instance may be deleted in the meantime (i.e. when a dialog is opened
         while in Dispatch()), accessing members will crash in this case. */
-    aLineEndSet.SetNoSelection();
+    aLineEndSet->SetNoSelection();
 
     SfxToolBoxControl::Dispatch( Reference< XDispatchProvider >( mxFrame->getController(), UNO_QUERY ),
                                  OUString( ".uno:LineEndStyle" ),
                                  aArgs );
 
-    delete pLineEndItem;
-    delete pLineStartItem;
-
     return 0;
 }
 
-// -----------------------------------------------------------------------
+
 
 void SvxLineEndWindow::FillValueSet()
 {
     if( pLineEndList.is() )
     {
         XLineEndEntry*      pEntry  = NULL;
-        VirtualDevice       aVD;
+        ScopedVclPtrInstance< VirtualDevice > pVD;
 
         long nCount = pLineEndList->Count();
 
@@ -510,14 +414,14 @@ void SvxLineEndWindow::FillValueSet()
         OSL_ENSURE( !aBmp.IsEmpty(), "UI bitmap was not created" );
 
         aBmpSize = aBmp.GetSizePixel();
-        aVD.SetOutputSizePixel( aBmpSize, sal_False );
+        pVD->SetOutputSizePixel( aBmpSize, false );
         aBmpSize.Width() = aBmpSize.Width() / 2;
         Point aPt0( 0, 0 );
         Point aPt1( aBmpSize.Width(), 0 );
 
-        aVD.DrawBitmap( Point(), aBmp );
-        aLineEndSet.InsertItem(1, Image(aVD.GetBitmap(aPt0, aBmpSize)), pEntry->GetName());
-        aLineEndSet.InsertItem(2, Image(aVD.GetBitmap(aPt1, aBmpSize)), pEntry->GetName());
+        pVD->DrawBitmap( Point(), aBmp );
+        aLineEndSet->InsertItem(1, Image(pVD->GetBitmap(aPt0, aBmpSize)), pEntry->GetName());
+        aLineEndSet->InsertItem(2, Image(pVD->GetBitmap(aPt1, aBmpSize)), pEntry->GetName());
 
         delete pLineEndList->Remove( nCount );
 
@@ -528,20 +432,20 @@ void SvxLineEndWindow::FillValueSet()
             aBmp = pLineEndList->GetUiBitmap( i );
             OSL_ENSURE( !aBmp.IsEmpty(), "UI bitmap was not created" );
 
-            aVD.DrawBitmap( aPt0, aBmp );
-            aLineEndSet.InsertItem((sal_uInt16)((i+1L)*2L+1L),
-                    Image(aVD.GetBitmap(aPt0, aBmpSize)), pEntry->GetName());
-            aLineEndSet.InsertItem((sal_uInt16)((i+2L)*2L),
-                    Image(aVD.GetBitmap(aPt1, aBmpSize)), pEntry->GetName());
+            pVD->DrawBitmap( aPt0, aBmp );
+            aLineEndSet->InsertItem((sal_uInt16)((i+1L)*2L+1L),
+                    Image(pVD->GetBitmap(aPt0, aBmpSize)), pEntry->GetName());
+            aLineEndSet->InsertItem((sal_uInt16)((i+2L)*2L),
+                    Image(pVD->GetBitmap(aPt1, aBmpSize)), pEntry->GetName());
         }
         nLines = std::min( (sal_uInt16)(nCount + 1), (sal_uInt16) MAX_LINES );
-        aLineEndSet.SetLineCount( nLines );
+        aLineEndSet->SetLineCount( nLines );
 
         SetSize();
     }
 }
 
-// -----------------------------------------------------------------------
+
 
 void SvxLineEndWindow::Resize()
 {
@@ -552,33 +456,33 @@ void SvxLineEndWindow::Resize()
         mbInResize = true;
         if ( !IsRollUp() )
         {
-            aLineEndSet.SetColCount( nCols );
-            aLineEndSet.SetLineCount( nLines );
+            aLineEndSet->SetColCount( nCols );
+            aLineEndSet->SetLineCount( nLines );
 
             SetSize();
 
             Size aSize = GetOutputSizePixel();
             aSize.Width()  -= 4;
             aSize.Height() -= 4;
-            aLineEndSet.SetPosSizePixel( Point( 2, 2 ), aSize );
+            aLineEndSet->SetPosSizePixel( Point( 2, 2 ), aSize );
         }
         //SfxPopupWindow::Resize();
         mbInResize = false;
     }
 }
 
-// -----------------------------------------------------------------------
+
 
 void SvxLineEndWindow::Resizing( Size& rNewSize )
 {
     Size aBitmapSize = aBmpSize; // -> Member
-    aBitmapSize.Width()  += 6; //
-    aBitmapSize.Height() += 6; //
+    aBitmapSize.Width()  += 6;
+    aBitmapSize.Height() += 6;
 
-    Size aItemSize = aLineEndSet.CalcItemSizePixel( aBitmapSize );  // -> Member
+    Size aItemSize = aLineEndSet->CalcItemSizePixel( aBitmapSize );  // -> Member
     //Size aOldSize = GetOutputSizePixel(); // for width
 
-    sal_uInt16 nItemCount = aLineEndSet.GetItemCount(); // -> Member
+    sal_uInt16 nItemCount = aLineEndSet->GetItemCount(); // -> Member
 
     // identify columns
     long nItemW = aItemSize.Width();
@@ -614,21 +518,21 @@ void SvxLineEndWindow::Resizing( Size& rNewSize )
     rNewSize.Width() = nW;
     rNewSize.Height() = nH;
 }
-// -----------------------------------------------------------------------
+
 
 void SvxLineEndWindow::StartSelection()
 {
-    aLineEndSet.StartSelection();
+    aLineEndSet->StartSelection();
 }
 
-// -----------------------------------------------------------------------
 
-sal_Bool SvxLineEndWindow::Close()
+
+bool SvxLineEndWindow::Close()
 {
     return SfxPopupWindow::Close();
 }
 
-// -----------------------------------------------------------------------
+
 
 void SvxLineEndWindow::StateChanged(
     sal_uInt16 nSID, SfxItemState, const SfxPoolItem* pState )
@@ -638,10 +542,10 @@ void SvxLineEndWindow::StateChanged(
         // The list of line ends (LineEndList) has changed
         if ( pState && pState->ISA( SvxLineEndListItem ))
         {
-            pLineEndList = ((SvxLineEndListItem*)pState)->GetLineEndList();
+            pLineEndList = static_cast<const SvxLineEndListItem*>(pState)->GetLineEndList();
             DBG_ASSERT( pLineEndList.is(), "LineEndList not found" );
 
-            aLineEndSet.Clear();
+            aLineEndSet->Clear();
             FillValueSet();
 
             Size aSize = GetOutputSizePixel();
@@ -651,42 +555,42 @@ void SvxLineEndWindow::StateChanged(
     }
 }
 
-// -----------------------------------------------------------------------
+
 
 void SvxLineEndWindow::PopupModeEnd()
 {
     if ( IsVisible() )
     {
-        bPopupMode = sal_False;
+        bPopupMode = false;
         SetSize();
     }
     SfxPopupWindow::PopupModeEnd();
 }
 
-// -----------------------------------------------------------------------
+
 
 void SvxLineEndWindow::SetSize()
 {
     //if( !bPopupMode )
     if( !IsInPopupMode() )
     {
-        sal_uInt16 nItemCount = aLineEndSet.GetItemCount(); // -> Member
+        sal_uInt16 nItemCount = aLineEndSet->GetItemCount(); // -> Member
         sal_uInt16 nMaxLines  = nItemCount / nCols; // -> Member ?
         if( nItemCount % nCols )
             nMaxLines++;
 
-        WinBits nBits = aLineEndSet.GetStyle();
+        WinBits nBits = aLineEndSet->GetStyle();
         if ( nLines == nMaxLines )
             nBits &= ~WB_VSCROLL;
         else
             nBits |= WB_VSCROLL;
-        aLineEndSet.SetStyle( nBits );
+        aLineEndSet->SetStyle( nBits );
     }
 
     Size aSize( aBmpSize );
     aSize.Width()  += 6;
     aSize.Height() += 6;
-    aSize = aLineEndSet.CalcWindowSizePixel( aSize );
+    aSize = aLineEndSet->CalcWindowSizePixel( aSize );
     aSize.Width()  += 4;
     aSize.Height() += 4;
     SetOutputSizePixel( aSize );
@@ -695,64 +599,58 @@ void SvxLineEndWindow::SetSize()
     //SetMinOutputSizePixel( aSize );
 }
 
-void SvxLineEndWindow::GetFocus (void)
+void SvxLineEndWindow::GetFocus()
 {
     SfxPopupWindow::GetFocus();
     // Grab the focus to the line ends value set so that it can be controlled
     // with the keyboard.
-    aLineEndSet.GrabFocus();
+    aLineEndSet->GrabFocus();
 }
 
-/*************************************************************************
-|*
-|* SvxLineEndToolBoxControl
-|*
-\************************************************************************/
-
 SvxLineEndToolBoxControl::SvxLineEndToolBoxControl( sal_uInt16 nSlotId, sal_uInt16 nId, ToolBox &rTbx ) :
     SfxToolBoxControl( nSlotId, nId, rTbx )
 {
-    rTbx.SetItemBits( nId, TIB_DROPDOWNONLY | rTbx.GetItemBits( nId ) );
+    rTbx.SetItemBits( nId, ToolBoxItemBits::DROPDOWNONLY | rTbx.GetItemBits( nId ) );
     rTbx.Invalidate();
 }
 
-// -----------------------------------------------------------------------
+
 
 SvxLineEndToolBoxControl::~SvxLineEndToolBoxControl()
 {
 }
 
-// -----------------------------------------------------------------------
+
 
 SfxPopupWindowType SvxLineEndToolBoxControl::GetPopupWindowType() const
 {
-    return SFX_POPUPWINDOW_ONCLICK;
+    return SfxPopupWindowType::ONCLICK;
 }
 
-// -----------------------------------------------------------------------
 
-SfxPopupWindow* SvxLineEndToolBoxControl::CreatePopupWindow()
+
+VclPtr<SfxPopupWindow> SvxLineEndToolBoxControl::CreatePopupWindow()
 {
     SvxLineEndWindow* pLineEndWin =
-        new SvxLineEndWindow( GetId(), m_xFrame, &GetToolBox(), SVX_RESSTR( RID_SVXSTR_LINEEND ) );
+        VclPtr<SvxLineEndWindow>::Create( GetId(), m_xFrame, &GetToolBox(), SVX_RESSTR( RID_SVXSTR_LINEEND ) );
     pLineEndWin->StartPopupMode( &GetToolBox(),
-                                 FLOATWIN_POPUPMODE_GRABFOCUS |
-                                 FLOATWIN_POPUPMODE_ALLOWTEAROFF |
-                                 FLOATWIN_POPUPMODE_NOAPPFOCUSCLOSE );
+                                 FloatWinPopupFlags::GrabFocus |
+                                 FloatWinPopupFlags::AllowTearOff |
+                                 FloatWinPopupFlags::NoAppFocusClose );
     pLineEndWin->StartSelection();
     SetPopupWindow( pLineEndWin );
     return pLineEndWin;
 }
 
-// -----------------------------------------------------------------------
+
 
 void SvxLineEndToolBoxControl::StateChanged( sal_uInt16, SfxItemState eState, const SfxPoolItem* )
 {
     sal_uInt16 nId = GetId();
     ToolBox& rTbx = GetToolBox();
 
-    rTbx.EnableItem( nId, SFX_ITEM_DISABLED != eState );
-    rTbx.SetItemState( nId, ( SFX_ITEM_DONTCARE == eState ) ? STATE_DONTKNOW : STATE_NOCHECK );
+    rTbx.EnableItem( nId, SfxItemState::DISABLED != eState );
+    rTbx.SetItemState( nId, ( SfxItemState::DONTCARE == eState ) ? TRISTATE_INDET : TRISTATE_FALSE );
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
