@@ -22,7 +22,12 @@
 #include <comphelper/string.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/window.hxx>
+#include <svx/svdview.hxx>
+#include <svl/srchitem.hxx>
+#include <sfx2/sfxsids.hrc>
+#include <editeng/outliner.hxx>
 
+#include <wrtsh.hxx>
 #include <txatritr.hxx>
 #include <fldbas.hxx>
 #include <fmtfld.hxx>
@@ -31,6 +36,9 @@
 #include <swcrsr.hxx>
 #include <doc.hxx>
 #include <IDocumentUndoRedo.hxx>
+#include <IDocumentState.hxx>
+#include <IDocumentDrawModelAccess.hxx>
+#include <dcontact.hxx>
 #include <pamtyp.hxx>
 #include <ndtxt.hxx>
 #include <swundo.hxx>
@@ -43,18 +51,16 @@
 using namespace ::com::sun::star;
 using namespace util;
 
-OUString *ReplaceBackReferences( const SearchOptions& rSearchOpt, SwPaM* pPam );
-
 static OUString
-lcl_CleanStr(const SwTxtNode& rNd, sal_Int32 const nStart, sal_Int32& rEnd,
+lcl_CleanStr(const SwTextNode& rNd, sal_Int32 const nStart, sal_Int32& rEnd,
              std::vector<sal_Int32> &rArr, bool const bRemoveSoftHyphen)
 {
-    OUStringBuffer buf(rNd.GetTxt());
+    OUStringBuffer buf(rNd.GetText());
     rArr.clear();
 
     const SwpHints *pHts = rNd.GetpSwpHints();
 
-    sal_uInt16 n = 0;
+    size_t n = 0;
     sal_Int32 nSoftHyphen = nStart;
     sal_Int32 nHintStart = -1;
     bool bNewHint       = true;
@@ -66,13 +72,13 @@ lcl_CleanStr(const SwTxtNode& rNd, sal_Int32 const nStart, sal_Int32& rEnd,
     {
         if ( bNewHint )
             nHintStart = pHts && n < pHts->Count() ?
-                         *(*pHts)[n]->GetStart() :
+                         (*pHts)[n]->GetStart() :
                          -1;
 
         if ( bNewSoftHyphen )
         {
             nSoftHyphen = (bRemoveSoftHyphen)
-                    ?  rNd.GetTxt().indexOf(CHAR_SOFTHYPHEN, nSoftHyphen)
+                    ?  rNd.GetText().indexOf(CHAR_SOFTHYPHEN, nSoftHyphen)
                     : -1;
         }
 
@@ -110,7 +116,7 @@ lcl_CleanStr(const SwTxtNode& rNd, sal_Int32 const nStart, sal_Int32& rEnd,
 
         if ( bNewHint )
         {
-            const SwTxtAttr* pHt = (*pHts)[n];
+            const SwTextAttr* pHt = (*pHts)[n];
             if ( pHt->HasDummyChar() && (nStt >= nStart) )
             {
                 switch( pHt->Which() )
@@ -118,6 +124,7 @@ lcl_CleanStr(const SwTxtNode& rNd, sal_Int32 const nStart, sal_Int32& rEnd,
                 case RES_TXTATR_FLYCNT:
                 case RES_TXTATR_FTN:
                 case RES_TXTATR_FIELD:
+                case RES_TXTATR_ANNOTATION:
                 case RES_TXTATR_REFMARK:
                 case RES_TXTATR_TOXMARK:
                 case RES_TXTATR_META:
@@ -130,9 +137,10 @@ lcl_CleanStr(const SwTxtNode& rNd, sal_Int32 const nStart, sal_Int32& rEnd,
                         // simply removed if first. If at the end, we keep the
                         // replacement and remove afterwards all at a string's
                         // end (might be normal 0x7f).
-                        bool bEmpty = RES_TXTATR_FIELD != pHt->Which() ||
-                            (static_cast<SwTxtFld const*>(pHt)
-                                ->GetFmtFld().GetField()->ExpandField(true).isEmpty());
+                        const bool bEmpty =
+                            ( pHt->Which() != RES_TXTATR_FIELD
+                              && pHt->Which() != RES_TXTATR_ANNOTATION )
+                            || (static_txtattr_cast<SwTextField const*>(pHt)->GetFormatField().GetField()->ExpandField(true).isEmpty());;
                         if ( bEmpty && nStart == nAkt )
                         {
                             rArr.push_back( nAkt );
@@ -165,7 +173,7 @@ lcl_CleanStr(const SwTxtNode& rNd, sal_Int32 const nStart, sal_Int32& rEnd,
     }
     while ( true );
 
-    for( sal_uInt16 i = aReplaced.size(); i; )
+    for( std::vector<sal_Int32>::size_type i = aReplaced.size(); i; )
     {
         const sal_Int32 nTmp = aReplaced[ --i ];
         if (nTmp == buf.getLength() - 1)
@@ -180,17 +188,16 @@ lcl_CleanStr(const SwTxtNode& rNd, sal_Int32 const nStart, sal_Int32& rEnd,
 }
 
 // skip all non SwPostIts inside the array
-xub_StrLen GetPostIt(xub_StrLen aCount,const SwpHints *pHts)
+size_t GetPostIt(sal_Int32 aCount,const SwpHints *pHts)
 {
-    xub_StrLen aIndex = 0;
+    size_t aIndex = 0;
     while (aCount)
     {
-        for (sal_Int32 i = 0; i < pHts->Count(); i++ )
+        for (size_t i = 0; i < pHts->Count(); ++i )
         {
             aIndex++;
-            const SwTxtAttr* pTxtAttr = (*pHts)[i];
-            if ( (pTxtAttr->Which()==RES_TXTATR_FIELD)
-                 && (pTxtAttr->GetFmtFld().GetField()->Which()==RES_POSTITFLD))
+            const SwTextAttr* pTextAttr = (*pHts)[i];
+            if ( pTextAttr->Which() == RES_TXTATR_ANNOTATION )
             {
                 aCount--;
                 if (!aCount)
@@ -199,11 +206,10 @@ xub_StrLen GetPostIt(xub_StrLen aCount,const SwpHints *pHts)
         }
     }
     // throw away all following non postits
-    for( sal_Int32 i = aIndex; i < pHts->Count(); i++ )
+    for( size_t i = aIndex; i < pHts->Count(); ++i )
     {
-        const SwTxtAttr* pTxtAttr = (*pHts)[i];
-        if ( (pTxtAttr->Which()==RES_TXTATR_FIELD)
-             && (pTxtAttr->GetFmtFld().GetField()->Which()==RES_POSTITFLD))
+        const SwTextAttr* pTextAttr = (*pHts)[i];
+        if ( pTextAttr->Which() == RES_TXTATR_ANNOTATION )
             break;
         else
             aIndex++;
@@ -211,7 +217,7 @@ xub_StrLen GetPostIt(xub_StrLen aCount,const SwpHints *pHts)
     return aIndex;
 }
 
-bool SwPaM::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes , utl::TextSearch& rSTxt,
+bool SwPaM::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes , utl::TextSearch& rSText,
                   SwMoveFn fnMove, const SwPaM * pRegion,
                   bool bInReadOnly )
 {
@@ -221,42 +227,43 @@ bool SwPaM::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes , utl::Te
     SwPaM* pPam = MakeRegion( fnMove, pRegion );
     const bool bSrchForward = fnMove == fnMoveForward;
     SwNodeIndex& rNdIdx = pPam->GetPoint()->nNode;
-    SwIndex& rCntntIdx = pPam->GetPoint()->nContent;
+    SwIndex& rContentIdx = pPam->GetPoint()->nContent;
 
     // If bFound is true then the string was found and is between nStart and nEnd
     bool bFound = false;
     // start position in text or initial position
-    sal_Bool bFirst = sal_True;
-    SwCntntNode * pNode;
+    bool bFirst = true;
+    SwContentNode * pNode;
 
     const bool bRegSearch = SearchAlgorithms_REGEXP == rSearchOpt.algorithmType;
     const bool bChkEmptyPara = bRegSearch && 2 == rSearchOpt.searchString.getLength() &&
-                        ( rSearchOpt.searchString.equalsAscii( "^$" ) ||
-                          rSearchOpt.searchString.equalsAscii( "$^" ) );
-    const bool bChkParaEnd = bRegSearch && rSearchOpt.searchString.equalsAscii( "$" );
+                        ( rSearchOpt.searchString == "^$" ||
+                          rSearchOpt.searchString == "$^" );
+    const bool bChkParaEnd = bRegSearch && rSearchOpt.searchString == "$";
 
     // LanguageType eLastLang = 0;
     while( 0 != ( pNode = ::GetNode( *pPam, bFirst, fnMove, bInReadOnly ) ))
     {
-        if( pNode->IsTxtNode() )
+        if( pNode->IsTextNode() )
         {
-            sal_Int32 nTxtLen = static_cast<SwTxtNode*>(pNode)->GetTxt().getLength();
+            SwTextNode& rTextNode = *pNode->GetTextNode();
+            sal_Int32 nTextLen = rTextNode.GetText().getLength();
             sal_Int32 nEnd;
             if( rNdIdx == pPam->GetMark()->nNode )
                 nEnd = pPam->GetMark()->nContent.GetIndex();
             else
-                nEnd = bSrchForward ? nTxtLen : 0;
-            sal_Int32 nStart = rCntntIdx.GetIndex();
+                nEnd = bSrchForward ? nTextLen : 0;
+            sal_Int32 nStart = rContentIdx.GetIndex();
 
             /* #i80135# */
             // if there are SwPostItFields inside our current node text, we
             // split the text into separate pieces and search for text inside
             // the pieces as well as inside the fields
-            const SwpHints *pHts = ((SwTxtNode*)pNode)->GetpSwpHints();
+            const SwpHints *pHts = rTextNode.GetpSwpHints();
 
             // count PostItFields by looping over all fields
-            xub_StrLen aNumberPostits = 0;
-            xub_StrLen aIgnore = 0;
+            sal_Int32 aNumberPostits = 0;
+            sal_Int32 aIgnore = 0;
             if (pHts && bSearchInNotes)
             {
                 if (!bSrchForward)
@@ -264,13 +271,12 @@ bool SwPaM::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes , utl::Te
                     std::swap(nStart, nEnd);
                 }
 
-                for( sal_Int32 i = 0; i < pHts->Count(); i++ )
+                for( size_t i = 0; i < pHts->Count(); ++i )
                 {
-                    const SwTxtAttr* pTxtAttr = (*pHts)[i];
-                    if ( (pTxtAttr->Which()==RES_TXTATR_FIELD)
-                         && (pTxtAttr->GetFmtFld().GetField()->Which()==RES_POSTITFLD))
+                    const SwTextAttr* pTextAttr = (*pHts)[i];
+                    if ( pTextAttr->Which()==RES_TXTATR_ANNOTATION )
                     {
-                        const sal_Int32 aPos = *pTxtAttr->GetStart();
+                        const sal_Int32 aPos = pTextAttr->GetStart();
                         if ( (aPos >= nStart) && (aPos <= nEnd) )
                             aNumberPostits++;
                         else
@@ -289,10 +295,83 @@ bool SwPaM::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes , utl::Te
             }
 
             SwDocShell *const pDocShell = pNode->GetDoc()->GetDocShell();
-            SwViewShell *const pWrtShell = (pDocShell) ? (SwViewShell*)(pDocShell->GetWrtShell()) : 0;
+            SwWrtShell *const pWrtShell = (pDocShell) ? pDocShell->GetWrtShell() : 0;
             SwPostItMgr *const pPostItMgr = (pWrtShell) ? pWrtShell->GetPostItMgr() : 0;
 
-            xub_StrLen aStart = 0;
+            SvxSearchItem aSearchItem(SID_SEARCH_ITEM);
+            aSearchItem.SetSearchOptions(rSearchOpt);
+            aSearchItem.SetBackward(!bSrchForward);
+
+            // If there is an active text edit, then search there.
+            bool bEndedTextEdit = false;
+            SdrView* pSdrView = pWrtShell->GetDrawView();
+            if (pSdrView)
+            {
+                // If the edited object is not anchored to this node, then ignore it.
+                SdrObject* pObject = pSdrView->GetTextEditObject();
+                if (pObject)
+                {
+                    if (SwFrameFormat* pFrameFormat = FindFrameFormat(pObject))
+                    {
+                        const SwPosition* pPosition = pFrameFormat->GetAnchor().GetContentAnchor();
+                        if (!pPosition || pPosition->nNode.GetIndex() != pNode->GetIndex())
+                            pObject = 0;
+                    }
+                }
+
+                if (pObject)
+                {
+                    sal_uInt16 nResult = pSdrView->GetTextEditOutlinerView()->StartSearchAndReplace(aSearchItem);
+                    if (!nResult)
+                    {
+                        // If not found, end the text edit.
+                        pSdrView->SdrEndTextEdit();
+                        const Point aPoint(pSdrView->GetAllMarkedRect().TopLeft());
+                        pSdrView->UnmarkAll();
+                        pWrtShell->SetCursor(&aPoint, true);
+                        pWrtShell->Edit();
+                        bEndedTextEdit = true;
+                    }
+                    else
+                    {
+                        bFound = true;
+                        break;
+                    }
+                }
+            }
+
+            // If we just finished search in shape text, don't attept to do that again.
+            if (!bEndedTextEdit)
+            {
+                // If there are any shapes anchored to this node, search there.
+                SwPaM aPaM(pNode->GetDoc()->GetNodes().GetEndOfContent());
+                aPaM.GetPoint()->nNode = rTextNode;
+                aPaM.GetPoint()->nContent.Assign(aPaM.GetPoint()->nNode.GetNode().GetTextNode(), nStart);
+                aPaM.SetMark();
+                aPaM.GetMark()->nNode = rTextNode.GetIndex() + 1;
+                aPaM.GetMark()->nContent.Assign(aPaM.GetMark()->nNode.GetNode().GetTextNode(), 0);
+                if (pNode->GetDoc()->getIDocumentDrawModelAccess().Search(aPaM, aSearchItem) && pSdrView)
+                {
+                    if (SdrObject* pObject = pSdrView->GetTextEditObject())
+                    {
+                        if (SwFrameFormat* pFrameFormat = FindFrameFormat(pObject))
+                        {
+                            const SwPosition* pPosition = pFrameFormat->GetAnchor().GetContentAnchor();
+                            if (pPosition)
+                            {
+                                // Set search position to the shape's anchor point.
+                                *GetPoint() = *pPosition;
+                                GetPoint()->nContent.Assign(pPosition->nNode.GetNode().GetContentNode(), 0);
+                                SetMark();
+                                bFound = true;
+                                break;
+                            }
+                        }
+                    }
+                }
+            }
+
+            sal_Int32 aStart = 0;
             // do we need to finish a note?
             if (pPostItMgr && pPostItMgr->HasActiveSidebarWin())
             {
@@ -329,20 +408,20 @@ bool SwPaM::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes , utl::Te
                 {
                     if (bSrchForward)
                     {
-                        nStartInside = aLoop==0 ? nStart : *(*pHts)[GetPostIt(aLoop+aIgnore-1,pHts)]->GetStart()+1;
-                        nEndInside = aLoop==aNumberPostits ? nEnd : *(*pHts)[GetPostIt(aLoop+aIgnore,pHts)]->GetStart();
-                        nTxtLen = nEndInside - nStartInside;
+                        nStartInside = aLoop==0 ? nStart : (*pHts)[GetPostIt(aLoop+aIgnore-1,pHts)]->GetStart()+1;
+                        nEndInside = aLoop==aNumberPostits ? nEnd : (*pHts)[GetPostIt(aLoop+aIgnore,pHts)]->GetStart();
+                        nTextLen = nEndInside - nStartInside;
                     }
                     else
                     {
-                        nStartInside =  aLoop==aNumberPostits ? nStart : *(*pHts)[GetPostIt(aLoop+aIgnore,pHts)]->GetStart();
-                        nEndInside = aLoop==0 ? nEnd : *(*pHts)[GetPostIt(aLoop+aIgnore-1,pHts)]->GetStart()+1;
-                        nTxtLen = nStartInside - nEndInside;
+                        nStartInside =  aLoop==aNumberPostits ? nStart : (*pHts)[GetPostIt(aLoop+aIgnore,pHts)]->GetStart();
+                        nEndInside = aLoop==0 ? nEnd : (*pHts)[GetPostIt(aLoop+aIgnore-1,pHts)]->GetStart()+1;
+                        nTextLen = nStartInside - nEndInside;
                     }
                     // search inside the text between a note
-                    bFound = DoSearch( rSearchOpt, rSTxt, fnMove, bSrchForward,
+                    bFound = DoSearch( rSearchOpt, rSText, fnMove, bSrchForward,
                                        bRegSearch, bChkEmptyPara, bChkParaEnd,
-                                       nStartInside, nEndInside, nTxtLen, pNode,
+                                       nStartInside, nEndInside, nTextLen, pNode,
                                        pPam );
                     if ( bFound )
                         break;
@@ -351,8 +430,9 @@ bool SwPaM::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes , utl::Te
                         // we should now be right in front of a note, search inside
                         if ( (bSrchForward && (GetPostIt(aLoop + aIgnore,pHts) < pHts->Count()) ) || ( !bSrchForward && (aLoop!=0) ))
                         {
-                            const SwTxtAttr* pTxtAttr = bSrchForward ?  (*pHts)[GetPostIt(aLoop+aIgnore,pHts)] : (*pHts)[GetPostIt(aLoop+aIgnore-1,pHts)];
-                            if ( pPostItMgr && pPostItMgr->SearchReplace(((SwTxtFld*)pTxtAttr)->GetFmtFld(),rSearchOpt,bSrchForward) )
+                            const SwTextAttr* pTextAttr = bSrchForward ?  (*pHts)[GetPostIt(aLoop+aIgnore,pHts)] : (*pHts)[GetPostIt(aLoop+aIgnore-1,pHts)];
+                            if (pPostItMgr && pPostItMgr->SearchReplace(
+                                    static_txtattr_cast<SwTextField const*>(pTextAttr)->GetFormatField(),rSearchOpt,bSrchForward))
                             {
                                 bFound = true ;
                                 break;
@@ -366,9 +446,9 @@ bool SwPaM::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes , utl::Te
             {
                 // if there is no SwPostItField inside or searching inside notes
                 // is disabled, we search the whole length just like before
-                bFound = DoSearch( rSearchOpt, rSTxt, fnMove, bSrchForward,
+                bFound = DoSearch( rSearchOpt, rSText, fnMove, bSrchForward,
                                    bRegSearch, bChkEmptyPara, bChkParaEnd,
-                                   nStart, nEnd, nTxtLen, pNode, pPam );
+                                   nStart, nEnd, nTextLen, pNode, pPam );
             }
             if (bFound)
                 break;
@@ -378,10 +458,10 @@ bool SwPaM::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes , utl::Te
     return bFound;
 }
 
-bool SwPaM::DoSearch( const SearchOptions& rSearchOpt, utl::TextSearch& rSTxt,
+bool SwPaM::DoSearch( const SearchOptions& rSearchOpt, utl::TextSearch& rSText,
                       SwMoveFn fnMove, bool bSrchForward, bool bRegSearch,
                       bool bChkEmptyPara, bool bChkParaEnd,
-                      sal_Int32 &nStart, sal_Int32 &nEnd, sal_Int32 nTxtLen,
+                      sal_Int32 &nStart, sal_Int32 &nEnd, sal_Int32 nTextLen,
                       SwNode* pNode, SwPaM* pPam)
 {
     bool bFound = false;
@@ -413,10 +493,10 @@ bool SwPaM::DoSearch( const SearchOptions& rSearchOpt, utl::TextSearch& rSTxt,
     }
 
     if( bSrchForward )
-        sCleanStr = lcl_CleanStr(*static_cast<SwTxtNode*>(pNode), nStart, nEnd,
+        sCleanStr = lcl_CleanStr(*pNode->GetTextNode(), nStart, nEnd,
                         aFltArr, bRemoveSoftHyphens);
     else
-        sCleanStr = lcl_CleanStr(*static_cast<SwTxtNode*>(pNode), nEnd, nStart,
+        sCleanStr = lcl_CleanStr(*pNode->GetTextNode(), nEnd, nStart,
                         aFltArr, bRemoveSoftHyphens);
 
     SwScriptIterator* pScriptIter = 0;
@@ -445,7 +525,7 @@ bool SwPaM::DoSearch( const SearchOptions& rSearchOpt, utl::TextSearch& rSTxt,
             if ( nSearchScript == nCurrScript )
             {
                 const LanguageType eCurrLang =
-                        ((SwTxtNode*)pNode)->GetLang( bSrchForward ?
+                        pNode->GetTextNode()->GetLang( bSrchForward ?
                                                       nStart :
                                                       nEnd );
 
@@ -453,7 +533,7 @@ bool SwPaM::DoSearch( const SearchOptions& rSearchOpt, utl::TextSearch& rSTxt,
                 {
                     const lang::Locale aLocale(
                             g_pBreakIt->GetLocale( eCurrLang ) );
-                    rSTxt.SetLocale( rSearchOpt, aLocale );
+                    rSText.SetLocale( rSearchOpt, aLocale );
                     eLastLang = eCurrLang;
                 }
             }
@@ -462,11 +542,11 @@ bool SwPaM::DoSearch( const SearchOptions& rSearchOpt, utl::TextSearch& rSTxt,
         sal_Int32 nProxyStart = nStart;
         sal_Int32 nProxyEnd = nEnd;
         if( nSearchScript == nCurrScript &&
-                (rSTxt.*fnMove->fnSearch)( sCleanStr, &nProxyStart, &nProxyEnd, 0 ) &&
+                (rSText.*fnMove->fnSearch)( sCleanStr, &nProxyStart, &nProxyEnd, 0 ) &&
                 !(bZeroMatch = (nProxyStart == nProxyEnd)))
         {
-            nStart = (xub_StrLen)nProxyStart;
-            nEnd = (xub_StrLen)nProxyEnd;
+            nStart = nProxyStart;
+            nEnd = nProxyEnd;
             // set section correctly
             *GetPoint() = *pPam->GetPoint();
             SetMark();
@@ -505,8 +585,8 @@ bool SwPaM::DoSearch( const SearchOptions& rSearchOpt, utl::TextSearch& rSTxt,
         }
         else
         {
-            nStart = (sal_uInt16)nProxyStart;
-            nEnd = (sal_uInt16)nProxyEnd;
+            nStart = nProxyStart;
+            nEnd = nProxyEnd;
         }
         nStart = nEnd;
     }
@@ -515,16 +595,16 @@ bool SwPaM::DoSearch( const SearchOptions& rSearchOpt, utl::TextSearch& rSTxt,
 
     if ( bFound )
         return true;
-    else if( ( bChkEmptyPara && !nStart && !nTxtLen ) || bChkParaEnd)
+    else if( ( bChkEmptyPara && !nStart && !nTextLen ) || bChkParaEnd)
     {
         *GetPoint() = *pPam->GetPoint();
-        GetPoint()->nContent = bChkParaEnd ? nTxtLen : 0;
+        GetPoint()->nContent = bChkParaEnd ? nTextLen : 0;
         SetMark();
         /* FIXME: this condition does not work for !bSrchForward backward
          * search, it probably never did. (pSttNd != &rNdIdx.GetNode())
          * is never true in this case. */
         if( (bSrchForward || pSttNd != &rNdIdx.GetNode()) &&
-            Move( fnMoveForward, fnGoCntnt ) &&
+            Move( fnMoveForward, fnGoContent ) &&
             (!bSrchForward || pSttNd != &GetPoint()->nNode.GetNode()) &&
             1 == std::abs( (int)( GetPoint()->nNode.GetIndex() -
                              GetMark()->nNode.GetIndex()) ) )
@@ -543,15 +623,15 @@ struct SwFindParaText : public SwFindParas
 {
     const SearchOptions& rSearchOpt;
     SwCursor& rCursor;
-    utl::TextSearch aSTxt;
-    sal_Bool bReplace;
-    sal_Bool bSearchInNotes;
+    utl::TextSearch aSText;
+    bool bReplace;
+    bool bSearchInNotes;
 
-    SwFindParaText( const SearchOptions& rOpt, sal_Bool bSearchNotes, int bRepl, SwCursor& rCrsr )
-        : rSearchOpt( rOpt ), rCursor( rCrsr ), aSTxt( rOpt ), bReplace( 0 != bRepl ), bSearchInNotes( bSearchNotes )
+    SwFindParaText( const SearchOptions& rOpt, bool bSearchNotes, bool bRepl, SwCursor& rCrsr )
+        : rSearchOpt( rOpt ), rCursor( rCrsr ), aSText( rOpt ), bReplace( bRepl ), bSearchInNotes( bSearchNotes )
     {}
-    virtual int Find( SwPaM* , SwMoveFn , const SwPaM*, sal_Bool bInReadOnly );
-    virtual int IsReplaceMode() const;
+    virtual int Find( SwPaM* , SwMoveFn , const SwPaM*, bool bInReadOnly ) SAL_OVERRIDE;
+    virtual bool IsReplaceMode() const SAL_OVERRIDE;
     virtual ~SwFindParaText();
 };
 
@@ -560,12 +640,12 @@ SwFindParaText::~SwFindParaText()
 }
 
 int SwFindParaText::Find( SwPaM* pCrsr, SwMoveFn fnMove,
-                            const SwPaM* pRegion, sal_Bool bInReadOnly )
+                          const SwPaM* pRegion, bool bInReadOnly )
 {
     if( bInReadOnly && bReplace )
-        bInReadOnly = sal_False;
+        bInReadOnly = false;
 
-    const bool bFnd = pCrsr->Find( rSearchOpt, bSearchInNotes, aSTxt, fnMove, pRegion, bInReadOnly );
+    const bool bFnd = pCrsr->Find( rSearchOpt, bSearchInNotes, aSText, fnMove, pRegion, bInReadOnly );
 
     if( bFnd && bReplace ) // replace string
     {
@@ -573,50 +653,61 @@ int SwFindParaText::Find( SwPaM* pCrsr, SwMoveFn fnMove,
         const bool bRegExp(SearchAlgorithms_REGEXP == rSearchOpt.algorithmType);
         SwIndex& rSttCntIdx = pCrsr->Start()->nContent;
         const sal_Int32 nSttCnt = rSttCntIdx.GetIndex();
-        // add to shell-cursor-ring so that the regions will be moved enventually
-        Ring *pPrev(0);
+        // add to shell-cursor-ring so that the regions will be moved eventually
+        SwPaM* pPrev(nullptr);
         if( bRegExp )
         {
-            pPrev = pRegion->GetPrev();
-            ((Ring*)pRegion)->MoveRingTo( &rCursor );
+            pPrev = const_cast<SwPaM*>(pRegion)->GetPrev();
+            const_cast<SwPaM*>(pRegion)->GetRingContainer().merge( rCursor.GetRingContainer() );
         }
 
         boost::scoped_ptr<OUString> pRepl( (bRegExp)
                 ? ReplaceBackReferences( rSearchOpt, pCrsr ) : 0 );
-        rCursor.GetDoc()->ReplaceRange( *pCrsr,
-            (pRepl.get()) ? *pRepl : rSearchOpt.replaceString,
-            bRegExp );
-        rCursor.SaveTblBoxCntnt( pCrsr->GetPoint() );
+        bool const bReplaced =
+            rCursor.GetDoc()->getIDocumentContentOperations().ReplaceRange(
+                *pCrsr,
+                (pRepl.get()) ? *pRepl : rSearchOpt.replaceString,
+                bRegExp );
+        rCursor.SaveTableBoxContent( pCrsr->GetPoint() );
 
         if( bRegExp )
         {
             // and remove region again
-            Ring *p, *pNext = (Ring*)pRegion;
+            SwPaM* p;
+            SwPaM* pNext(const_cast<SwPaM*>(pRegion));
             do {
                 p = pNext;
                 pNext = p->GetNext();
-                p->MoveTo( (Ring*)pRegion );
+                p->MoveTo( const_cast<SwPaM*>(pRegion) );
             } while( p != pPrev );
         }
-        pCrsr->Start()->nContent = nSttCnt;
+        if (bRegExp && !bReplaced)
+        {   // fdo#80715 avoid infinite loop if join failed
+            bool bRet = ((fnMoveForward == fnMove) ? &GoNextPara : &GoPrevPara)
+                (*pCrsr, fnMove);
+            (void) bRet;
+            assert(bRet); // if join failed, next node must be SwTextNode
+        }
+        else
+            pCrsr->Start()->nContent = nSttCnt;
         return FIND_NO_RING;
     }
     return bFnd ? FIND_FOUND : FIND_NOT_FOUND;
 }
 
-int SwFindParaText::IsReplaceMode() const
+bool SwFindParaText::IsReplaceMode() const
 {
     return bReplace;
 }
 
-sal_uLong SwCursor::Find( const SearchOptions& rSearchOpt, sal_Bool bSearchInNotes,
+sal_uLong SwCursor::Find( const SearchOptions& rSearchOpt, bool bSearchInNotes,
                           SwDocPositions nStart, SwDocPositions nEnd,
-                          sal_Bool& bCancel, FindRanges eFndRngs, int bReplace )
+                          bool& bCancel, FindRanges eFndRngs, bool bReplace )
 {
     // switch off OLE-notifications
     SwDoc* pDoc = GetDoc();
-    Link aLnk( pDoc->GetOle2Link() );
-    pDoc->SetOle2Link( Link() );
+    Link<> aLnk( pDoc->GetOle2Link() );
+    pDoc->SetOle2Link( Link<>() );
 
     bool const bStartUndo = pDoc->GetIDocumentUndoRedo().DoesUndo() && bReplace;
     if (bStartUndo)
@@ -631,7 +722,7 @@ sal_uLong SwCursor::Find( const SearchOptions& rSearchOpt, sal_Bool bSearchInNot
     sal_uLong nRet = FindAll( aSwFindParaText, nStart, nEnd, eFndRngs, bCancel );
     pDoc->SetOle2Link( aLnk );
     if( nRet && bReplace )
-        pDoc->SetModified();
+        pDoc->getIDocumentState().SetModified();
 
     if (bStartUndo)
     {
@@ -648,18 +739,18 @@ OUString *ReplaceBackReferences( const SearchOptions& rSearchOpt, SwPaM* pPam )
     if( pPam && pPam->HasMark() &&
         SearchAlgorithms_REGEXP == rSearchOpt.algorithmType )
     {
-        const SwCntntNode* pTxtNode = pPam->GetCntntNode( sal_True );
-        if( pTxtNode && pTxtNode->IsTxtNode() && pTxtNode == pPam->GetCntntNode( sal_False ) )
+        const SwContentNode* pTextNode = pPam->GetContentNode( true );
+        if( pTextNode && pTextNode->IsTextNode() && pTextNode == pPam->GetContentNode( false ) )
         {
-            utl::TextSearch aSTxt( rSearchOpt );
-            const OUString& rStr = static_cast<const SwTxtNode*>(pTxtNode)->GetTxt();
+            utl::TextSearch aSText( rSearchOpt );
+            const OUString& rStr = pTextNode->GetTextNode()->GetText();
             sal_Int32 nStart = pPam->Start()->nContent.GetIndex();
             sal_Int32 nEnd = pPam->End()->nContent.GetIndex();
             SearchResult aResult;
-            if( aSTxt.SearchForward( rStr, &nStart, &nEnd, &aResult ) )
+            if( aSText.SearchForward( rStr, &nStart, &nEnd, &aResult ) )
             {
                 OUString aReplaceStr( rSearchOpt.replaceString );
-                aSTxt.ReplaceBackReferences( aReplaceStr, rStr, aResult );
+                aSText.ReplaceBackReferences( aReplaceStr, rStr, aResult );
                 pRet = new OUString( aReplaceStr );
             }
         }
