@@ -18,8 +18,10 @@
  */
 
 #include <hintids.hxx>
+#include <mdiexp.hxx>
 #include <tools/helpers.hxx>
 #include <tools/urlobj.hxx>
+#include <tools/fract.hxx>
 #include <svl/undo.hxx>
 #include <svl/fstathelper.hxx>
 #include <svtools/imap.hxx>
@@ -33,6 +35,8 @@
 #include <fmturl.hxx>
 #include <frmfmt.hxx>
 #include <doc.hxx>
+#include <IDocumentLinksAdministration.hxx>
+#include <IDocumentLayoutAccess.hxx>
 #include <frmatr.hxx>
 #include <grfatr.hxx>
 #include <swtypes.hxx>
@@ -56,52 +60,41 @@
 
 using namespace com::sun::star;
 
-SVX_DLLPUBLIC sal_uInt32 getCacheTimeInMs();
-
 SwGrfNode::SwGrfNode(
         const SwNodeIndex & rWhere,
         const OUString& rGrfName, const OUString& rFltName,
         const Graphic* pGraphic,
-        SwGrfFmtColl *pGrfColl,
+        SwGrfFormatColl *pGrfColl,
         SwAttrSet* pAutoAttr ) :
-    SwNoTxtNode( rWhere, ND_GRFNODE, pGrfColl, pAutoAttr ),
+    SwNoTextNode( rWhere, ND_GRFNODE, pGrfColl, pAutoAttr ),
     maGrfObj(),
     mpReplacementGraphic(0),
     // #i73788#
     mbLinkedInputStreamReady( false ),
-    mbIsStreamReadOnly( sal_False )
+    mbIsStreamReadOnly( false )
 {
-    maGrfObj.SetSwapStreamHdl( LINK(this, SwGrfNode, SwapGraphic), getCacheTimeInMs() );
-    bInSwapIn = bChgTwipSize = bChgTwipSizeFromPixel = bLoadLowResGrf =
-        bFrameInPaint = bScaleImageMap = sal_False;
+    maGrfObj.SetSwapStreamHdl( LINK(this, SwGrfNode, SwapGraphic) );
+    bInSwapIn = bChgTwipSize =
+        bFrameInPaint = bScaleImageMap = false;
 
-    bGrafikArrived = sal_True;
-
-    // fdo#50763 inline image has already been read into memory
-    if (rGrfName.startsWith("data:")) {
-        maGrfObj.SetGraphic( *pGraphic, rGrfName );
-    }
-    else {
-        ReRead(rGrfName,rFltName, pGraphic, 0, sal_False);
-    }
+    bGraphicArrived = true;
+    ReRead(rGrfName, rFltName, pGraphic, 0, false);
 }
 
 SwGrfNode::SwGrfNode( const SwNodeIndex & rWhere,
                           const GraphicObject& rGrfObj,
-                      SwGrfFmtColl *pGrfColl, SwAttrSet* pAutoAttr ) :
-    SwNoTxtNode( rWhere, ND_GRFNODE, pGrfColl, pAutoAttr ),
+                      SwGrfFormatColl *pGrfColl, SwAttrSet* pAutoAttr ) :
+    SwNoTextNode( rWhere, ND_GRFNODE, pGrfColl, pAutoAttr ),
     maGrfObj(rGrfObj),
     mpReplacementGraphic(0),
     // #i73788#
     mbLinkedInputStreamReady( false ),
-    mbIsStreamReadOnly( sal_False )
+    mbIsStreamReadOnly( false )
 {
-    maGrfObj.SetSwapStreamHdl( LINK(this, SwGrfNode, SwapGraphic), getCacheTimeInMs() );
-    if( rGrfObj.HasUserData() && rGrfObj.IsSwappedOut() )
-        maGrfObj.SetSwapState();
-    bInSwapIn = bChgTwipSize = bChgTwipSizeFromPixel= bLoadLowResGrf =
-        bFrameInPaint = bScaleImageMap = sal_False;
-    bGrafikArrived = sal_True;
+    maGrfObj.SetSwapStreamHdl( LINK(this, SwGrfNode, SwapGraphic) );
+    bInSwapIn = bChgTwipSize  =
+        bFrameInPaint = bScaleImageMap = false;
+    bGraphicArrived = true;
 }
 
 /** Create new SW/G reader.
@@ -112,43 +105,44 @@ SwGrfNode::SwGrfNode( const SwNodeIndex & rWhere,
  */
 SwGrfNode::SwGrfNode( const SwNodeIndex & rWhere,
                       const OUString& rGrfName, const OUString& rFltName,
-                      SwGrfFmtColl *pGrfColl,
+                      SwGrfFormatColl *pGrfColl,
                       SwAttrSet* pAutoAttr ) :
-    SwNoTxtNode( rWhere, ND_GRFNODE, pGrfColl, pAutoAttr ),
+    SwNoTextNode( rWhere, ND_GRFNODE, pGrfColl, pAutoAttr ),
     maGrfObj(),
     mpReplacementGraphic(0),
     // #i73788#
     mbLinkedInputStreamReady( false ),
-    mbIsStreamReadOnly( sal_False )
+    mbIsStreamReadOnly( false )
 {
-    maGrfObj.SetSwapStreamHdl( LINK(this, SwGrfNode, SwapGraphic), getCacheTimeInMs() );
+    maGrfObj.SetSwapStreamHdl( LINK(this, SwGrfNode, SwapGraphic) );
 
     Graphic aGrf; aGrf.SetDefaultType();
     maGrfObj.SetGraphic( aGrf, rGrfName );
 
-    bInSwapIn = bChgTwipSize = bChgTwipSizeFromPixel = bLoadLowResGrf =
-        bFrameInPaint = bScaleImageMap = sal_False;
-    bGrafikArrived = sal_True;
+    bInSwapIn = bChgTwipSize =
+        bFrameInPaint = bScaleImageMap = false;
+    bGraphicArrived = true;
 
     InsertLink( rGrfName, rFltName );
     if( IsLinkedFile() )
     {
         INetURLObject aUrl( rGrfName );
-        if( INET_PROT_FILE == aUrl.GetProtocol() &&
+        if( INetProtocol::File == aUrl.GetProtocol() &&
             FStatHelper::IsDocument( aUrl.GetMainURL( INetURLObject::NO_DECODE ) ))
         {
             // file exists, so create connection without an update
-            ((SwBaseLink*)&refLink)->Connect();
+            static_cast<SwBaseLink*>(&refLink)->Connect();
         }
     }
 }
 
-sal_Bool SwGrfNode::ReRead(
+bool SwGrfNode::ReRead(
     const OUString& rGrfName, const OUString& rFltName,
     const Graphic* pGraphic, const GraphicObject* pGrfObj,
-    sal_Bool bNewGrf )
+    bool bNewGrf )
 {
-    sal_Bool bReadGrf = sal_False, bSetTwipSize = sal_True;
+    bool bReadGrf = false;
+    bool bSetTwipSize = true;
     delete mpReplacementGraphic;
     mpReplacementGraphic = 0;
 
@@ -171,14 +165,14 @@ sal_Bool SwGrfNode::ReRead(
                     nNewType = OBJECT_CLIENT_DDE;
                 else
                 {
-                    sfx2::MakeLnkName( sCmd, 0, rGrfName, aEmptyOUStr, &rFltName );
+                    sfx2::MakeLnkName( sCmd, 0, rGrfName, OUString(), &rFltName );
                     nNewType = OBJECT_CLIENT_GRF;
                 }
 
                 if( nNewType != refLink->GetObjType() )
                 {
                     refLink->Disconnect();
-                    ((SwBaseLink*)&refLink)->SetObjType( nNewType );
+                    static_cast<SwBaseLink*>(&refLink)->SetObjType( nNewType );
                 }
             }
 
@@ -186,7 +180,7 @@ sal_Bool SwGrfNode::ReRead(
         }
         else // no name anymore, so remove link
         {
-            GetDoc()->GetLinkManager().Remove( refLink );
+            GetDoc()->getIDocumentLinksAdministration().GetLinkManager().Remove( refLink );
             refLink.Clear();
         }
 
@@ -194,16 +188,14 @@ sal_Bool SwGrfNode::ReRead(
         {
             maGrfObj.SetGraphic( *pGraphic, rGrfName );
             onGraphicChanged();
-            bReadGrf = sal_True;
+            bReadGrf = true;
         }
         else if( pGrfObj )
         {
             maGrfObj = *pGrfObj;
-            if( pGrfObj->HasUserData() && pGrfObj->IsSwappedOut() )
-                maGrfObj.SetSwapState();
             maGrfObj.SetLink( rGrfName );
             onGraphicChanged();
-            bReadGrf = sal_True;
+            bReadGrf = true;
         }
         else
         {
@@ -214,52 +206,38 @@ sal_Bool SwGrfNode::ReRead(
 
             if( refLink.Is() )
             {
-                if( getLayoutFrm( GetDoc()->GetCurrentLayout() ) )
+                if( getLayoutFrm( GetDoc()->getIDocumentLayoutAccess().GetCurrentLayout() ) )
                 {
                     SwMsgPoolItem aMsgHint( RES_GRF_REREAD_AND_INCACHE );
                     ModifyNotification( &aMsgHint, &aMsgHint );
                 }
-                // #i59688# - do not load linked graphic, if it isn't a new linked graphic.
                 else if ( bNewGrf )
                 {
                     //TODO refLink->setInputStream(getInputStream());
-                    ((SwBaseLink*)&refLink)->SwapIn();
+                    static_cast<SwBaseLink*>(&refLink)->SwapIn();
                 }
             }
             onGraphicChanged();
-            bSetTwipSize = sal_False;
+            bSetTwipSize = false;
         }
     }
     else if( pGraphic && rGrfName.isEmpty() )
     {
-        // Old stream must be deleted before the new one is set.
-        if( HasEmbeddedStreamName() )
-            DelStreamName();
-
         maGrfObj.SetGraphic( *pGraphic );
         onGraphicChanged();
-        bReadGrf = sal_True;
+        bReadGrf = true;
     }
     else if( pGrfObj && rGrfName.isEmpty() )
     {
-        // Old stream must be deleted before the new one is set.
-        if( HasEmbeddedStreamName() )
-            DelStreamName();
-
         maGrfObj = *pGrfObj;
         onGraphicChanged();
-        if( pGrfObj->HasUserData() && pGrfObj->IsSwappedOut() )
-            maGrfObj.SetSwapState();
-        bReadGrf = sal_True;
+        bReadGrf = true;
     }
     // Was the graphic already loaded?
     else if( !bNewGrf && GRAPHIC_NONE != maGrfObj.GetType() )
-        return sal_True;
+        return true;
     else
     {
-        if( HasEmbeddedStreamName() )
-            DelStreamName();
-
         // create new link for the graphic object
         InsertLink( rGrfName, rFltName );
 
@@ -269,30 +247,28 @@ sal_Bool SwGrfNode::ReRead(
             {
                 maGrfObj.SetGraphic( *pGraphic, rGrfName );
                 onGraphicChanged();
-                bReadGrf = sal_True;
+                bReadGrf = true;
                 // create connection without update, as we have the graphic
-                ((SwBaseLink*)&refLink)->Connect();
+                static_cast<SwBaseLink*>(&refLink)->Connect();
             }
             else if( pGrfObj )
             {
                 maGrfObj = *pGrfObj;
                 maGrfObj.SetLink( rGrfName );
                 onGraphicChanged();
-                bReadGrf = sal_True;
+                bReadGrf = true;
                 // create connection without update, as we have the graphic
-                ((SwBaseLink*)&refLink)->Connect();
+                static_cast<SwBaseLink*>(&refLink)->Connect();
             }
             else
             {
-                // reset data of the old graphic so that the correct placeholder is
-                // shown in case the new link could not be loaded
-                Graphic aGrf; aGrf.SetDefaultType();
+                Graphic aGrf;
+                aGrf.SetDefaultType();
                 maGrfObj.SetGraphic( aGrf, rGrfName );
                 onGraphicChanged();
-                // #i59688# - do not load linked graphic, if it isn't a new linked graphic.
                 if ( bNewGrf )
                 {
-                    ((SwBaseLink*)&refLink)->SwapIn();
+                    static_cast<SwBaseLink*>(&refLink)->SwapIn();
                 }
             }
         }
@@ -325,7 +301,7 @@ SwGrfNode::~SwGrfNode()
     if( refLink.Is() )
     {
         OSL_ENSURE( !bInSwapIn, "DTOR: I am still in SwapIn" );
-        pDoc->GetLinkManager().Remove( refLink );
+        pDoc->getIDocumentLinksAdministration().GetLinkManager().Remove( refLink );
         refLink->Disconnect();
     }
     else
@@ -341,22 +317,19 @@ SwGrfNode::~SwGrfNode()
         // inside one document has to be implemented.
     }
     //#39289# delete frames already here since the Frms' dtor needs the graphic for its StopAnimation
-    if( GetDepends() )
+    if( HasWriterListeners() )
         DelFrms();
 }
 
 /// allow reaction on change of content of GraphicObject
 void SwGrfNode::onGraphicChanged()
 {
-    if (GetGrfObj().IsSwappedOut()) // don't force swap-in for this
-        return;
-
-    // try to access SwFlyFrmFmt; since title/desc/name are set there, there is no
+    // try to access SwFlyFrameFormat; since title/desc/name are set there, there is no
     // use to continue if it is not yet set. If not yet set, call onGraphicChanged()
     // when it is set.
-    SwFlyFrmFmt* pFlyFmt = dynamic_cast< SwFlyFrmFmt* >(GetFlyFmt());
+    SwFlyFrameFormat* pFlyFormat = dynamic_cast< SwFlyFrameFormat* >(GetFlyFormat());
 
-    if(pFlyFmt)
+    if(pFlyFormat)
     {
         OUString aName;
         OUString aTitle;
@@ -389,6 +362,10 @@ void SwGrfNode::onGraphicChanged()
         {
             SetTitle(aTitle);
         }
+        else if (!aName.isEmpty())
+        {
+            SetTitle(aName);
+        }
 
         if(!aDesc.isEmpty())
         {
@@ -403,6 +380,18 @@ void SwGrfNode::SetGraphic(const Graphic& rGraphic, const OUString& rLink)
     onGraphicChanged();
 }
 
+const Graphic& SwGrfNode::GetGrf(bool bWait) const
+{
+    const_cast<SwGrfNode*>(this)->SwapIn(bWait);
+    return maGrfObj.GetGraphic();
+}
+
+const GraphicObject& SwGrfNode::GetGrfObj(bool bWait) const
+{
+    const_cast<SwGrfNode*>(this)->SwapIn(bWait);
+    return maGrfObj;
+}
+
 const GraphicObject* SwGrfNode::GetReplacementGrfObj() const
 {
     if(!mpReplacementGraphic)
@@ -418,7 +407,7 @@ const GraphicObject* SwGrfNode::GetReplacementGrfObj() const
     return mpReplacementGraphic;
 }
 
-SwCntntNode *SwGrfNode::SplitCntntNode( const SwPosition & )
+SwContentNode *SwGrfNode::SplitContentNode( const SwPosition & )
 {
     return this;
 }
@@ -427,9 +416,9 @@ SwGrfNode * SwNodes::MakeGrfNode( const SwNodeIndex & rWhere,
                                 const OUString& rGrfName,
                                 const OUString& rFltName,
                                 const Graphic* pGraphic,
-                                SwGrfFmtColl* pGrfColl,
+                                SwGrfFormatColl* pGrfColl,
                                 SwAttrSet* pAutoAttr,
-                                sal_Bool bDelayed )
+                                bool bDelayed )
 {
     OSL_ENSURE( pGrfColl, "MakeGrfNode: Formatpointer ist 0." );
     SwGrfNode *pNode;
@@ -445,7 +434,7 @@ SwGrfNode * SwNodes::MakeGrfNode( const SwNodeIndex & rWhere,
 
 SwGrfNode * SwNodes::MakeGrfNode( const SwNodeIndex & rWhere,
                                 const GraphicObject& rGrfObj,
-                                SwGrfFmtColl* pGrfColl,
+                                SwGrfFormatColl* pGrfColl,
                                 SwAttrSet* pAutoAttr )
 {
     OSL_ENSURE( pGrfColl, "MakeGrfNode: Formatpointer ist 0." );
@@ -454,10 +443,14 @@ SwGrfNode * SwNodes::MakeGrfNode( const SwNodeIndex & rWhere,
 
 Size SwGrfNode::GetTwipSize() const
 {
+    if( !nGrfSize.Width() && !nGrfSize.Height() )
+    {
+        const_cast<SwGrfNode*>(this)->SwapIn();
+    }
     return nGrfSize;
 }
 
-sal_Bool SwGrfNode::ImportGraphic( SvStream& rStrm )
+bool SwGrfNode::ImportGraphic( SvStream& rStrm )
 {
     Graphic aGraphic;
     const OUString aURL(maGrfObj.GetUserData());
@@ -468,12 +461,11 @@ sal_Bool SwGrfNode::ImportGraphic( SvStream& rStrm )
         mpReplacementGraphic = 0;
 
         maGrfObj.SetGraphic( aGraphic );
-        maGrfObj.SetUserData( aURL );
         onGraphicChanged();
-        return sal_True;
+        return true;
     }
 
-    return sal_False;
+    return false;
 }
 
 namespace
@@ -485,7 +477,7 @@ struct StreamAndStorageNames
     OUString sStorage;
 };
 
-StreamAndStorageNames lcl_GetStreamStorageNames( const OUString sUserData )
+StreamAndStorageNames lcl_GetStreamStorageNames( const OUString& sUserData )
 {
     StreamAndStorageNames aNames;
     if( sUserData.isEmpty() )
@@ -518,18 +510,17 @@ StreamAndStorageNames lcl_GetStreamStorageNames( const OUString sUserData )
 }
 
 /**
- * @return -1 if ReRead successful,
- *          1 if reading successful,
- *          0 if not loaded
+ * @return true if ReRead or reading successful,
+ *         false if not loaded
  */
-short SwGrfNode::SwapIn( sal_Bool bWaitForData )
+bool SwGrfNode::SwapIn( bool bWaitForData )
 {
     if( bInSwapIn ) // not recursively!
         return !maGrfObj.IsSwappedOut();
 
-    short nRet = 0;
-    bInSwapIn = sal_True;
-    SwBaseLink* pLink = (SwBaseLink*)(::sfx2::SvBaseLink*) refLink;
+    bool bRet = false;
+    bInSwapIn = true;
+    SwBaseLink* pLink = static_cast<SwBaseLink*>((::sfx2::SvBaseLink*) refLink);
 
     if( pLink )
     {
@@ -538,7 +529,9 @@ short SwGrfNode::SwapIn( sal_Bool bWaitForData )
         {
             // link was not loaded yet
             if( pLink->SwapIn( bWaitForData ) )
-                nRet = -1;
+            {
+                bRet = true;
+            }
             else if( GRAPHIC_DEFAULT == maGrfObj.GetType() )
             {
                 // no default bitmap anymore, thus re-paint
@@ -551,18 +544,21 @@ short SwGrfNode::SwapIn( sal_Bool bWaitForData )
                 ModifyNotification( &aMsgHint, &aMsgHint );
             }
         }
-        else if( maGrfObj.IsSwappedOut() ) {
+        else if( maGrfObj.IsSwappedOut() )
+        {
             // link to download
-            nRet = pLink->SwapIn( bWaitForData ) ? 1 : 0;
+            bRet = pLink->SwapIn( bWaitForData );
         }
         else
-            nRet = 1;
+            bRet = true;
     }
     else if( maGrfObj.IsSwappedOut() )
     {
         // graphic is in storage or in a temp file
         if( !HasEmbeddedStreamName() )
-            nRet = (short)maGrfObj.SwapIn();
+        {
+            bRet = maGrfObj.SwapIn();
+        }
         else
         {
             try
@@ -572,9 +568,12 @@ short SwGrfNode::SwapIn( sal_Bool bWaitForData )
                 SvStream* pStrm = _GetStreamForEmbedGrf( refPics, aNames.sStream );
                 if ( pStrm )
                 {
-                    if ( ImportGraphic( *pStrm ) )
-                        nRet = 1;
+                    bRet = ImportGraphic( *pStrm );
                     delete pStrm;
+                    if( bRet )
+                    {
+                        maGrfObj.SetUserData();
+                    }
                 }
             }
             catch (const uno::Exception&)
@@ -584,44 +583,43 @@ short SwGrfNode::SwapIn( sal_Bool bWaitForData )
             }
         }
 
-        if( 1 == nRet )
+        if( bRet )
         {
             SwMsgPoolItem aMsg( RES_GRAPHIC_SWAPIN );
             ModifyNotification( &aMsg, &aMsg );
         }
     }
     else
-        nRet = 1;
-    OSL_ENSURE( nRet, "Cannot swap in graphic" );
+        bRet = true;
+    OSL_ENSURE( bRet, "Cannot swap in graphic" );
 
-    if( nRet )
+    if( bRet )
     {
         if( !nGrfSize.Width() && !nGrfSize.Height() )
             SetTwipSize( ::GetGraphicSizeTwip( maGrfObj.GetGraphic(), 0 ) );
     }
-    bInSwapIn = sal_False;
-    return nRet;
+    bInSwapIn = false;
+    return bRet;
 }
 
-short SwGrfNode::SwapOut()
+bool SwGrfNode::SwapOut()
 {
     if( maGrfObj.GetType() != GRAPHIC_DEFAULT &&
         maGrfObj.GetType() != GRAPHIC_NONE &&
         !maGrfObj.IsSwappedOut() && !bInSwapIn )
     {
-        if( !refLink.Is() )
+        if( refLink.Is() )
         {
-            // Swapping is only needed for embedded pictures.
-            // The graphic will be written into a temp file if it is new, i.e.
-            // if there is no stream name in the storage yet
-            if( !HasEmbeddedStreamName() )
-                if( !maGrfObj.SwapOut() )
-                    return 0;
+            // written graphics and links are removed here
+            return maGrfObj.SwapOut( GRFMGR_AUTOSWAPSTREAM_LINK );
         }
-        // written graphics and links are removed here
-        return (short) maGrfObj.SwapOut( NULL );
+        else
+        {
+            return maGrfObj.SwapOut();
+        }
+
     }
-    return 1;
+    return true;
 }
 
 bool SwGrfNode::GetFileFilterNms( OUString* pFileNm, OUString* pFilterNm ) const
@@ -631,14 +629,14 @@ bool SwGrfNode::GetFileFilterNms( OUString* pFileNm, OUString* pFilterNm ) const
     {
         sal_uInt16 nType = refLink->GetObjType();
         if( OBJECT_CLIENT_GRF == nType )
-            bRet = refLink->GetLinkManager()->GetDisplayNames(
+            bRet = sfx2::LinkManager::GetDisplayNames(
                     refLink, 0, pFileNm, 0, pFilterNm );
         else if( OBJECT_CLIENT_DDE == nType && pFileNm && pFilterNm )
         {
             OUString sApp;
             OUString sTopic;
             OUString sItem;
-            if( refLink->GetLinkManager()->GetDisplayNames(
+            if( sfx2::LinkManager::GetDisplayNames(
                     refLink, &sApp, &sTopic, &sItem ) )
             {
                 *pFileNm = sApp + OUString(sfx2::cTokenSeparator)
@@ -656,18 +654,18 @@ bool SwGrfNode::GetFileFilterNms( OUString* pFileNm, OUString* pFilterNm ) const
  *
  * If it is already in storage, it needs to be loaded.
  */
-sal_Bool SwGrfNode::SavePersistentData()
+bool SwGrfNode::SavePersistentData()
 {
     if( refLink.Is() )
     {
         OSL_ENSURE( !bInSwapIn, "SavePersistentData: I am still in SwapIn" );
-        GetDoc()->GetLinkManager().Remove( refLink );
-        return sal_True;
+        GetDoc()->getIDocumentLinksAdministration().GetLinkManager().Remove( refLink );
+        return true;
     }
 
-    // swap in first if already in storage
+    // swap in first if in storage
     if( HasEmbeddedStreamName() && !SwapIn() )
-        return sal_False;
+        return false;
 
     // #i44367#
     // Do not delete graphic file in storage, because the graphic file could
@@ -681,10 +679,10 @@ sal_Bool SwGrfNode::SavePersistentData()
     // Important note: see also fix for #i40014#
 
     // swap out into temp file
-    return (sal_Bool) SwapOut();
+    return SwapOut();
 }
 
-sal_Bool SwGrfNode::RestorePersistentData()
+bool SwGrfNode::RestorePersistentData()
 {
     if( refLink.Is() )
     {
@@ -694,12 +692,12 @@ sal_Bool SwGrfNode::RestorePersistentData()
         if( getIDocumentLayoutAccess()->GetCurrentLayout() )
             refLink->Update();
     }
-    return sal_True;
+    return true;
 }
 
 void SwGrfNode::InsertLink( const OUString& rGrfName, const OUString& rFltName )
 {
-    refLink = new SwBaseLink( sfx2::LINKUPDATE_ONCALL, FORMAT_GDIMETAFILE, this );
+    refLink = new SwBaseLink( SfxLinkUpdateMode::ONCALL, SotClipboardFormatId::GDIMETAFILE, this );
 
     IDocumentLinksAdministration* pIDLA = getIDocumentLinksAdministration();
     if( GetNodes().IsDocNodes() )
@@ -717,9 +715,9 @@ void SwGrfNode::InsertLink( const OUString& rGrfName, const OUString& rFltName )
         }
         else
         {
-            sal_Bool bSync = rFltName == "SYNCHRON";
+            const bool bSync = rFltName == "SYNCHRON";
             refLink->SetSynchron( bSync );
-            refLink->SetContentType( SOT_FORMATSTR_ID_SVXB );
+            refLink->SetContentType( SotClipboardFormatId::SVXB );
 
             pIDLA->GetLinkManager().InsertFileLink( *refLink,
                                             OBJECT_CLIENT_GRF, rGrfName,
@@ -733,15 +731,51 @@ void SwGrfNode::ReleaseLink()
 {
     if( refLink.Is() )
     {
+        const OUString aFileName(maGrfObj.GetLink());
+        const Graphic aLocalGraphic(maGrfObj.GetGraphic());
+        const bool bHasOriginalData(aLocalGraphic.IsLink());
+
         {
-            bInSwapIn = sal_True;
-            SwBaseLink* pLink = (SwBaseLink*)(::sfx2::SvBaseLink*) refLink;
-            pLink->SwapIn( sal_True, sal_True );
-            bInSwapIn = sal_False;
+            bInSwapIn = true;
+            SwBaseLink* pLink = static_cast<SwBaseLink*>((::sfx2::SvBaseLink*) refLink);
+            pLink->SwapIn( true, true );
+            bInSwapIn = false;
         }
+
         getIDocumentLinksAdministration()->GetLinkManager().Remove( refLink );
         refLink.Clear();
         maGrfObj.SetLink();
+
+        // #i15508# added extra processing after getting rid of the link. Use whatever is
+        // known from the formally linked graphic to get to a state as close to a directly
+        // unlinked inserted graphic as possible. Goal is to have a valid GfxLink at the
+        // ImplGraphic (see there) that holds temporary data to the original data and type
+        // information about the original data. Only when this is given will
+        // SvXMLGraphicHelper::ImplInsertGraphicURL which is used at export use that type
+        // and use the original graphic at export for the ODF, without evtl. recoding
+        // of trhe bitmap graphic data to something without loss (e.g. PNG) but bigger
+        if(bHasOriginalData)
+        {
+            // #i15508# if we have the original data at the Graphic, let it survive
+            // by using that Graphic again, this time at a GraphicObject without link.
+            // This happens e.g. when inserting a linked graphic and breaking the link
+            maGrfObj.SetGraphic(aLocalGraphic);
+        }
+        else if(!aFileName.isEmpty())
+        {
+            // #i15508# we have no original data, but a file name. This happens e.g.
+            // when inserting a linked graphic and save, reload document. Try to access
+            // that data from the original file; if this works, use it. Else use the
+            // data we have (but without knowing the original format)
+            GraphicFilter& rFlt = GraphicFilter::GetGraphicFilter();
+            Graphic aNew;
+            int nRes = GraphicFilter::LoadGraphic( aFileName, OUString(), aNew, &rFlt);
+
+            if(GRFILTER_OK == nRes)
+            {
+                maGrfObj.SetGraphic(aNew);
+            }
+        }
     }
 }
 
@@ -754,7 +788,7 @@ void SwGrfNode::SetTwipSize( const Size& rSz )
         ScaleImageMap();
 
         // do not re-scale Image-Map
-        SetScaleImageMap( sal_False );
+        SetScaleImageMap( false );
     }
 }
 
@@ -764,12 +798,12 @@ void SwGrfNode::ScaleImageMap()
         return;
 
     // re-scale Image-Map
-    SwFrmFmt* pFmt = GetFlyFmt();
+    SwFrameFormat* pFormat = GetFlyFormat();
 
-    if( !pFmt )
+    if( !pFormat )
         return;
 
-    SwFmtURL aURL( pFmt->GetURL() );
+    SwFormatURL aURL( pFormat->GetURL() );
     if ( !aURL.GetMap() )
         return;
 
@@ -777,15 +811,15 @@ void SwGrfNode::ScaleImageMap()
     Fraction aScaleX( 1, 1 );
     Fraction aScaleY( 1, 1 );
 
-    const SwFmtFrmSize& rFrmSize = pFmt->GetFrmSize();
-    const SvxBoxItem& rBox = pFmt->GetBox();
+    const SwFormatFrmSize& rFrmSize = pFormat->GetFrmSize();
+    const SvxBoxItem& rBox = pFormat->GetBox();
 
     if( !rFrmSize.GetWidthPercent() )
     {
         SwTwips nWidth = rFrmSize.GetWidth();
 
-        nWidth -= rBox.CalcLineSpace(BOX_LINE_LEFT) +
-                  rBox.CalcLineSpace(BOX_LINE_RIGHT);
+        nWidth -= rBox.CalcLineSpace(SvxBoxItemLine::LEFT) +
+                  rBox.CalcLineSpace(SvxBoxItemLine::RIGHT);
 
         OSL_ENSURE( nWidth>0, "Do any 0 twip wide graphics exist!?" );
 
@@ -799,8 +833,8 @@ void SwGrfNode::ScaleImageMap()
     {
         SwTwips nHeight = rFrmSize.GetHeight();
 
-        nHeight -= rBox.CalcLineSpace(BOX_LINE_TOP) +
-                   rBox.CalcLineSpace(BOX_LINE_BOTTOM);
+        nHeight -= rBox.CalcLineSpace(SvxBoxItemLine::TOP) +
+                   rBox.CalcLineSpace(SvxBoxItemLine::BOTTOM);
 
         OSL_ENSURE( nHeight>0, "Do any 0 twip high graphics exist!?" );
 
@@ -814,37 +848,7 @@ void SwGrfNode::ScaleImageMap()
     if( bScale )
     {
         aURL.GetMap()->Scale( aScaleX, aScaleY );
-        pFmt->SetFmtAttr( aURL );
-    }
-}
-
-void SwGrfNode::DelStreamName()
-{
-    if( HasEmbeddedStreamName() )
-    {
-        // then remove graphic from storage
-        uno::Reference < embed::XStorage > xDocStg = GetDoc()->GetDocStorage();
-        if( xDocStg.is() )
-        {
-            try
-            {
-                const StreamAndStorageNames aNames = lcl_GetStreamStorageNames( maGrfObj.GetUserData() );
-                uno::Reference < embed::XStorage > refPics = xDocStg;
-                if ( !aNames.sStorage.isEmpty() )
-                    refPics = xDocStg->openStorageElement( aNames.sStorage, embed::ElementModes::READWRITE );
-                refPics->removeElement( aNames.sStream );
-                uno::Reference < embed::XTransactedObject > xTrans( refPics, uno::UNO_QUERY );
-                if ( xTrans.is() )
-                    xTrans->commit();
-            }
-            catch (const uno::Exception&)
-            {
-                // #i48434#
-                OSL_FAIL( "<SwGrfNode::DelStreamName()> - unhandled exception!" );
-            }
-        }
-
-        maGrfObj.SetUserData();
+        pFormat->SetFormatAttr( aURL );
     }
 }
 
@@ -922,55 +926,27 @@ SvStream* SwGrfNode::_GetStreamForEmbedGrf(
     return pStrm;
 }
 
-SwCntntNode* SwGrfNode::MakeCopy( SwDoc* pDoc, const SwNodeIndex& rIdx ) const
+SwContentNode* SwGrfNode::MakeCopy( SwDoc* pDoc, const SwNodeIndex& rIdx ) const
 {
     // copy formats into the other document
-    SwGrfFmtColl* pColl = pDoc->CopyGrfColl( *GetGrfColl() );
+    SwGrfFormatColl* pColl = pDoc->CopyGrfColl( *GetGrfColl() );
 
-    Graphic aTmpGrf;
-    SwBaseLink* pLink = (SwBaseLink*)(::sfx2::SvBaseLink*) refLink;
-    if( !pLink && HasEmbeddedStreamName() )
-    {
-        try
-        {
-            const StreamAndStorageNames aNames = lcl_GetStreamStorageNames( maGrfObj.GetUserData() );
-            uno::Reference < embed::XStorage > refPics = _GetDocSubstorageOrRoot( aNames.sStorage );
-            SvStream* pStrm = _GetStreamForEmbedGrf( refPics, aNames.sStream );
-            if ( pStrm )
-            {
-                const OUString aURL(maGrfObj.GetUserData());
-                GraphicFilter::GetGraphicFilter().ImportGraphic(aTmpGrf, aURL, *pStrm);
-                delete pStrm;
-            }
-        }
-        catch (const uno::Exception& e)
-        {
-            // #i48434#
-            SAL_WARN("sw.core", "<SwGrfNode::MakeCopy(..)> - unhandled exception!" << e.Message);
-        }
-    }
-    else
-    {
-        if( maGrfObj.IsSwappedOut() )
-            const_cast<SwGrfNode*>(this)->SwapIn();
-        aTmpGrf = maGrfObj.GetGraphic();
-    }
+    Graphic aTmpGrf = GetGrf();
 
-    const sfx2::LinkManager& rMgr = getIDocumentLinksAdministration()->GetLinkManager();
     OUString sFile, sFilter;
     if( IsLinkedFile() )
-        rMgr.GetDisplayNames( refLink, 0, &sFile, 0, &sFilter );
+        sfx2::LinkManager::GetDisplayNames( refLink, 0, &sFile, 0, &sFilter );
     else if( IsLinkedDDE() )
     {
         OUString sTmp1, sTmp2;
-        rMgr.GetDisplayNames( refLink, &sTmp1, &sTmp2, &sFilter );
+        sfx2::LinkManager::GetDisplayNames( refLink, &sTmp1, &sTmp2, &sFilter );
         sfx2::MakeLnkName( sFile, &sTmp1, sTmp2, sFilter );
         sFilter = "DDE";
     }
 
-    SwGrfNode* pGrfNd = pDoc->GetNodes().MakeGrfNode( rIdx, sFile, sFilter,
+    SwGrfNode* pGrfNd = SwNodes::MakeGrfNode( rIdx, sFile, sFilter,
                                                     &aTmpGrf, pColl,
-                                            (SwAttrSet*)GetpSwAttrSet() );
+                                            const_cast<SwAttrSet*>(GetpSwAttrSet()) );
     pGrfNd->SetTitle( GetTitle() );
     pGrfNd->SetDescription( GetDescription() );
     pGrfNd->SetContour( HasContour(), HasAutomaticContour() );
@@ -993,9 +969,9 @@ IMPL_LINK( SwGrfNode, SwapGraphic, GraphicObject*, pGrfObj )
             // then make it by your self
             if( !bInSwapIn )
             {
-                bool bIsModifyLocked = IsModifyLocked();
+                const bool bIsModifyLocked = IsModifyLocked();
                 LockModify();
-                SwapIn( sal_False );
+                SwapIn( false );
                 if( !bIsModifyLocked )
                     UnlockModify();
             }
@@ -1007,61 +983,9 @@ IMPL_LINK( SwGrfNode, SwapGraphic, GraphicObject*, pGrfObj )
     else
     {
         pRet = GRFMGR_AUTOSWAPSTREAM_TEMP;
-
-        if( HasEmbeddedStreamName() )
-        {
-            try
-            {
-                const StreamAndStorageNames aNames = lcl_GetStreamStorageNames( maGrfObj.GetUserData() );
-                uno::Reference < embed::XStorage > refPics = _GetDocSubstorageOrRoot( aNames.sStorage );
-                SvStream* pStrm = _GetStreamForEmbedGrf( refPics, aNames.sStream );
-                if ( pStrm )
-                {
-                    if( pGrfObj->IsInSwapOut() )
-                    {
-                        pRet = GRFMGR_AUTOSWAPSTREAM_LINK;
-                    }
-                    else
-                    {
-                        ImportGraphic( *pStrm );
-                        pRet = GRFMGR_AUTOSWAPSTREAM_LOADED;
-                    }
-                    delete pStrm;
-                }
-            }
-            catch (const uno::Exception&)
-            {
-                // #i48434#
-                OSL_FAIL( "<SwapGraphic> - unhandled exception!" );
-            }
-        }
     }
 
-    return (sal_IntPtr)pRet;
-}
-
-/// delete all QuickDraw-Bitmaps in the specified document
-void DelAllGrfCacheEntries( SwDoc* pDoc )
-{
-    if( pDoc )
-    {
-        // delete all Graphic-Links with this name from cache
-        const sfx2::LinkManager& rLnkMgr = pDoc->GetLinkManager();
-        const ::sfx2::SvBaseLinks& rLnks = rLnkMgr.GetLinks();
-        SwGrfNode* pGrfNd;
-        OUString sFileNm;
-        for( sal_uInt16 n = rLnks.size(); n; )
-        {
-            ::sfx2::SvBaseLink* pLnk = &(*rLnks[ --n ]);
-            if( pLnk && OBJECT_CLIENT_GRF == pLnk->GetObjType() &&
-                rLnkMgr.GetDisplayNames( pLnk, 0, &sFileNm ) &&
-                pLnk->ISA( SwBaseLink ) && 0 != ( pGrfNd =
-                ((SwBaseLink*)pLnk)->GetCntntNode()->GetGrfNode()) )
-            {
-                pGrfNd->ReleaseGraphicFromCache();
-            }
-        }
-    }
+    return reinterpret_cast<sal_IntPtr>(pRet);
 }
 
 /// returns the Graphic-Attr-Structure filled with our graphic attributes
@@ -1073,34 +997,46 @@ GraphicAttr& SwGrfNode::GetGraphicAttr( GraphicAttr& rGA,
     rGA.SetDrawMode( (GraphicDrawMode)rSet.GetDrawModeGrf().GetValue() );
 
     const SwMirrorGrf & rMirror = rSet.GetMirrorGrf();
-    sal_uLong nMirror = BMP_MIRROR_NONE;
+    BmpMirrorFlags nMirror = BmpMirrorFlags::NONE;
     if( rMirror.IsGrfToggle() && pFrm && !pFrm->FindPageFrm()->OnRightPage() )
     {
         switch( rMirror.GetValue() )
         {
-        case RES_MIRROR_GRAPH_DONT:     nMirror = BMP_MIRROR_HORZ; break;
-        case RES_MIRROR_GRAPH_VERT:     nMirror = BMP_MIRROR_NONE; break;
-        case RES_MIRROR_GRAPH_HOR:  nMirror = BMP_MIRROR_HORZ|BMP_MIRROR_VERT;
-                                    break;
-        default:                    nMirror = BMP_MIRROR_VERT; break;
+        case RES_MIRROR_GRAPH_DONT:
+            nMirror = BmpMirrorFlags::Horizontal;
+            break;
+        case RES_MIRROR_GRAPH_VERT:
+            nMirror = BmpMirrorFlags::NONE;
+            break;
+        case RES_MIRROR_GRAPH_HOR:
+            nMirror = BmpMirrorFlags::Horizontal|BmpMirrorFlags::Vertical;
+            break;
+        default:
+            nMirror = BmpMirrorFlags::Vertical;
+            break;
         }
     }
     else
         switch( rMirror.GetValue() )
         {
-        case RES_MIRROR_GRAPH_BOTH:     nMirror = BMP_MIRROR_HORZ|BMP_MIRROR_VERT;
-                                    break;
-        case RES_MIRROR_GRAPH_VERT: nMirror = BMP_MIRROR_HORZ; break;
-        case RES_MIRROR_GRAPH_HOR:  nMirror = BMP_MIRROR_VERT; break;
+        case RES_MIRROR_GRAPH_BOTH:
+            nMirror = BmpMirrorFlags::Horizontal|BmpMirrorFlags::Vertical;
+            break;
+        case RES_MIRROR_GRAPH_VERT:
+            nMirror = BmpMirrorFlags::Horizontal;
+            break;
+        case RES_MIRROR_GRAPH_HOR:
+            nMirror = BmpMirrorFlags::Vertical;
+            break;
         }
 
     rGA.SetMirrorFlags( nMirror );
 
     const SwCropGrf& rCrop = rSet.GetCropGrf();
-    rGA.SetCrop( TWIP_TO_MM100( rCrop.GetLeft() ),
-                 TWIP_TO_MM100( rCrop.GetTop() ),
-                 TWIP_TO_MM100( rCrop.GetRight() ),
-                 TWIP_TO_MM100( rCrop.GetBottom() ));
+    rGA.SetCrop( convertTwipToMm100( rCrop.GetLeft() ),
+                 convertTwipToMm100( rCrop.GetTop() ),
+                 convertTwipToMm100( rCrop.GetRight() ),
+                 convertTwipToMm100( rCrop.GetBottom() ));
 
     const SwRotationGrf& rRotation = rSet.GetRotationGrf();
     rGA.SetRotation( rRotation.GetValue() );
@@ -1120,42 +1056,32 @@ GraphicAttr& SwGrfNode::GetGraphicAttr( GraphicAttr& rGA,
     return rGA;
 }
 
-sal_Bool SwGrfNode::IsTransparent() const
+bool SwGrfNode::IsTransparent() const
 {
-    sal_Bool bRet = maGrfObj.IsTransparent();
-    if( !bRet ) // ask the attribut
-        bRet = 0 != GetSwAttrSet().GetTransparencyGrf().GetValue();
-
-    return bRet;
+    return maGrfObj.IsTransparent() ||
+        GetSwAttrSet().GetTransparencyGrf().GetValue() != 0;
 }
 
-sal_Bool SwGrfNode::IsSelected() const
+bool SwGrfNode::IsSelected() const
 {
-    sal_Bool bRet = sal_False;
+    bool bRet = false;
     const SwEditShell* pESh = GetDoc()->GetEditShell();
     if( pESh )
     {
         const SwNode* pN = this;
-        const SwViewShell* pV = pESh;
-        do {
-            if( pV->ISA( SwEditShell ) && pN == &((SwCrsrShell*)pV)
+        for(const SwViewShell& rCurrentShell : pESh->GetRingContainer())
+        {
+            if( rCurrentShell.ISA( SwEditShell ) && pN == &static_cast<const SwCrsrShell*>(&rCurrentShell)
                                 ->GetCrsr()->GetPoint()->nNode.GetNode() )
             {
-                bRet = sal_True;
+                bRet = true;
                 break;
             }
         }
-        while( pESh != ( pV = (SwViewShell*)pV->GetNext() ));
     }
     return bRet;
 }
 
-// #i73788#
-boost::weak_ptr< SwAsyncRetrieveInputStreamThreadConsumer > SwGrfNode::GetThreadConsumer()
-{
-    return mpThreadConsumer;
-}
-
 void SwGrfNode::TriggerAsyncRetrieveInputStream()
 {
     if ( !IsLinkedFile() )
@@ -1169,7 +1095,7 @@ void SwGrfNode::TriggerAsyncRetrieveInputStream()
         mpThreadConsumer.reset( new SwAsyncRetrieveInputStreamThreadConsumer( *this ) );
 
         OUString sGrfNm;
-        refLink->GetLinkManager()->GetDisplayNames( refLink, 0, &sGrfNm, 0, 0 );
+        sfx2::LinkManager::GetDisplayNames( refLink, 0, &sGrfNm, 0, 0 );
         OUString sReferer;
         SfxObjectShell * sh = GetDoc()->GetPersist();
         if (sh != 0 && sh->HasName())
@@ -1180,14 +1106,10 @@ void SwGrfNode::TriggerAsyncRetrieveInputStream()
     }
 }
 
-bool SwGrfNode::IsLinkedInputStreamReady() const
-{
-    return mbLinkedInputStreamReady;
-}
 
 void SwGrfNode::ApplyInputStream(
     com::sun::star::uno::Reference<com::sun::star::io::XInputStream> xInputStream,
-    const sal_Bool bIsStreamReadOnly )
+    const bool bIsStreamReadOnly )
 {
     if ( IsLinkedFile() )
     {
@@ -1228,7 +1150,7 @@ bool SwGrfNode::IsAsyncRetrieveInputStreamPossible() const
     if ( IsLinkedFile() )
     {
         OUString sGrfNm;
-        refLink->GetLinkManager()->GetDisplayNames( refLink, 0, &sGrfNm, 0, 0 );
+        sfx2::LinkManager::GetDisplayNames( refLink, 0, &sGrfNm, 0, 0 );
         if ( !sGrfNm.startsWith( "vnd.sun.star.pkg:" ) )
         {
             bRet = true;
