@@ -19,37 +19,29 @@
 
 #include <svx/svdmodel.hxx>
 #include <svx/svdpage.hxx>
-#include <fmtfordr.hxx>
+#include <drawdoc.hxx>
 #include <fmtpdsc.hxx>
-#include <frmfmt.hxx>
 #include <swtable.hxx>
 #include <rootfrm.hxx>
 #include <pagefrm.hxx>
-#include <cntfrm.hxx>
-#include <viewsh.hxx>
-#include <doc.hxx>
-#include <node.hxx>
 #include <dflyobj.hxx>
 #include <frmtool.hxx>
 #include <virtoutp.hxx>
 #include <blink.hxx>
-#include <ndindex.hxx>
 #include <sectfrm.hxx>
 #include <notxtfrm.hxx>
 #include <pagedesc.hxx>
 #include "viewimp.hxx"
-#include "IDocumentTimerAccess.hxx"
-#include "IDocumentLayoutAccess.hxx"
-#include "IDocumentFieldsAccess.hxx"
-#include "IDocumentSettingAccess.hxx"
-#include "IDocumentDrawModelAccess.hxx"
 #include <hints.hxx>
 #include <viewopt.hxx>
 #include <set>
+#include <IDocumentSettingAccess.hxx>
+#include <IDocumentFieldsAccess.hxx>
+#include <DocumentLayoutManager.hxx>
 
-SwLayVout     *SwRootFrm::pVout = 0;
-bool           SwRootFrm::bInPaint = false;
-sal_Bool           SwRootFrm::bNoVirDev = sal_False;
+SwLayVout     *SwRootFrm::mpVout = 0;
+bool           SwRootFrm::mbInPaint = false;
+bool           SwRootFrm::mbNoVirDev = false;
 
 SwCache *SwFrm::mpCache = 0;
 
@@ -281,7 +273,7 @@ static SwRectFnCollection aVerticalRightToLeft = {
     &SwRect::SetBottomAndHeight,
     &SwRect::SetLeftAndWidth
 };
-//Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
+
 static SwRectFnCollection aVerticalLeftToRight = {
     /* fnRectGet      */
     &SwRect::_Left,
@@ -336,12 +328,12 @@ static SwRectFnCollection aVerticalLeftToRight = {
     &SwRect::SetTopAndHeight,
     &SwRect::SetLeftAndWidth
 };
-//End of SCMS
+
 SwRectFn fnRectHori = &aHorizontal;
 SwRectFn fnRectVert = &aVertical;
-//Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
+
 SwRectFn fnRectVertL2R = &aVerticalLeftToRight;
-//End of SCMS
+
 SwRectFn fnRectB2T = &aBottomToTop;
 SwRectFn fnRectVL2R = &aVerticalRightToLeft;
 
@@ -349,12 +341,11 @@ SwRectFn fnRectVL2R = &aVerticalRightToLeft;
 sal_uInt32 SwFrm::mnLastFrmId=0;
 
 TYPEINIT1(SwFrm,SwClient);      //rtti for SwFrm
-TYPEINIT1(SwCntntFrm,SwFrm);    //rtti for SwCntntFrm
-
+TYPEINIT1(SwContentFrm,SwFrm);    //rtti for SwContentFrm
 
 void _FrmInit()
 {
-    SwRootFrm::pVout = new SwLayVout();
+    SwRootFrm::mpVout = new SwLayVout();
     SwCache *pNew = new SwCache( 100
 #ifdef DBG_UTIL
     , "static SwBorderAttrs::pCache"
@@ -363,28 +354,22 @@ void _FrmInit()
     SwFrm::SetCache( pNew );
 }
 
-
-
 void _FrmFinit()
 {
 #if OSL_DEBUG_LEVEL > 0
     // The cache may only contain null pointers at this time.
-    for( sal_uInt16 n = SwFrm::GetCachePtr()->size(); n; )
+    for( size_t n = SwFrm::GetCachePtr()->size(); n; )
         if( (*SwFrm::GetCachePtr())[ --n ] )
         {
             SwCacheObj* pObj = (*SwFrm::GetCachePtr())[ n ];
             OSL_ENSURE( !pObj, "Who didn't deregister?");
         }
 #endif
-    delete SwRootFrm::pVout;
+    delete SwRootFrm::mpVout;
     delete SwFrm::GetCachePtr();
 }
 
-/*************************************************************************
-|*
-|*  RootFrm::Everything that belongs to CurrShell
-|*
-|*************************************************************************/
+// RootFrm::Everything that belongs to CurrShell
 
 class SwCurrShells : public std::set<CurrShell*> {};
 
@@ -394,9 +379,9 @@ CurrShell::CurrShell( SwViewShell *pNew )
     pRoot = pNew->GetLayout();
     if ( pRoot )
     {
-        pPrev = pRoot->pCurrShell;
-        pRoot->pCurrShell = pNew;
-        pRoot->pCurrShells->insert( this );
+        pPrev = pRoot->mpCurrShell;
+        pRoot->mpCurrShell = pNew;
+        pRoot->mpCurrShells->insert( this );
     }
     else
         pPrev = 0;
@@ -406,13 +391,13 @@ CurrShell::~CurrShell()
 {
     if ( pRoot )
     {
-        pRoot->pCurrShells->erase( this );
+        pRoot->mpCurrShells->erase( this );
         if ( pPrev )
-            pRoot->pCurrShell = pPrev;
-        if ( pRoot->pCurrShells->empty() && pRoot->pWaitingCurrShell )
+            pRoot->mpCurrShell = pPrev;
+        if ( pRoot->mpCurrShells->empty() && pRoot->mpWaitingCurrShell )
         {
-            pRoot->pCurrShell = pRoot->pWaitingCurrShell;
-            pRoot->pWaitingCurrShell = 0;
+            pRoot->mpCurrShell = pRoot->mpWaitingCurrShell;
+            pRoot->mpWaitingCurrShell = 0;
         }
     }
 }
@@ -420,24 +405,34 @@ CurrShell::~CurrShell()
 void SetShell( SwViewShell *pSh )
 {
     SwRootFrm *pRoot = pSh->GetLayout();
-    if ( pRoot->pCurrShells->empty() )
-        pRoot->pCurrShell = pSh;
+    if ( pRoot->mpCurrShells->empty() )
+        pRoot->mpCurrShell = pSh;
     else
-        pRoot->pWaitingCurrShell = pSh;
+        pRoot->mpWaitingCurrShell = pSh;
 }
 
 void SwRootFrm::DeRegisterShell( SwViewShell *pSh )
 {
     // Activate some shell if possible
-    if ( pCurrShell == pSh )
-        pCurrShell = pSh->GetNext() != pSh ? (SwViewShell*)pSh->GetNext() : 0;
+    if ( mpCurrShell == pSh )
+    {
+        mpCurrShell = nullptr;
+        for(SwViewShell& rShell : pSh->GetRingContainer())
+        {
+            if(&rShell != pSh)
+            {
+                mpCurrShell = &rShell;
+                break;
+            }
+        }
+    }
 
     // Doesn't matter anymore
-    if ( pWaitingCurrShell == pSh )
-        pWaitingCurrShell = 0;
+    if ( mpWaitingCurrShell == pSh )
+        mpWaitingCurrShell = 0;
 
     // Remove references
-    for ( SwCurrShells::iterator it = pCurrShells->begin(); it != pCurrShells->end(); ++it )
+    for ( SwCurrShells::iterator it = mpCurrShells->begin(); it != mpCurrShells->end(); ++it )
     {
         CurrShell *pC = *it;
         if (pC->pPrev == pSh)
@@ -447,209 +442,185 @@ void SwRootFrm::DeRegisterShell( SwViewShell *pSh )
 
 void InitCurrShells( SwRootFrm *pRoot )
 {
-    pRoot->pCurrShells = new SwCurrShells;
+    pRoot->mpCurrShells = new SwCurrShells;
 }
 
-
-/*************************************************************************
-|*
-|*  SwRootFrm::SwRootFrm()
-|*
-|*  Description:
-|*      The RootFrm requests an own FrmFmt from the document, which it is
-|*      going to delete again in the dtor. The own FrmFmt is derived from
-|*      the passed FrmFmt.
-|*
-|*************************************************************************/
-
-
-SwRootFrm::SwRootFrm( SwFrmFmt *pFmt, SwViewShell * pSh ) :
-    SwLayoutFrm( pFmt->GetDoc()->MakeFrmFmt(
-        OUString("Root"), pFmt ), 0 ),
+/*
+|*      The RootFrm requests an own FrameFormat from the document, which it is
+|*      going to delete again in the dtor. The own FrameFormat is derived from
+|*      the passed FrameFormat.
+|*/
+SwRootFrm::SwRootFrm( SwFrameFormat *pFormat, SwViewShell * pSh ) :
+    SwLayoutFrm( pFormat->GetDoc()->MakeFrameFormat(
+        OUString("Root"), pFormat ), 0 ),
     maPagesArea(),
     mnViewWidth( -1 ),
     mnColumns( 0 ),
     mbBookMode( false ),
     mbSidebarChanged( false ),
     mbNeedGrammarCheck( false ),
-    bCheckSuperfluous( false ),
-    bIdleFormat( true ),
-    bBrowseWidthValid( false ),
-    bTurboAllowed( true ),
-    bAssertFlyPages( true ),
-    bIsVirtPageNum( false ),
-    bIsNewLayout( true ),
-    bCallbackActionEnabled ( false ),
-    bLayoutFreezed ( false ),
-    nBrowseWidth( MM50*4 ), //2cm minimum
-    pTurbo( 0 ),
-    pLastPage( 0 ),
-    pCurrShell( pSh ),
-    pWaitingCurrShell( 0 ),
-    pDrawPage( 0 ),
-    pDestroy( 0 ),
-    nPhyPageNums( 0 ),
-    nAccessibleShells( 0 )
+    mbCheckSuperfluous( false ),
+    mbIdleFormat( true ),
+    mbBrowseWidthValid( false ),
+    mbTurboAllowed( true ),
+    mbAssertFlyPages( true ),
+    mbIsVirtPageNum( false ),
+    mbIsNewLayout( true ),
+    mbCallbackActionEnabled ( false ),
+    mbLayoutFreezed ( false ),
+    mnBrowseWidth( MM50*4 ), //2cm minimum
+    mpTurbo( 0 ),
+    mpLastPage( 0 ),
+    mpCurrShell( pSh ),
+    mpWaitingCurrShell( 0 ),
+    mpCurrShells(NULL),
+    mpDrawPage( 0 ),
+    mpDestroy( 0 ),
+    mnPhyPageNums( 0 ),
+    mnAccessibleShells( 0 )
 {
-    mnType = FRMC_ROOT;
+    mnFrmType = FRM_ROOT;
     setRootFrm( this );
 }
 
-void SwRootFrm::Init( SwFrmFmt* pFmt )
+void SwRootFrm::Init( SwFrameFormat* pFormat )
 {
     InitCurrShells( this );
 
-    IDocumentTimerAccess *pTimerAccess = pFmt->getIDocumentTimerAccess();
-    IDocumentLayoutAccess *pLayoutAccess = pFmt->getIDocumentLayoutAccess();
-    IDocumentFieldsAccess *pFieldsAccess = pFmt->getIDocumentFieldsAccess();
-    const IDocumentSettingAccess *pSettingAccess = pFmt->getIDocumentSettingAccess();
+    IDocumentTimerAccess *pTimerAccess = pFormat->getIDocumentTimerAccess();
+    IDocumentLayoutAccess *pLayoutAccess = pFormat->getIDocumentLayoutAccess();
+    IDocumentFieldsAccess *pFieldsAccess = pFormat->getIDocumentFieldsAccess();
+    const IDocumentSettingAccess *pSettingAccess = pFormat->getIDocumentSettingAccess();
     pTimerAccess->StopIdling();
     // For creating the Flys by MakeFrms()
     pLayoutAccess->SetCurrentViewShell( this->GetCurrShell() );
-    bCallbackActionEnabled = sal_False; // needs to be set to sal_True before leaving!
+    mbCallbackActionEnabled = false; // needs to be set to true before leaving!
 
-    SdrModel *pMd = pFmt->getIDocumentDrawModelAccess()->GetDrawModel();
+    SwDrawModel* pMd = pFormat->getIDocumentDrawModelAccess()->GetDrawModel();
     if ( pMd )
     {
         // Disable "multiple layout"
-        pDrawPage = pMd->GetPage(0); //pMd->AllocPage( FALSE );
-        //pMd->InsertPage( pDrawPage );
-        // end of disabling
+        mpDrawPage = pMd->GetPage(0);
 
-        pDrawPage->SetSize( Frm().SSize() );
+        mpDrawPage->SetSize( Frm().SSize() );
     }
 
-    // Initialize the layout: create pages, link content with Cntnt etc.
+    // Initialize the layout: create pages, link content with Content etc.
     // First, initialize some stuff, then get hold of the first
     // node (which will be needed for the PageDesc).
 
-    SwDoc* pDoc = pFmt->GetDoc();
+    SwDoc* pDoc = pFormat->GetDoc();
     SwNodeIndex aIndex( *pDoc->GetNodes().GetEndOfContent().StartOfSectionNode() );
-    SwCntntNode *pNode = pDoc->GetNodes().GoNextSection( &aIndex, sal_True, sal_False );
+    SwContentNode *pNode = pDoc->GetNodes().GoNextSection( &aIndex, true, false );
     // #123067# pNode = 0 can really happen
-    SwTableNode *pTblNd= pNode ? pNode->FindTableNode() : 0;
+    SwTableNode *pTableNd= pNode ? pNode->FindTableNode() : 0;
 
-    // Get hold of PageDesc (either via FrmFmt of the first node or the initial one).
+    // Get hold of PageDesc (either via FrameFormat of the first node or the initial one).
     SwPageDesc *pDesc = 0;
     ::boost::optional<sal_uInt16> oPgNum;
 
-    if ( pTblNd )
+    if ( pTableNd )
     {
-        const SwFmtPageDesc &rDesc = pTblNd->GetTable().GetFrmFmt()->GetPageDesc();
-        pDesc = (SwPageDesc*)rDesc.GetPageDesc();
+        const SwFormatPageDesc &rDesc = pTableNd->GetTable().GetFrameFormat()->GetPageDesc();
+        pDesc = const_cast<SwPageDesc*>(rDesc.GetPageDesc());
         //#19104# respect the page number offset!!
         oPgNum = rDesc.GetNumOffset();
         if (oPgNum)
-            bIsVirtPageNum = true;
+            mbIsVirtPageNum = true;
     }
     else if ( pNode )
     {
-        const SwFmtPageDesc &rDesc = pNode->GetSwAttrSet().GetPageDesc();
-        pDesc = (SwPageDesc*)rDesc.GetPageDesc();
+        const SwFormatPageDesc &rDesc = pNode->GetSwAttrSet().GetPageDesc();
+        pDesc = const_cast<SwPageDesc*>(rDesc.GetPageDesc());
         //#19104# respect the page number offset!!
         oPgNum = rDesc.GetNumOffset();
         if (oPgNum)
-            bIsVirtPageNum = true;
+            mbIsVirtPageNum = true;
     }
     else
-        bIsVirtPageNum = sal_False;
+        mbIsVirtPageNum = false;
     if ( !pDesc )
         pDesc = &pDoc->GetPageDesc( 0 );
     const bool bOdd = !oPgNum || 0 != ( oPgNum.get() % 2 );
     bool bFirst = !oPgNum || 1 == oPgNum.get();
 
     // Create a page and put it in the layout
-    SwPageFrm *pPage = ::InsertNewPage( *pDesc, this, bOdd, bFirst, false, sal_False, 0 );
+    SwPageFrm *pPage = ::InsertNewPage( *pDesc, this, bOdd, bFirst, false, false, 0 );
 
     // Find the first page in the Bodytext section.
     SwLayoutFrm *pLay = pPage->FindBodyCont();
     while( pLay->Lower() )
-        pLay = (SwLayoutFrm*)pLay->Lower();
+        pLay = static_cast<SwLayoutFrm*>(pLay->Lower());
 
     SwNodeIndex aTmp( *pDoc->GetNodes().GetEndOfContent().StartOfSectionNode(), 1 );
-    ::_InsertCnt( pLay, pDoc, aTmp.GetIndex(), sal_True );
+    ::_InsertCnt( pLay, pDoc, aTmp.GetIndex(), true );
     //Remove masters that haven't been replaced yet from the list.
-    RemoveMasterObjs( pDrawPage );
-    if( pSettingAccess->get(IDocumentSettingAccess::GLOBAL_DOCUMENT) )
-        pFieldsAccess->UpdateRefFlds( NULL );
+    RemoveMasterObjs( mpDrawPage );
+    if( pSettingAccess->get(DocumentSettingId::GLOBAL_DOCUMENT) )
+        pFieldsAccess->UpdateRefFields( NULL );
     //b6433357: Update page fields after loading
-    // --->
-    if ( !pCurrShell || !pCurrShell->Imp()->IsUpdateExpFlds() )
+    if ( !mpCurrShell || !mpCurrShell->Imp()->IsUpdateExpFields() )
     {
-        SwDocPosUpdate aMsgHnt( pPage->Frm().Top() );
-        pFieldsAccess->UpdatePageFlds( &aMsgHnt );
+        SwDocPosUpdate aMsgHint( pPage->Frm().Top() );
+        pFieldsAccess->UpdatePageFields( &aMsgHint );
     }
 
     pTimerAccess->StartIdling();
-    bCallbackActionEnabled = sal_True;
+    mbCallbackActionEnabled = true;
 
     SwViewShell *pViewSh  = GetCurrShell();
     if (pViewSh)
         mbNeedGrammarCheck = pViewSh->GetViewOptions()->IsOnlineSpell();
 }
 
-/*************************************************************************
-|*
-|*  SwRootFrm::~SwRootFrm()
-|*
-|*************************************************************************/
-
-
-
-SwRootFrm::~SwRootFrm()
+void SwRootFrm::DestroyImpl()
 {
-    bTurboAllowed = sal_False;
-    pTurbo = 0;
+    mbTurboAllowed = false;
+    mpTurbo = 0;
     // fdo#39510 crash on document close with footnotes
     // Object ownership in writer and esp. in layout are a mess: Before the
     // document/layout split SwDoc and SwRootFrm were essentially one object
     // and magically/uncleanly worked around their common destruction by call
     // to SwDoc::IsInDtor() -- even from the layout. As of now destuction of
-    // the layout proceeds forward through the frames. Since SwTxtFtn::DelFrms
+    // the layout proceeds forward through the frames. Since SwTextFootnote::DelFrms
     // also searches backwards to find the master of footnotes, they must be
     // considered to be owned by the SwRootFrm and also be destroyed here,
     // before tearing down the (now footnote free) rest of the layout.
-    RemoveFtns(0, false, true);
+    RemoveFootnotes(0, false, true);
 
     if(pBlink)
         pBlink->FrmDelete( this );
-    SwFrmFmt *pRegisteredInNonConst = static_cast<SwFrmFmt*>(GetRegisteredInNonConst());
+    SwFrameFormat *pRegisteredInNonConst = static_cast<SwFrameFormat*>(GetRegisteredInNonConst());
     if ( pRegisteredInNonConst )
     {
         SwDoc *pDoc = pRegisteredInNonConst->GetDoc();
-        pDoc->DelFrmFmt( pRegisteredInNonConst );
-        pDoc->ClearSwLayouterEntries();
+        pDoc->DelFrameFormat( pRegisteredInNonConst );
+        pDoc->GetDocumentLayoutManager().ClearSwLayouterEntries();
     }
-    delete pDestroy;
-    pDestroy = 0;
+    delete mpDestroy;
+    mpDestroy = 0;
 
     // Remove references
-    for ( SwCurrShells::iterator it = pCurrShells->begin(); it != pCurrShells->end(); ++it )
+    for ( SwCurrShells::iterator it = mpCurrShells->begin(); it != mpCurrShells->end(); ++it )
         (*it)->pRoot = 0;
 
-    delete pCurrShells;
-    pCurrShells = 0;
+    delete mpCurrShells;
+    mpCurrShells = 0;
 
     // Some accessible shells are left => problems on second SwFrm::Destroy call
-    assert(0 == nAccessibleShells);
+    assert(0 == mnAccessibleShells);
 
-    // manually call base classes Destroy because it could call stuff
-    // that accesses members of this
-    SwLayoutFrm::Destroy();
-    SwFrm::Destroy();
+    SwLayoutFrm::DestroyImpl();
 }
 
-/*************************************************************************
-|*
-|*  SwRootFrm::RemoveMasterObjs()
-|*
-|*************************************************************************/
-
+SwRootFrm::~SwRootFrm()
+{
+}
 
 void SwRootFrm::RemoveMasterObjs( SdrPage *pPg )
 {
     // Remove all master objects from the Page. But don't delete!
-    for( sal_uLong i = pPg ? pPg->GetObjCount() : 0; i; )
+    for( size_t i = pPg ? pPg->GetObjCount() : 0; i; )
     {
         SdrObject* pObj = pPg->GetObj( --i );
         if( pObj->ISA(SwFlyDrawObj ) )
@@ -657,40 +628,42 @@ void SwRootFrm::RemoveMasterObjs( SdrPage *pPg )
     }
 }
 
-
 void SwRootFrm::AllCheckPageDescs() const
 {
     if ( !IsLayoutFreezed() )
-        CheckPageDescs( (SwPageFrm*)this->Lower() );
+        CheckPageDescs( const_cast<SwPageFrm*>(static_cast<const SwPageFrm*>(this->Lower())) );
 }
 
 void SwRootFrm::AllInvalidateAutoCompleteWords() const
 {
-    SwPageFrm *pPage = (SwPageFrm*)this->Lower();
+    SwPageFrm *pPage = const_cast<SwPageFrm*>(static_cast<const SwPageFrm*>(this->Lower()));
     while ( pPage )
     {
         pPage->InvalidateAutoCompleteWords();
-        pPage = (SwPageFrm*)pPage->GetNext();
+        pPage = static_cast<SwPageFrm*>(pPage->GetNext());
     }
 }
+
 void SwRootFrm::AllAddPaintRect() const
 {
     GetCurrShell()->AddPaintRect( this->Frm() );
 }
-void SwRootFrm::AllRemoveFtns()
+
+void SwRootFrm::AllRemoveFootnotes()
 {
-    RemoveFtns();
+    RemoveFootnotes();
 }
+
 void SwRootFrm::AllInvalidateSmartTagsOrSpelling(bool bSmartTags) const
 {
-    SwPageFrm *pPage = (SwPageFrm*)this->Lower();
+    SwPageFrm *pPage = const_cast<SwPageFrm*>(static_cast<const SwPageFrm*>(this->Lower()));
     while ( pPage )
     {
         if ( bSmartTags )
             pPage->InvalidateSmartTags();
 
         pPage->InvalidateSpelling();
-        pPage = (SwPageFrm*)pPage->GetNext();
+        pPage = static_cast<SwPageFrm*>(pPage->GetNext());
     }
 }
 
