@@ -40,40 +40,39 @@
 
 #undef WIDOWTWIPS
 
+namespace
+{
 
-/*************************************************************************
- *                  inline IsNastyFollow()
- *************************************************************************/
 // A Follow on the same page as its master is nasty.
-inline sal_Bool IsNastyFollow( const SwTxtFrm *pFrm )
+inline bool IsNastyFollow( const SwTextFrm *pFrm )
 {
     OSL_ENSURE( !pFrm->IsFollow() || !pFrm->GetPrev() ||
-            ((const SwTxtFrm*)pFrm->GetPrev())->GetFollow() == pFrm,
+            static_cast<const SwTextFrm*>(pFrm->GetPrev())->GetFollow() == pFrm,
             "IsNastyFollow: Was ist denn hier los?" );
     return  pFrm->IsFollow() && pFrm->GetPrev();
 }
 
-/*************************************************************************
- *                  SwTxtFrmBreak::SwTxtFrmBreak()
- *************************************************************************/
+}
 
-SwTxtFrmBreak::SwTxtFrmBreak( SwTxtFrm *pNewFrm, const SwTwips nRst )
+SwTextFrmBreak::SwTextFrmBreak( SwTextFrm *pNewFrm, const SwTwips nRst )
     : nRstHeight(nRst), pFrm(pNewFrm)
 {
     SWAP_IF_SWAPPED( pFrm )
     SWRECTFN( pFrm )
     nOrigin = (pFrm->*fnRect->fnGetPrtTop)();
-    SwSectionFrm* pSct;
-    bKeep = !pFrm->IsMoveable() || IsNastyFollow( pFrm ) ||
-            ( pFrm->IsInSct() && (pSct=pFrm->FindSctFrm())->Lower()->IsColumnFrm()
-              && !pSct->MoveAllowed( pFrm ) ) ||
-            !pFrm->GetTxtNode()->GetSwAttrSet().GetSplit().GetValue() ||
-            pFrm->GetTxtNode()->GetSwAttrSet().GetKeep().GetValue();
-    bBreak = sal_False;
-
-    if( !nRstHeight && !pFrm->IsFollow() && pFrm->IsInFtn() && pFrm->HasPara() )
+    bKeep = !pFrm->IsMoveable() || IsNastyFollow( pFrm );
+    if( !bKeep && pFrm->IsInSct() )
     {
-        nRstHeight = pFrm->GetFtnFrmHeight();
+        const SwSectionFrm* const pSct = pFrm->FindSctFrm();
+        bKeep = pSct->Lower()->IsColumnFrm() && !pSct->MoveAllowed( pFrm );
+    }
+    bKeep = bKeep || !pFrm->GetTextNode()->GetSwAttrSet().GetSplit().GetValue() ||
+        pFrm->GetTextNode()->GetSwAttrSet().GetKeep().GetValue();
+    bBreak = false;
+
+    if( !nRstHeight && !pFrm->IsFollow() && pFrm->IsInFootnote() && pFrm->HasPara() )
+    {
+        nRstHeight = pFrm->GetFootnoteFrmHeight();
         nRstHeight += (pFrm->Prt().*fnRect->fnGetHeight)() -
                       (pFrm->Frm().*fnRect->fnGetHeight)();
         if( nRstHeight < 0 )
@@ -83,35 +82,29 @@ SwTxtFrmBreak::SwTxtFrmBreak( SwTxtFrm *pNewFrm, const SwTwips nRst )
     UNDO_SWAP( pFrm )
 }
 
-/* BP 18.6.93: Widows.
+/**
+ * BP 18.6.93: Widows.
  * In contrast to the first implementation the Widows are not calculated
- * in advance but detected when formating the split Follow.
+ * in advance but detected when formatting the split Follow.
  * In Master the Widows-calculation is dropped completely
  * (nWidows is manipulated). If the Follow detects that the
  * Widows rule applies it sends a Prepare to its predecessor.
  * A special problem is when the Widow rule applies but in Master
  * there are some lines available.
  *
- */
-
-/*************************************************************************
- *                  SwTxtFrmBreak::IsInside()
- *************************************************************************/
-
-/* BP(22.07.92): Calculation of Widows and Orphans.
- * The method returns sal_True if one of the rules matches.
+ * BP(22.07.92): Calculation of Widows and Orphans.
+ * The method returns true if one of the rules matches.
  *
  * One difficulty with Widows and different formats between
  * Master- and Follow-Frame:
  * Example: If the first column is 3cm and the second is 4cm and
  * Widows is set to 3, the decision if the Widows rule matches can not
- * be done until the Follow is formated. Unfortunately this is crucial
+ * be done until the Follow is formatted. Unfortunately this is crucial
  * to decide if the whole paragraph goes to the next page or not.
  */
-
-sal_Bool SwTxtFrmBreak::IsInside( SwTxtMargin &rLine ) const
+bool SwTextFrmBreak::IsInside( SwTextMargin &rLine ) const
 {
-    sal_Bool bFit = sal_False;
+    bool bFit = false;
 
     SWAP_IF_SWAPPED( pFrm )
     SWRECTFN( pFrm )
@@ -135,7 +128,7 @@ sal_Bool SwTxtFrmBreak::IsInside( SwTxtMargin &rLine ) const
         // The Frm has a height to fit on the page.
         SwTwips nHeight =
             (*fnRect->fnYDiff)( (pFrm->GetUpper()->*fnRect->fnGetPrtBottom)(), nOrigin );
-        // If everything is inside the existing frame the result is sal_True;
+        // If everything is inside the existing frame the result is true;
         bFit = nHeight >= nLineHeight;
 
         // --> OD #i103292#
@@ -158,9 +151,9 @@ sal_Bool SwTxtFrmBreak::IsInside( SwTxtMargin &rLine ) const
             // grow the requested area.
             nHeight += pFrm->GrowTst( LONG_MAX );
 
-            // The Grow() returns the height by which the Upper of the TxtFrm
-            // would let the TxtFrm grow.
-            // The TxtFrm itself can grow as much as it wants.
+            // The Grow() returns the height by which the Upper of the TextFrm
+            // would let the TextFrm grow.
+            // The TextFrm itself can grow as much as it wants.
             bFit = nHeight >= nLineHeight;
         }
     }
@@ -170,21 +163,17 @@ sal_Bool SwTxtFrmBreak::IsInside( SwTxtMargin &rLine ) const
     return bFit;
 }
 
-/*************************************************************************
- *                  SwTxtFrmBreak::IsBreakNow()
- *************************************************************************/
-
-sal_Bool SwTxtFrmBreak::IsBreakNow( SwTxtMargin &rLine )
+bool SwTextFrmBreak::IsBreakNow( SwTextMargin &rLine )
 {
     SWAP_IF_SWAPPED( pFrm )
 
     // bKeep is stronger than IsBreakNow()
     // Is there enough space ?
     if( bKeep || IsInside( rLine ) )
-        bBreak = sal_False;
+        bBreak = false;
     else
     {
-        /* This class assumes that the SwTxtMargin is processed from Top to
+        /* This class assumes that the SwTextMargin is processed from Top to
          * Bottom. Because of performance reasons we stop splitting in the
          * following cases:
          * If only one line does not fit.
@@ -194,18 +183,18 @@ sal_Bool SwTxtFrmBreak::IsBreakNow( SwTxtMargin &rLine )
         // 6010: include DropLines
 
         bool bFirstLine = 1 == rLine.GetLineNr() && !rLine.GetPrev();
-        bBreak = sal_True;
+        bBreak = true;
         if( ( bFirstLine && pFrm->GetIndPrev() )
             || ( rLine.GetLineNr() <= rLine.GetDropLines() ) )
         {
-            bKeep = sal_True;
-            bBreak = sal_False;
+            bKeep = true;
+            bBreak = false;
         }
-        else if(bFirstLine && pFrm->IsInFtn() && !pFrm->FindFtnFrm()->GetPrev())
+        else if(bFirstLine && pFrm->IsInFootnote() && !pFrm->FindFootnoteFrm()->GetPrev())
         {
-            SwLayoutFrm* pTmp = pFrm->FindFtnBossFrm()->FindBodyCont();
+            SwLayoutFrm* pTmp = pFrm->FindFootnoteBossFrm()->FindBodyCont();
             if( !pTmp || !pTmp->Lower() )
-                bBreak = sal_False;
+                bBreak = false;
         }
     }
 
@@ -214,8 +203,8 @@ sal_Bool SwTxtFrmBreak::IsBreakNow( SwTxtMargin &rLine )
     return bBreak;
 }
 
-// OD 2004-02-27 #106629# - no longer inline
-void SwTxtFrmBreak::SetRstHeight( const SwTxtMargin &rLine )
+/// OD 2004-02-27 #106629# - no longer inline
+void SwTextFrmBreak::SetRstHeight( const SwTextMargin &rLine )
 {
     // OD, FME 2004-02-27 #106629# - consider bottom margin
     SWRECTFN( pFrm )
@@ -223,7 +212,6 @@ void SwTxtFrmBreak::SetRstHeight( const SwTxtMargin &rLine )
     nRstHeight = (pFrm->*fnRect->fnGetBottomMargin)();
 
     if ( bVert )
-    //Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
     {
            if ( pFrm->IsVertLR() )
               nRstHeight = (*fnRect->fnYDiff)( pFrm->SwitchHorizontalToVertical( rLine.Y() ) , nOrigin );
@@ -234,13 +222,9 @@ void SwTxtFrmBreak::SetRstHeight( const SwTxtMargin &rLine )
         nRstHeight += rLine.Y() - nOrigin;
 }
 
-/*************************************************************************
- *                  WidowsAndOrphans::WidowsAndOrphans()
- *************************************************************************/
-
-WidowsAndOrphans::WidowsAndOrphans( SwTxtFrm *pNewFrm, const SwTwips nRst,
-    sal_Bool bChkKeep   )
-    : SwTxtFrmBreak( pNewFrm, nRst ), nWidLines( 0 ), nOrphLines( 0 )
+WidowsAndOrphans::WidowsAndOrphans( SwTextFrm *pNewFrm, const SwTwips nRst,
+    bool bChkKeep   )
+    : SwTextFrmBreak( pNewFrm, nRst ), nWidLines( 0 ), nOrphLines( 0 )
 {
     SWAP_IF_SWAPPED( pFrm )
 
@@ -248,21 +232,21 @@ WidowsAndOrphans::WidowsAndOrphans( SwTxtFrm *pNewFrm, const SwTwips nRst,
     {
         // 5652: If pararagraph should not be split but is larger than
         // the page, then bKeep is overruled.
-        if( bChkKeep && !pFrm->GetPrev() && !pFrm->IsInFtn() &&
+        if( bChkKeep && !pFrm->GetPrev() && !pFrm->IsInFootnote() &&
             pFrm->IsMoveable() &&
             ( !pFrm->IsInSct() || pFrm->FindSctFrm()->MoveAllowed(pFrm) ) )
-            bKeep = sal_False;
+            bKeep = false;
         // Even if Keep is set, Orphans has to be respected.
         // e.g. if there are chained frames where a Follow in the last frame
         // receives a Keep, because it is not (forward) movable -
         // nevertheless the paragraph can request lines from the Master
         // because of the Orphan rule.
         if( pFrm->IsFollow() )
-            nWidLines = pFrm->GetTxtNode()->GetSwAttrSet().GetWidows().GetValue();
+            nWidLines = pFrm->GetTextNode()->GetSwAttrSet().GetWidows().GetValue();
     }
     else
     {
-        const SwAttrSet& rSet = pFrm->GetTxtNode()->GetSwAttrSet();
+        const SwAttrSet& rSet = pFrm->GetTextNode()->GetSwAttrSet();
         const SvxOrphansItem  &rOrph = rSet.GetOrphans();
         if ( rOrph.GetValue() > 1 )
             nOrphLines = rOrph.GetValue();
@@ -289,14 +273,14 @@ WidowsAndOrphans::WidowsAndOrphans( SwTxtFrm *pNewFrm, const SwTwips nRst,
             }
         }
 
-        if( pFrm->IsInFtn() && !pFrm->GetIndPrev() )
+        if( pFrm->IsInFootnote() && !pFrm->GetIndPrev() )
         {
             // Inside of footnotes there are good reasons to turn off the Keep attribute
             // as well as Widows/Orphans.
-            SwFtnFrm *pFtn = pFrm->FindFtnFrm();
-            sal_Bool bFt = !pFtn->GetAttr()->GetFtn().IsEndNote();
-            if( !pFtn->GetPrev() &&
-                pFtn->FindFtnBossFrm( bFt ) != pFtn->GetRef()->FindFtnBossFrm( bFt )
+            SwFootnoteFrm *pFootnote = pFrm->FindFootnoteFrm();
+            const bool bFt = !pFootnote->GetAttr()->GetFootnote().IsEndNote();
+            if( !pFootnote->GetPrev() &&
+                pFootnote->FindFootnoteBossFrm( bFt ) != pFootnote->GetRef()->FindFootnoteBossFrm( bFt )
                 && ( !pFrm->IsInSct() || pFrm->FindSctFrm()->MoveAllowed(pFrm) ) )
             {
                 bResetFlags = true;
@@ -305,7 +289,7 @@ WidowsAndOrphans::WidowsAndOrphans( SwTxtFrm *pNewFrm, const SwTwips nRst,
 
         if ( bResetFlags )
         {
-            bKeep = sal_False;
+            bKeep = false;
             nOrphLines = 0;
             nWidLines = 0;
         }
@@ -314,17 +298,13 @@ WidowsAndOrphans::WidowsAndOrphans( SwTxtFrm *pNewFrm, const SwTwips nRst,
     UNDO_SWAP( pFrm )
 }
 
-/*************************************************************************
- *                  WidowsAndOrphans::FindBreak()
- *************************************************************************/
-
-/* The Find*-Methodes do not only search, but adjust the SwTxtMargin to the
+/**
+ * The Find*-Methodes do not only search, but adjust the SwTextMargin to the
  * line where the paragraph should have a break and truncate the paragraph there.
  * FindBreak()
  */
-
-sal_Bool WidowsAndOrphans::FindBreak( SwTxtFrm *pFrame, SwTxtMargin &rLine,
-    sal_Bool bHasToFit )
+bool WidowsAndOrphans::FindBreak( SwTextFrm *pFrame, SwTextMargin &rLine,
+    bool bHasToFit )
 {
     // OD 2004-02-25 #i16128# - Why member <pFrm> _*and*_ parameter <pFrame>??
     // Thus, assertion on situation, that these are different to figure out why.
@@ -332,22 +312,22 @@ sal_Bool WidowsAndOrphans::FindBreak( SwTxtFrm *pFrame, SwTxtMargin &rLine,
 
     SWAP_IF_SWAPPED( pFrm )
 
-    sal_Bool bRet = sal_True;
-    MSHORT nOldOrphans = nOrphLines;
+    bool bRet = true;
+    sal_uInt16 nOldOrphans = nOrphLines;
     if( bHasToFit )
         nOrphLines = 0;
     rLine.Bottom();
     // OD 2004-02-25 #i16128# - method renamed
     if( !IsBreakNowWidAndOrp( rLine ) )
-        bRet = sal_False;
+        bRet = false;
     if( !FindWidows( pFrame, rLine ) )
     {
-        sal_Bool bBack = sal_False;
+        bool bBack = false;
         // OD 2004-02-25 #i16128# - method renamed
         while( IsBreakNowWidAndOrp( rLine ) )
         {
             if( rLine.PrevLine() )
-                bBack = sal_True;
+                bBack = true;
             else
                 break;
         }
@@ -370,36 +350,32 @@ sal_Bool WidowsAndOrphans::FindBreak( SwTxtFrm *pFrame, SwTxtMargin &rLine,
     return bRet;
 }
 
-/*************************************************************************
- *                  WidowsAndOrphans::FindWidows()
- *************************************************************************/
-
-/*  FindWidows positions the SwTxtMargin of the Master to the line where to
- *  break by examining and formatting the Follow.
- *  Returns sal_True if the Widows-rule matches, that means that the
- *  paragraph should not be split (keep) !
+/**
+ * FindWidows positions the SwTextMargin of the Master to the line where to
+ * break by examining and formatting the Follow.
+ * Returns true if the Widows-rule matches, that means that the
+ * paragraph should not be split (keep) !
  */
-
-sal_Bool WidowsAndOrphans::FindWidows( SwTxtFrm *pFrame, SwTxtMargin &rLine )
+bool WidowsAndOrphans::FindWidows( SwTextFrm *pFrame, SwTextMargin &rLine )
 {
     OSL_ENSURE( ! pFrame->IsVertical() || ! pFrame->IsSwapped(),
             "WidowsAndOrphans::FindWidows with swapped frame" );
 
     if( !nWidLines || !pFrame->IsFollow() )
-        return sal_False;
+        return false;
 
     rLine.Bottom();
 
-    // Wir koennen noch was abzwacken
-    SwTxtFrm *pMaster = pFrame->FindMaster();
+    // We can still cut something off
+    SwTextFrm *pMaster = pFrame->FindMaster();
     OSL_ENSURE(pMaster, "+WidowsAndOrphans::FindWidows: Widows in a master?");
     if( !pMaster )
-        return sal_False;
+        return false;
 
     // 5156: If the first line of the Follow does not fit, the master
     // probably is full of Dummies. In this case a PREP_WIDOWS would be fatal.
     if( pMaster->GetOfst() == pFrame->GetOfst() )
-        return sal_False;
+        return false;
 
     // Remaining height of the master
     SWRECTFN( pFrame )
@@ -444,9 +420,9 @@ sal_Bool WidowsAndOrphans::FindWidows( SwTxtFrm *pFrame, SwTxtMargin &rLine )
                 }
             }
 
-            pFrame->SetJustWidow( sal_False );
+            pFrame->SetJustWidow( false );
         }
-        return sal_False;
+        return false;
     }
 
     // 8575: Follow to Master II
@@ -463,28 +439,27 @@ sal_Bool WidowsAndOrphans::FindWidows( SwTxtFrm *pFrame, SwTxtMargin &rLine )
             pMaster->Prepare( PREP_ADJUST_FRM );
             pMaster->_InvalidateSize();
             pMaster->InvalidatePage();
-            pFrame->SetJustWidow( sal_False );
-            return sal_False;
+            pFrame->SetJustWidow( false );
+            return false;
         }
     }
 
     // Master to Follow
-    // Wenn der Follow nach seiner Formatierung weniger Zeilen enthaelt
-    // als Widows, so besteht noch die Chance, einige Zeilen des Masters
-    // abzuzwacken. Wenn dadurch die Orphans-Regel des Masters in Kraft
-    // tritt muss im CalcPrep() des Master-Frame der Frame so vergroessert
-    // werden, dass er nicht mehr auf seine urspruengliche Seite passt.
-    // Wenn er noch ein paar Zeilen entbehren kann, dann muss im CalcPrep()
-    // ein Shrink() erfolgen, der Follow mit dem Widows rutscht dann auf
-    // die Seite des Masters, haelt sich aber zusammen, so dass er (endlich)
-    // auf die naechste Seite rutscht. - So die Theorie!
-
-
-    // Wir fordern nur noch ein Zeile zur Zeit an, weil eine Zeile des Masters
-    // bei uns durchaus mehrere Zeilen ergeben koennten.
-    // Dafuer behaelt CalcFollow solange die Kontrolle, bis der Follow alle
-    // notwendigen Zeilen bekommen hat.
-    MSHORT nNeed = 1; // frueher: nWidLines - rLine.GetLineNr();
+    // If the Follow contains fewer rows than Widows after formatting,
+    // we still can cut off some rows from the Master. If the Orphans
+    // rule of the Master hereby comes into effect, we need to enlarge
+    // the Frame in CalcPrep() of the Master Frame, as it won't fit into
+    // the original page anymore.
+    // If the Master Frame can still miss a few more rows, we need to
+    // do a Shrink() in the CalcPrep(): the Follow with the Widows then
+    // moves onto the page of the Master, but remains unsplit, so that
+    // it (finally) moves onto the next page. So much for the theory!
+    //
+    // We only request one row at a time for now, because a Master's row could
+    // result in multiple lines for us.
+    // Therefore, the CalcFollow() remains in control until the Follow got all
+    // necessary rows.
+    sal_uInt16 nNeed = 1; // was: nWidLines - rLine.GetLineNr();
 
     // Special case: Master cannot give lines to follow
     // #i91421#
@@ -498,30 +473,26 @@ sal_Bool WidowsAndOrphans::FindWidows( SwTxtFrm *pFrame, SwTxtMargin &rLine )
                 nLines = 2;
         }
         if( nLines <= nNeed )
-            return sal_False;
+            return false;
     }
 
     pMaster->Prepare( PREP_WIDOWS, (void*)&nNeed );
-    return sal_True;
+    return true;
 }
 
-/*************************************************************************
- *                  WidowsAndOrphans::WouldFit()
- *************************************************************************/
-
-sal_Bool WidowsAndOrphans::WouldFit( SwTxtMargin &rLine, SwTwips &rMaxHeight, sal_Bool bTst )
+bool WidowsAndOrphans::WouldFit( SwTextMargin &rLine, SwTwips &rMaxHeight, bool bTst )
 {
     // Here it does not matter, if pFrm is swapped or not.
-    // IsInside() takes care for itself
+    // IsInside() takes care of itself
 
     // We expect that rLine is set to the last line
     OSL_ENSURE( !rLine.GetNext(), "WouldFit: aLine::Bottom missed!" );
-    MSHORT nLineCnt = rLine.GetLineNr();
+    sal_uInt16 nLineCnt = rLine.GetLineNr();
 
     // First satisfy the Orphans-rule and the wish for initials ...
-    const MSHORT nMinLines = std::max( GetOrphansLines(), rLine.GetDropLines() );
+    const sal_uInt16 nMinLines = std::max( GetOrphansLines(), rLine.GetDropLines() );
     if ( nLineCnt < nMinLines )
-        return sal_False;
+        return false;
 
     rLine.Top();
     SwTwips nLineSum = rLine.GetLineHeight();
@@ -529,13 +500,13 @@ sal_Bool WidowsAndOrphans::WouldFit( SwTxtMargin &rLine, SwTwips &rMaxHeight, sa
     while( nMinLines > rLine.GetLineNr() )
     {
         if( !rLine.NextLine() )
-            return sal_False;
+            return false;
         nLineSum += rLine.GetLineHeight();
     }
 
     // We do not fit
     if( !IsInside( rLine ) )
-        return sal_False;
+        return false;
 
     // Check the Widows-rule
     if( !nWidLines && !pFrm->IsFollow() )
@@ -545,7 +516,7 @@ sal_Bool WidowsAndOrphans::WouldFit( SwTxtMargin &rLine, SwTwips &rMaxHeight, sa
         // because we are just in the middle of calculating the break.
         // In Ctor of WidowsAndOrphans the nWidLines are only calced for
         // Follows from the AttrSet - so we catch up now:
-        const SwAttrSet& rSet = pFrm->GetTxtNode()->GetSwAttrSet();
+        const SwAttrSet& rSet = pFrm->GetTextNode()->GetSwAttrSet();
         nWidLines = rSet.GetWidows().GetValue();
     }
 
@@ -561,10 +532,10 @@ sal_Bool WidowsAndOrphans::WouldFit( SwTxtMargin &rLine, SwTwips &rMaxHeight, sa
         if( rMaxHeight >= nLineSum )
         {
             rMaxHeight -= nLineSum;
-            return sal_True;
+            return true;
         }
     }
-    return sal_False;
+    return false;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
