@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include <UndoInsert.hxx>
 
 #include <hintids.hxx>
@@ -25,7 +24,6 @@
 #include <sot/storage.hxx>
 #include <editeng/keepitem.hxx>
 #include <svx/svdobj.hxx>
-#include <xmloff/odffields.hxx>
 
 #include <docsh.hxx>
 #include <fmtcntnt.hxx>
@@ -33,6 +31,9 @@
 #include <frmfmt.hxx>
 #include <doc.hxx>
 #include <IDocumentUndoRedo.hxx>
+#include <IDocumentDrawModelAccess.hxx>
+#include <IDocumentRedlineAccess.hxx>
+#include <IDocumentLayoutAccess.hxx>
 #include <swundo.hxx>
 #include <pam.hxx>
 #include <ndtxt.hxx>
@@ -57,26 +58,23 @@
 
 using namespace ::com::sun::star;
 
-
-//------------------------------------------------------------
-
 // INSERT
 
-OUString * SwUndoInsert::GetTxtFromDoc() const
+OUString * SwUndoInsert::GetTextFromDoc() const
 {
     OUString * pResult = NULL;
 
     SwNodeIndex aNd( pDoc->GetNodes(), nNode);
-    SwCntntNode* pCNd = aNd.GetNode().GetCntntNode();
-    SwPaM aPaM( *pCNd, nCntnt );
+    SwContentNode* pCNd = aNd.GetNode().GetContentNode();
+    SwPaM aPaM( *pCNd, nContent );
 
     aPaM.SetMark();
 
-    if( pCNd->IsTxtNode() )
+    if( pCNd->IsTextNode() )
     {
-        OUString sTxt = static_cast<SwTxtNode*>(pCNd)->GetTxt();
+        OUString sText = pCNd->GetTextNode()->GetText();
 
-        sal_Int32 nStart = nCntnt-nLen;
+        sal_Int32 nStart = nContent-nLen;
         sal_Int32 nLength = nLen;
 
         if (nStart < 0)
@@ -85,7 +83,7 @@ OUString * SwUndoInsert::GetTxtFromDoc() const
             nStart = 0;
         }
 
-        pResult = new OUString(sTxt.copy(nStart, nLength));
+        pResult = new OUString(sText.copy(nStart, nLength));
     }
 
     return pResult;
@@ -95,26 +93,26 @@ void SwUndoInsert::Init(const SwNodeIndex & rNd)
 {
     // consider Redline
     pDoc = rNd.GetNode().GetDoc();
-    if( pDoc->IsRedlineOn() )
+    if( pDoc->getIDocumentRedlineAccess().IsRedlineOn() )
     {
         pRedlData = new SwRedlineData( nsRedlineType_t::REDLINE_INSERT,
-                                       pDoc->GetRedlineAuthor() );
-        SetRedlineMode( pDoc->GetRedlineMode() );
+                                       pDoc->getIDocumentRedlineAccess().GetRedlineAuthor() );
+        SetRedlineMode( pDoc->getIDocumentRedlineAccess().GetRedlineMode() );
     }
 
-    pUndoTxt = GetTxtFromDoc();
+    pUndoText = GetTextFromDoc();
 
     bCacheComment = false;
 }
 
 // #111827#
-SwUndoInsert::SwUndoInsert( const SwNodeIndex& rNd, xub_StrLen nCnt,
-            xub_StrLen nL,
-            const IDocumentContentOperations::InsertFlags nInsertFlags,
-            sal_Bool bWDelim )
-    : SwUndo(UNDO_TYPING), pTxt( 0 ), pRedlData( 0 ),
-        nNode( rNd.GetIndex() ), nCntnt(nCnt), nLen(nL),
-        bIsWordDelim( bWDelim ), bIsAppend( sal_False )
+SwUndoInsert::SwUndoInsert( const SwNodeIndex& rNd, sal_Int32 nCnt,
+            sal_Int32 nL,
+            const SwInsertFlags nInsertFlags,
+            bool bWDelim )
+    : SwUndo(UNDO_TYPING), pText( 0 ), pRedlData( 0 ),
+        nNode( rNd.GetIndex() ), nContent(nCnt), nLen(nL),
+        bIsWordDelim( bWDelim ), bIsAppend( false )
     , m_bWithRsid(false)
     , m_nInsertFlags(nInsertFlags)
 {
@@ -123,11 +121,11 @@ SwUndoInsert::SwUndoInsert( const SwNodeIndex& rNd, xub_StrLen nCnt,
 
 // #111827#
 SwUndoInsert::SwUndoInsert( const SwNodeIndex& rNd )
-    : SwUndo(UNDO_SPLITNODE), pTxt( 0 ),
-        pRedlData( 0 ), nNode( rNd.GetIndex() ), nCntnt(0), nLen(1),
-        bIsWordDelim( sal_False ), bIsAppend( sal_True )
+    : SwUndo(UNDO_SPLITNODE), pText( 0 ),
+        pRedlData( 0 ), nNode( rNd.GetIndex() ), nContent(0), nLen(1),
+        bIsWordDelim( false ), bIsAppend( true )
     , m_bWithRsid(false)
-    , m_nInsertFlags(IDocumentContentOperations::INS_EMPTYEXPAND)
+    , m_nInsertFlags(SwInsertFlags::EMPTYEXPAND)
 {
     Init(rNd);
 }
@@ -136,54 +134,54 @@ SwUndoInsert::SwUndoInsert( const SwNodeIndex& rNd )
 // change the length and InsPos. As a result, SwDoc::Inser will not add a
 // new object into the Undo list.
 
-sal_Bool SwUndoInsert::CanGrouping( sal_Unicode cIns )
+bool SwUndoInsert::CanGrouping( sal_Unicode cIns )
 {
     if( !bIsAppend && bIsWordDelim ==
         !GetAppCharClass().isLetterNumeric( OUString( cIns )) )
     {
         nLen++;
-        nCntnt++;
+        nContent++;
 
-        if (pUndoTxt)
-            (*pUndoTxt) += OUString(cIns);
+        if (pUndoText)
+            (*pUndoText) += OUString(cIns);
 
-        return sal_True;
+        return true;
     }
-    return sal_False;
+    return false;
 }
 
-sal_Bool SwUndoInsert::CanGrouping( const SwPosition& rPos )
+bool SwUndoInsert::CanGrouping( const SwPosition& rPos )
 {
-    sal_Bool bRet = sal_False;
+    bool bRet = false;
     if( nNode == rPos.nNode.GetIndex() &&
-        nCntnt == rPos.nContent.GetIndex() )
+        nContent == rPos.nContent.GetIndex() )
     {
         // consider Redline
         SwDoc& rDoc = *rPos.nNode.GetNode().GetDoc();
-        if( ( ~nsRedlineMode_t::REDLINE_SHOW_MASK & rDoc.GetRedlineMode() ) ==
+        if( ( ~nsRedlineMode_t::REDLINE_SHOW_MASK & rDoc.getIDocumentRedlineAccess().GetRedlineMode() ) ==
             ( ~nsRedlineMode_t::REDLINE_SHOW_MASK & GetRedlineMode() ) )
         {
-            bRet = sal_True;
+            bRet = true;
 
             // than there is or was still an active Redline:
             // Check if there is another Redline at the InsPosition. If the
             // same exists only once, it can be combined.
-            const SwRedlineTbl& rTbl = rDoc.GetRedlineTbl();
-            if( !rTbl.empty() )
+            const SwRedlineTable& rTable = rDoc.getIDocumentRedlineAccess().GetRedlineTable();
+            if( !rTable.empty() )
             {
-                SwRedlineData aRData( nsRedlineType_t::REDLINE_INSERT, rDoc.GetRedlineAuthor() );
+                SwRedlineData aRData( nsRedlineType_t::REDLINE_INSERT, rDoc.getIDocumentRedlineAccess().GetRedlineAuthor() );
                 const SwIndexReg* pIReg = rPos.nContent.GetIdxReg();
-                SwIndex* pIdx;
-                for( sal_uInt16 i = 0; i < rTbl.size(); ++i )
+                for( size_t i = 0; i < rTable.size(); ++i )
                 {
-                    SwRedline* pRedl = rTbl[ i ];
-                    if( pIReg == (pIdx = &pRedl->End()->nContent)->GetIdxReg() &&
-                        nCntnt == pIdx->GetIndex() )
+                    SwRangeRedline* pRedl = rTable[ i ];
+                    SwIndex* pIdx = &pRedl->End()->nContent;
+                    if( pIReg == pIdx->GetIdxReg() &&
+                        nContent == pIdx->GetIndex() )
                     {
                         if( !pRedl->HasMark() || !pRedlData ||
                             *pRedl != *pRedlData || *pRedl != aRData )
                         {
-                            bRet = sal_False;
+                            bRet = false;
                             break;
                         }
                     }
@@ -204,10 +202,10 @@ SwUndoInsert::~SwUndoInsert()
             rUNds.GetEndOfExtras().GetIndex() - m_pUndoNodeIndex->GetIndex());
         m_pUndoNodeIndex.reset();
     }
-    else if( pTxt )     // the inserted text
-        delete pTxt;
+    else if( pText )     // the inserted text
+        delete pText;
     delete pRedlData;
-    delete pUndoTxt;
+    delete pUndoText;
 }
 
 void SwUndoInsert::UndoImpl(::sw::UndoRedoContext & rContext)
@@ -221,89 +219,69 @@ void SwUndoInsert::UndoImpl(::sw::UndoRedoContext & rContext)
 
         if( IDocumentRedlineAccess::IsRedlineOn( GetRedlineMode() ))
         {
-            pPam->GetPoint()->nContent.Assign( pPam->GetCntntNode(), 0 );
+            pPam->GetPoint()->nContent.Assign( pPam->GetContentNode(), 0 );
             pPam->SetMark();
             pPam->Move( fnMoveBackward );
             pPam->Exchange();
-            pTmpDoc->DeleteRedline( *pPam, true, USHRT_MAX );
+            pTmpDoc->getIDocumentRedlineAccess().DeleteRedline( *pPam, true, USHRT_MAX );
         }
         pPam->DeleteMark();
-        pTmpDoc->DelFullPara( *pPam );
-        pPam->GetPoint()->nContent.Assign( pPam->GetCntntNode(), 0 );
+        pTmpDoc->getIDocumentContentOperations().DelFullPara( *pPam );
+        pPam->GetPoint()->nContent.Assign( pPam->GetContentNode(), 0 );
     }
     else
     {
         sal_uLong nNd = nNode;
-        sal_Int32 nCnt = nCntnt;
+        sal_Int32 nCnt = nContent;
         if( nLen )
         {
             SwNodeIndex aNd( pTmpDoc->GetNodes(), nNode);
-            SwCntntNode* pCNd = aNd.GetNode().GetCntntNode();
-            SwPaM aPaM( *pCNd, nCntnt );
+            SwContentNode* pCNd = aNd.GetNode().GetContentNode();
+            SwPaM aPaM( *pCNd, nContent );
 
             aPaM.SetMark();
 
-            SwTxtNode * const pTxtNode( pCNd->GetTxtNode() );
-            if ( pTxtNode )
+            SwTextNode * const pTextNode( pCNd->GetTextNode() );
+            if ( pTextNode )
             {
                 aPaM.GetPoint()->nContent -= nLen;
                 if( IDocumentRedlineAccess::IsRedlineOn( GetRedlineMode() ))
-                    pTmpDoc->DeleteRedline( aPaM, true, USHRT_MAX );
+                    pTmpDoc->getIDocumentRedlineAccess().DeleteRedline( aPaM, true, USHRT_MAX );
                 if (m_bWithRsid)
                 {
                     // RSID was added: remove any CHARFMT/AUTOFMT that may be
                     // set on the deleted text; EraseText will leave empty
                     // ones behind otherwise
-                    pTxtNode->DeleteAttributes(RES_TXTATR_AUTOFMT,
+                    pTextNode->DeleteAttributes(RES_TXTATR_AUTOFMT,
                         aPaM.GetPoint()->nContent.GetIndex(),
                         aPaM.GetMark()->nContent.GetIndex());
-                    pTxtNode->DeleteAttributes(RES_TXTATR_CHARFMT,
+                    pTextNode->DeleteAttributes(RES_TXTATR_CHARFMT,
                         aPaM.GetPoint()->nContent.GetIndex(),
                         aPaM.GetMark()->nContent.GetIndex());
                 }
-                RemoveIdxFromRange( aPaM, sal_False );
-                pTxt = new OUString( pTxtNode->GetTxt().copy(nCntnt-nLen, nLen) );
-                pTxtNode->EraseText( aPaM.GetPoint()->nContent, nLen );
-
-                // Undo deletes fieldmarks in two step: first the end then the start position.
-                // Once the start position is deleted, make sure the fieldmark itself is deleted as well.
-                if (nLen == 1)
-                {
-                    IDocumentMarkAccess* const pMarkAccess = pTmpDoc->getIDocumentMarkAccess();
-                    for ( IDocumentMarkAccess::const_iterator_t i = pMarkAccess->getMarksBegin(); i != pMarkAccess->getMarksEnd(); ++i)
-                    {
-                        sw::mark::IMark* pMark = i->get();
-                        if (pMark->GetMarkStart() == *aPaM.GetPoint() && pMark->GetMarkStart().nContent == aPaM.GetPoint()->nContent)
-                        {
-                            sw::mark::IFieldmark* pFieldmark = dynamic_cast<sw::mark::IFieldmark*>(pMark);
-                            if (pFieldmark && pFieldmark->GetFieldname() == ODF_COMMENTRANGE)
-                            {
-                                pTmpDoc->getIDocumentMarkAccess()->deleteMark(pMark);
-                                break;
-                            }
-                        }
-                    }
-                }
+                RemoveIdxFromRange( aPaM, false );
+                pText = new OUString( pTextNode->GetText().copy(nContent-nLen, nLen) );
+                pTextNode->EraseText( aPaM.GetPoint()->nContent, nLen );
             }
             else                // otherwise Graphics/OLE/Text/...
             {
                 aPaM.Move(fnMoveBackward);
                 if( IDocumentRedlineAccess::IsRedlineOn( GetRedlineMode() ))
-                    pTmpDoc->DeleteRedline( aPaM, true, USHRT_MAX );
-                RemoveIdxFromRange( aPaM, sal_False );
+                    pTmpDoc->getIDocumentRedlineAccess().DeleteRedline( aPaM, true, USHRT_MAX );
+                RemoveIdxFromRange( aPaM, false );
             }
 
             nNd = aPaM.GetPoint()->nNode.GetIndex();
             nCnt = aPaM.GetPoint()->nContent.GetIndex();
 
-            if( !pTxt )
+            if( !pText )
             {
                 m_pUndoNodeIndex.reset(
                         new SwNodeIndex(pDoc->GetNodes().GetEndOfContent()));
                 MoveToUndoNds(aPaM, m_pUndoNodeIndex.get());
             }
             nNode = aPaM.GetPoint()->nNode.GetIndex();
-            nCntnt = aPaM.GetPoint()->nContent.GetIndex();
+            nContent = aPaM.GetPoint()->nContent.GetIndex();
         }
 
         // set cursor to Undo range
@@ -311,13 +289,12 @@ void SwUndoInsert::UndoImpl(::sw::UndoRedoContext & rContext)
 
         pPam->GetPoint()->nNode = nNd;
         pPam->GetPoint()->nContent.Assign(
-                pPam->GetPoint()->nNode.GetNode().GetCntntNode(), nCnt );
+                pPam->GetPoint()->nNode.GetNode().GetContentNode(), nCnt );
     }
 
-    DELETEZ(pUndoTxt);
+    DELETEZ(pUndoText);
 }
 
-
 void SwUndoInsert::RedoImpl(::sw::UndoRedoContext & rContext)
 {
     SwDoc *const pTmpDoc = & rContext.GetDoc();
@@ -327,7 +304,7 @@ void SwUndoInsert::RedoImpl(::sw::UndoRedoContext & rContext)
     if( bIsAppend )
     {
         pPam->GetPoint()->nNode = nNode - 1;
-        pTmpDoc->AppendTxtNode( *pPam->GetPoint() );
+        pTmpDoc->getIDocumentContentOperations().AppendTextNode( *pPam->GetPoint() );
 
         pPam->SetMark();
         pPam->Move( fnMoveBackward );
@@ -335,37 +312,37 @@ void SwUndoInsert::RedoImpl(::sw::UndoRedoContext & rContext)
 
         if( pRedlData && IDocumentRedlineAccess::IsRedlineOn( GetRedlineMode() ))
         {
-            RedlineMode_t eOld = pTmpDoc->GetRedlineMode();
-            pTmpDoc->SetRedlineMode_intern((RedlineMode_t)(eOld & ~nsRedlineMode_t::REDLINE_IGNORE));
-            pTmpDoc->AppendRedline( new SwRedline( *pRedlData, *pPam ), true);
-            pTmpDoc->SetRedlineMode_intern( eOld );
+            RedlineMode_t eOld = pTmpDoc->getIDocumentRedlineAccess().GetRedlineMode();
+            pTmpDoc->getIDocumentRedlineAccess().SetRedlineMode_intern((RedlineMode_t)(eOld & ~nsRedlineMode_t::REDLINE_IGNORE));
+            pTmpDoc->getIDocumentRedlineAccess().AppendRedline( new SwRangeRedline( *pRedlData, *pPam ), true);
+            pTmpDoc->getIDocumentRedlineAccess().SetRedlineMode_intern( eOld );
         }
         else if( !( nsRedlineMode_t::REDLINE_IGNORE & GetRedlineMode() ) &&
-                !pTmpDoc->GetRedlineTbl().empty() )
-            pTmpDoc->SplitRedline( *pPam );
+                !pTmpDoc->getIDocumentRedlineAccess().GetRedlineTable().empty() )
+            pTmpDoc->getIDocumentRedlineAccess().SplitRedline( *pPam );
 
         pPam->DeleteMark();
     }
     else
     {
         pPam->GetPoint()->nNode = nNode;
-        SwCntntNode *const pCNd =
-            pPam->GetPoint()->nNode.GetNode().GetCntntNode();
-        pPam->GetPoint()->nContent.Assign( pCNd, nCntnt );
+        SwContentNode *const pCNd =
+            pPam->GetPoint()->nNode.GetNode().GetContentNode();
+        pPam->GetPoint()->nContent.Assign( pCNd, nContent );
 
         if( nLen )
         {
-            sal_Bool bMvBkwrd = MovePtBackward( *pPam );
+            const bool bMvBkwrd = MovePtBackward( *pPam );
 
-            if( pTxt )
+            if( pText )
             {
-                SwTxtNode *const pTxtNode = pCNd->GetTxtNode();
-                OSL_ENSURE( pTxtNode, "where is my textnode ?" );
+                SwTextNode *const pTextNode = pCNd->GetTextNode();
+                OSL_ENSURE( pTextNode, "where is my textnode ?" );
                 OUString const ins(
-                    pTxtNode->InsertText( *pTxt, pPam->GetMark()->nContent,
+                    pTextNode->InsertText( *pText, pPam->GetMark()->nContent,
                     m_nInsertFlags) );
-                assert(ins.getLength() == pTxt->getLength()); // must succeed
-                DELETEZ( pTxt );
+                assert(ins.getLength() == pText->getLength()); // must succeed
+                DELETEZ( pText );
                 if (m_bWithRsid) // re-insert RSID
                 {
                     SwPaM pam(*pPam->GetMark(), 0); // mark -> point
@@ -380,25 +357,25 @@ void SwUndoInsert::RedoImpl(::sw::UndoRedoContext & rContext)
                 MoveFromUndoNds(*pTmpDoc, nMvNd, *pPam->GetMark());
             }
             nNode = pPam->GetMark()->nNode.GetIndex();
-            nCntnt = pPam->GetMark()->nContent.GetIndex();
+            nContent = pPam->GetMark()->nContent.GetIndex();
 
             MovePtForward( *pPam, bMvBkwrd );
             pPam->Exchange();
             if( pRedlData && IDocumentRedlineAccess::IsRedlineOn( GetRedlineMode() ))
             {
-                RedlineMode_t eOld = pTmpDoc->GetRedlineMode();
-                pTmpDoc->SetRedlineMode_intern((RedlineMode_t)(eOld & ~nsRedlineMode_t::REDLINE_IGNORE));
-                pTmpDoc->AppendRedline( new SwRedline( *pRedlData,
+                RedlineMode_t eOld = pTmpDoc->getIDocumentRedlineAccess().GetRedlineMode();
+                pTmpDoc->getIDocumentRedlineAccess().SetRedlineMode_intern((RedlineMode_t)(eOld & ~nsRedlineMode_t::REDLINE_IGNORE));
+                pTmpDoc->getIDocumentRedlineAccess().AppendRedline( new SwRangeRedline( *pRedlData,
                                             *pPam ), true);
-                pTmpDoc->SetRedlineMode_intern( eOld );
+                pTmpDoc->getIDocumentRedlineAccess().SetRedlineMode_intern( eOld );
             }
             else if( !( nsRedlineMode_t::REDLINE_IGNORE & GetRedlineMode() ) &&
-                    !pTmpDoc->GetRedlineTbl().empty() )
-                pTmpDoc->SplitRedline(*pPam);
+                    !pTmpDoc->getIDocumentRedlineAccess().GetRedlineTable().empty() )
+                pTmpDoc->getIDocumentRedlineAccess().SplitRedline(*pPam);
         }
     }
 
-    pUndoTxt = GetTxtFromDoc();
+    pUndoText = GetTextFromDoc();
 }
 
 void SwUndoInsert::RepeatImpl(::sw::RepeatContext & rContext)
@@ -408,14 +385,14 @@ void SwUndoInsert::RepeatImpl(::sw::RepeatContext & rContext)
 
     SwDoc & rDoc = rContext.GetDoc();
     SwNodeIndex aNd( rDoc.GetNodes(), nNode );
-    SwCntntNode* pCNd = aNd.GetNode().GetCntntNode();
+    SwContentNode* pCNd = aNd.GetNode().GetContentNode();
 
     if( !bIsAppend && 1 == nLen )       // >1 than always Text, otherwise Graphics/OLE/Text/...
     {
-        SwPaM aPaM( *pCNd, nCntnt );
+        SwPaM aPaM( *pCNd, nContent );
         aPaM.SetMark();
         aPaM.Move(fnMoveBackward);
-        pCNd = aPaM.GetCntntNode();
+        pCNd = aPaM.GetContentNode();
     }
 
 // What happens with the possible selected range ???
@@ -425,25 +402,25 @@ void SwUndoInsert::RepeatImpl(::sw::RepeatContext & rContext)
     case ND_TEXTNODE:
         if( bIsAppend )
         {
-            rDoc.AppendTxtNode( *rContext.GetRepeatPaM().GetPoint() );
+            rDoc.getIDocumentContentOperations().AppendTextNode( *rContext.GetRepeatPaM().GetPoint() );
         }
         else
         {
-            OUString const aTxt( static_cast<SwTxtNode*>(pCNd)->GetTxt() );
+            OUString const aText( pCNd->GetTextNode()->GetText() );
             ::sw::GroupUndoGuard const undoGuard(rDoc.GetIDocumentUndoRedo());
-            rDoc.InsertString( rContext.GetRepeatPaM(),
-                aTxt.copy(nCntnt - nLen, nLen) );
+            rDoc.getIDocumentContentOperations().InsertString( rContext.GetRepeatPaM(),
+                aText.copy(nContent - nLen, nLen) );
         }
         break;
     case ND_GRFNODE:
         {
-            SwGrfNode* pGrfNd = (SwGrfNode*)pCNd;
+            SwGrfNode* pGrfNd = static_cast<SwGrfNode*>(pCNd);
             OUString sFile;
             OUString sFilter;
             if( pGrfNd->IsGrfLink() )
                 pGrfNd->GetFileFilterNms( &sFile, &sFilter );
 
-            rDoc.Insert( rContext.GetRepeatPaM(), sFile, sFilter,
+            rDoc.getIDocumentContentOperations().Insert( rContext.GetRepeatPaM(), sFile, sFilter,
                                 &pGrfNd->GetGrf(),
                                 0/* Graphics collection*/, NULL, NULL );
         }
@@ -452,8 +429,8 @@ void SwUndoInsert::RepeatImpl(::sw::RepeatContext & rContext)
     case ND_OLENODE:
         {
             // StarView does not yet provide an option to copy a StarOBJ
-            SvStorageRef aRef = new SvStorage( aEmptyOUStr );
-            SwOLEObj& rSwOLE = (SwOLEObj&)((SwOLENode*)pCNd)->GetOLEObj();
+            tools::SvRef<SotStorage> aRef = new SotStorage( OUString() );
+            SwOLEObj& rSwOLE = (SwOLEObj&)static_cast<SwOLENode*>(pCNd)->GetOLEObj();
 
             // temporary storage until object is inserted
             // TODO/MBA: seems that here a physical copy is done - not as in drawing layer! Testing!
@@ -463,7 +440,7 @@ void SwUndoInsert::RepeatImpl(::sw::RepeatContext & rContext)
             if (aCnt.StoreEmbeddedObject(rSwOLE.GetOleRef(), aName, true, OUString(), OUString()))
             {
                 uno::Reference < embed::XEmbeddedObject > aNew = aCnt.GetEmbeddedObject( aName );
-                rDoc.Insert( rContext.GetRepeatPaM(),
+                rDoc.getIDocumentContentOperations().Insert( rContext.GetRepeatPaM(),
                     svt::EmbeddedObjectRef( aNew,
                         static_cast<SwOLENode*>(pCNd)->GetAspect() ),
                     NULL, NULL, NULL );
@@ -481,10 +458,10 @@ SwRewriter SwUndoInsert::GetRewriter() const
     OUString * pStr = NULL;
     bool bDone = false;
 
-    if (pTxt)
-        pStr = pTxt;
-    else if (pUndoTxt)
-        pStr = pUndoTxt;
+    if (pText)
+        pStr = pText;
+    else if (pUndoText)
+        pStr = pUndoText;
 
     if (pStr)
     {
@@ -505,22 +482,18 @@ SwRewriter SwUndoInsert::GetRewriter() const
     return aResult;
 }
 
-
-// SwUndoReplace /////////////////////////////////////////////////////////
-
-
 class SwUndoReplace::Impl
-    : private SwUndoSaveCntnt
+    : private SwUndoSaveContent
 {
     OUString m_sOld;
     OUString m_sIns;
     sal_uLong m_nSttNd, m_nEndNd, m_nOffset;
-    xub_StrLen m_nSttCnt, m_nEndCnt, m_nSetPos, m_nSelEnd;
+    sal_Int32 m_nSttCnt, m_nEndCnt, m_nSetPos, m_nSelEnd;
     bool m_bSplitNext : 1;
     bool m_bRegExp : 1;
     // metadata references for paragraph and following para (if m_bSplitNext)
-    ::boost::shared_ptr< ::sfx2::MetadatableUndo > m_pMetadataUndoStart;
-    ::boost::shared_ptr< ::sfx2::MetadatableUndo > m_pMetadataUndoEnd;
+    std::shared_ptr< ::sfx2::MetadatableUndo > m_pMetadataUndoStart;
+    std::shared_ptr< ::sfx2::MetadatableUndo > m_pMetadataUndoEnd;
 
 public:
     Impl(SwPaM const& rPam, OUString const& rIns, bool const bRegExp);
@@ -528,8 +501,8 @@ public:
     {
     }
 
-    virtual void UndoImpl( ::sw::UndoRedoContext & );
-    virtual void RedoImpl( ::sw::UndoRedoContext & );
+    void UndoImpl( ::sw::UndoRedoContext & );
+    void RedoImpl( ::sw::UndoRedoContext & );
 
     void SetEnd(SwPaM const& rPam);
 
@@ -537,7 +510,6 @@ public:
     OUString const& GetIns() const { return m_sIns; }
 };
 
-
 SwUndoReplace::SwUndoReplace(SwPaM const& rPam,
         OUString const& rIns, bool const bRegExp)
     : SwUndo( UNDO_REPLACE )
@@ -634,11 +606,11 @@ SwUndoReplace::Impl::Impl(
 
     m_bSplitNext = m_nSttNd != pEnd->nNode.GetIndex();
 
-    SwTxtNode* pNd = pStt->nNode.GetNode().GetTxtNode();
+    SwTextNode* pNd = pStt->nNode.GetNode().GetTextNode();
     OSL_ENSURE( pNd, "Dude, where's my TextNode?" );
 
     pHistory = new SwHistory;
-    DelCntntIndex( *rPam.GetMark(), *rPam.GetPoint() );
+    DelContentIndex( *rPam.GetMark(), *rPam.GetPoint() );
 
     m_nSetPos = pHistory->Count();
 
@@ -648,22 +620,22 @@ SwUndoReplace::Impl::Impl(
     if ( pNd->GetpSwpHints() )
     {
         pHistory->CopyAttr( pNd->GetpSwpHints(), nNewPos, 0,
-                            pNd->GetTxt().getLength(), true );
+                            pNd->GetText().getLength(), true );
     }
 
     if ( m_bSplitNext )
     {
         if( pNd->HasSwAttrSet() )
-            pHistory->CopyFmtAttr( *pNd->GetpSwAttrSet(), nNewPos );
-        pHistory->Add( pNd->GetTxtColl(), nNewPos, ND_TEXTNODE );
+            pHistory->CopyFormatAttr( *pNd->GetpSwAttrSet(), nNewPos );
+        pHistory->Add( pNd->GetTextColl(), nNewPos, ND_TEXTNODE );
 
-        SwTxtNode* pNext = pEnd->nNode.GetNode().GetTxtNode();
+        SwTextNode* pNext = pEnd->nNode.GetNode().GetTextNode();
         sal_uLong nTmp = pNext->GetIndex();
         pHistory->CopyAttr( pNext->GetpSwpHints(), nTmp, 0,
-                            pNext->GetTxt().getLength(), true );
+                            pNext->GetText().getLength(), true );
         if( pNext->HasSwAttrSet() )
-            pHistory->CopyFmtAttr( *pNext->GetpSwAttrSet(), nTmp );
-        pHistory->Add( pNext->GetTxtColl(),nTmp, ND_TEXTNODE );
+            pHistory->CopyFormatAttr( *pNext->GetpSwAttrSet(), nTmp );
+        pHistory->Add( pNext->GetTextColl(),nTmp, ND_TEXTNODE );
         // METADATA: store
         m_pMetadataUndoStart = pNd  ->CreateUndo();
         m_pMetadataUndoEnd   = pNext->CreateUndo();
@@ -672,9 +644,9 @@ SwUndoReplace::Impl::Impl(
     if( !pHistory->Count() )
         delete pHistory, pHistory = 0;
 
-    const sal_Int32 nECnt = m_bSplitNext ? pNd->GetTxt().getLength()
+    const sal_Int32 nECnt = m_bSplitNext ? pNd->GetText().getLength()
         : pEnd->nContent.GetIndex();
-    m_sOld = pNd->GetTxt().copy( m_nSttCnt, nECnt - m_nSttCnt );
+    m_sOld = pNd->GetText().copy( m_nSttCnt, nECnt - m_nSttCnt );
 }
 
 void SwUndoReplace::Impl::UndoImpl(::sw::UndoRedoContext & rContext)
@@ -683,7 +655,7 @@ void SwUndoReplace::Impl::UndoImpl(::sw::UndoRedoContext & rContext)
     SwPaM & rPam(rContext.GetCursorSupplier().CreateNewShellCursor());
     rPam.DeleteMark();
 
-    SwTxtNode* pNd = pDoc->GetNodes()[ m_nSttNd - m_nOffset ]->GetTxtNode();
+    SwTextNode* pNd = pDoc->GetNodes()[ m_nSttNd - m_nOffset ]->GetTextNode();
     OSL_ENSURE( pNd, "Dude, where's my TextNode?" );
 
     SwAutoCorrExceptWord* pACEWord = pDoc->GetAutoCorrExceptWord();
@@ -704,13 +676,13 @@ void SwUndoReplace::Impl::UndoImpl(::sw::UndoRedoContext & rContext)
         rPam.GetPoint()->nContent.Assign( pNd, m_nSttCnt );
         rPam.SetMark();
         rPam.GetPoint()->nNode = m_nEndNd - m_nOffset;
-        rPam.GetPoint()->nContent.Assign( rPam.GetCntntNode(), m_nEndCnt );
+        rPam.GetPoint()->nContent.Assign( rPam.GetContentNode(), m_nEndCnt );
         // move it out of the way so it is not registered at deleted node
         aIdx.Assign(0, 0);
 
-        pDoc->DeleteAndJoin( rPam );
+        pDoc->getIDocumentContentOperations().DeleteAndJoin( rPam );
         rPam.DeleteMark();
-        pNd = rPam.GetNode()->GetTxtNode();
+        pNd = rPam.GetNode().GetTextNode();
         OSL_ENSURE( pNd, "Dude, where's my TextNode?" );
         aIdx.Assign( pNd, m_nSttCnt );
     }
@@ -718,9 +690,9 @@ void SwUndoReplace::Impl::UndoImpl(::sw::UndoRedoContext & rContext)
     if( m_bSplitNext )
     {
         SwPosition aPos( *pNd, aIdx );
-        pDoc->SplitNode( aPos, false );
+        pDoc->getIDocumentContentOperations().SplitNode( aPos, false );
         pNd->RestoreMetadata(m_pMetadataUndoEnd);
-        pNd = pDoc->GetNodes()[ m_nSttNd - m_nOffset ]->GetTxtNode();
+        pNd = pDoc->GetNodes()[ m_nSttNd - m_nOffset ]->GetTextNode();
         aIdx.Assign( pNd, m_nSttCnt );
         // METADATA: restore
         pNd->RestoreMetadata(m_pMetadataUndoStart);
@@ -769,14 +741,14 @@ void SwUndoReplace::Impl::RedoImpl(::sw::UndoRedoContext & rContext)
     rPam.DeleteMark();
     rPam.GetPoint()->nNode = m_nSttNd;
 
-    SwTxtNode* pNd = rPam.GetPoint()->nNode.GetNode().GetTxtNode();
+    SwTextNode* pNd = rPam.GetPoint()->nNode.GetNode().GetTextNode();
     OSL_ENSURE( pNd, "Dude, where's my TextNode?" );
     rPam.GetPoint()->nContent.Assign( pNd, m_nSttCnt );
     rPam.SetMark();
     if( m_bSplitNext )
     {
         rPam.GetPoint()->nNode = m_nSttNd + 1;
-        pNd = rPam.GetPoint()->nNode.GetNode().GetTxtNode();
+        pNd = rPam.GetPoint()->nNode.GetNode().GetTextNode();
     }
     rPam.GetPoint()->nContent.Assign( pNd, m_nSelEnd );
 
@@ -785,7 +757,7 @@ void SwUndoReplace::Impl::RedoImpl(::sw::UndoRedoContext & rContext)
         SwHistory* pSave = pHistory;
         SwHistory aHst;
         pHistory = &aHst;
-        DelCntntIndex( *rPam.GetMark(), *rPam.GetPoint() );
+        DelContentIndex( *rPam.GetMark(), *rPam.GetPoint() );
         m_nSetPos = pHistory->Count();
 
         pHistory = pSave;
@@ -794,13 +766,13 @@ void SwUndoReplace::Impl::RedoImpl(::sw::UndoRedoContext & rContext)
     else
     {
         pHistory = new SwHistory;
-        DelCntntIndex( *rPam.GetMark(), *rPam.GetPoint() );
+        DelContentIndex( *rPam.GetMark(), *rPam.GetPoint() );
         m_nSetPos = pHistory->Count();
         if( !m_nSetPos )
             delete pHistory, pHistory = 0;
     }
 
-    rDoc.ReplaceRange( rPam, m_sIns, m_bRegExp );
+    rDoc.getIDocumentContentOperations().ReplaceRange( rPam, m_sIns, m_bRegExp );
     rPam.DeleteMark();
 }
 
@@ -811,17 +783,12 @@ void SwUndoReplace::Impl::SetEnd(SwPaM const& rPam)
     m_nEndCnt = pEnd->nContent.GetIndex();
 }
 
-
-// SwUndoReRead //////////////////////////////////////////////////////////
-
-
 SwUndoReRead::SwUndoReRead( const SwPaM& rPam, const SwGrfNode& rGrfNd )
     : SwUndo( UNDO_REREAD ), nPos( rPam.GetPoint()->nNode.GetIndex() )
 {
     SaveGraphicData( rGrfNd );
 }
 
-
 SwUndoReRead::~SwUndoReRead()
 {
     delete pGrf;
@@ -829,7 +796,6 @@ SwUndoReRead::~SwUndoReRead()
     delete pFltr;
 }
 
-
 void SwUndoReRead::SetAndSave(::sw::UndoRedoContext & rContext)
 {
     SwDoc & rDoc = rContext.GetDoc();
@@ -848,35 +814,32 @@ void SwUndoReRead::SetAndSave(::sw::UndoRedoContext & rContext)
 
     if( pOldNm )
     {
-        pGrfNd->ReRead( *pOldNm, pFltr ? *pFltr : OUString(), 0, 0, sal_True );
+        pGrfNd->ReRead( *pOldNm, pFltr ? *pFltr : OUString(), 0, 0, true );
         delete pOldNm;
         delete pOldFltr;
     }
     else
     {
-        pGrfNd->ReRead( aEmptyOUStr, aEmptyOUStr, pOldGrf, 0, sal_True );
+        pGrfNd->ReRead( OUString(), OUString(), pOldGrf, 0, true );
         delete pOldGrf;
     }
 
     if( RES_MIRROR_GRAPH_DONT != nOldMirr )
         pGrfNd->SetAttr( SwMirrorGrf() );
 
-    rContext.SetSelections(pGrfNd->GetFlyFmt(), 0);
+    rContext.SetSelections(pGrfNd->GetFlyFormat(), 0);
 }
 
-
 void SwUndoReRead::UndoImpl(::sw::UndoRedoContext & rContext)
 {
     SetAndSave(rContext);
 }
 
-
 void SwUndoReRead::RedoImpl(::sw::UndoRedoContext & rContext)
 {
     SetAndSave(rContext);
 }
 
-
 void SwUndoReRead::SaveGraphicData( const SwGrfNode& rGrfNd )
 {
     if( rGrfNd.IsGrfLink() )
@@ -888,34 +851,32 @@ void SwUndoReRead::SaveGraphicData( const SwGrfNode& rGrfNd )
     }
     else
     {
-        ((SwGrfNode&)rGrfNd).SwapIn( sal_True );
-        pGrf = new Graphic( rGrfNd.GetGrf() );
+        pGrf = new Graphic( rGrfNd.GetGrf(true) );
         pNm = pFltr = 0;
     }
     nMirr = rGrfNd.GetSwAttrSet().GetMirrorGrf().GetValue();
 }
 
-
 SwUndoInsertLabel::SwUndoInsertLabel( const SwLabelType eTyp,
-                                      const OUString &rTxt,
+                                      const OUString &rText,
                                       const OUString& rSeparator,
                                       const OUString& rNumberSeparator,
-                                      const sal_Bool bBef,
+                                      const bool bBef,
                                       const sal_uInt16 nInitId,
                                       const OUString& rCharacterStyle,
-                                      const sal_Bool bCpyBorder )
+                                      const bool bCpyBorder )
     : SwUndo( UNDO_INSERTLABEL ),
-      sText( rTxt ),
+      sText( rText ),
       sSeparator( rSeparator ),
       sNumberSeparator( rNumberSeparator ),//#i61007# order of captions
       sCharacterStyle( rCharacterStyle ),
-      nFldId( nInitId ),
+      nFieldId( nInitId ),
       eType( eTyp ),
       nLayerId( 0 ),
       bBefore( bBef ),
       bCpyBrd( bCpyBorder )
 {
-    bUndoKeep = sal_False;
+    bUndoKeep = false;
     OBJECT.pUndoFly = 0;
     OBJECT.pUndoAttr = 0;
 }
@@ -938,12 +899,12 @@ void SwUndoInsertLabel::UndoImpl(::sw::UndoRedoContext & rContext)
     if( LTYPE_OBJECT == eType || LTYPE_DRAW == eType )
     {
         OSL_ENSURE( OBJECT.pUndoAttr && OBJECT.pUndoFly, "Pointer not initialized" );
-        SwFrmFmt* pFmt;
+        SwFrameFormat* pFormat;
         SdrObject *pSdrObj = 0;
         if( OBJECT.pUndoAttr &&
-            0 != (pFmt = (SwFrmFmt*)OBJECT.pUndoAttr->GetFmt( rDoc )) &&
+            0 != (pFormat = static_cast<SwFrameFormat*>(OBJECT.pUndoAttr->GetFormat( rDoc ))) &&
             ( LTYPE_DRAW != eType ||
-              0 != (pSdrObj = pFmt->FindSdrObject()) ) )
+              0 != (pSdrObj = pFormat->FindSdrObject()) ) )
         {
             OBJECT.pUndoAttr->UndoImpl(rContext);
             OBJECT.pUndoFly->UndoImpl(rContext);
@@ -960,17 +921,16 @@ void SwUndoInsertLabel::UndoImpl(::sw::UndoRedoContext & rContext)
             SwTableNode *pNd = rDoc.GetNodes()[
                         rDoc.GetNodes()[NODE.nNode-1]->StartOfSectionIndex()]->GetTableNode();
             if ( pNd )
-                pNd->GetTable().GetFrmFmt()->ResetFmtAttr( RES_KEEP );
+                pNd->GetTable().GetFrameFormat()->ResetFormatAttr( RES_KEEP );
         }
         SwPaM aPam( rDoc.GetNodes().GetEndOfContent() );
         aPam.GetPoint()->nNode = NODE.nNode;
         aPam.SetMark();
         aPam.GetPoint()->nNode = NODE.nNode + 1;
-        NODE.pUndoInsNd = new SwUndoDelete( aPam, sal_True );
+        NODE.pUndoInsNd = new SwUndoDelete( aPam, true );
     }
 }
 
-
 void SwUndoInsertLabel::RedoImpl(::sw::UndoRedoContext & rContext)
 {
     SwDoc & rDoc = rContext.GetDoc();
@@ -978,23 +938,23 @@ void SwUndoInsertLabel::RedoImpl(::sw::UndoRedoContext & rContext)
     if( LTYPE_OBJECT == eType || LTYPE_DRAW == eType )
     {
         OSL_ENSURE( OBJECT.pUndoAttr && OBJECT.pUndoFly, "Pointer not initialized" );
-        SwFrmFmt* pFmt;
+        SwFrameFormat* pFormat;
         SdrObject *pSdrObj = 0;
         if( OBJECT.pUndoAttr &&
-            0 != (pFmt = (SwFrmFmt*)OBJECT.pUndoAttr->GetFmt( rDoc )) &&
+            0 != (pFormat = static_cast<SwFrameFormat*>(OBJECT.pUndoAttr->GetFormat( rDoc ))) &&
             ( LTYPE_DRAW != eType ||
-              0 != (pSdrObj = pFmt->FindSdrObject()) ) )
+              0 != (pSdrObj = pFormat->FindSdrObject()) ) )
         {
             OBJECT.pUndoFly->RedoImpl(rContext);
             OBJECT.pUndoAttr->RedoImpl(rContext);
             if( LTYPE_DRAW == eType )
             {
                 pSdrObj->SetLayer( nLayerId );
-                if( pSdrObj->GetLayer() == rDoc.GetHellId() )
-                    pSdrObj->SetLayer( rDoc.GetHeavenId() );
+                if( pSdrObj->GetLayer() == rDoc.getIDocumentDrawModelAccess().GetHellId() )
+                    pSdrObj->SetLayer( rDoc.getIDocumentDrawModelAccess().GetHeavenId() );
                 // OD 02.07.2003 #108784#
-                else if( pSdrObj->GetLayer() == rDoc.GetInvisibleHellId() )
-                    pSdrObj->SetLayer( rDoc.GetInvisibleHeavenId() );
+                else if( pSdrObj->GetLayer() == rDoc.getIDocumentDrawModelAccess().GetInvisibleHellId() )
+                    pSdrObj->SetLayer( rDoc.getIDocumentDrawModelAccess().GetInvisibleHeavenId() );
             }
         }
     }
@@ -1005,7 +965,7 @@ void SwUndoInsertLabel::RedoImpl(::sw::UndoRedoContext & rContext)
             SwTableNode *pNd = rDoc.GetNodes()[
                         rDoc.GetNodes()[NODE.nNode-1]->StartOfSectionIndex()]->GetTableNode();
             if ( pNd )
-                pNd->GetTable().GetFrmFmt()->SetFmtAttr( SvxFmtKeepItem(sal_True, RES_KEEP) );
+                pNd->GetTable().GetFrameFormat()->SetFormatAttr( SvxFormatKeepItem(true, RES_KEEP) );
         }
         NODE.pUndoInsNd->UndoImpl(rContext);
         delete NODE.pUndoInsNd, NODE.pUndoInsNd = 0;
@@ -1019,7 +979,7 @@ void SwUndoInsertLabel::RepeatImpl(::sw::RepeatContext & rContext)
 
     sal_uLong nIdx = 0;
 
-    SwCntntNode* pCNd = rPos.nNode.GetNode().GetCntntNode();
+    SwContentNode* pCNd = rPos.nNode.GetNode().GetContentNode();
     if( pCNd )
         switch( eType )
         {
@@ -1035,9 +995,9 @@ void SwUndoInsertLabel::RepeatImpl(::sw::RepeatContext & rContext)
         case LTYPE_OBJECT:
             {
                 SwFlyFrm* pFly;
-                SwCntntFrm *pCnt = pCNd->getLayoutFrm( rDoc.GetCurrentLayout() );
+                SwContentFrm *pCnt = pCNd->getLayoutFrm( rDoc.getIDocumentLayoutAccess().GetCurrentLayout() );
                 if( pCnt && 0 != ( pFly = pCnt->FindFlyFrm() ) )
-                    nIdx = pFly->GetFmt()->GetCntnt().GetCntntIdx()->GetIndex();
+                    nIdx = pFly->GetFormat()->GetContent().GetContentIdx()->GetIndex();
             }
             break;
         case LTYPE_DRAW:
@@ -1047,7 +1007,7 @@ void SwUndoInsertLabel::RepeatImpl(::sw::RepeatContext & rContext)
     if( nIdx )
     {
         rDoc.InsertLabel( eType, sText, sSeparator, sNumberSeparator, bBefore,
-            nFldId, nIdx, sCharacterStyle, bCpyBrd );
+            nFieldId, nIdx, sCharacterStyle, bCpyBrd );
     }
 }
 
@@ -1068,18 +1028,18 @@ SwRewriter SwUndoInsertLabel::GetRewriter() const
     return aRewriter;
 }
 
-void SwUndoInsertLabel::SetFlys( SwFrmFmt& rOldFly, SfxItemSet& rChgSet,
-                                SwFrmFmt& rNewFly )
+void SwUndoInsertLabel::SetFlys( SwFrameFormat& rOldFly, SfxItemSet& rChgSet,
+                                SwFrameFormat& rNewFly )
 {
     if( LTYPE_OBJECT == eType || LTYPE_DRAW == eType )
     {
-        SwUndoFmtAttrHelper aTmp( rOldFly, false );
-        rOldFly.SetFmtAttr( rChgSet );
+        SwUndoFormatAttrHelper aTmp( rOldFly, false );
+        rOldFly.SetFormatAttr( rChgSet );
         if ( aTmp.GetUndo() )
         {
             OBJECT.pUndoAttr = aTmp.ReleaseUndo();
         }
-        OBJECT.pUndoFly = new SwUndoInsLayFmt( &rNewFly,0,0 );
+        OBJECT.pUndoFly = new SwUndoInsLayFormat( &rNewFly,0,0 );
     }
 }
 
