@@ -17,13 +17,16 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "vcl/svapp.hxx"
+#include <vcl/svapp.hxx>
 
 #include <pagepreviewlayout.hxx>
 #include <prevwpage.hxx>
 
 #include <algorithm>
+#include <tools/fract.hxx>
 #include <vcl/window.hxx>
+#include <vcl/settings.hxx>
+
 #include <rootfrm.hxx>
 #include <pagefrm.hxx>
 #include <viewsh.hxx>
@@ -31,18 +34,13 @@
 #include <viewopt.hxx>
 #include <swregion.hxx>
 #include <comcore.hrc>
-// OD 19.02.2003 #107369# - method <SwAlignRect(..)>
 #include <frmtool.hxx>
-// OD 24.09.2003 #i19975#
 #include <sfx2/zoomitem.hxx>
 #include <printdata.hxx>
+#include <paintfrm.hxx>
 
 #include <IDocumentDeviceAccess.hxx>
 
-// OD 20.02.2003 #107369# - method to update statics for paint
-// Note: method defined in '/sw/source/core/layout/paintfrm.cxx'
-extern void SwCalcPixStatics( OutputDevice *pOut );
-
 // methods to initialize page preview layout
 
 SwPagePreviewLayout::SwPagePreviewLayout( SwViewShell& _rParentViewShell,
@@ -124,6 +122,7 @@ void SwPagePreviewLayout::_ClearPreviewPageData()
 */
 void SwPagePreviewLayout::_CalcPreviewLayoutSizes()
 {
+    vcl::RenderContext* pRenderContext = mrParentViewShell.GetOut();
     // calculate maximal page size; calculate also number of pages
 
     const SwPageFrm* pPage = static_cast<const SwPageFrm*>(mrLayoutRootFrm.Lower());
@@ -136,7 +135,7 @@ void SwPagePreviewLayout::_CalcPreviewLayoutSizes()
         }
 
         ++mnPages;
-        pPage->Calc();
+        pPage->Calc(pRenderContext);
         const Size& rPageSize = pPage->Frm().SSize();
         if ( rPageSize.Width() > maMaxPageSize.Width() )
             maMaxPageSize.Width() = rPageSize.Width();
@@ -161,7 +160,7 @@ void SwPagePreviewLayout::_CalcPreviewLayoutSizes()
         // document height
         // determine number of rows needed for <nPages> in preview layout
         // OD 19.02.2003 #107369# - use method <GetRowOfPage(..)>.
-        sal_uInt16 nDocRows = GetRowOfPage( mnPages );
+        const sal_uInt16 nDocRows = GetRowOfPage( mnPages );
         aDocSize.Height() = nDocRows * maMaxPageSize.Height() +
                             (nDocRows+1) * mnYFree;
         maPreviewDocRect.SetPos( Point( 0, 0 ) );
@@ -256,7 +255,7 @@ void SwPagePreviewLayout::_ApplyNewZoomAtViewShell( sal_uInt8 _aNewZoom )
     {
         aNewViewOptions.SetZoom( _aNewZoom );
         //#i19975# - consider zoom type.
-        enum SvxZoomType eZoomType = SVX_ZOOM_PERCENT;
+        SvxZoomType eZoomType = SvxZoomType::PERCENT;
         aNewViewOptions.SetZoomType( eZoomType );
         mrParentViewShell.ApplyViewOptions( aNewViewOptions );
     }
@@ -293,7 +292,7 @@ bool SwPagePreviewLayout::ReInit()
     @note _nProposedStartPageNum, _onStartPageNum are absolute
 */
 bool SwPagePreviewLayout::Prepare( const sal_uInt16 _nProposedStartPageNum,
-                                   const Point      _aProposedStartPos,
+                                   const Point&      rProposedStartPos,
                                    const Size&      _rPxWinSize,
                                    sal_uInt16&      _onStartPageNum,
                                    Rectangle&       _orDocPreviewPaintRect,
@@ -316,9 +315,9 @@ bool SwPagePreviewLayout::Prepare( const sal_uInt16 _nProposedStartPageNum,
             return false;
 
         bool bStartPosRangeValid =
-                _aProposedStartPos.X() >= 0 && _aProposedStartPos.Y() >= 0 &&
-                _aProposedStartPos.X() <= maPreviewDocRect.Right() &&
-                _aProposedStartPos.Y() <= maPreviewDocRect.Bottom();
+                rProposedStartPos.X() >= 0 && rProposedStartPos.Y() >= 0 &&
+                rProposedStartPos.X() <= maPreviewDocRect.Right() &&
+                rProposedStartPos.Y() <= maPreviewDocRect.Bottom();
         OSL_ENSURE( bStartPosRangeValid,
                 "proposed start position out of range - no prepare of preview paint");
         if ( !bStartPosRangeValid )
@@ -330,7 +329,7 @@ bool SwPagePreviewLayout::Prepare( const sal_uInt16 _nProposedStartPageNum,
             return false;
 
         bool bStartInfoValid = _nProposedStartPageNum > 0 ||
-                               _aProposedStartPos != Point(0,0);
+                               rProposedStartPos != Point(0,0);
         if ( !bStartInfoValid )
             nProposedStartPageNum = 1;
     }
@@ -344,8 +343,8 @@ bool SwPagePreviewLayout::Prepare( const sal_uInt16 _nProposedStartPageNum,
     if ( nProposedStartPageNum > 0 )
     {
         // determine column and row of proposed start page in virtual preview layout
-        sal_uInt16 nColOfProposed = GetColOfPage( nProposedStartPageNum );
-        sal_uInt16 nRowOfProposed = GetRowOfPage( nProposedStartPageNum );
+        const sal_uInt16 nColOfProposed = GetColOfPage( nProposedStartPageNum );
+        const sal_uInt16 nRowOfProposed = GetRowOfPage( nProposedStartPageNum );
         // determine start page
         if ( _bStartWithPageAtFirstCol )
         {
@@ -384,10 +383,10 @@ bool SwPagePreviewLayout::Prepare( const sal_uInt16 _nProposedStartPageNum,
     {
         // determine column and row of proposed start position.
         // Note: paint starts at point (0,0)
-        sal_uInt16 nColOfProposed =
-                static_cast<sal_uInt16>(_aProposedStartPos.X() / mnColWidth) + 1;
-        sal_uInt16 nRowOfProposed =
-                static_cast<sal_uInt16>(_aProposedStartPos.Y() / mnRowHeight) + 1;
+        const sal_uInt16 nColOfProposed =
+                static_cast<sal_uInt16>(rProposedStartPos.X() / mnColWidth) + 1;
+        const sal_uInt16 nRowOfProposed =
+                static_cast<sal_uInt16>(rProposedStartPos.Y() / mnRowHeight) + 1;
         // determine start page == page at proposed start position
         // OD 19.02.2003 #107369# - leaving left-top-corner blank is
         // controlled by <mbBookPreview>.
@@ -415,11 +414,11 @@ bool SwPagePreviewLayout::Prepare( const sal_uInt16 _nProposedStartPageNum,
         mnPaintStartRow = nRowOfProposed;
         // page offset
         maPaintStartPageOffset.X() =
-                (_aProposedStartPos.X() % mnColWidth) - mnXFree;
+                (rProposedStartPos.X() % mnColWidth) - mnXFree;
         maPaintStartPageOffset.Y() =
-                (_aProposedStartPos.Y() % mnRowHeight) - mnYFree;
+                (rProposedStartPos.Y() % mnRowHeight) - mnYFree;
         // virtual preview document offset.
-        maPaintPreviewDocOffset = _aProposedStartPos;
+        maPaintPreviewDocOffset = rProposedStartPos;
     }
 
     // determine additional paint offset, if preview layout fits into window.
@@ -549,6 +548,7 @@ void SwPagePreviewLayout::_CalcDocPreviewPaintRect()
 */
 void SwPagePreviewLayout::_CalcPreviewPages()
 {
+    vcl::RenderContext* pRenderContext = mrParentViewShell.GetOut();
     _ClearPreviewPageData();
 
     if ( mbNoPageVisible )
@@ -560,7 +560,7 @@ void SwPagePreviewLayout::_CalcPreviewPages()
     // calculate initial paint offset
     Point aInitialPaintOffset;
     /// check whether RTL interface or not
-    if(!Application::GetSettings().GetLayoutRTL()){
+    if(!AllSettings::GetLayoutRTL()){
         if ( maPaintStartPageOffset != Point( -1, -1 ) )
             aInitialPaintOffset = Point(0,0) - maPaintStartPageOffset;
         else
@@ -591,7 +591,7 @@ void SwPagePreviewLayout::_CalcPreviewPages()
             continue;
         }
 
-        pPage->Calc();
+        pPage->Calc(pRenderContext);
 
         // consider only pages, which have to be painted.
         if ( nCurrCol < mnPaintStartCol )
@@ -618,7 +618,7 @@ void SwPagePreviewLayout::_CalcPreviewPages()
                 // first page in 2nd column
                 // --> continue with increased paint offset and next column
                 /// check whether RTL interface or not
-                if(!Application::GetSettings().GetLayoutRTL())
+                if(!AllSettings::GetLayoutRTL())
                     aCurrPaintOffset.X() += mnColWidth;
                 else aCurrPaintOffset.X() -= mnColWidth;
                 ++nCurrCol;
@@ -644,7 +644,7 @@ void SwPagePreviewLayout::_CalcPreviewPages()
         pPage = static_cast<const SwPageFrm*>(pPage->GetNext());
 
         /// check whether RTL interface or not
-        if(!Application::GetSettings().GetLayoutRTL())
+        if(!AllSettings::GetLayoutRTL())
             aCurrPaintOffset.X() += mnColWidth;
         else aCurrPaintOffset.X() -= mnColWidth;
         ++nCurrCol;
@@ -708,8 +708,6 @@ bool SwPagePreviewLayout::SetBookPreviewMode( const bool _bEnableBookPreview,
                                               sal_uInt16& _onStartPageNum,
                                               Rectangle&  _orDocPreviewPaintRect )
 {
-    bool bRet = false;
-
     if ( mbBookPreview != _bEnableBookPreview)
     {
         mbBookPreview = _bEnableBookPreview;
@@ -731,10 +729,10 @@ bool SwPagePreviewLayout::SetBookPreviewMode( const bool _bEnableBookPreview,
             mbBookPreviewModeToggled = false;
         }
 
-        bRet = true;
+        return true;
     }
 
-    return bRet;
+    return false;
 }
 
 // methods to determine new data for changing the current shown part of the
@@ -826,17 +824,7 @@ bool SwPagePreviewLayout::CalcStartValuesForSelectedPageMove(
     sal_uInt16 nTmpRelSelPageNum = ConvertAbsoluteToRelativePageNum( mnSelectedPageNum );
     sal_uInt16 nNewRelSelectedPageNum = nTmpRelSelPageNum;
 
-    // leaving left-top-corner blank is controlled
-    // by <mbBookPreview>.
-    if ( mbBookPreview )
-    {
-        // Note: consider that left-top-corner is left blank --> +1
-        ++nTmpRelSelPageNum;
-    }
-    sal_uInt16 nTmpCol = nTmpRelSelPageNum % mnCols;
-    sal_uInt16 nCurrRow = nTmpRelSelPageNum / mnCols;
-    if ( nTmpCol > 0 )
-        ++nCurrRow;
+    const sal_uInt16 nCurrRow = GetRowOfPage(nTmpRelSelPageNum);
 
     // determine new selected page number
     {
@@ -863,7 +851,7 @@ bool SwPagePreviewLayout::CalcStartValuesForSelectedPageMove(
     sal_uInt16 nNewStartPage = mnPaintPhyStartPageNum;
     Point aNewStartPos = Point(0,0);
 
-    sal_uInt16 nNewAbsSelectedPageNum = ConvertRelativeToAbsolutePageNum( nNewRelSelectedPageNum );
+    const sal_uInt16 nNewAbsSelectedPageNum = ConvertRelativeToAbsolutePageNum( nNewRelSelectedPageNum );
     if ( !IsPageVisible( nNewAbsSelectedPageNum ) )
     {
         if ( _nHoriMove != 0 && _nVertMove != 0 )
@@ -874,7 +862,7 @@ bool SwPagePreviewLayout::CalcStartValuesForSelectedPageMove(
 
         // new selected page has to be brought into view considering current
         // visible preview.
-        sal_Int16 nTotalRows = GetRowOfPage( mnPages );
+        const sal_uInt16 nTotalRows = GetRowOfPage( mnPages );
         if ( (_nHoriMove > 0 || _nVertMove > 0) &&
              mbDoesLayoutRowsFitIntoWindow &&
              mbDoesLayoutColsFitIntoWindow &&
@@ -911,26 +899,23 @@ bool SwPagePreviewLayout::CalcStartValuesForSelectedPageMove(
 struct PreviewPosInsidePagePred
 {
     const Point mnPreviewPos;
-    PreviewPosInsidePagePred( const Point _nPreviewPos ) : mnPreviewPos( _nPreviewPos ) {};
+    PreviewPosInsidePagePred( const Point& rPreviewPos ) : mnPreviewPos( rPreviewPos ) {};
     bool operator() ( const PreviewPage* _pPreviewPage )
     {
         if ( _pPreviewPage->bVisible )
         {
             Rectangle aPreviewPageRect( _pPreviewPage->aPreviewWinPos, _pPreviewPage->aPageSize );
-            return aPreviewPageRect.IsInside( mnPreviewPos ) ? true : false;
+            return aPreviewPageRect.IsInside( mnPreviewPos );
         }
-        else
-            return false;
+        return false;
     }
 };
 
-bool SwPagePreviewLayout::IsPreviewPosInDocPreviewPage( const Point  _aPreviewPos,
+bool SwPagePreviewLayout::IsPreviewPosInDocPreviewPage( const Point&  rPreviewPos,
                                                     Point&       _orDocPos,
                                                     bool&        _obPosInEmptyPage,
                                                     sal_uInt16&  _onPageNum ) const
 {
-    bool bIsPosInsideDoc;
-
     // initialize variable parameter values.
     _orDocPos.X() = 0;
     _orDocPos.Y() = 0;
@@ -939,31 +924,24 @@ bool SwPagePreviewLayout::IsPreviewPosInDocPreviewPage( const Point  _aPreviewPo
 
     std::vector<PreviewPage*>::const_iterator aFoundPreviewPageIter =
             std::find_if( maPreviewPages.begin(), maPreviewPages.end(),
-                          PreviewPosInsidePagePred( _aPreviewPos ) );
+                          PreviewPosInsidePagePred( rPreviewPos ) );
 
-    if ( aFoundPreviewPageIter == maPreviewPages.end() )
-        // given preview position outside a document page.
-        bIsPosInsideDoc = false;
-    else
+    if ( aFoundPreviewPageIter != maPreviewPages.end() )
     {
+        // given preview position is inside a document page.
         _onPageNum = (*aFoundPreviewPageIter)->pPage->GetPhyPageNum();
-        if ( (*aFoundPreviewPageIter)->pPage->IsEmptyPage() )
-        {
-            // given preview position inside an empty page
-            bIsPosInsideDoc = false;
-            _obPosInEmptyPage = true;
-        }
-        else
+        _obPosInEmptyPage = (*aFoundPreviewPageIter)->pPage->IsEmptyPage();
+        if ( !_obPosInEmptyPage )
         {
             // given preview position inside a normal page
-            bIsPosInsideDoc = true;
-            _orDocPos = _aPreviewPos -
+            _orDocPos = rPreviewPos -
                         (*aFoundPreviewPageIter)->aPreviewWinPos +
                         (*aFoundPreviewPageIter)->aLogicPos;
+            return true;
         }
     }
 
-    return bIsPosInsideDoc;
+    return false;
 }
 
 /** determine window page scroll amount */
@@ -1006,26 +984,50 @@ SwTwips SwPagePreviewLayout::GetWinPagesScrollAmount(
 
 // methods to paint page preview layout
 
+namespace
+{
+/// Similar to RenderContextGuard, but does not touch the draw view.
+class PreviewRenderContextGuard
+{
+    VclPtr<vcl::RenderContext> m_pOriginalValue;
+    SwViewShell& m_rShell;
+
+public:
+    PreviewRenderContextGuard(SwViewShell& rShell, vcl::RenderContext* pValue)
+        : m_pOriginalValue(rShell.GetOut()),
+        m_rShell(rShell)
+    {
+        m_rShell.SetOut(pValue);
+    }
+
+    ~PreviewRenderContextGuard()
+    {
+        m_rShell.SetOut(m_pOriginalValue);
+    }
+};
+}
+
 /** paint prepared preview
 
     OD 12.12.2002 #103492#
 */
-bool SwPagePreviewLayout::Paint( const Rectangle  _aOutRect ) const
+bool SwPagePreviewLayout::Paint(vcl::RenderContext& rRenderContext, const Rectangle& rOutRect) const
 {
+    PreviewRenderContextGuard aGuard(mrParentViewShell, &rRenderContext);
     // check environment and parameters
     {
-        if ( !mrParentViewShell.GetWin() &&
-             !mrParentViewShell.GetOut()->GetConnectMetaFile() )
+        if (!mrParentViewShell.GetWin() && !mrParentViewShell.GetOut()->GetConnectMetaFile())
+        {
             return false;
+        }
 
-        OSL_ENSURE( mbPaintInfoValid,
-                "invalid preview settings - no paint of preview" );
-        if ( !mbPaintInfoValid )
+        OSL_ENSURE(mbPaintInfoValid, "invalid preview settings - no paint of preview");
+        if (!mbPaintInfoValid)
             return false;
     }
 
     // OD 17.11.2003 #i22014# - no paint, if <superfluous> flag is set at layout
-    if ( mrLayoutRootFrm.IsSuperfluous() )
+    if (mrLayoutRootFrm.IsSuperfluous())
     {
         return true;
     }
@@ -1033,25 +1035,25 @@ bool SwPagePreviewLayout::Paint( const Rectangle  _aOutRect ) const
     // environment and parameter ok
 
     // OD 07.11.2003 #i22014#
-    if ( mbInPaint )
+    if (mbInPaint)
     {
         return false;
     }
     mbInPaint = true;
 
-    OutputDevice* pOutputDev = mrParentViewShell.GetOut();
+    OutputDevice* pOutputDev = &rRenderContext;
 
     // prepare paint
     if ( maPreviewPages.size() > 0 )
     {
-        mrParentViewShell.Imp()->bFirstPageInvalid = sal_False;
+        mrParentViewShell.Imp()->bFirstPageInvalid = false;
         mrParentViewShell.Imp()->pFirstVisPage =
                 const_cast<SwPageFrm*>(maPreviewPages[0]->pPage);
     }
 
     // paint preview background
     {
-        SwRegionRects aPreviewBackgrdRegion( _aOutRect );
+        SwRegionRects aPreviewBackgrdRegion(rOutRect);
         // calculate preview background rectangles
         for ( std::vector<PreviewPage*>::const_iterator aPageIter = maPreviewPages.begin();
               aPageIter != maPreviewPages.end();
@@ -1064,16 +1066,16 @@ bool SwPagePreviewLayout::Paint( const Rectangle  _aOutRect ) const
             }
         }
         // paint preview background rectangles
-        mrParentViewShell._PaintDesktop( aPreviewBackgrdRegion );
+        mrParentViewShell._PaintDesktop(rRenderContext, aPreviewBackgrdRegion);
     }
 
     // prepare data for paint of pages
-    const Rectangle aPxOutRect( pOutputDev->LogicToPixel( _aOutRect ) );
+    const Rectangle aPxOutRect( pOutputDev->LogicToPixel(rOutRect) );
 
     MapMode aMapMode( pOutputDev->GetMapMode() );
     MapMode aSavedMapMode = aMapMode;
 
-    const Font& rEmptyPgFont = SwPageFrm::GetEmptyPageFont();
+    const vcl::Font& rEmptyPgFont = SwPageFrm::GetEmptyPageFont();
 
     for ( std::vector<PreviewPage*>::const_iterator aPageIter = maPreviewPages.begin();
           aPageIter != maPreviewPages.end();
@@ -1097,18 +1099,18 @@ bool SwPagePreviewLayout::Paint( const Rectangle  _aOutRect ) const
                 // OD 20.02.2003 #107369# - use aligned page rectangle
                 {
                     SwRect aTmpPageRect( aPageRect );
-                    ::SwAlignRect( aTmpPageRect, &mrParentViewShell);
+                    ::SwAlignRect( aTmpPageRect, &mrParentViewShell, &rRenderContext );
                     aPageRect = aTmpPageRect.SVRect();
                 }
                 pOutputDev->DrawRect( aPageRect );
 
                 // paint empty page text
-                Font aOldFont( pOutputDev->GetFont() );
+                vcl::Font aOldFont( pOutputDev->GetFont() );
                 pOutputDev->SetFont( rEmptyPgFont );
                 pOutputDev->DrawText( aPageRect, SW_RESSTR( STR_EMPTYPAGE ),
-                                    TEXT_DRAW_VCENTER |
-                                    TEXT_DRAW_CENTER |
-                                    TEXT_DRAW_CLIP );
+                                    DrawTextFlags::VCenter |
+                                    DrawTextFlags::Center |
+                                    DrawTextFlags::Clip );
                 pOutputDev->SetFont( aOldFont );
                 // paint shadow and border for empty page
                 // OD 19.02.2003 #107369# - use new method to paint page border and shadow
@@ -1119,14 +1121,14 @@ bool SwPagePreviewLayout::Paint( const Rectangle  _aOutRect ) const
                 mrParentViewShell.maVisArea = aPageRect;
                 aPxPaintRect.Intersection( aPxOutRect );
                 Rectangle aPaintRect = pOutputDev->PixelToLogic( aPxPaintRect );
-                mrParentViewShell.Paint( aPaintRect );
+                mrParentViewShell.Paint(rRenderContext, aPaintRect);
                 // --> OD 2007-08-15 #i80691#
                 // paint page border and shadow
                 {
                     SwRect aPageBorderRect;
-                    SwPageFrm::GetBorderAndShadowBoundRect( SwRect( aPageRect ), &mrParentViewShell, aPageBorderRect,
+                    SwPageFrm::GetBorderAndShadowBoundRect( SwRect( aPageRect ), &mrParentViewShell, &rRenderContext, aPageBorderRect,
                         (*aPageIter)->pPage->IsLeftShadowNeeded(), (*aPageIter)->pPage->IsRightShadowNeeded(), true );
-                    const Region aDLRegion(aPageBorderRect.SVRect());
+                    const vcl::Region aDLRegion(aPageBorderRect.SVRect());
                     mrParentViewShell.DLPrePaint2(aDLRegion);
                     SwPageFrm::PaintBorderAndShadow( aPageRect, &mrParentViewShell, true, false, true );
                     mrParentViewShell.DLPostPaint2(true);
@@ -1142,7 +1144,7 @@ bool SwPagePreviewLayout::Paint( const Rectangle  _aOutRect ) const
 
             if ( (*aPageIter)->pPage->GetPhyPageNum() == mnSelectedPageNum )
             {
-                _PaintSelectMarkAtPage( (*aPageIter) );
+                _PaintSelectMarkAtPage(rRenderContext, *aPageIter);
             }
 
         }
@@ -1174,7 +1176,7 @@ bool SwPagePreviewLayout::Paint( const Rectangle  _aOutRect ) const
 
     OD 18.12.2002 #103492#
 */
-void SwPagePreviewLayout::Repaint( const Rectangle _aInvalidCoreRect ) const
+void SwPagePreviewLayout::Repaint( const Rectangle& rInvalidCoreRect ) const
 {
     // check environment and parameters
     {
@@ -1193,7 +1195,7 @@ void SwPagePreviewLayout::Repaint( const Rectangle _aInvalidCoreRect ) const
     // prepare paint
     if ( maPreviewPages.size() > 0 )
     {
-        mrParentViewShell.Imp()->bFirstPageInvalid = sal_False;
+        mrParentViewShell.Imp()->bFirstPageInvalid = false;
         mrParentViewShell.Imp()->pFirstVisPage =
                 const_cast<SwPageFrm*>(maPreviewPages[0]->pPage);
     }
@@ -1207,9 +1209,9 @@ void SwPagePreviewLayout::Repaint( const Rectangle _aInvalidCoreRect ) const
             continue;
 
         Rectangle aPageRect( (*aPageIter)->aLogicPos, (*aPageIter)->aPageSize );
-        if ( _aInvalidCoreRect.IsOver( aPageRect ) )
+        if ( rInvalidCoreRect.IsOver( aPageRect ) )
         {
-            aPageRect.Intersection( _aInvalidCoreRect );
+            aPageRect.Intersection(rInvalidCoreRect);
             Rectangle aInvalidPreviewRect = aPageRect;
             aInvalidPreviewRect.SetPos( aInvalidPreviewRect.TopLeft() -
                                       (*aPageIter)->aLogicPos +
@@ -1223,10 +1225,10 @@ void SwPagePreviewLayout::Repaint( const Rectangle _aInvalidCoreRect ) const
 
     OD 17.12.2002 #103492#
 */
-void SwPagePreviewLayout::_PaintSelectMarkAtPage(
+void SwPagePreviewLayout::_PaintSelectMarkAtPage(vcl::RenderContext& rRenderContext,
                                     const PreviewPage* _aSelectedPreviewPage ) const
 {
-    OutputDevice* pOutputDev = mrParentViewShell.GetOut();
+    OutputDevice* pOutputDev = &rRenderContext;
     MapMode aMapMode( pOutputDev->GetMapMode() );
     // save mapping mode of output device
     MapMode aSavedMapMode = aMapMode;
@@ -1250,7 +1252,7 @@ void SwPagePreviewLayout::_PaintSelectMarkAtPage(
                          _aSelectedPreviewPage->aPageSize );
     // OD 19.02.2003 #107369# - use aligned page rectangle, as it is used for
     // page border and shadow paint - see <SwPageFrm::PaintBorderAndShadow(..)>
-    ::SwAlignRect( aPageRect, &mrParentViewShell);
+    ::SwAlignRect( aPageRect, &mrParentViewShell, pOutputDev );
     Rectangle aPxPageRect = pOutputDev->LogicToPixel( aPageRect.SVRect() );
 
     // draw two rectangle
@@ -1285,18 +1287,18 @@ void SwPagePreviewLayout::_PaintSelectMarkAtPage(
 */
 void SwPagePreviewLayout::MarkNewSelectedPage( const sal_uInt16 _nSelectedPage )
 {
-    sal_uInt16 nOldSelectedPageNum = mnSelectedPageNum;
+    const sal_uInt16 nOldSelectedPageNum = mnSelectedPageNum;
     mnSelectedPageNum = _nSelectedPage;
 
     // re-paint for current selected page in order to umark it.
     const PreviewPage* pOldSelectedPreviewPage = _GetPreviewPageByPageNum( nOldSelectedPageNum );
+    OutputDevice* pOutputDev = mrParentViewShell.GetOut();
     if ( pOldSelectedPreviewPage && pOldSelectedPreviewPage->bVisible )
     {
         // OD 20.02.2003 #107369# - invalidate only areas of selection mark.
         SwRect aPageRect( pOldSelectedPreviewPage->aPreviewWinPos,
                               pOldSelectedPreviewPage->aPageSize );
-        ::SwAlignRect( aPageRect, &mrParentViewShell);
-        OutputDevice* pOutputDev = mrParentViewShell.GetOut();
+        ::SwAlignRect( aPageRect, &mrParentViewShell, pOutputDev );
         Rectangle aPxPageRect = pOutputDev->LogicToPixel( aPageRect.SVRect() );
         // invalidate top mark line
         Rectangle aInvalPxRect( aPxPageRect.Left(), aPxPageRect.Top(),
@@ -1319,7 +1321,12 @@ void SwPagePreviewLayout::MarkNewSelectedPage( const sal_uInt16 _nSelectedPage )
     // re-paint for new selected page in order to mark it.
     const PreviewPage* pNewSelectedPreviewPage = _GetPreviewPageByPageNum( _nSelectedPage );
     if ( pNewSelectedPreviewPage && pNewSelectedPreviewPage->bVisible )
-        _PaintSelectMarkAtPage( pNewSelectedPreviewPage );
+    {
+        const PreviewPage* pSelectedPreviewPage = _GetPreviewPageByPageNum(mnSelectedPageNum);
+        SwRect aPageRect(pSelectedPreviewPage->aPreviewWinPos, pSelectedPreviewPage->aPageSize);
+        ::SwAlignRect(aPageRect, &mrParentViewShell, pOutputDev);
+        mrParentViewShell.GetWin()->Invalidate(aPageRect.SVRect());
+    }
 }
 
 // helper methods
@@ -1346,8 +1353,8 @@ const PreviewPage* SwPagePreviewLayout::_GetPreviewPageByPageNum( const sal_uInt
 
     if ( aFoundPreviewPageIter == maPreviewPages.end() )
         return 0;
-    else
-        return (*aFoundPreviewPageIter);
+
+    return (*aFoundPreviewPageIter);
 }
 
 /** determine row the page with the given number is in
@@ -1367,11 +1374,7 @@ sal_uInt16 SwPagePreviewLayout::GetRowOfPage( sal_uInt16 _nPageNum ) const
         ++_nPageNum;
     }
 
-    sal_uInt16 nRow = (_nPageNum) / mnCols;
-    if ( ( (_nPageNum) % mnCols ) > 0 )
-        ++nRow;
-
-    return nRow;
+    return _nPageNum / mnCols + ((_nPageNum % mnCols)>0 ? 1 : 0);
 }
 
 /** determine column the page with the given number is in
@@ -1391,11 +1394,8 @@ sal_uInt16 SwPagePreviewLayout::GetColOfPage( sal_uInt16 _nPageNum ) const
         ++_nPageNum;
     }
 
-    sal_uInt16 nCol = (_nPageNum) % mnCols;
-    if ( nCol == 0 )
-        nCol = mnCols;
-
-    return nCol;
+    const sal_uInt16 nCol = _nPageNum % mnCols;
+    return nCol ? nCol : mnCols;
 }
 
 Size SwPagePreviewLayout::GetPreviewDocSize() const
@@ -1415,10 +1415,7 @@ Size SwPagePreviewLayout::GetPreviewPageSizeByPageNum( sal_uInt16 _nPageNum ) co
     {
         return pPreviewPage->aPageSize;
     }
-    else
-    {
-        return Size( 0, 0 );
-    }
+    return Size( 0, 0 );
 }
 
 /** get virtual page number by its physical page number
@@ -1432,10 +1429,7 @@ sal_uInt16 SwPagePreviewLayout::GetVirtPageNumByPageNum( sal_uInt16 _nPageNum )
     {
         return pPreviewPage->pPage->GetVirtPageNum();
     }
-    else
-    {
-        return 0;
-    }
+    return 0;
 }
 
 /** Convert absolute to relative page numbers (see PrintEmptyPages) */
