@@ -17,10 +17,8 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include <ctype.h>
 #include <stdlib.h>
-#include <stdio.h>
 #include <limits.h>
 #include <rtl/ustrbuf.hxx>
 #include <vcl/svapp.hxx>
@@ -29,7 +27,6 @@
 #include "css1kywd.hxx"
 #include "parcss1.hxx"
 
-
 // Loop-Check: Um Endlos-Schleifen zu vermeiden, wird in jeder
 // Schalife geprueft, ob ein Fortschritt in der Eingabe-Position
 // stattgefunden hat
@@ -56,17 +53,15 @@
 
 #endif
 
-
 const sal_Int32 MAX_LEN = 1024;
 
-
 void CSS1Parser::InitRead( const OUString& rIn )
 {
     nlLineNr = 0;
     nlLinePos = 0;
 
-    bWhiteSpace = sal_True; // Wenn noch nichts gelesen wurde ist das wie WS
-    bEOF = sal_False;
+    bWhiteSpace = true; // Wenn noch nichts gelesen wurde ist das wie WS
+    bEOF = false;
     eState = CSS1_PAR_WORKING;
     nValue = 0.;
 
@@ -80,7 +75,7 @@ sal_Unicode CSS1Parser::GetNextChar()
 {
     if( nInPos >= aIn.getLength() )
     {
-        bEOF = sal_True;
+        bEOF = true;
         return (sal_Unicode)EOF;
     }
 
@@ -99,24 +94,24 @@ sal_Unicode CSS1Parser::GetNextChar()
 }
 
 // Diese Funktion realisiert den in
-//
+
 //      http://www.w3.orh/pub/WWW/TR/WD-css1.html
 // bzw. http://www.w3.orh/pub/WWW/TR/WD-css1-960220.html
-//
+
 // beschriebenen Scanner fuer CSS1. Es handelt sich um eine direkte
 // Umsetzung der dort beschriebenen Lex-Grammatik
-//
+
 CSS1Token CSS1Parser::GetNextToken()
 {
     CSS1Token nRet = CSS1_NULL;
-    aToken = "";
+    aToken.clear();
 
     do {
         // Merken, ob davor White-Space gelesen wurde
-        sal_Bool bPrevWhiteSpace = bWhiteSpace;
-        bWhiteSpace = sal_False;
+        bool bPrevWhiteSpace = bWhiteSpace;
+        bWhiteSpace = false;
 
-        sal_Bool bNextCh = sal_True;
+        bool bNextCh = true;
         switch( cNextCh )
         {
         case '/': // COMMENT | '/'
@@ -127,17 +122,17 @@ CSS1Token CSS1Parser::GetNextToken()
                     // COMMENT
                     cNextCh = GetNextChar();
 
-                    sal_Bool bAsterix = sal_False;
-                    while( !(bAsterix && '/'==cNextCh) && !IsEOF() )
+                    bool bAsterisk = false;
+                    while( !(bAsterisk && '/'==cNextCh) && !IsEOF() )
                     {
-                        bAsterix = ('*'==cNextCh);
+                        bAsterisk = ('*'==cNextCh);
                         cNextCh = GetNextChar();
                     }
                 }
                 else
                 {
                     // '/'
-                    bNextCh = sal_False;
+                    bNextCh = false;
                     nRet = CSS1_SLASH;
                 }
             }
@@ -149,7 +144,7 @@ CSS1Token CSS1Parser::GetNextToken()
                 if (comphelper::string::isalphaAscii(cNextCh))
                 {
                     // den naechsten Identifer scannen
-                    OUStringBuffer sTmpBuffer( 32L );
+                    OUStringBuffer sTmpBuffer(32);
                     do {
                         sTmpBuffer.append( cNextCh );
                         cNextCh = GetNextChar();
@@ -180,14 +175,14 @@ CSS1Token CSS1Parser::GetNextToken()
                     // Blocks ignorieren
                     if( CSS1_NULL==nRet )
                     {
-                        aToken = "";
-                        sal_uInt16 nBlockLvl = 0;
+                        aToken.clear();
+                        int nBlockLvl = 0;
                         sal_Unicode cQuoteCh = 0;
-                        sal_Bool bDone = sal_False, bEscape = sal_False;
+                        bool bDone = false, bEscape = false;
                         while( !bDone && !IsEOF() )
                         {
-                            sal_Bool bOldEscape = bEscape;
-                            bEscape = sal_False;
+                            bool bOldEscape = bEscape;
+                            bEscape = false;
                             switch( cNextCh )
                             {
                             case '{':
@@ -219,14 +214,14 @@ CSS1Token CSS1Parser::GetNextToken()
                                 break;
                             case '\\':
                                 if( !bOldEscape )
-                                    bEscape = sal_True;
+                                    bEscape = true;
                                 break;
                             }
                             cNextCh = GetNextChar();
                         }
                     }
 
-                    bNextCh = sal_False;
+                    bNextCh = false;
                 }
             }
             break;
@@ -238,14 +233,14 @@ CSS1Token CSS1Parser::GetNextToken()
                 while( ( ' ' == cNextCh ||
                        (cNextCh >= 0x09 && cNextCh <= 0x0d) ) && !IsEOF() )
                 {
-                    bWhiteSpace = sal_True;
+                    bWhiteSpace = true;
                     cNextCh = GetNextChar();
                 }
 
                 if( 'i'==cNextCh || 'I'==cNextCh)
                 {
                     // den naechsten Identifer scannen
-                    OUStringBuffer sTmpBuffer( 32L );
+                    OUStringBuffer sTmpBuffer(32);
                     do {
                         sTmpBuffer.append( cNextCh );
                         cNextCh = GetNextChar();
@@ -266,13 +261,13 @@ CSS1Token CSS1Parser::GetNextToken()
                         nRet = CSS1_IDENT;
                     }
 
-                    bWhiteSpace = sal_False;
-                    bNextCh = sal_False;
+                    bWhiteSpace = false;
+                    bNextCh = false;
                 }
                 else
                 {
                     // Fehlerbehandlung: '!' ignorieren
-                    bNextCh = sal_False;
+                    bNextCh = false;
                 }
             }
             break;
@@ -312,7 +307,7 @@ CSS1Token CSS1Parser::GetNextToken()
                 sal_Unicode cNextChSave = cNextCh;
                 sal_uInt32 nlLineNrSave = nlLineNr;
                 sal_uInt32 nlLinePosSave = nlLinePos;
-                sal_Bool bEOFSave = bEOF;
+                bool bEOFSave = bEOF;
 
                 // erstmal versuchen eine Hex-Zahl zu scannen
                 OUStringBuffer sTmpBuffer( 16 );
@@ -330,7 +325,7 @@ CSS1Token CSS1Parser::GetNextToken()
                     // wir haben eine hexadezimale Farbe gefunden
                     aToken += sTmpBuffer.makeStringAndClear();
                     nRet = CSS1_HEXCOLOR;
-                    bNextCh = sal_False;
+                    bNextCh = false;
 
                     break;
                 }
@@ -357,7 +352,7 @@ CSS1Token CSS1Parser::GetNextToken()
                 while( ( ' ' == cNextCh ||
                        (cNextCh >= 0x09 && cNextCh <= 0x0d) ) && !IsEOF() )
                 {
-                    bWhiteSpace = sal_True;
+                    bWhiteSpace = true;
                     cNextCh = GetNextChar();
                 }
 
@@ -365,7 +360,7 @@ CSS1Token CSS1Parser::GetNextToken()
                 switch( cNextCh )
                 {
                 case '%': // PERCENTAGE
-                    bWhiteSpace = sal_False;
+                    bWhiteSpace = false;
                     nRet = CSS1_PERCENTAGE;
                     break;
 
@@ -385,11 +380,11 @@ CSS1Token CSS1Parser::GetNextToken()
                         sal_Unicode cNextChOld = cNextCh;
                         sal_uLong nlLineNrOld  = nlLineNr;
                         sal_uLong nlLinePosOld = nlLinePos;
-                        sal_Bool bEOFOld = bEOF;
+                        bool bEOFOld = bEOF;
 
                         // den naechsten Identifer scannen
                         OUString aIdent;
-                        OUStringBuffer sTmpBuffer2( 64L );
+                        OUStringBuffer sTmpBuffer2(64);
                         do {
                             sTmpBuffer2.append( cNextCh );
                             cNextCh = GetNextChar();
@@ -479,13 +474,13 @@ CSS1Token CSS1Parser::GetNextToken()
                         }
                         else
                         {
-                            bWhiteSpace = sal_False;
+                            bWhiteSpace = false;
                         }
-                        bNextCh = sal_False;
+                        bNextCh = false;
                     }
                     break;
                 default: // NUMBER IDENT
-                    bNextCh = sal_False;
+                    bNextCh = false;
                     nRet = CSS1_NUMBER;
                     break;
                 }
@@ -536,10 +531,10 @@ CSS1Token CSS1Parser::GetNextToken()
                 sal_Unicode cNextChSave = cNextCh;
                 sal_uLong nlLineNrSave = nlLineNr;
                 sal_uLong nlLinePosSave = nlLinePos;
-                sal_Bool bEOFSave = bEOF;
+                bool bEOFSave = bEOF;
 
                 // erstmal versuchen eine Hex-Zahl zu scannen
-                OUStringBuffer sTmpBuffer( 6L );
+                OUStringBuffer sTmpBuffer(6);
                 do {
                     sTmpBuffer.append( cNextCh );
                     cNextCh = GetNextChar();
@@ -554,7 +549,7 @@ CSS1Token CSS1Parser::GetNextToken()
                     // wir haben eine hexadezimale Farbe gefunden
                     aToken += sTmpBuffer.makeStringAndClear();
                     nRet = CSS1_HEXCOLOR;
-                    bNextCh = sal_False;
+                    bNextCh = false;
 
                     break;
                 }
@@ -568,34 +563,34 @@ CSS1Token CSS1Parser::GetNextToken()
             }
 
             nRet = CSS1_HASH;
-            bNextCh = sal_False;
+            bNextCh = false;
             break;
 
         case ' ':
         case '\t':
         case '\r':
         case '\n': // White-Space
-            bWhiteSpace = sal_True;
+            bWhiteSpace = true;
             break;
 
         case (sal_Unicode)EOF:
             if( IsEOF() )
             {
                 eState = CSS1_PAR_ACCEPTED;
-                bNextCh = sal_False;
+                bNextCh = false;
                 break;
             }
-            // kein break;
+            // no break
 
         default: // IDENT | syntax error
             if (comphelper::string::isalphaAscii(cNextCh))
             {
                 // IDENT
 
-                sal_Bool bHexColor = sal_True;
+                bool bHexColor = true;
 
                 // den naechsten Identifer scannen
-                OUStringBuffer sTmpBuffer( 64L );
+                OUStringBuffer sTmpBuffer(64);
                 do {
                     sTmpBuffer.append( cNextCh );
                     if( bHexColor )
@@ -613,7 +608,7 @@ CSS1Token CSS1Parser::GetNextToken()
 
                 if( bHexColor && sTmpBuffer.getLength()==6 )
                 {
-                    bNextCh = sal_False;
+                    bNextCh = false;
                     nRet = CSS1_HEXCOLOR;
 
                     break;
@@ -624,8 +619,8 @@ CSS1Token CSS1Parser::GetNextToken()
                       (('r'==aToken[0] || 'R'==aToken[0]) &&
                        aToken.equalsIgnoreAsciiCase( "rgb" )) ) )
                 {
-                    sal_uInt16 nNestCnt = 0;
-                    OUStringBuffer sTmpBuffer2( 64L );
+                    int nNestCnt = 0;
+                    OUStringBuffer sTmpBuffer2(64);
                     do {
                         sTmpBuffer2.append( cNextCh );
                         switch( cNextCh )
@@ -637,14 +632,14 @@ CSS1Token CSS1Parser::GetNextToken()
                     } while( (nNestCnt>1 || ')'!=cNextCh) && !IsEOF() );
                     sTmpBuffer2.append( cNextCh );
                     aToken += sTmpBuffer2.makeStringAndClear();
-                    bNextCh = sal_True;
+                    bNextCh = true;
                     nRet = 'u'==aToken[0] || 'U'==aToken[0]
                                 ? CSS1_URL
                                 : CSS1_RGB;
                 }
                 else
                 {
-                    bNextCh = sal_False;
+                    bNextCh = false;
                     nRet = CSS1_IDENT;
                 }
             }
@@ -659,30 +654,29 @@ CSS1Token CSS1Parser::GetNextToken()
     return nRet;
 }
 
-
 // Dies folegenden Funktionen realisieren den in
-//
+
 //      http://www.w3.orh/pub/WWW/TR/WD-css1.html
 // bzw. http://www.w3.orh/pub/WWW/TR/WD-css1-960220.html
-//
+
 // beschriebenen Parser fuer CSS1. Es handelt sich um eine direkte
 // Umsetzung der dort beschriebenen Grammatik
 
 // stylesheet
 //  : import* rule*
-//
+
 // import
 //  : IMPORT_SYM url
-//
+
 // url
 //  : STRING
-//
+
 void CSS1Parser::ParseStyleSheet()
 {
     LOOP_CHECK_DECL
 
     // import*
-    sal_Bool bDone = sal_False;
+    bool bDone = false;
     while( !bDone && IsParserWorking() )
     {
         LOOP_CHECK_CHECK( "Endlos-Schleife in ParseStyleSheet()/import *" )
@@ -701,7 +695,7 @@ void CSS1Parser::ParseStyleSheet()
         case CSS1_PAGE_SYM:
 // /Feature: PrintExt
             // rule
-            bDone = sal_True;
+            bDone = true;
             break;
         default:
             // Fehlerbehandlung: ueberlesen
@@ -741,7 +735,7 @@ void CSS1Parser::ParseStyleSheet()
 // rule
 //  : selector [ ',' selector ]*
 //    '{' declaration [ ';' declaration ]* '}'
-//
+
 void CSS1Parser::ParseRule()
 {
     // selector
@@ -750,7 +744,7 @@ void CSS1Parser::ParseRule()
         return;
 
     // Selektor verarbeiten
-    if( SelectorParsed( pSelector, sal_True ) )
+    if( SelectorParsed( pSelector, true ) )
         delete pSelector;
 
     LOOP_CHECK_DECL
@@ -769,7 +763,7 @@ void CSS1Parser::ParseRule()
             return;
 
         // Selektor verarbeiten
-        if( SelectorParsed( pSelector, sal_False ) )
+        if( SelectorParsed( pSelector, false ) )
             delete pSelector;
     }
 
@@ -818,29 +812,29 @@ void CSS1Parser::ParseRule()
 
 // selector
 //  : simple_selector+ [ ':' pseudo_element ]?
-//
+
 // simple_selector
 //  : element_name [ DOT_WO_WS class ]?
 //  | DOT_W_WS class
 //  | id_selector
-//
+
 // element_name
 //  : IDENT
-//
+
 // class
 //  : IDENT
-//
+
 // id_selector
 //  : '#' IDENT
-//
+
 // pseude_element
 //  : IDENT
-//
+
 CSS1Selector *CSS1Parser::ParseSelector()
 {
     CSS1Selector *pRoot = 0, *pLast = 0;
 
-    sal_Bool bDone = sal_False;
+    bool bDone = false;
     CSS1Selector *pNew = 0;
 
     LOOP_CHECK_DECL
@@ -850,7 +844,7 @@ CSS1Selector *CSS1Parser::ParseSelector()
     {
         LOOP_CHECK_CHECK( "Endlos-Schleife in ParseSelector()" )
 
-        sal_Bool bNextToken = sal_True;
+        bool bNextToken = true;
 
         switch( nToken )
         {
@@ -883,7 +877,7 @@ CSS1Selector *CSS1Parser::ParseSelector()
                 else
                 {
                     // das war jetzt ein Look-Ahead
-                    bNextToken = sal_False;
+                    bNextToken = false;
                 }
                 pNew = new CSS1Selector( eType, aElement );
             }
@@ -934,7 +928,7 @@ CSS1Selector *CSS1Parser::ParseSelector()
 
         default:
             // wir wissen nicht was kommt, also aufhoehren
-            bDone = sal_True;
+            bDone = true;
             break;
         }
 
@@ -985,24 +979,24 @@ CSS1Selector *CSS1Parser::ParseSelector()
 // declaration
 //  : property ':' expr prio?
 //  | /* empty */
-//
+
 // expression
 //  : term [ operator term ]*
-//
+
 // term
 //  : unary_operator?
 //     [ NUMBER | STRING | PERCENTAGE | LENGTH | EMS | EXS | IDENT |
 //       HEXCOLOR | URL | RGB ]
-//
+
 // operator
 //  : '/' | ',' | /* empty */
-//
+
 // unary_operator
 //  : '-' | '+'
-//
+
 // property
 //  : ident
-//
+
 // das Vorzeichen wird nur fuer numerische Werte (ausser PERCENTAGE)
 // beruecksichtigt und wird auf nValue angewendet!
 CSS1Expression *CSS1Parser::ParseDeclaration( OUString& rProperty )
@@ -1019,7 +1013,6 @@ CSS1Expression *CSS1Parser::ParseDeclaration( OUString& rProperty )
 
     nToken = GetNextToken();
 
-
     // ':'
     if( CSS1_COLON != nToken )
     {
@@ -1031,7 +1024,7 @@ CSS1Expression *CSS1Parser::ParseDeclaration( OUString& rProperty )
     // term [operator term]*
     // hier sind wir sehr lax, was die Syntax angeht, sollte aber kein
     // Problem sein
-    sal_Bool bDone = sal_False;
+    bool bDone = false;
     sal_Unicode cSign = 0, cOp = 0;
     CSS1Expression *pNew = 0;
 
@@ -1058,6 +1051,7 @@ CSS1Expression *CSS1Parser::ParseDeclaration( OUString& rProperty )
         case CSS1_EMX:
             if( '-'==cSign )
                 nValue = -nValue;
+            //fall-through
         case CSS1_STRING:
         case CSS1_PERCENTAGE:
         case CSS1_IDENT:
@@ -1081,7 +1075,7 @@ CSS1Expression *CSS1Parser::ParseDeclaration( OUString& rProperty )
             break;
 
         default:
-            bDone = sal_True;
+            bDone = true;
             break;
         }
 
@@ -1119,9 +1113,14 @@ CSS1Expression *CSS1Parser::ParseDeclaration( OUString& rProperty )
     return pRoot;
 }
 
-
 CSS1Parser::CSS1Parser()
-    : nValue(0)
+    : bWhiteSpace(false)
+    , bEOF(false)
+    , cNextCh(0)
+    , nInPos(0)
+    , nlLineNr(0)
+    , nlLinePos(0)
+    , nValue(0)
     , eState(CSS1_PAR_ACCEPTED)
     , nToken(CSS1_NULL)
 {
@@ -1131,8 +1130,7 @@ CSS1Parser::~CSS1Parser()
 {
 }
 
-
-sal_Bool CSS1Parser::ParseStyleSheet( const OUString& rIn )
+bool CSS1Parser::ParseStyleSheet( const OUString& rIn )
 {
     OUString aTmp( rIn );
 
@@ -1155,20 +1153,19 @@ sal_Bool CSS1Parser::ParseStyleSheet( const OUString& rIn )
         aTmp = aTmp.copy( 0, aTmp.getLength() - 3 );
 
     if( aTmp.isEmpty() )
-        return sal_True;
+        return true;
 
     InitRead( aTmp );
 
     ParseStyleSheet();
 
-    return sal_True;
+    return true;
 }
 
-
-sal_Bool CSS1Parser::ParseStyleOption( const OUString& rIn )
+bool CSS1Parser::ParseStyleOption( const OUString& rIn )
 {
     if( rIn.isEmpty() )
-        return sal_True;
+        return true;
 
     InitRead( rIn );
 
@@ -1182,7 +1179,7 @@ sal_Bool CSS1Parser::ParseStyleOption( const OUString& rIn )
     CSS1Expression *pExpr = ParseDeclaration( aProperty );
     if( !pExpr )
     {
-        return sal_False;
+        return false;
     }
 
     // expression verarbeiten
@@ -1209,7 +1206,7 @@ sal_Bool CSS1Parser::ParseStyleOption( const OUString& rIn )
         }
     }
 
-    return sal_True;
+    return true;
 }
 
 bool CSS1Parser::SelectorParsed( CSS1Selector* /* pSelector */, bool /*bFirst*/ )
@@ -1218,14 +1215,13 @@ bool CSS1Parser::SelectorParsed( CSS1Selector* /* pSelector */, bool /*bFirst*/
     return true;
 }
 
-sal_Bool CSS1Parser::DeclarationParsed( const OUString& /*rProperty*/,
+bool CSS1Parser::DeclarationParsed( const OUString& /*rProperty*/,
                                     const CSS1Expression * /* pExpr */ )
 {
     // Deklaration loeschen
-    return sal_True;
+    return true;
 }
 
-
 CSS1Selector::~CSS1Selector()
 {
     delete pNext;
@@ -1236,7 +1232,7 @@ CSS1Expression::~CSS1Expression()
     delete pNext;
 }
 
-sal_Bool CSS1Expression::GetURL( OUString& rURL  ) const
+bool CSS1Expression::GetURL( OUString& rURL  ) const
 {
     OSL_ENSURE( CSS1_URL==eType, "CSS1-Ausruck ist keine Farbe URL" );
 
@@ -1246,25 +1242,25 @@ sal_Bool CSS1Expression::GetURL( OUString& rURL  ) const
                 ')' == aValue[aValue.getLength()-1],
                 "keine gueltiges URL(...)" );
 
-    sal_Bool bRet = sal_False;
+    bool bRet = false;
 
     if( aValue.getLength() > 5 )
     {
         rURL = aValue.copy( 4, aValue.getLength() - 5 );
         rURL = comphelper::string::strip(rURL, ' ');
-        bRet = sal_True;
+        bRet = true;
     }
 
     return bRet;
 }
 
-sal_Bool CSS1Expression::GetColor( Color &rColor ) const
+bool CSS1Expression::GetColor( Color &rColor ) const
 {
     OSL_ENSURE( CSS1_IDENT==eType || CSS1_RGB==eType ||
                 CSS1_HEXCOLOR==eType || CSS1_STRING==eType,
                 "CSS1-Ausruck kann keine Farbe sein" );
 
-    sal_Bool bRet = sal_False;
+    bool bRet = false;
     sal_uInt32 nColor = SAL_MAX_UINT32;
 
     switch( eType )
@@ -1273,40 +1269,23 @@ sal_Bool CSS1Expression::GetColor( Color &rColor ) const
         {
             sal_uInt8 aColors[3] = { 0, 0, 0 };
 
-            OSL_ENSURE( aValue.startsWithIgnoreAsciiCase( "rgb" ) &&
-                        aValue.getLength() > 5 &&
-                        '(' == aValue[3] &&
-                        ')' == aValue[aValue.getLength()-1],
-                        "keine gueltiges RGB(...)" );
-
-            OUString aColorStr(aValue.copy(4, aValue.getLength() - 5));
-
-            sal_Int32 nPos = 0;
-            sal_uInt16 nCol = 0;
-
-            while( nCol < 3 && nPos < aColorStr.getLength() )
+            if (!aValue.startsWithIgnoreAsciiCase( "rgb" ) || aValue.getLength() < 6 ||
+                    aValue[3] != '(' || aValue[aValue.getLength()-1] != ')')
             {
-                sal_Unicode c;
-                while( nPos < aColorStr.getLength() &&
-                        ((c=aColorStr[nPos]) == ' ' || c == '\t' ||
-                        c == '\n' || c== '\r' ) )
-                    nPos++;
+                break;
+            }
 
-                sal_Int32 nEnd = aColorStr.indexOf( ',', nPos );
-                OUString aNumber;
-                if( nEnd == -1 )
-                {
-                    aNumber = aColorStr.copy(nPos);
-                    nPos = aColorStr.getLength();
-                }
-                else
-                {
-                    aNumber = aColorStr.copy( nPos, nEnd-nPos );
-                    nPos = nEnd+1;
-                }
+            sal_Int32 nPos = 4; // start after "rgb("
+            for ( int nCol = 0; nCol < 3 && nPos > 0; ++nCol )
+            {
+                const OUString aNumber = aValue.getToken(0, ',', nPos);
 
-                sal_uInt16 nNumber = (sal_uInt16)aNumber.toInt32();
-                if( aNumber.indexOf('%') >= 0 )
+                sal_Int32 nNumber = aNumber.toInt32();
+                if( nNumber<0 )
+                {
+                    nNumber = 0;
+                }
+                else if( aNumber.indexOf('%') >= 0 )
                 {
                     if( nNumber > 100 )
                         nNumber = 100;
@@ -1316,15 +1295,14 @@ sal_Bool CSS1Expression::GetColor( Color &rColor ) const
                 else if( nNumber > 255 )
                     nNumber = 255;
 
-                aColors[nCol] = (sal_uInt8)nNumber;
-                nCol ++;
+                aColors[nCol] = static_cast<sal_uInt8>(nNumber);
             }
 
             rColor.SetRed( aColors[0] );
             rColor.SetGreen( aColors[1] );
             rColor.SetBlue( aColors[2] );
 
-            bRet = sal_True;    // etwas anderes als eine Farbe kann es nicht sein
+            bRet = true;    // etwas anderes als eine Farbe kann es nicht sein
         }
         break;
 
@@ -1343,7 +1321,7 @@ sal_Bool CSS1Expression::GetColor( Color &rColor ) const
         {
             // HACK fuer MS-IE: DIe Farbe kann auch in einem String stehen
             sal_Int32 nOffset = CSS1_STRING==eType ? 1 : 0;
-            sal_Bool bDouble = aValue.getLength()-nOffset == 3;
+            bool bDouble = aValue.getLength()-nOffset == 3;
             sal_Int32 i = nOffset, nEnd = (bDouble ? 3 : 6) + nOffset;
 
             nColor = 0;
@@ -1370,14 +1348,13 @@ sal_Bool CSS1Expression::GetColor( Color &rColor ) const
                         nColor += c;
                 }
             }
-            bRet = sal_True;
+            bRet = true;
         }
         break;
     default:
         ;
     }
 
-
     if( bRet && nColor!=SAL_MAX_UINT32 )
     {
         rColor.SetRed( (sal_uInt8)((nColor & 0x00ff0000UL) >> 16) );
