@@ -25,6 +25,7 @@
 #include <unotools/collatorwrapper.hxx>
 #include <svl/urihelper.hxx>
 #include <svl/stritem.hxx>
+#include <svl/grabbagitem.hxx>
 #include <unotools/syslocale.hxx>
 #include <sfx2/app.hxx>
 #include <IDocumentStylePoolAccess.hxx>
@@ -103,7 +104,7 @@ void PrepareBoxInfo(SfxItemSet& rSet, const SwWrtShell& rSh)
     const SfxPoolItem *pBoxInfo;
     if ( SfxItemState::SET == rSet.GetItemState( SID_ATTR_BORDER_INNER,
                                         true, &pBoxInfo))
-        aBoxInfo = *(SvxBoxInfoItem*)pBoxInfo;
+        aBoxInfo = *static_cast<const SvxBoxInfoItem*>(pBoxInfo);
 
         // Table variant: If more than one table cells are selected
     rSh.GetCrsr();                  //So that GetCrsrCnt() returns the right thing
@@ -115,24 +116,26 @@ void PrepareBoxInfo(SfxItemSet& rSet, const SwWrtShell& rSh)
         // Set always the default distance
     aBoxInfo.SetDefDist        (MIN_BORDER_DIST);
         // Single lines can have only in tables DontCare-Status
-    aBoxInfo.SetValid(VALID_DISABLE, !rSh.IsTableMode());
+    aBoxInfo.SetValid(SvxBoxInfoItemValidFlags::DISABLE, !rSh.IsTableMode());
 
     rSet.Put(aBoxInfo);
 }
 
 void ConvertAttrCharToGen(SfxItemSet& rSet, const sal_uInt8 nMode)
 {
-    // Background
+    // Background / highlight
     {
+        // Always use the visible background
         const SfxPoolItem *pTmpBrush;
-        if( SfxItemState::SET == rSet.GetItemState( RES_CHRATR_BACKGROUND, true, &pTmpBrush ) )
+        if( SfxItemState::SET == rSet.GetItemState( RES_CHRATR_HIGHLIGHT, true, &pTmpBrush ) )
         {
-            SvxBrushItem aTmpBrush( *((SvxBrushItem*)pTmpBrush) );
-            aTmpBrush.SetWhich( RES_BACKGROUND );
-            rSet.Put( aTmpBrush );
+            SvxBrushItem aTmpBrush( *static_cast<const SvxBrushItem*>(pTmpBrush) );
+            if( aTmpBrush.GetColor() != COL_TRANSPARENT )
+            {
+                aTmpBrush.SetWhich( RES_CHRATR_BACKGROUND );
+                rSet.Put( aTmpBrush );
+            }
         }
-        else
-            rSet.ClearItem(RES_BACKGROUND);
     }
 
     if( nMode == CONV_ATTR_STD )
@@ -141,7 +144,7 @@ void ConvertAttrCharToGen(SfxItemSet& rSet, const sal_uInt8 nMode)
         const SfxPoolItem *pTmpItem;
         if( SfxItemState::SET == rSet.GetItemState( RES_CHRATR_BOX, true, &pTmpItem ) )
         {
-            SvxBoxItem aTmpBox( *((SvxBoxItem*)pTmpItem) );
+            SvxBoxItem aTmpBox( *static_cast<const SvxBoxItem*>(pTmpItem) );
             aTmpBox.SetWhich( RES_BOX );
             rSet.Put( aTmpBox );
         }
@@ -151,7 +154,7 @@ void ConvertAttrCharToGen(SfxItemSet& rSet, const sal_uInt8 nMode)
         // Border shadow
         if( SfxItemState::SET == rSet.GetItemState( RES_CHRATR_SHADOW, false, &pTmpItem ) )
         {
-            SvxShadowItem aTmpShadow( *((SvxShadowItem*)pTmpItem) );
+            SvxShadowItem aTmpShadow( *static_cast<const SvxShadowItem*>(pTmpItem) );
             aTmpShadow.SetWhich( RES_SHADOW );
             rSet.Put( aTmpShadow );
         }
@@ -160,16 +163,29 @@ void ConvertAttrCharToGen(SfxItemSet& rSet, const sal_uInt8 nMode)
     }
 }
 
-void ConvertAttrGenToChar(SfxItemSet& rSet, const sal_uInt8 nMode)
+void ConvertAttrGenToChar(SfxItemSet& rSet, const SfxItemSet& rOrigSet, const sal_uInt8 nMode)
 {
-    // Background
+    // Background / highlighting
     {
-        const SfxPoolItem *pTmpBrush;
-        if( SfxItemState::SET == rSet.GetItemState( RES_BACKGROUND, false, &pTmpBrush ) )
+        const SfxPoolItem *pTmpItem;
+        if( SfxItemState::SET == rSet.GetItemState( RES_CHRATR_BACKGROUND, false, &pTmpItem ) )
         {
-            SvxBrushItem aTmpBrush( *((SvxBrushItem*)pTmpBrush) );
-            aTmpBrush.SetWhich( RES_CHRATR_BACKGROUND );
-            rSet.Put( aTmpBrush );
+            // Highlight is an MS specific thing, so remove it at the first time when LO modifies
+            // this part of the imported document.
+            rSet.Put( SvxBrushItem(RES_CHRATR_HIGHLIGHT) );
+
+            // Remove shading marker
+            if( SfxItemState::SET == rOrigSet.GetItemState( RES_CHRATR_GRABBAG, false, &pTmpItem ) )
+            {
+                SfxGrabBagItem aGrabBag(*static_cast<const SfxGrabBagItem*>(pTmpItem));
+                std::map<OUString, com::sun::star::uno::Any>& rMap = aGrabBag.GetGrabBag();
+                auto aIterator = rMap.find("CharShadingMarker");
+                if( aIterator != rMap.end() )
+                {
+                    aIterator->second = uno::makeAny(false);
+                }
+                rSet.Put( aGrabBag );
+            }
         }
         rSet.ClearItem( RES_BACKGROUND );
     }
@@ -180,7 +196,7 @@ void ConvertAttrGenToChar(SfxItemSet& rSet, const sal_uInt8 nMode)
         const SfxPoolItem *pTmpItem;
         if( SfxItemState::SET == rSet.GetItemState( RES_BOX, false, &pTmpItem ) )
         {
-            SvxBoxItem aTmpBox( *((SvxBoxItem*)pTmpItem) );
+            SvxBoxItem aTmpBox( *static_cast<const SvxBoxItem*>(pTmpItem) );
             aTmpBox.SetWhich( RES_CHRATR_BOX );
             rSet.Put( aTmpBox );
         }
@@ -189,7 +205,7 @@ void ConvertAttrGenToChar(SfxItemSet& rSet, const sal_uInt8 nMode)
         // Border shadow
         if( SfxItemState::SET == rSet.GetItemState( RES_SHADOW, false, &pTmpItem ) )
         {
-            SvxShadowItem aTmpShadow( *((SvxShadowItem*)pTmpItem) );
+            SvxShadowItem aTmpShadow( *static_cast<const SvxShadowItem*>(pTmpItem) );
             aTmpShadow.SetWhich( RES_CHRATR_SHADOW );
             rSet.Put( aTmpShadow );
         }
@@ -199,20 +215,20 @@ void ConvertAttrGenToChar(SfxItemSet& rSet, const sal_uInt8 nMode)
 
 // Fill header footer
 
-void FillHdFt(SwFrmFmt* pFmt, const  SfxItemSet& rSet)
+void FillHdFt(SwFrameFormat* pFormat, const  SfxItemSet& rSet)
 {
-    SwAttrSet aSet(pFmt->GetAttrSet());
+    SwAttrSet aSet(pFormat->GetAttrSet());
     aSet.Put(rSet);
 
-    const SvxSizeItem& rSize = (const SvxSizeItem&)rSet.Get(SID_ATTR_PAGE_SIZE);
-    const SfxBoolItem& rDynamic = (const SfxBoolItem&)rSet.Get(SID_ATTR_PAGE_DYNAMIC);
+    const SvxSizeItem& rSize = static_cast<const SvxSizeItem&>(rSet.Get(SID_ATTR_PAGE_SIZE));
+    const SfxBoolItem& rDynamic = static_cast<const SfxBoolItem&>(rSet.Get(SID_ATTR_PAGE_DYNAMIC));
 
     // Convert size
-    SwFmtFrmSize aFrmSize(rDynamic.GetValue() ? ATT_MIN_SIZE : ATT_FIX_SIZE,
+    SwFormatFrmSize aFrmSize(rDynamic.GetValue() ? ATT_MIN_SIZE : ATT_FIX_SIZE,
                             rSize.GetSize().Width(),
                             rSize.GetSize().Height());
     aSet.Put(aFrmSize);
-    pFmt->SetFmtAttr(aSet);
+    pFormat->SetFormatAttr(aSet);
 }
 
 /// Convert from UseOnPage to SvxPageUsage.
@@ -249,16 +265,16 @@ UseOnPage lcl_convertUseFromSvx(UseOnPage nUse)
 
 void ItemSetToPageDesc( const SfxItemSet& rSet, SwPageDesc& rPageDesc )
 {
-    SwFrmFmt& rMaster = rPageDesc.GetMaster();
+    SwFrameFormat& rMaster = rPageDesc.GetMaster();
     int nFirstShare = -1;
 
     // Transfer all general frame attributes
-    rMaster.SetFmtAttr(rSet);
+    rMaster.SetFormatAttr(rSet);
 
     // PageData
     if(rSet.GetItemState(SID_ATTR_PAGE) == SfxItemState::SET)
     {
-        const SvxPageItem& rPageItem = (const SvxPageItem&)rSet.Get(SID_ATTR_PAGE);
+        const SvxPageItem& rPageItem = static_cast<const SvxPageItem&>(rSet.Get(SID_ATTR_PAGE));
 
         const sal_uInt16 nUse = rPageItem.GetPageUsage();
         if(nUse)
@@ -271,37 +287,37 @@ void ItemSetToPageDesc( const SfxItemSet& rSet, SwPageDesc& rPageDesc )
     // Size
     if(rSet.GetItemState(SID_ATTR_PAGE_SIZE) == SfxItemState::SET)
     {
-        const SvxSizeItem& rSizeItem = (const SvxSizeItem&)rSet.Get(SID_ATTR_PAGE_SIZE);
-        SwFmtFrmSize aSize(ATT_FIX_SIZE);
+        const SvxSizeItem& rSizeItem = static_cast<const SvxSizeItem&>(rSet.Get(SID_ATTR_PAGE_SIZE));
+        SwFormatFrmSize aSize(ATT_FIX_SIZE);
         aSize.SetSize(rSizeItem.GetSize());
-        rMaster.SetFmtAttr(aSize);
+        rMaster.SetFormatAttr(aSize);
     }
     // Evaluate header attributes
     const SfxPoolItem* pItem;
     if( SfxItemState::SET == rSet.GetItemState( SID_ATTR_PAGE_HEADERSET,
             false, &pItem ) )
     {
-        const SfxItemSet& rHeaderSet = ((SvxSetItem*)pItem)->GetItemSet();
-        const SfxBoolItem& rHeaderOn = (const SfxBoolItem&)rHeaderSet.Get(SID_ATTR_PAGE_ON);
+        const SfxItemSet& rHeaderSet = static_cast<const SvxSetItem*>(pItem)->GetItemSet();
+        const SfxBoolItem& rHeaderOn = static_cast<const SfxBoolItem&>(rHeaderSet.Get(SID_ATTR_PAGE_ON));
 
         if(rHeaderOn.GetValue())
         {
             // Take over values
             if(!rMaster.GetHeader().IsActive())
-                rMaster.SetFmtAttr(SwFmtHeader(true));
+                rMaster.SetFormatAttr(SwFormatHeader(true));
 
             // Pick out everything and adapt the header format
-            SwFmtHeader aHeaderFmt(rMaster.GetHeader());
-            SwFrmFmt *pHeaderFmt = aHeaderFmt.GetHeaderFmt();
-            OSL_ENSURE(pHeaderFmt != 0, "no header format");
+            SwFormatHeader aHeaderFormat(rMaster.GetHeader());
+            SwFrameFormat *pHeaderFormat = aHeaderFormat.GetHeaderFormat();
+            OSL_ENSURE(pHeaderFormat != 0, "no header format");
 
-            ::FillHdFt(pHeaderFmt, rHeaderSet);
+            ::FillHdFt(pHeaderFormat, rHeaderSet);
 
-            rPageDesc.ChgHeaderShare(((const SfxBoolItem&)
+            rPageDesc.ChgHeaderShare(static_cast<const SfxBoolItem&>(
                         rHeaderSet.Get(SID_ATTR_PAGE_SHARED)).GetValue());
             if (nFirstShare < 0)
             {
-                rPageDesc.ChgFirstShare(((const SfxBoolItem&)
+                rPageDesc.ChgFirstShare(static_cast<const SfxBoolItem&>(
                             rHeaderSet.Get(SID_ATTR_PAGE_SHARED_FIRST)).GetValue());
                 nFirstShare = rPageDesc.IsFirstShared() ? 1 : 0;
             }
@@ -311,7 +327,7 @@ void ItemSetToPageDesc( const SfxItemSet& rSet, SwPageDesc& rPageDesc )
             // Disable header
             if(rMaster.GetHeader().IsActive())
             {
-                rMaster.SetFmtAttr(SwFmtHeader(false));
+                rMaster.SetFormatAttr(SwFormatHeader(false));
                 rPageDesc.ChgHeaderShare(false);
             }
         }
@@ -321,27 +337,27 @@ void ItemSetToPageDesc( const SfxItemSet& rSet, SwPageDesc& rPageDesc )
     if( SfxItemState::SET == rSet.GetItemState( SID_ATTR_PAGE_FOOTERSET,
             false, &pItem ) )
     {
-        const SfxItemSet& rFooterSet = ((SvxSetItem*)pItem)->GetItemSet();
-        const SfxBoolItem& rFooterOn = (const SfxBoolItem&)rFooterSet.Get(SID_ATTR_PAGE_ON);
+        const SfxItemSet& rFooterSet = static_cast<const SvxSetItem*>(pItem)->GetItemSet();
+        const SfxBoolItem& rFooterOn = static_cast<const SfxBoolItem&>(rFooterSet.Get(SID_ATTR_PAGE_ON));
 
         if(rFooterOn.GetValue())
         {
             // Take over values
             if(!rMaster.GetFooter().IsActive())
-                rMaster.SetFmtAttr(SwFmtFooter(true));
+                rMaster.SetFormatAttr(SwFormatFooter(true));
 
             // Pick out everything and adapt the footer format
-            SwFmtFooter aFooterFmt(rMaster.GetFooter());
-            SwFrmFmt *pFooterFmt = aFooterFmt.GetFooterFmt();
-            OSL_ENSURE(pFooterFmt != 0, "no footer format");
+            SwFormatFooter aFooterFormat(rMaster.GetFooter());
+            SwFrameFormat *pFooterFormat = aFooterFormat.GetFooterFormat();
+            OSL_ENSURE(pFooterFormat != 0, "no footer format");
 
-            ::FillHdFt(pFooterFmt, rFooterSet);
+            ::FillHdFt(pFooterFormat, rFooterSet);
 
-            rPageDesc.ChgFooterShare(((const SfxBoolItem&)
+            rPageDesc.ChgFooterShare(static_cast<const SfxBoolItem&>(
                         rFooterSet.Get(SID_ATTR_PAGE_SHARED)).GetValue());
             if (nFirstShare < 0)
             {
-                rPageDesc.ChgFirstShare(((const SfxBoolItem&)
+                rPageDesc.ChgFirstShare(static_cast<const SfxBoolItem&>(
                             rFooterSet.Get(SID_ATTR_PAGE_SHARED_FIRST)).GetValue());
                 nFirstShare = rPageDesc.IsFirstShared() ? 1 : 0;
             }
@@ -351,7 +367,7 @@ void ItemSetToPageDesc( const SfxItemSet& rSet, SwPageDesc& rPageDesc )
             // Disable footer
             if(rMaster.GetFooter().IsActive())
             {
-                rMaster.SetFmtAttr(SwFmtFooter(false));
+                rMaster.SetFormatAttr(SwFormatFooter(false));
                 rPageDesc.ChgFooterShare(false);
             }
         }
@@ -361,7 +377,7 @@ void ItemSetToPageDesc( const SfxItemSet& rSet, SwPageDesc& rPageDesc )
 
     if( SfxItemState::SET == rSet.GetItemState( FN_PARAM_FTN_INFO,
             false, &pItem ) )
-        rPageDesc.SetFtnInfo( ((SwPageFtnInfoItem*)pItem)->GetPageFtnInfo() );
+        rPageDesc.SetFootnoteInfo( static_cast<const SwPageFootnoteInfoItem*>(pItem)->GetPageFootnoteInfo() );
 
     // Columns
 
@@ -370,35 +386,35 @@ void ItemSetToPageDesc( const SfxItemSet& rSet, SwPageDesc& rPageDesc )
     if(SfxItemState::SET == rSet.GetItemState(
                             SID_SWREGISTER_MODE, false, &pItem))
     {
-        bool bSet = ((const SfxBoolItem*)pItem)->GetValue();
+        bool bSet = static_cast<const SfxBoolItem*>(pItem)->GetValue();
         if(!bSet)
-            rPageDesc.SetRegisterFmtColl(0);
+            rPageDesc.SetRegisterFormatColl(0);
         else if(SfxItemState::SET == rSet.GetItemState(
                                 SID_SWREGISTER_COLLECTION, false, &pItem))
         {
-            const OUString& rColl = ((const SfxStringItem*)pItem)->GetValue();
+            const OUString& rColl = static_cast<const SfxStringItem*>(pItem)->GetValue();
             SwDoc& rDoc = *rMaster.GetDoc();
-            SwTxtFmtColl* pColl = rDoc.FindTxtFmtCollByName( rColl );
+            SwTextFormatColl* pColl = rDoc.FindTextFormatCollByName( rColl );
             if( !pColl )
             {
                 const sal_uInt16 nId = SwStyleNameMapper::GetPoolIdFromUIName(
                     rColl, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
                 if( USHRT_MAX != nId )
-                    pColl = rDoc.getIDocumentStylePoolAccess().GetTxtCollFromPool( nId );
+                    pColl = rDoc.getIDocumentStylePoolAccess().GetTextCollFromPool( nId );
                 else
-                    pColl = rDoc.MakeTxtFmtColl( rColl,
-                                (SwTxtFmtColl*)rDoc.GetDfltTxtFmtColl() );
+                    pColl = rDoc.MakeTextFormatColl( rColl,
+                                rDoc.GetDfltTextFormatColl() );
             }
             if( pColl )
-                pColl->SetFmtAttr( SwRegisterItem ( true ));
-            rPageDesc.SetRegisterFmtColl( pColl );
+                pColl->SetFormatAttr( SwRegisterItem ( true ));
+            rPageDesc.SetRegisterFormatColl( pColl );
         }
     }
 }
 
 void PageDescToItemSet( const SwPageDesc& rPageDesc, SfxItemSet& rSet)
 {
-    const SwFrmFmt& rMaster = rPageDesc.GetMaster();
+    const SwFrameFormat& rMaster = rPageDesc.GetMaster();
 
     // Page data
     SvxPageItem aPageItem(SID_ATTR_PAGE);
@@ -423,7 +439,7 @@ void PageDescToItemSet( const SwPageDesc& rPageDesc, SfxItemSet& rSet)
     const SfxPoolItem *pBoxInfo;
     if ( SfxItemState::SET == rSet.GetItemState( SID_ATTR_BORDER_INNER,
                                             true, &pBoxInfo) )
-        aBoxInfo = *(SvxBoxInfoItem*)pBoxInfo;
+        aBoxInfo = *static_cast<const SvxBoxInfoItem*>(pBoxInfo);
 
     aBoxInfo.SetTable( false );
         // Show always the distance field
@@ -433,7 +449,7 @@ void PageDescToItemSet( const SwPageDesc& rPageDesc, SfxItemSet& rSet)
         // Set always the default distance
     aBoxInfo.SetDefDist( MIN_BORDER_DIST );
         // Single lines can have only in tables DontCare-Status
-    aBoxInfo.SetValid( VALID_DISABLE );
+    aBoxInfo.SetValid( SvxBoxInfoItemValidFlags::DISABLE );
     rSet.Put( aBoxInfo );
 
     SfxStringItem aFollow(SID_ATTR_PAGE_EXT1, OUString());
@@ -444,9 +460,9 @@ void PageDescToItemSet( const SwPageDesc& rPageDesc, SfxItemSet& rSet)
     // Header
     if(rMaster.GetHeader().IsActive())
     {
-        const SwFmtHeader &rHeaderFmt = rMaster.GetHeader();
-        const SwFrmFmt *pHeaderFmt = rHeaderFmt.GetHeaderFmt();
-        OSL_ENSURE(pHeaderFmt != 0, "no header format");
+        const SwFormatHeader &rHeaderFormat = rMaster.GetHeader();
+        const SwFrameFormat *pHeaderFormat = rHeaderFormat.GetHeaderFormat();
+        OSL_ENSURE(pHeaderFormat != 0, "no header format");
 
         // HeaderInfo, margins, background, border
         SfxItemSet aHeaderSet(*rSet.GetPool(),
@@ -462,13 +478,13 @@ void PageDescToItemSet( const SwPageDesc& rPageDesc, SfxItemSet& rSet)
             0, 0);
 
         //UUUU set correct parent to get the XFILL_NONE FillStyle as needed
-        aHeaderSet.SetParent(&rMaster.GetDoc()->GetDfltFrmFmt()->GetAttrSet());
+        aHeaderSet.SetParent(&rMaster.GetDoc()->GetDfltFrameFormat()->GetAttrSet());
 
         // Dynamic or fixed height
         SfxBoolItem aOn(SID_ATTR_PAGE_ON, true);
         aHeaderSet.Put(aOn);
 
-        const SwFmtFrmSize &rFrmSize = pHeaderFmt->GetFrmSize();
+        const SwFormatFrmSize &rFrmSize = pHeaderFormat->GetFrmSize();
         const SwFrmSize eSizeType = rFrmSize.GetHeightSizeType();
         SfxBoolItem aDynamic(SID_ATTR_PAGE_DYNAMIC, eSizeType != ATT_FIX_SIZE);
         aHeaderSet.Put(aDynamic);
@@ -484,7 +500,7 @@ void PageDescToItemSet( const SwPageDesc& rPageDesc, SfxItemSet& rSet)
         aHeaderSet.Put(aSize);
 
         // Shifting frame attributes
-        aHeaderSet.Put(pHeaderFmt->GetAttrSet());
+        aHeaderSet.Put(pHeaderFormat->GetAttrSet());
         aHeaderSet.Put( aBoxInfo );
 
         // Create SetItem
@@ -495,9 +511,9 @@ void PageDescToItemSet( const SwPageDesc& rPageDesc, SfxItemSet& rSet)
     // Footer
     if(rMaster.GetFooter().IsActive())
     {
-        const SwFmtFooter &rFooterFmt = rMaster.GetFooter();
-        const SwFrmFmt *pFooterFmt = rFooterFmt.GetFooterFmt();
-        OSL_ENSURE(pFooterFmt != 0, "no footer format");
+        const SwFormatFooter &rFooterFormat = rMaster.GetFooter();
+        const SwFrameFormat *pFooterFormat = rFooterFormat.GetFooterFormat();
+        OSL_ENSURE(pFooterFormat != 0, "no footer format");
 
         // FooterInfo, margins, background, border
         SfxItemSet aFooterSet(*rSet.GetPool(),
@@ -513,13 +529,13 @@ void PageDescToItemSet( const SwPageDesc& rPageDesc, SfxItemSet& rSet)
             0, 0);
 
         //UUUU set correct parent to get the XFILL_NONE FillStyle as needed
-        aFooterSet.SetParent(&rMaster.GetDoc()->GetDfltFrmFmt()->GetAttrSet());
+        aFooterSet.SetParent(&rMaster.GetDoc()->GetDfltFrameFormat()->GetAttrSet());
 
         // Dynamic or fixed height
         SfxBoolItem aOn(SID_ATTR_PAGE_ON, true);
         aFooterSet.Put(aOn);
 
-        const SwFmtFrmSize &rFrmSize = pFooterFmt->GetFrmSize();
+        const SwFormatFrmSize &rFrmSize = pFooterFormat->GetFrmSize();
         const SwFrmSize eSizeType = rFrmSize.GetHeightSizeType();
         SfxBoolItem aDynamic(SID_ATTR_PAGE_DYNAMIC, eSizeType != ATT_FIX_SIZE);
         aFooterSet.Put(aDynamic);
@@ -535,7 +551,7 @@ void PageDescToItemSet( const SwPageDesc& rPageDesc, SfxItemSet& rSet)
         aFooterSet.Put(aSize);
 
         // Shifting Frame attributes
-        aFooterSet.Put(pFooterFmt->GetAttrSet());
+        aFooterSet.Put(pFooterFormat->GetAttrSet());
         aFooterSet.Put( aBoxInfo );
 
         // Create SetItem
@@ -544,12 +560,12 @@ void PageDescToItemSet( const SwPageDesc& rPageDesc, SfxItemSet& rSet)
     }
 
     // Integrate footnotes
-    SwPageFtnInfo& rInfo = (SwPageFtnInfo&)rPageDesc.GetFtnInfo();
-    SwPageFtnInfoItem aFtnItem(FN_PARAM_FTN_INFO, rInfo);
-    rSet.Put(aFtnItem);
+    SwPageFootnoteInfo& rInfo = (SwPageFootnoteInfo&)rPageDesc.GetFootnoteInfo();
+    SwPageFootnoteInfoItem aFootnoteItem(FN_PARAM_FTN_INFO, rInfo);
+    rSet.Put(aFootnoteItem);
 
     // Register compliant
-    const SwTxtFmtColl* pCol = rPageDesc.GetRegisterFmtColl();
+    const SwTextFormatColl* pCol = rPageDesc.GetRegisterFormatColl();
     SwRegisterItem aReg(pCol != 0);
     aReg.SetWhich(SID_SWREGISTER_MODE);
     rSet.Put(aReg);
@@ -581,18 +597,18 @@ SwTwips GetTabDist(const SvxTabStopItem& rTabs)
 void SfxToSwPageDescAttr( const SwWrtShell& rShell, SfxItemSet& rSet )
 {
     const SfxPoolItem* pItem;
-    SwFmtPageDesc aPgDesc;
+    SwFormatPageDesc aPgDesc;
 
     bool bChanged = false;
     // Page number
     if(SfxItemState::SET == rSet.GetItemState(SID_ATTR_PARA_PAGENUM, false, &pItem))
     {
-        aPgDesc.SetNumOffset(((SfxUInt16Item*)pItem)->GetValue());
+        aPgDesc.SetNumOffset(static_cast<const SfxUInt16Item*>(pItem)->GetValue());
         bChanged = true;
     }
     if( SfxItemState::SET == rSet.GetItemState( SID_ATTR_PARA_MODEL, false, &pItem ))
     {
-        const OUString& rDescName = ((SvxPageModelItem*)pItem)->GetValue();
+        const OUString& rDescName = static_cast<const SvxPageModelItem*>(pItem)->GetValue();
         if( !rDescName.isEmpty() )   // No name -> disable PageDesc!
         {
             // Delete only, if PageDesc will be enabled!
@@ -611,9 +627,9 @@ void SfxToSwPageDescAttr( const SwWrtShell& rShell, SfxItemSet& rSet )
         rShell.GetCurAttr( aCoreSet );
         if(SfxItemState::SET == aCoreSet.GetItemState( RES_PAGEDESC, true, &pItem ) )
         {
-            if( ((SwFmtPageDesc*)pItem)->GetPageDesc() )
+            if( static_cast<const SwFormatPageDesc*>(pItem)->GetPageDesc() )
             {
-                aPgDesc.RegisterToPageDesc( *((SwFmtPageDesc*)pItem)->GetPageDesc() );
+                aPgDesc.RegisterToPageDesc( *const_cast<SwFormatPageDesc*>(static_cast<const SwFormatPageDesc*>(pItem))->GetPageDesc() );
             }
         }
     }
@@ -633,10 +649,10 @@ void SwToSfxPageDescAttr( SfxItemSet& rCoreSet )
     {
     case SfxItemState::SET:
         {
-            if( ((SwFmtPageDesc*)pItem)->GetPageDesc() )
+            if( static_cast<const SwFormatPageDesc*>(pItem)->GetPageDesc() )
             {
-                aName = ((SwFmtPageDesc*)pItem)->GetPageDesc()->GetName();
-                oNumOffset = ((SwFmtPageDesc*)pItem)->GetNumOffset();
+                aName = static_cast<const SwFormatPageDesc*>(pItem)->GetPageDesc()->GetName();
+                oNumOffset = static_cast<const SwFormatPageDesc*>(pItem)->GetNumOffset();
             }
             rCoreSet.ClearItem( RES_PAGEDESC );
             // Page number
@@ -704,35 +720,35 @@ void FillCharStyleListBox(ListBox& rToFill, SwDocShell* pDocSh, bool bSorted, bo
                 ? InsertStringSorted(pBase->GetName(), rToFill, nOffset )
                 : rToFill.InsertEntry(pBase->GetName());
             sal_IntPtr nPoolId = SwStyleNameMapper::GetPoolIdFromUIName( pBase->GetName(), nsSwGetPoolIdFromName::GET_POOLID_CHRFMT );
-            rToFill.SetEntryData( nPos, (void*) (nPoolId));
+            rToFill.SetEntryData( nPos, reinterpret_cast<void*>(nPoolId));
         }
         pBase = pPool->Next();
     }
     // non-pool styles
-    const SwCharFmts* pFmts = pDoc->GetCharFmts();
-    for(size_t i = 0; i < pFmts->size(); ++i)
+    const SwCharFormats* pFormats = pDoc->GetCharFormats();
+    for(size_t i = 0; i < pFormats->size(); ++i)
     {
-        const SwCharFmt* pFmt = (*pFmts)[i];
-        if(pFmt->IsDefault())
+        const SwCharFormat* pFormat = (*pFormats)[i];
+        if(pFormat->IsDefault())
             continue;
-        const OUString& rName = pFmt->GetName();
+        const OUString& rName = pFormat->GetName();
         if(rToFill.GetEntryPos(rName) == LISTBOX_ENTRY_NOTFOUND)
         {
             const sal_Int32 nPos = bSorted
                 ? InsertStringSorted(rName, rToFill, nOffset )
                 : rToFill.InsertEntry(rName);
             sal_IntPtr nPoolId = USHRT_MAX;
-            rToFill.SetEntryData( nPos, (void*) (nPoolId));
+            rToFill.SetEntryData( nPos, reinterpret_cast<void*>(nPoolId));
         }
     }
 };
 
-SwTwips GetTableWidth( SwFrmFmt* pFmt, SwTabCols& rCols, sal_uInt16 *pPercent,
+SwTwips GetTableWidth( SwFrameFormat* pFormat, SwTabCols& rCols, sal_uInt16 *pPercent,
             SwWrtShell* pSh )
 {
     // To get the width is slightly more complicated.
     SwTwips nWidth = 0;
-    const sal_Int16 eOri = pFmt->GetHoriOrient().GetHoriOrient();
+    const sal_Int16 eOri = pFormat->GetHoriOrient().GetHoriOrient();
     switch(eOri)
     {
         case text::HoriOrientation::FULL: nWidth = rCols.GetRight(); break;
@@ -740,13 +756,13 @@ SwTwips GetTableWidth( SwFrmFmt* pFmt, SwTabCols& rCols, sal_uInt16 *pPercent,
         case text::HoriOrientation::LEFT:
         case text::HoriOrientation::RIGHT:
         case text::HoriOrientation::CENTER:
-            nWidth = pFmt->GetFrmSize().GetWidth();
+            nWidth = pFormat->GetFrmSize().GetWidth();
         break;
         default:
         {
             if(pSh)
             {
-                if ( 0 == pSh->GetFlyFrmFmt() )
+                if ( 0 == pSh->GetFlyFrameFormat() )
                 {
                     nWidth = pSh->GetAnyCurRect(RECT_PAGE_PRT).Width();
                 }
@@ -759,12 +775,12 @@ SwTwips GetTableWidth( SwFrmFmt* pFmt, SwTabCols& rCols, sal_uInt16 *pPercent,
             {
                 OSL_FAIL("where to get the actual width from?");
             }
-            const SvxLRSpaceItem& rLRSpace = pFmt->GetLRSpace();
+            const SvxLRSpaceItem& rLRSpace = pFormat->GetLRSpace();
             nWidth -= (rLRSpace.GetRight() + rLRSpace.GetLeft());
         }
     }
     if (pPercent)
-        *pPercent = pFmt->GetFrmSize().GetWidthPercent();
+        *pPercent = pFormat->GetFrmSize().GetWidthPercent();
     return nWidth;
 }
 
