@@ -33,6 +33,7 @@
 #include <com/sun/star/io/XActiveDataSink.hpp>
 #include <com/sun/star/io/XOutputStream.hpp>
 #include <com/sun/star/lang/IllegalAccessException.hpp>
+#include <com/sun/star/lang/WrappedTargetRuntimeException.hpp>
 #include <com/sun/star/ucb/ContentInfoAttribute.hpp>
 #include <com/sun/star/ucb/InsertCommandArgument.hpp>
 #include <com/sun/star/ucb/InteractiveBadTransferURLException.hpp>
@@ -58,6 +59,8 @@
 #include <com/sun/star/ucb/XContentCreator.hpp>
 
 #include <comphelper/processfactory.hxx>
+#include <comphelper/seekableinput.hxx>
+#include <cppuhelper/exc_hlp.hxx>
 #include <ucbhelper/contentidentifier.hxx>
 #include <ucbhelper/propertyvalueset.hxx>
 #include <ucbhelper/interactionrequest.hxx>
@@ -88,23 +91,19 @@ Content::Content(
     : ContentImplHelper( rxContext, pProvider, Identifier ),
       m_pProvider( pProvider ), mpFile (NULL), mpInfo( NULL ), mbTransient(false)
 {
-#if OSL_DEBUG_LEVEL > 1
-    fprintf(stderr, "New Content ('%s')\n", OUStringToOString(m_xIdentifier->getContentIdentifier(), RTL_TEXTENCODING_UTF8).getStr());
-#endif
+    SAL_INFO("ucb.ucp.gio", "New Content ('" << m_xIdentifier->getContentIdentifier() << "')\n");
 }
 
 Content::Content(
     const uno::Reference< uno::XComponentContext >& rxContext,
     ContentProvider* pProvider,
     const uno::Reference< ucb::XContentIdentifier >& Identifier,
-    sal_Bool bIsFolder)
+    bool bIsFolder)
         throw ( ucb::ContentCreationException )
     : ContentImplHelper( rxContext, pProvider, Identifier ),
       m_pProvider( pProvider ), mpFile (NULL), mpInfo( NULL ), mbTransient(true)
 {
-#if OSL_DEBUG_LEVEL > 1
-    fprintf(stderr, "Create Content ('%s')\n", OUStringToOString(m_xIdentifier->getContentIdentifier(), RTL_TEXTENCODING_UTF8).getStr());
-#endif
+    SAL_INFO("ucb.ucp.gio", "Create Content ('" << m_xIdentifier->getContentIdentifier() << "')\n");
     mpInfo = g_file_info_new();
     g_file_info_set_file_type(mpInfo, bIsFolder ? G_FILE_TYPE_DIRECTORY : G_FILE_TYPE_REGULAR);
 }
@@ -129,14 +128,14 @@ OUString Content::getParentURL()
 }
 
 void SAL_CALL Content::abort( sal_Int32 /*CommandId*/ )
-       throw( uno::RuntimeException )
+       throw( uno::RuntimeException, std::exception )
 {
     //TODO
-    //stick a map from each CommandId to a new GCancellable and propogate
+    //stick a map from each CommandId to a new GCancellable and propagate
     //it throughout the g_file_* calls
 }
 
-OUString SAL_CALL Content::getContentType() throw( uno::RuntimeException )
+OUString SAL_CALL Content::getContentType() throw( uno::RuntimeException, std::exception )
 {
     return isFolder(uno::Reference< ucb::XCommandEnvironment >())
         ? OUString( GIO_FOLDER_TYPE )
@@ -147,7 +146,7 @@ OUString SAL_CALL Content::getContentType() throw( uno::RuntimeException )
 do { \
     if (bThrow) throw aExcept;\
     aRet = uno::makeAny( aExcept );\
-} while(0)
+} while(false)
 
 uno::Any convertToException(GError *pError, const uno::Reference< uno::XInterface >& rContext, bool bThrow)
 {
@@ -283,6 +282,30 @@ uno::Any convertToException(GError *pError, const uno::Reference< uno::XInterfac
     return aRet;
 }
 
+void convertToIOException(GError *pError, const uno::Reference< uno::XInterface >& rContext)
+    throw( io::IOException, uno::RuntimeException, std::exception )
+{
+    try
+    {
+        convertToException(pError, rContext);
+    }
+    catch (const io::IOException&)
+    {
+        throw;
+    }
+    catch (const uno::RuntimeException&)
+    {
+        throw;
+    }
+    catch (const uno::Exception& e)
+    {
+        css::uno::Any a(cppu::getCaughtException());
+        throw css::lang::WrappedTargetRuntimeException(
+            "wrapped Exception " + e.Message,
+            css::uno::Reference<css::uno::XInterface>(), a);
+    }
+}
+
 uno::Any Content::mapGIOError( GError *pError )
 {
     if (!pError)
@@ -318,7 +341,7 @@ MountOperation::MountOperation(const uno::Reference< ucb::XCommandEnvironment >&
 
 void MountOperation::Completed(GObject *source, GAsyncResult *res, gpointer user_data)
 {
-    MountOperation *pThis = (MountOperation*)user_data;
+    MountOperation *pThis = static_cast<MountOperation*>(user_data);
     g_file_mount_enclosing_volume_finish(G_FILE(source), res, &(pThis->mpError));
     g_main_loop_quit(pThis->mpLoop);
 }
@@ -481,7 +504,7 @@ uno::Reference< sdbc::XRow > Content::getPropertyValuesFromGFileInfo(GFileInfo *
         else if ( rProp.Name == "IsVolume" )
         {
             //What do we use this for ?
-            xRow->appendBoolean( rProp, sal_False );
+            xRow->appendBoolean( rProp, false );
         }
         else if ( rProp.Name == "IsCompactDisc" )
         {
@@ -499,7 +522,7 @@ uno::Reference< sdbc::XRow > Content::getPropertyValuesFromGFileInfo(GFileInfo *
         }
         else if ( rProp.Name == "IsFloppy" )
         {
-            xRow->appendBoolean( rProp, sal_False );
+            xRow->appendBoolean( rProp, false );
         }
         else if ( rProp.Name == "IsHidden" )
         {
@@ -539,7 +562,7 @@ getReadOnlyException( const uno::Reference< uno::XInterface >& rContext )
 
 void Content::queryChildren( ContentRefList& rChildren )
 {
-    // Obtain a list with a snapshot of all currently instanciated contents
+    // Obtain a list with a snapshot of all currently instantiated contents
     // from provider and extract the contents which are direct children
     // of this content.
 
@@ -563,7 +586,7 @@ void Content::queryChildren( ContentRefList& rChildren )
         OUString aChildURL = xChild->getIdentifier()->getContentIdentifier();
 
         // Is aURL a prefix of aChildURL?
-        if ( ( aChildURL.getLength() > nLen ) && ( aChildURL.compareTo( aURL, nLen ) == 0 ) )
+        if ( ( aChildURL.getLength() > nLen ) && aChildURL.startsWith( aURL ) )
         {
             sal_Int32 nPos = nLen;
             nPos = aChildURL.indexOf( '/', nPos );
@@ -578,17 +601,17 @@ void Content::queryChildren( ContentRefList& rChildren )
     }
 }
 
-sal_Bool Content::exchangeIdentity( const uno::Reference< ucb::XContentIdentifier >& xNewId )
+bool Content::exchangeIdentity( const uno::Reference< ucb::XContentIdentifier >& xNewId )
 {
     if ( !xNewId.is() )
-        return sal_False;
+        return false;
 
     uno::Reference< ucb::XContent > xThis = this;
 
     if ( mbTransient )
     {
         m_xIdentifier = xNewId;
-        return sal_False;
+        return false;
     }
 
     OUString aOldURL = m_xIdentifier->getContentIdentifier();
@@ -596,7 +619,7 @@ sal_Bool Content::exchangeIdentity( const uno::Reference< ucb::XContentIdentifie
     // Exchange own identitity.
     if ( exchange( xNewId ) )
     {
-        // Process instanciated children...
+        // Process instantiated children...
         ContentRefList aChildren;
         queryChildren( aChildren );
 
@@ -617,14 +640,14 @@ sal_Bool Content::exchangeIdentity( const uno::Reference< ucb::XContentIdentifie
                 = new ::ucbhelper::ContentIdentifier( aNewChildURL );
 
             if ( !xChild->exchangeIdentity( xNewChildId ) )
-                return sal_False;
+                return false;
 
             ++it;
          }
-         return sal_True;
+         return true;
     }
 
-    return sal_False;
+    return false;
 }
 
 uno::Sequence< uno::Any > Content::setPropertyValues(
@@ -718,9 +741,7 @@ uno::Sequence< uno::Any > Content::setPropertyValues(
         }
         else
         {
-#ifdef DEBUG
-            fprintf(stderr, "Unknown property %s\n", OUStringToOString(rValue.Name, RTL_TEXTENCODING_UTF8).getStr());
-#endif
+            SAL_WARN("ucb.ucp.gio", "Unknown property " << rValue.Name << "\n");
             aRet[ n ] <<= getReadOnlyException( static_cast< cppu::OWeakObject * >(this) );
             //TODO
         }
@@ -809,26 +830,26 @@ void Content::copyData( uno::Reference< io::XInputStream > xIn,
     xOut->closeOutput();
 }
 
-sal_Bool Content::feedSink( uno::Reference< uno::XInterface > xSink,
+bool Content::feedSink( uno::Reference< uno::XInterface > xSink,
     const uno::Reference< ucb::XCommandEnvironment >& /*xEnv*/ )
 {
     if ( !xSink.is() )
-        return sal_False;
+        return false;
 
     uno::Reference< io::XOutputStream > xOut = uno::Reference< io::XOutputStream >(xSink, uno::UNO_QUERY );
     uno::Reference< io::XActiveDataSink > xDataSink = uno::Reference< io::XActiveDataSink >(xSink, uno::UNO_QUERY );
 
     if ( !xOut.is() && !xDataSink.is() )
-        return sal_False;
+        return false;
 
     GError *pError=NULL;
     GFileInputStream *pStream = g_file_read(getGFile(), NULL, &pError);
     if (!pStream)
        convertToException(pError, static_cast< cppu::OWeakObject * >(this));
 
-    uno::Reference< io::XInputStream > xIn = new ::gio::InputStream(pStream);
-    if ( !xIn.is() )
-        return sal_False;
+    uno::Reference< io::XInputStream > xIn(
+        new comphelper::OSeekableInputWrapper(
+            new ::gio::InputStream(pStream), m_xContext));
 
     if ( xOut.is() )
         copyData( xIn, xOut );
@@ -836,7 +857,7 @@ sal_Bool Content::feedSink( uno::Reference< uno::XInterface > xSink,
     if ( xDataSink.is() )
         xDataSink->setInputStream( xIn );
 
-    return sal_True;
+    return true;
 }
 
 uno::Any Content::open(const ucb::OpenCommandArgument2 & rOpenCommand,
@@ -860,7 +881,7 @@ uno::Any Content::open(const ucb::OpenCommandArgument2 & rOpenCommand,
 
     uno::Any aRet;
 
-    sal_Bool bOpenFolder = (
+    bool bOpenFolder = (
         ( rOpenCommand.Mode == ucb::OpenMode::ALL ) ||
         ( rOpenCommand.Mode == ucb::OpenMode::FOLDERS ) ||
         ( rOpenCommand.Mode == ucb::OpenMode::DOCUMENTS )
@@ -914,11 +935,9 @@ uno::Any SAL_CALL Content::execute(
         const uno::Reference< ucb::XCommandEnvironment >& xEnv )
     throw( uno::Exception,
            ucb::CommandAbortedException,
-           uno::RuntimeException )
+           uno::RuntimeException, std::exception )
 {
-#if OSL_DEBUG_LEVEL > 1
-    fprintf(stderr, "Content::execute %s\n", OUStringToOString(aCommand.Name, RTL_TEXTENCODING_UTF8).getStr());
-#endif
+    SAL_INFO("ucb.ucp.gio", "Content::execute " << aCommand.Name << "\n");
     uno::Any aRet;
 
     if ( aCommand.Name == "getPropertyValues" )
@@ -929,9 +948,9 @@ uno::Any SAL_CALL Content::execute(
         aRet <<= getPropertyValues( Properties, xEnv );
     }
     else if ( aCommand.Name == "getPropertySetInfo" )
-        aRet <<= getPropertySetInfo( xEnv, sal_False );
+        aRet <<= getPropertySetInfo( xEnv, false );
     else if ( aCommand.Name == "getCommandInfo" )
-        aRet <<= getCommandInfo( xEnv, sal_False );
+        aRet <<= getCommandInfo( xEnv, false );
     else if ( aCommand.Name == "open" )
     {
         ucb::OpenCommandArgument2 aOpenCommand;
@@ -970,7 +989,7 @@ uno::Any SAL_CALL Content::execute(
     }
     else if ( aCommand.Name == "delete" )
     {
-        sal_Bool bDeletePhysical = sal_False;
+        bool bDeletePhysical = false;
         aCommand.Argument >>= bDeletePhysical;
 
         //If no delete physical, try and trashcan it, if that doesn't work go
@@ -989,10 +1008,7 @@ uno::Any SAL_CALL Content::execute(
     }
     else
     {
-#ifdef DEBUG
-        fprintf(stderr, "UNKNOWN COMMAND\n");
-        //TODO
-#endif
+        SAL_WARN("ucb.ucp.gio", "Unknown command " << aCommand.Name << "\n");
 
         ucbhelper::cancelCommandExecution
             ( uno::makeAny( ucb::UnsupportedCommandException
@@ -1004,7 +1020,7 @@ uno::Any SAL_CALL Content::execute(
     return aRet;
 }
 
-void Content::destroy( sal_Bool bDeletePhysical )
+void Content::destroy( bool bDeletePhysical )
     throw( uno::Exception )
 {
     uno::Reference< ucb::XContent > xThis = this;
@@ -1025,7 +1041,7 @@ void Content::destroy( sal_Bool bDeletePhysical )
 }
 
 void Content::insert(const uno::Reference< io::XInputStream > &xInputStream,
-    sal_Bool bReplaceExisting, const uno::Reference< ucb::XCommandEnvironment > &xEnv )
+    bool bReplaceExisting, const uno::Reference< ucb::XCommandEnvironment > &xEnv )
         throw( uno::Exception )
 {
     GError *pError = NULL;
@@ -1068,7 +1084,7 @@ void Content::insert(const uno::Reference< io::XInputStream > &xInputStream,
 
     if (mbTransient)
     {
-        mbTransient = sal_False;
+        mbTransient = false;
         inserted();
     }
 }
@@ -1116,17 +1132,17 @@ uno::Sequence< ucb::ContentInfo > Content::queryCreatableContentsInfo(
         props[0] = beans::Property(
             OUString("Title"),
             -1,
-            getCppuType( static_cast< OUString* >( 0 ) ),
+            cppu::UnoType<OUString>::get(),
             beans::PropertyAttribute::MAYBEVOID | beans::PropertyAttribute::BOUND );
 
         // file
-        seq[0].Type       = OUString( GIO_FILE_TYPE );
+        seq[0].Type       = GIO_FILE_TYPE;
         seq[0].Attributes = ( ucb::ContentInfoAttribute::INSERT_WITH_INPUTSTREAM |
                               ucb::ContentInfoAttribute::KIND_DOCUMENT );
         seq[0].Properties = props;
 
         // folder
-        seq[1].Type       = OUString( GIO_FOLDER_TYPE );
+        seq[1].Type       = GIO_FOLDER_TYPE;
         seq[1].Attributes = ucb::ContentInfoAttribute::KIND_FOLDER;
         seq[1].Properties = props;
 
@@ -1139,14 +1155,14 @@ uno::Sequence< ucb::ContentInfo > Content::queryCreatableContentsInfo(
 }
 
 uno::Sequence< ucb::ContentInfo > SAL_CALL Content::queryCreatableContentsInfo()
-            throw( uno::RuntimeException )
+            throw( uno::RuntimeException, std::exception )
 {
     return queryCreatableContentsInfo( uno::Reference< ucb::XCommandEnvironment >() );
 }
 
 uno::Reference< ucb::XContent >
     SAL_CALL Content::createNewContent( const ucb::ContentInfo& Info )
-        throw( uno::RuntimeException )
+        throw( uno::RuntimeException, std::exception )
 {
     bool create_document;
     const char *name;
@@ -1188,7 +1204,7 @@ uno::Reference< ucb::XContent >
 }
 
 uno::Sequence< uno::Type > SAL_CALL Content::getTypes()
-    throw( uno::RuntimeException )
+    throw( uno::RuntimeException, std::exception )
 {
     if ( isFolder( uno::Reference< ucb::XCommandEnvironment >() ) )
     {
@@ -1230,40 +1246,40 @@ uno::Sequence< beans::Property > Content::getProperties(
     static const beans::Property aGenericProperties[] =
     {
         beans::Property( OUString(  "IsDocument"  ),
-            -1, getCppuBooleanType(),
+            -1, cppu::UnoType<bool>::get(),
             beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY ),
         beans::Property( OUString(  "IsFolder"  ),
-            -1, getCppuBooleanType(),
+            -1, cppu::UnoType<bool>::get(),
             beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY ),
         beans::Property( OUString(  "Title"  ),
-            -1, getCppuType( static_cast< const OUString * >( 0 ) ),
+            -1, cppu::UnoType<OUString>::get(),
             beans::PropertyAttribute::BOUND ),
         beans::Property( OUString(  "IsReadOnly"  ),
-            -1, getCppuBooleanType(),
+            -1, cppu::UnoType<bool>::get(),
             beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY ),
         beans::Property( OUString(  "DateCreated"  ),
-            -1, getCppuType( static_cast< const util::DateTime * >( 0 ) ),
+            -1, cppu::UnoType<util::DateTime>::get(),
             beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY ),
         beans::Property( OUString(  "DateModified"  ),
-            -1, getCppuType( static_cast< const util::DateTime * >( 0 ) ),
+            -1, cppu::UnoType<util::DateTime>::get(),
             beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY ),
         beans::Property( OUString(  "Size"  ),
-            -1, getCppuType( static_cast< const sal_Int64 * >( 0 ) ),
+            -1, cppu::UnoType<sal_Int64>::get(),
             beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY ),
         beans::Property( OUString(  "IsVolume"  ),
-            -1, getCppuBooleanType(),
+            1, cppu::UnoType<bool>::get(),
             beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY ),
         beans::Property( OUString(  "IsCompactDisc"  ),
-            -1, getCppuBooleanType(),
+            -1, cppu::UnoType<bool>::get(),
             beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY ),
         beans::Property( OUString(  "IsRemoveable"  ),
-            -1, getCppuBooleanType(),
+            -1, cppu::UnoType<bool>::get(),
             beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY ),
         beans::Property( OUString(  "IsHidden"  ),
-            -1, getCppuBooleanType(),
+            -1, cppu::UnoType<bool>::get(),
             beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY ),
         beans::Property( OUString(  "CreatableContentsInfo"  ),
-            -1, getCppuType( static_cast< const uno::Sequence< ucb::ContentInfo > * >( 0 ) ),
+            -1, cppu::UnoType<uno::Sequence< ucb::ContentInfo >>::get(),
             beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY )
     };
 
@@ -1278,35 +1294,35 @@ uno::Sequence< ucb::CommandInfo > Content::getCommands( const uno::Reference< uc
         // Required commands
         ucb::CommandInfo
         ( OUString(  "getCommandInfo"  ),
-          -1, getCppuVoidType() ),
+          -1, cppu::UnoType<void>::get() ),
         ucb::CommandInfo
         ( OUString(  "getPropertySetInfo"  ),
-          -1, getCppuVoidType() ),
+          -1, cppu::UnoType<void>::get() ),
         ucb::CommandInfo
         ( OUString(  "getPropertyValues"  ),
-          -1, getCppuType( static_cast<uno::Sequence< beans::Property > * >( 0 ) ) ),
+          -1, cppu::UnoType<uno::Sequence< beans::Property >>::get() ),
         ucb::CommandInfo
         ( OUString(  "setPropertyValues"  ),
-          -1, getCppuType( static_cast<uno::Sequence< beans::PropertyValue > * >( 0 ) ) ),
+          -1, cppu::UnoType<uno::Sequence< beans::PropertyValue >>::get() ),
 
         // Optional standard commands
         ucb::CommandInfo
         ( OUString(  "delete"  ),
-          -1, getCppuBooleanType() ),
+          -1, cppu::UnoType<bool>::get() ),
         ucb::CommandInfo
         ( OUString(  "insert"  ),
-          -1, getCppuType( static_cast<ucb::InsertCommandArgument * >( 0 ) ) ),
+          -1, cppu::UnoType<ucb::InsertCommandArgument>::get() ),
         ucb::CommandInfo
         ( OUString(  "open"  ),
-          -1, getCppuType( static_cast<ucb::OpenCommandArgument2 * >( 0 ) ) ),
+          -1, cppu::UnoType<ucb::OpenCommandArgument2>::get() ),
 
         // Folder Only, omitted if not a folder
         ucb::CommandInfo
         ( OUString(  "transfer"  ),
-          -1, getCppuType( static_cast<ucb::TransferInfo * >( 0 ) ) ),
+          -1, cppu::UnoType<ucb::TransferInfo>::get() ),
         ucb::CommandInfo
         ( OUString(  "createNewContent"  ),
-          -1, getCppuType( static_cast<ucb::ContentInfo * >( 0 ) ) )
+          -1, cppu::UnoType<ucb::ContentInfo>::get() )
     };
 
     const int nProps = sizeof (aCommandInfoTable) / sizeof (aCommandInfoTable[0]);
@@ -1325,19 +1341,19 @@ void SAL_CALL Content::release() throw()
     ContentImplHelper::release();
 }
 
-uno::Any SAL_CALL Content::queryInterface( const uno::Type & rType ) throw ( uno::RuntimeException )
+uno::Any SAL_CALL Content::queryInterface( const uno::Type & rType ) throw ( uno::RuntimeException, std::exception )
 {
     uno::Any aRet = cppu::queryInterface( rType, static_cast< ucb::XContentCreator * >( this ) );
     return aRet.hasValue() ? aRet : ContentImplHelper::queryInterface(rType);
 }
 
-OUString SAL_CALL Content::getImplementationName() throw( uno::RuntimeException )
+OUString SAL_CALL Content::getImplementationName() throw( uno::RuntimeException, std::exception )
 {
        return OUString("com.sun.star.comp.GIOContent");
 }
 
 uno::Sequence< OUString > SAL_CALL Content::getSupportedServiceNames()
-       throw( uno::RuntimeException )
+       throw( uno::RuntimeException, std::exception )
 {
        uno::Sequence< OUString > aSNS( 1 );
        aSNS.getArray()[ 0 ] = "com.sun.star.ucb.GIOContent";
