@@ -23,6 +23,7 @@
 
 #include <osl/diagnose.h>
 #include <osl/mutex.hxx>
+#include <sal/log.hxx>
 #include <salhelper/simplereferenceobject.hxx>
 #include <cppuhelper/weak.hxx>
 
@@ -80,21 +81,21 @@ class EmptyInputStream : public ::cppu::WeakImplHelper1< XInputStream >
 public:
     virtual sal_Int32 SAL_CALL readBytes(
         Sequence< sal_Int8 > & data, sal_Int32 nBytesToRead )
-        throw (IOException, RuntimeException);
+        throw (IOException, RuntimeException, std::exception) SAL_OVERRIDE;
     virtual sal_Int32 SAL_CALL readSomeBytes(
         Sequence< sal_Int8 > & data, sal_Int32 nMaxBytesToRead )
-        throw (IOException, RuntimeException);
+        throw (IOException, RuntimeException, std::exception) SAL_OVERRIDE;
     virtual void SAL_CALL skipBytes( sal_Int32 nBytesToSkip )
-        throw (IOException, RuntimeException);
+        throw (IOException, RuntimeException, std::exception) SAL_OVERRIDE;
     virtual sal_Int32 SAL_CALL available()
-        throw (IOException, RuntimeException);
+        throw (IOException, RuntimeException, std::exception) SAL_OVERRIDE;
     virtual void SAL_CALL closeInput()
-        throw (IOException, RuntimeException);
+        throw (IOException, RuntimeException, std::exception) SAL_OVERRIDE;
 };
 
 sal_Int32 EmptyInputStream::readBytes(
     Sequence< sal_Int8 > & data, sal_Int32 )
-    throw (IOException, RuntimeException)
+    throw (IOException, RuntimeException, std::exception)
 {
     data.realloc( 0 );
     return 0;
@@ -102,36 +103,36 @@ sal_Int32 EmptyInputStream::readBytes(
 
 sal_Int32 EmptyInputStream::readSomeBytes(
     Sequence< sal_Int8 > & data, sal_Int32 )
-    throw (IOException, RuntimeException)
+    throw (IOException, RuntimeException, std::exception)
 {
     data.realloc( 0 );
     return 0;
 }
 
 void EmptyInputStream::skipBytes( sal_Int32 )
-    throw (IOException, RuntimeException)
+    throw (IOException, RuntimeException, std::exception)
 {
 }
 
 sal_Int32 EmptyInputStream::available()
-    throw (IOException, RuntimeException)
+    throw (IOException, RuntimeException, std::exception)
 {
     return 0;
 }
 
 void EmptyInputStream::closeInput()
-    throw (IOException, RuntimeException)
+    throw (IOException, RuntimeException, std::exception)
 {
 }
 
 
-//=========================================================================
-//=========================================================================
-//
+
+
+
 // class ContentEventListener_Impl.
-//
-//=========================================================================
-//=========================================================================
+
+
+
 
 class ContentEventListener_Impl : public cppu::OWeakObject,
                                       public XContentEventListener
@@ -143,24 +144,29 @@ public:
     : m_rContent( rContent ) {}
 
     // XInterface
-    XINTERFACE_DECL()
+    virtual css::uno::Any SAL_CALL queryInterface( const css::uno::Type & rType )
+        throw( css::uno::RuntimeException, std::exception ) SAL_OVERRIDE;
+    virtual void SAL_CALL acquire()
+        throw() SAL_OVERRIDE;
+    virtual void SAL_CALL release()
+        throw() SAL_OVERRIDE;
 
     // XContentEventListener
     virtual void SAL_CALL contentEvent( const ContentEvent& evt )
-        throw( RuntimeException );
+        throw( RuntimeException, std::exception ) SAL_OVERRIDE;
 
     // XEventListener ( base of XContentEventListener )
     virtual void SAL_CALL disposing( const EventObject& Source )
-        throw( RuntimeException );
+        throw( RuntimeException, std::exception ) SAL_OVERRIDE;
 };
 
-//=========================================================================
-//=========================================================================
-//
+
+
+
 // class Content_Impl.
-//
-//=========================================================================
-//=========================================================================
+
+
+
 
 class Content_Impl : public salhelper::SimpleReferenceObject
 {
@@ -201,9 +207,9 @@ public:
     void inserted();
 };
 
-//=========================================================================
+
 // Helpers.
-//=========================================================================
+
 
 static void ensureContentProviderForURL( const Reference< XUniversalContentBroker >& rBroker,
                                          const OUString & rURL )
@@ -220,20 +226,16 @@ static void ensureContentProviderForURL( const Reference< XUniversalContentBroke
     }
 }
 
-//=========================================================================
-static Reference< XContentIdentifier > getContentIdentifier(
+
+static Reference< XContentIdentifier > getContentIdentifierThrow(
                                     const Reference< XUniversalContentBroker > & rBroker,
-                                    const OUString & rURL,
-                                    bool bThrow )
-    throw ( ContentCreationException, RuntimeException )
+                                    const OUString & rURL)
+    throw (ContentCreationException, RuntimeException)
 {
     Reference< XContentIdentifier > xId
         = rBroker->createContentIdentifier( rURL );
 
-    if ( xId.is() )
-        return xId;
-
-    if ( bThrow )
+    if (!xId.is())
     {
         ensureContentProviderForURL( rBroker, rURL );
 
@@ -243,14 +245,20 @@ static Reference< XContentIdentifier > getContentIdentifier(
             ContentCreationError_IDENTIFIER_CREATION_FAILED );
     }
 
-    return Reference< XContentIdentifier >();
+    return xId;
 }
 
-//=========================================================================
-static Reference< XContent > getContent(
+static Reference< XContentIdentifier > getContentIdentifierNoThrow(
                                     const Reference< XUniversalContentBroker > & rBroker,
-                                    const Reference< XContentIdentifier > & xId,
-                                    bool bThrow )
+                                    const OUString & rURL)
+    throw (RuntimeException)
+{
+    return rBroker->createContentIdentifier(rURL);
+}
+
+static Reference< XContent > getContentThrow(
+                                    const Reference< XUniversalContentBroker > & rBroker,
+                                    const Reference< XContentIdentifier > & xId)
     throw ( ContentCreationException, RuntimeException )
 {
     Reference< XContent > xContent;
@@ -265,36 +273,52 @@ static Reference< XContent > getContent(
         // handled below.
     }
 
-    if ( xContent.is() )
-        return xContent;
-
-    if ( bThrow )
+    if ( !xContent.is() )
     {
         ensureContentProviderForURL( rBroker, xId->getContentIdentifier() );
 
         throw ContentCreationException(
-            "Unable to create Content! " + msg,
+            "Unable to create Content for <" + xId->getContentIdentifier() + ">: " + msg,
             Reference< XInterface >(),
             ContentCreationError_CONTENT_CREATION_FAILED );
     }
 
-    return Reference< XContent >();
+    return xContent;
 }
 
-//=========================================================================
-//=========================================================================
-//
+
+static Reference< XContent > getContentNoThrow(
+                                    const Reference< XUniversalContentBroker > & rBroker,
+                                    const Reference< XContentIdentifier > & xId)
+    throw ( RuntimeException )
+{
+    Reference< XContent > xContent;
+    try
+    {
+        xContent = rBroker->queryContent( xId );
+    }
+    catch ( IllegalIdentifierException const & e )
+    {
+        SAL_WARN("ucbhelper", "getContentNoThrow: exception: " << e.Message);
+    }
+
+    return xContent;
+}
+
+
+
+
 // Content Implementation.
-//
-//=========================================================================
-//=========================================================================
+
+
+
 
 Content::Content()
 : m_xImpl( new Content_Impl )
 {
 }
 
-//=========================================================================
+
 Content::Content( const OUString& rURL,
                   const Reference< XCommandEnvironment >& rEnv,
                   const Reference< XComponentContext >& rCtx )
@@ -304,14 +328,14 @@ Content::Content( const OUString& rURL,
         UniversalContentBroker::create( rCtx ) );
 
     Reference< XContentIdentifier > xId
-        = getContentIdentifier( pBroker, rURL, true );
+        = getContentIdentifierThrow(pBroker, rURL);
 
-    Reference< XContent > xContent = getContent( pBroker, xId, true );
+    Reference< XContent > xContent = getContentThrow(pBroker, xId);
 
     m_xImpl = new Content_Impl( rCtx, xContent, rEnv );
 }
 
-//=========================================================================
+
 Content::Content( const Reference< XContent >& rContent,
                   const Reference< XCommandEnvironment >& rEnv,
                   const Reference< XComponentContext >& rCtx )
@@ -320,15 +344,15 @@ Content::Content( const Reference< XContent >& rContent,
     m_xImpl = new Content_Impl( rCtx, rContent, rEnv );
 }
 
-//=========================================================================
+
 Content::Content( const Content& rOther )
 {
     m_xImpl = rOther.m_xImpl;
 }
 
-//=========================================================================
+
 // static
-sal_Bool Content::create( const OUString& rURL,
+bool Content::create( const OUString& rURL,
                           const Reference< XCommandEnvironment >& rEnv,
                           const Reference< XComponentContext >& rCtx,
                           Content& rContent )
@@ -337,58 +361,58 @@ sal_Bool Content::create( const OUString& rURL,
         UniversalContentBroker::create( rCtx ) );
 
     Reference< XContentIdentifier > xId
-        = getContentIdentifier( pBroker, rURL, false );
+        = getContentIdentifierNoThrow(pBroker, rURL);
     if ( !xId.is() )
-        return sal_False;
+        return false;
 
-    Reference< XContent > xContent = getContent( pBroker, xId, false );
+    Reference< XContent > xContent = getContentNoThrow(pBroker, xId);
     if ( !xContent.is() )
-        return sal_False;
+        return false;
 
     rContent.m_xImpl
         = new Content_Impl( rCtx, xContent, rEnv );
 
-    return sal_True;
+    return true;
 }
 
-//=========================================================================
+
 Content::~Content()
 {
 }
 
-//=========================================================================
+
 Content& Content::operator=( const Content& rOther )
 {
     m_xImpl = rOther.m_xImpl;
     return *this;
 }
 
-//=========================================================================
+
 Reference< XContent > Content::get() const
 {
     return m_xImpl->getContent();
 }
 
-//=========================================================================
+
 const OUString& Content::getURL() const
 {
     return m_xImpl->getURL();
 }
 
-//=========================================================================
+
 const Reference< XCommandEnvironment >& Content::getCommandEnvironment() const
 {
     return m_xImpl->getEnvironment();
 }
 
-//=========================================================================
+
 void Content::setCommandEnvironment(
                         const Reference< XCommandEnvironment >& xNewEnv )
 {
     m_xImpl->setEnvironment( xNewEnv );
 }
 
-//=========================================================================
+
 Reference< XCommandInfo > Content::getCommands()
     throw( CommandAbortedException, RuntimeException, Exception )
 {
@@ -404,7 +428,7 @@ Reference< XCommandInfo > Content::getCommands()
     return xInfo;
 }
 
-//=========================================================================
+
 Reference< XPropertySetInfo > Content::getProperties()
     throw( CommandAbortedException, RuntimeException, Exception )
 {
@@ -420,7 +444,7 @@ Reference< XPropertySetInfo > Content::getProperties()
     return xInfo;
 }
 
-//=========================================================================
+
 Any Content::getPropertyValue( const OUString& rPropertyName )
     throw( CommandAbortedException, RuntimeException, Exception )
 {
@@ -431,7 +455,7 @@ Any Content::getPropertyValue( const OUString& rPropertyName )
     return aRet.getConstArray()[ 0 ];
 }
 
-//=========================================================================
+
 Any Content::setPropertyValue( const OUString& rName,
                                 const Any& rValue )
     throw( CommandAbortedException, RuntimeException, Exception )
@@ -446,7 +470,7 @@ Any Content::setPropertyValue( const OUString& rName,
     return aErrors.getConstArray()[ 0 ];
 }
 
-//=========================================================================
+
 Sequence< Any > Content::getPropertyValues(
                             const Sequence< OUString >& rPropertyNames )
     throw( CommandAbortedException, RuntimeException, Exception )
@@ -467,7 +491,7 @@ Sequence< Any > Content::getPropertyValues(
     return aValues;
 }
 
-//=========================================================================
+
 Reference< XRow > Content::getPropertyValuesInterface(
                             const Sequence< OUString >& rPropertyNames )
     throw( CommandAbortedException, RuntimeException, Exception )
@@ -500,7 +524,7 @@ Reference< XRow > Content::getPropertyValuesInterface(
     return xRow;
 }
 
-//=========================================================================
+
 Sequence< Any > Content::setPropertyValues(
                             const Sequence< OUString >& rPropertyNames,
                                 const Sequence< Any >& rValues )
@@ -548,7 +572,7 @@ Sequence< Any > Content::setPropertyValues(
     return aErrors;
 }
 
-//=========================================================================
+
 Any Content::executeCommand( const OUString& rCommandName,
                              const Any& rCommandArgument )
     throw( CommandAbortedException, RuntimeException, Exception )
@@ -561,7 +585,7 @@ Any Content::executeCommand( const OUString& rCommandName,
     return m_xImpl->executeCommand( aCommand );
 }
 
-//=========================================================================
+
 Any Content::createCursorAny( const Sequence< OUString >& rPropertyNames,
                               ResultSetInclude eMode )
     throw( CommandAbortedException, RuntimeException, Exception )
@@ -594,7 +618,7 @@ Any Content::createCursorAny( const Sequence< OUString >& rPropertyNames,
     return m_xImpl->executeCommand( aCommand );
 }
 
-//=========================================================================
+
 Reference< XResultSet > Content::createCursor(
                             const Sequence< OUString >& rPropertyNames,
                             ResultSetInclude eMode )
@@ -624,7 +648,7 @@ Reference< XResultSet > Content::createCursor(
     return aResult;
 }
 
-//=========================================================================
+
 Reference< XDynamicResultSet > Content::createDynamicCursor(
                             const Sequence< OUString >& rPropertyNames,
                             ResultSetInclude eMode )
@@ -638,7 +662,7 @@ Reference< XDynamicResultSet > Content::createDynamicCursor(
     return aResult;
 }
 
-//=========================================================================
+
 Reference< XResultSet > Content::createSortedCursor(
                             const Sequence< OUString >& rPropertyNames,
                             const Sequence< NumberedSortingInfo >& rSortInfo,
@@ -690,7 +714,7 @@ Reference< XResultSet > Content::createSortedCursor(
     return aResult;
 }
 
-//=========================================================================
+
 Reference< XInputStream > Content::openStream()
     throw( CommandAbortedException, RuntimeException, Exception )
 {
@@ -715,7 +739,7 @@ Reference< XInputStream > Content::openStream()
     return xSink->getInputStream();
 }
 
-//=========================================================================
+
 Reference< XInputStream > Content::openStreamNoLock()
     throw( CommandAbortedException, RuntimeException, Exception )
 {
@@ -740,7 +764,7 @@ Reference< XInputStream > Content::openStreamNoLock()
     return xSink->getInputStream();
 }
 
-//=========================================================================
+
 Reference< XStream > Content::openWriteableStream()
     throw( CommandAbortedException, RuntimeException, Exception )
 {
@@ -765,7 +789,7 @@ Reference< XStream > Content::openWriteableStream()
     return xStreamer->getStream();
 }
 
-//=========================================================================
+
 Reference< XStream > Content::openWriteableStreamNoLock()
     throw( CommandAbortedException, RuntimeException, Exception )
 {
@@ -790,12 +814,12 @@ Reference< XStream > Content::openWriteableStreamNoLock()
     return xStreamer->getStream();
 }
 
-//=========================================================================
-sal_Bool Content::openStream( const Reference< XActiveDataSink >& rSink )
+
+bool Content::openStream( const Reference< XActiveDataSink >& rSink )
     throw( CommandAbortedException, RuntimeException, Exception )
 {
     if ( !isDocument() )
-        return sal_False;
+        return false;
 
     OpenCommandArgument2 aArg;
     aArg.Mode       = OpenMode::DOCUMENT;
@@ -810,15 +834,15 @@ sal_Bool Content::openStream( const Reference< XActiveDataSink >& rSink )
 
     m_xImpl->executeCommand( aCommand );
 
-    return sal_True;
+    return true;
 }
 
-//=========================================================================
-sal_Bool Content::openStream( const Reference< XOutputStream >& rStream )
+
+bool Content::openStream( const Reference< XOutputStream >& rStream )
     throw( CommandAbortedException, RuntimeException, Exception )
 {
     if ( !isDocument() )
-        return sal_False;
+        return false;
 
     OpenCommandArgument2 aArg;
     aArg.Mode       = OpenMode::DOCUMENT;
@@ -833,12 +857,12 @@ sal_Bool Content::openStream( const Reference< XOutputStream >& rStream )
 
     m_xImpl->executeCommand( aCommand );
 
-    return sal_True;
+    return true;
 }
 
-//=========================================================================
+
 void Content::writeStream( const Reference< XInputStream >& rStream,
-                           sal_Bool bReplaceExisting )
+                           bool bReplaceExisting )
     throw( CommandAbortedException, RuntimeException, Exception )
 {
     InsertCommandArgument aArg;
@@ -855,7 +879,7 @@ void Content::writeStream( const Reference< XInputStream >& rStream,
     m_xImpl->inserted();
 }
 
-//=========================================================================
+
 Sequence< ContentInfo > Content::queryCreatableContentsInfo()
     throw( CommandAbortedException, RuntimeException, Exception )
 {
@@ -875,8 +899,8 @@ Sequence< ContentInfo > Content::queryCreatableContentsInfo()
     return aInfo;
 }
 
-//=========================================================================
-sal_Bool Content::insertNewContent( const OUString& rContentType,
+
+bool Content::insertNewContent( const OUString& rContentType,
                                     const Sequence< OUString >&
                                         rPropertyNames,
                                     const Sequence< Any >& rPropertyValues,
@@ -890,8 +914,8 @@ sal_Bool Content::insertNewContent( const OUString& rContentType,
                              rNewContent );
 }
 
-//=========================================================================
-sal_Bool Content::insertNewContent( const OUString& rContentType,
+
+bool Content::insertNewContent( const OUString& rContentType,
                                     const Sequence< OUString >&
                                         rPropertyNames,
                                     const Sequence< Any >& rPropertyValues,
@@ -900,7 +924,7 @@ sal_Bool Content::insertNewContent( const OUString& rContentType,
     throw( CommandAbortedException, RuntimeException, Exception )
 {
     if ( rContentType.isEmpty() )
-        return sal_False;
+        return false;
 
     // First, try it using "createNewContent" command -> the "new" way.
     ContentInfo aInfo;
@@ -932,12 +956,12 @@ sal_Bool Content::insertNewContent( const OUString& rContentType,
         Reference< XContentCreator > xCreator( m_xImpl->getContent(), UNO_QUERY );
 
         if ( !xCreator.is() )
-            return sal_False;
+            return false;
 
         xNew = xCreator->createNewContent( aInfo );
 
         if ( !xNew.is() )
-            return sal_False;
+            return false;
     }
 
     Content aNewContent(
@@ -951,11 +975,11 @@ sal_Bool Content::insertNewContent( const OUString& rContentType,
     aNewContent.m_xImpl->inserted();
 
     rNewContent = aNewContent;
-    return sal_True;
+    return true;
 }
 
-//=========================================================================
-sal_Bool Content::transferContent( const Content& rSourceContent,
+
+bool Content::transferContent( const Content& rSourceContent,
                                    InsertOperation eOperation,
                                    const OUString & rTitle,
                                    const sal_Int32 nNameClashAction,
@@ -993,16 +1017,6 @@ sal_Bool Content::transferContent( const Content& rSourceContent,
             sCommand = "checkin";
             bCheckIn = true;
             break;
-
-        default:
-            ucbhelper::cancelCommandExecution(
-                makeAny( IllegalArgumentException(
-                            OUString(
-                                "Unknown transfer operation!" ),
-                            get(),
-                            -1 ) ),
-                         m_xImpl->getEnvironment() );
-            // Unreachable
     }
     Command aCommand;
     aCommand.Name     = sCommand;
@@ -1030,14 +1044,14 @@ sal_Bool Content::transferContent( const Content& rSourceContent,
     Any aRet = pBroker->execute( aCommand, 0, m_xImpl->getEnvironment() );
     if ( pResultURL != NULL )
         aRet >>= *pResultURL;
-    return sal_True;
+    return true;
 }
 
-//=========================================================================
-sal_Bool Content::isFolder()
+
+bool Content::isFolder()
     throw( CommandAbortedException, RuntimeException, Exception )
 {
-    sal_Bool bFolder = sal_False;
+    bool bFolder = false;
     if ( getPropertyValue("IsFolder")
         >>= bFolder )
         return bFolder;
@@ -1052,18 +1066,18 @@ sal_Bool Content::isFolder()
 #if !(defined(_MSC_VER) && defined(ENABLE_LTO))
     // Unreachable - cancelCommandExecution always throws an exception.
     // But some compilers complain...
-    return sal_False;
+    return false;
 #endif
 }
 
-//=========================================================================
+
 
 SAL_WNOUNREACHABLE_CODE_PUSH
 
-sal_Bool Content::isDocument()
+bool Content::isDocument()
     throw( CommandAbortedException, RuntimeException, Exception )
 {
-    sal_Bool bDoc = sal_False;
+    bool bDoc = false;
     if ( getPropertyValue("IsDocument")
         >>= bDoc )
         return bDoc;
@@ -1077,18 +1091,18 @@ sal_Bool Content::isDocument()
 
     // Unreachable - cancelCommandExecution always throws an exception,
     // But some compilers complain...
-    return sal_False;
+    return false;
 }
 
 SAL_WNOUNREACHABLE_CODE_POP
 
-//=========================================================================
-//=========================================================================
-//
+
+
+
 // Content_Impl Implementation.
-//
-//=========================================================================
-//=========================================================================
+
+
+
 
 Content_Impl::Content_Impl( const Reference< XComponentContext >& rCtx,
                             const Reference< XContent >& rContent,
@@ -1111,7 +1125,7 @@ Content_Impl::Content_Impl( const Reference< XComponentContext >& rCtx,
     }
 }
 
-//=========================================================================
+
 void Content_Impl::reinit( const Reference< XContent >& xContent )
 {
     osl::MutexGuard aGuard( m_aMutex );
@@ -1152,7 +1166,7 @@ void Content_Impl::reinit( const Reference< XContent >& xContent )
     }
 }
 
-//=========================================================================
+
 // virtual
 Content_Impl::~Content_Impl()
 {
@@ -1168,7 +1182,7 @@ Content_Impl::~Content_Impl()
     }
 }
 
-//=========================================================================
+
 void Content_Impl::disposing( const EventObject& Source )
 {
     Reference<XContent> xContent;
@@ -1180,7 +1194,7 @@ void Content_Impl::disposing( const EventObject& Source )
 
         xContent = m_xContent;
 
-        m_aURL = "";
+        m_aURL.clear();
         m_xCommandProcessor = 0;
         m_xContent = 0;
     }
@@ -1197,7 +1211,7 @@ void Content_Impl::disposing( const EventObject& Source )
     }
 }
 
-//=========================================================================
+
 const OUString& Content_Impl::getURL() const
 {
     if ( m_aURL.isEmpty() && m_xContent.is() )
@@ -1215,7 +1229,7 @@ const OUString& Content_Impl::getURL() const
     return m_aURL;
 }
 
-//=========================================================================
+
 Reference< XContent > Content_Impl::getContent()
 {
     if ( !m_xContent.is() && !m_aURL.isEmpty() )
@@ -1255,7 +1269,7 @@ Reference< XContent > Content_Impl::getContent()
     return m_xContent;
 }
 
-//=========================================================================
+
 Reference< XCommandProcessor > Content_Impl::getCommandProcessor()
 {
     if ( !m_xCommandProcessor.is() )
@@ -1270,7 +1284,7 @@ Reference< XCommandProcessor > Content_Impl::getCommandProcessor()
     return m_xCommandProcessor;
 }
 
-//=========================================================================
+
 Any Content_Impl::executeCommand( const Command& rCommand )
 {
     Reference< XCommandProcessor > xProc = getCommandProcessor();
@@ -1281,14 +1295,14 @@ Any Content_Impl::executeCommand( const Command& rCommand )
     return xProc->execute( rCommand, 0, m_xEnv );
 }
 
-//=========================================================================
+
 inline const Reference< XCommandEnvironment >&
                                         Content_Impl::getEnvironment() const
 {
     return m_xEnv;
 }
 
-//=========================================================================
+
 inline void Content_Impl::setEnvironment(
                         const Reference< XCommandEnvironment >& xNewEnv )
 {
@@ -1296,41 +1310,55 @@ inline void Content_Impl::setEnvironment(
     m_xEnv = xNewEnv;
 }
 
-//=========================================================================
+
 void Content_Impl::inserted()
 {
     // URL might have changed during 'insert' => recalculate in next getURL()
     osl::MutexGuard aGuard( m_aMutex );
-    m_aURL = "";
+    m_aURL.clear();
 }
 
-//=========================================================================
-//=========================================================================
-//
+
+
+
 // ContentEventListener_Impl Implementation.
-//
-//=========================================================================
-//=========================================================================
 
-//=========================================================================
-//
+
+
+
+
+
 // XInterface methods.
-//
-//=========================================================================
 
-XINTERFACE_IMPL_2( ContentEventListener_Impl,
-                   XContentEventListener,
-                   XEventListener ); /* base of XContentEventListener */
+void SAL_CALL ContentEventListener_Impl::acquire()
+    throw()
+{
+    OWeakObject::acquire();
+}
+
+void SAL_CALL ContentEventListener_Impl::release()
+    throw()
+{
+    OWeakObject::release();
+}
+
+css::uno::Any SAL_CALL ContentEventListener_Impl::queryInterface( const css::uno::Type & rType )
+    throw( css::uno::RuntimeException, std::exception )
+{
+    css::uno::Any aRet = cppu::queryInterface( rType,
+                                               (static_cast< XContentEventListener* >(this)),
+                                               (static_cast< XEventListener* >(this))
+                                               );
+    return aRet.hasValue() ? aRet : OWeakObject::queryInterface( rType );
+}
 
-//=========================================================================
-//
 // XContentEventListener methods.
-//
-//=========================================================================
+
+
 
 // virtual
 void SAL_CALL ContentEventListener_Impl::contentEvent( const ContentEvent& evt )
-    throw( RuntimeException )
+    throw( RuntimeException, std::exception )
 {
     if ( evt.Source == m_rContent.m_xContent )
     {
@@ -1350,15 +1378,15 @@ void SAL_CALL ContentEventListener_Impl::contentEvent( const ContentEvent& evt )
     }
 }
 
-//=========================================================================
-//
+
+
 // XEventListenr methods.
-//
-//=========================================================================
+
+
 
 // virtual
 void SAL_CALL ContentEventListener_Impl::disposing( const EventObject& Source )
-    throw( RuntimeException )
+    throw( RuntimeException, std::exception )
 {
     m_rContent.disposing(Source);
 }
