@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include <unotools/securityoptions.hxx>
 #include <unotools/configmgr.hxx>
 #include <unotools/configitem.hxx>
@@ -27,21 +26,18 @@
 #include <com/sun/star/uno/Sequence.hxx>
 
 #include <com/sun/star/beans/PropertyValue.hpp>
-#include <comphelper/sequenceasvector.hxx>
+#include <comphelper/sequence.hxx>
 #include <tools/urlobj.hxx>
 
 #include <unotools/pathoptions.hxx>
 
 #include "itemholder1.hxx"
 
-//_________________________________________________________________________________________________________________
 //  namespaces
-//_________________________________________________________________________________________________________________
 
-using namespace ::utl                   ;
-using namespace ::rtl                   ;
-using namespace ::osl                   ;
-using namespace ::com::sun::star::uno   ;
+using namespace ::utl;
+using namespace ::osl;
+using namespace ::com::sun::star::uno;
 
 #define ROOTNODE_SECURITY               OUString("Office.Common/Security/Scripting")
 #define DEFAULT_SECUREURL               Sequence< OUString >()
@@ -73,7 +69,6 @@ using namespace ::com::sun::star::uno   ;
 #define PROPERTYNAME_CONFIRMATIONENABLED "Confirmation"
 // xmlsec05 deprecated
 
-
 #define PROPERTYHANDLE_SECUREURL                    0
 
 // xmlsec05 deprecated
@@ -98,32 +93,28 @@ using namespace ::com::sun::star::uno   ;
 #define PROPERTYCOUNT                               16
 #define PROPERTYHANDLE_INVALID                      -1
 
-#define CFG_READONLY_DEFAULT                        sal_False
+#define CFG_READONLY_DEFAULT                        false
 
-//_________________________________________________________________________________________________________________
 //  private declarations!
-//_________________________________________________________________________________________________________________
 
 class SvtSecurityOptions_Impl : public ConfigItem
 {
-    //-------------------------------------------------------------------------------------------------------------
+
+    private:
+        virtual void ImplCommit() SAL_OVERRIDE;
+
     //  public methods
-    //-------------------------------------------------------------------------------------------------------------
 
     public:
 
-        //---------------------------------------------------------------------------------------------------------
         //  constructor / destructor
-        //---------------------------------------------------------------------------------------------------------
 
          SvtSecurityOptions_Impl();
-        ~SvtSecurityOptions_Impl();
+        virtual ~SvtSecurityOptions_Impl();
 
-        //---------------------------------------------------------------------------------------------------------
-        //  overloaded methods of baseclass
-        //---------------------------------------------------------------------------------------------------------
+        //  override methods of baseclass
 
-        /*-****************************************************************************************************//**
+        /*-****************************************************************************************************
             @short      called for notify of configmanager
             @descr      These method is called from the ConfigManager before application ends or from the
                          PropertyChangeListener if the sub tree broadcasts changes. You must update your
@@ -132,145 +123,124 @@ class SvtSecurityOptions_Impl : public ConfigItem
             @seealso    baseclass ConfigItem
 
             @param      "seqPropertyNames" is the list of properties which should be updated.
-            @return     -
-
-            @onerror    -
         *//*-*****************************************************************************************************/
 
-        virtual void Notify( const Sequence< OUString >& seqPropertyNames );
+        virtual void Notify( const Sequence< OUString >& seqPropertyNames ) SAL_OVERRIDE;
 
-        /*-****************************************************************************************************//**
-            @short      write changes to configuration
-            @descr      These method writes the changed values into the sub tree
-                        and should always called in our destructor to guarantee consistency of config data.
-
-            @seealso    baseclass ConfigItem
-
-            @param      -
-            @return     -
-
-            @onerror    -
-        *//*-*****************************************************************************************************/
-
-        virtual void Commit();
-
-        //---------------------------------------------------------------------------------------------------------
         //  public interface
-        //---------------------------------------------------------------------------------------------------------
 
-        sal_Bool                IsReadOnly      ( SvtSecurityOptions::EOption eOption                   ) const ;
+        bool                IsReadOnly      ( SvtSecurityOptions::EOption eOption                   ) const;
 
-        Sequence< OUString >    GetSecureURLs   (                                                       ) const ;
-        void                    SetSecureURLs   (   const   Sequence< OUString >&   seqURLList          )       ;
-        inline sal_Int32        GetMacroSecurityLevel   (                                               ) const ;
-        void                    SetMacroSecurityLevel   ( sal_Int32 _nLevel                             )       ;
+        Sequence< OUString >    GetSecureURLs   (                                                       ) const { return m_seqSecureURLs;}
+        void                    SetSecureURLs   (   const   Sequence< OUString >&   seqURLList          );
+        inline sal_Int32        GetMacroSecurityLevel   (                                               ) const;
+        void                    SetMacroSecurityLevel   ( sal_Int32 _nLevel                             );
 
-        inline sal_Bool         IsMacroDisabled         (                                               ) const ;
+        inline bool         IsMacroDisabled         (                                               ) const;
 
-        Sequence< SvtSecurityOptions::Certificate > GetTrustedAuthors       (                                                                                       ) const ;
-        void                                        SetTrustedAuthors       ( const Sequence< SvtSecurityOptions::Certificate >& rAuthors                           )       ;
+        Sequence< SvtSecurityOptions::Certificate > GetTrustedAuthors       (                                                                                       ) const { return m_seqTrustedAuthors;}
+        void                                        SetTrustedAuthors       ( const Sequence< SvtSecurityOptions::Certificate >& rAuthors                           );
 
-        sal_Bool                IsOptionSet     ( SvtSecurityOptions::EOption eOption                   ) const ;
-        sal_Bool                SetOption       ( SvtSecurityOptions::EOption eOption, sal_Bool bValue  )       ;
-        sal_Bool                IsOptionEnabled ( SvtSecurityOptions::EOption eOption                   ) const ;
+        bool                IsOptionSet     ( SvtSecurityOptions::EOption eOption                   ) const;
+        bool                SetOption       ( SvtSecurityOptions::EOption eOption, bool bValue  );
+        bool                IsOptionEnabled ( SvtSecurityOptions::EOption eOption                   ) const;
 
-        /*-****************************************************************************************************//**
-            @short      return list of key names of ouer configuration management which represent our module tree
+        /*-****************************************************************************************************
+            @short      return list of key names of our configuration management which represent our module tree
             @descr      These methods return a static const list of key names. We need it to get needed values from our
                         configuration management.
-
-            @seealso    -
-
-            @param      -
             @return     A list of needed configuration keys is returned.
-
-            @onerror    -
         *//*-*****************************************************************************************************/
 
-        void                    SetProperty( sal_Int32 nHandle, const Any& rValue, sal_Bool bReadOnly );
-        void                    LoadAuthors( void );
+        void                    SetProperty( sal_Int32 nHandle, const Any& rValue, bool bReadOnly );
+        void                    LoadAuthors();
         static sal_Int32        GetHandle( const OUString& rPropertyName );
-        bool                    GetOption( SvtSecurityOptions::EOption eOption, sal_Bool*& rpValue, sal_Bool*& rpRO );
+        bool                    GetOption( SvtSecurityOptions::EOption eOption, bool*& rpValue, bool*& rpRO );
 
         static Sequence< OUString > GetPropertyNames();
 
         Sequence< OUString >                        m_seqSecureURLs;
-        sal_Bool                                    m_bSaveOrSend;
-        sal_Bool                                    m_bSigning;
-        sal_Bool                                    m_bPrint;
-        sal_Bool                                    m_bCreatePDF;
-        sal_Bool                                    m_bRemoveInfo;
-        sal_Bool                                    m_bRecommendPwd;
-        sal_Bool                                    m_bCtrlClickHyperlink;
-        sal_Bool                                    m_bBlockUntrustedRefererLinks;
+        bool                                    m_bSaveOrSend;
+        bool                                    m_bSigning;
+        bool                                    m_bPrint;
+        bool                                    m_bCreatePDF;
+        bool                                    m_bRemoveInfo;
+        bool                                    m_bRecommendPwd;
+        bool                                    m_bCtrlClickHyperlink;
+        bool                                    m_bBlockUntrustedRefererLinks;
         sal_Int32                                   m_nSecLevel;
         Sequence< SvtSecurityOptions::Certificate > m_seqTrustedAuthors;
-        sal_Bool                                    m_bDisableMacros;
-
-        sal_Bool                                    m_bROSecureURLs;
-        sal_Bool                                    m_bROSaveOrSend;
-        sal_Bool                                    m_bROSigning;
-        sal_Bool                                    m_bROPrint;
-        sal_Bool                                    m_bROCreatePDF;
-        sal_Bool                                    m_bRORemoveInfo;
-        sal_Bool                                    m_bRORecommendPwd;
-        sal_Bool                                    m_bROCtrlClickHyperlink;
-        sal_Bool                                    m_bROBlockUntrustedRefererLinks;
-        sal_Bool                                    m_bROSecLevel;
-        sal_Bool                                    m_bROTrustedAuthors;
-        sal_Bool                                    m_bRODisableMacros;
+        bool                                    m_bDisableMacros;
 
+        bool                                    m_bROSecureURLs;
+        bool                                    m_bROSaveOrSend;
+        bool                                    m_bROSigning;
+        bool                                    m_bROPrint;
+        bool                                    m_bROCreatePDF;
+        bool                                    m_bRORemoveInfo;
+        bool                                    m_bRORecommendPwd;
+        bool                                    m_bROCtrlClickHyperlink;
+        bool                                    m_bROBlockUntrustedRefererLinks;
+        bool                                    m_bROSecLevel;
+        bool                                    m_bROTrustedAuthors;
+        bool                                    m_bRODisableMacros;
 
         // xmlsec05 deprecated
         EBasicSecurityMode      m_eBasicMode;
-        sal_Bool                m_bExecutePlugins;
-        sal_Bool                m_bWarning;
-        sal_Bool                m_bConfirmation;
+        bool                m_bExecutePlugins;
+        bool                m_bWarning;
+        bool                m_bConfirmation;
 
-        sal_Bool                m_bROConfirmation;
-        sal_Bool                m_bROWarning;
-        sal_Bool                m_bROExecutePlugins;
-        sal_Bool                m_bROBasicMode;
+        bool                m_bROConfirmation;
+        bool                m_bROWarning;
+        bool                m_bROExecutePlugins;
+        bool                m_bROBasicMode;
         public:
-        sal_Bool IsWarningEnabled() const;
-        void SetWarningEnabled( sal_Bool bSet );
-        sal_Bool IsConfirmationEnabled() const;
-        void SetConfirmationEnabled( sal_Bool bSet );
-        sal_Bool    IsExecutePlugins() const;
-        void        SetExecutePlugins( sal_Bool bSet );
-        EBasicSecurityMode      GetBasicMode    (                                               ) const ;
-        void                    SetBasicMode    (           EBasicSecurityMode      eMode       )       ;
+        bool IsWarningEnabled() const { return m_bWarning;}
+        void SetWarningEnabled( bool bSet );
+        bool IsConfirmationEnabled() const { return m_bConfirmation;}
+        void SetConfirmationEnabled( bool bSet );
+        bool    IsExecutePlugins() const { return m_bExecutePlugins;}
+        void        SetExecutePlugins( bool bSet );
+        // xmlsec05 deprecated
+        EBasicSecurityMode      GetBasicMode    (                                               ) const { return m_eBasicMode;}
+        void                    SetBasicMode    (           EBasicSecurityMode      eMode       );
 };
 
-//*****************************************************************************************************************
 //  constructor
-//*****************************************************************************************************************
+
 SvtSecurityOptions_Impl::SvtSecurityOptions_Impl()
     :ConfigItem             ( ROOTNODE_SECURITY         )
     ,m_seqSecureURLs        ( DEFAULT_SECUREURL         )
-    ,m_bSaveOrSend          ( sal_True                  )
-    ,m_bSigning             ( sal_True                  )
-    ,m_bPrint               ( sal_True                  )
-    ,m_bCreatePDF           ( sal_True                  )
-    ,m_bRemoveInfo          ( sal_True                  )
-    ,m_nSecLevel            ( sal_True                  )
+    ,m_bSaveOrSend          ( true                  )
+    ,m_bSigning             ( true                  )
+    ,m_bPrint               ( true                  )
+    ,m_bCreatePDF           ( true                  )
+    ,m_bRemoveInfo          ( true                  )
+    ,m_bRecommendPwd(false)
+    ,m_bCtrlClickHyperlink(false)
+    ,m_bBlockUntrustedRefererLinks(false)
+    ,m_nSecLevel            ( 1                     )
     ,m_seqTrustedAuthors    ( DEFAULT_TRUSTEDAUTHORS    )
-    ,m_bDisableMacros       ( sal_False                 )
+    ,m_bDisableMacros       ( false                 )
     ,m_bROSecureURLs        ( CFG_READONLY_DEFAULT      )
     ,m_bROSaveOrSend        ( CFG_READONLY_DEFAULT      )
     ,m_bROSigning           ( CFG_READONLY_DEFAULT      )
     ,m_bROPrint             ( CFG_READONLY_DEFAULT      )
     ,m_bROCreatePDF         ( CFG_READONLY_DEFAULT      )
     ,m_bRORemoveInfo        ( CFG_READONLY_DEFAULT      )
+    ,m_bRORecommendPwd(CFG_READONLY_DEFAULT)
+    ,m_bROCtrlClickHyperlink(CFG_READONLY_DEFAULT)
+    ,m_bROBlockUntrustedRefererLinks(CFG_READONLY_DEFAULT)
     ,m_bROSecLevel          ( CFG_READONLY_DEFAULT      )
     ,m_bROTrustedAuthors    ( CFG_READONLY_DEFAULT      )
-    ,m_bRODisableMacros     ( sal_True                  ) // currently is not intended to be changed
+    ,m_bRODisableMacros     ( true                  ) // currently is not intended to be changed
 
     // xmlsec05 deprecated
     ,   m_eBasicMode        ( DEFAULT_STAROFFICEBASIC )
-    ,   m_bExecutePlugins   ( sal_True                )
-    ,   m_bWarning          ( sal_True                )
-    ,   m_bConfirmation     ( sal_True                )
+    ,   m_bExecutePlugins   ( true                )
+    ,   m_bWarning          ( true                )
+    ,   m_bConfirmation     ( true                )
     ,   m_bROConfirmation   ( CFG_READONLY_DEFAULT    )
     ,   m_bROWarning        ( CFG_READONLY_DEFAULT    )
     ,   m_bROExecutePlugins ( CFG_READONLY_DEFAULT    )
@@ -289,7 +259,7 @@ SvtSecurityOptions_Impl::SvtSecurityOptions_Impl()
 
     // Copy values from list in right order to our internal member.
     sal_Int32               nPropertyCount = seqValues.getLength();
-    for( sal_Int32 nProperty = 0 ; nProperty < nPropertyCount ; ++nProperty )
+    for( sal_Int32 nProperty = 0; nProperty < nPropertyCount; ++nProperty )
         SetProperty( nProperty, seqValues[ nProperty ], seqRO[ nProperty ] );
 
     LoadAuthors();
@@ -300,16 +270,14 @@ SvtSecurityOptions_Impl::SvtSecurityOptions_Impl()
     EnableNotification( seqNames );
 }
 
-//*****************************************************************************************************************
 //  destructor
-//*****************************************************************************************************************
+
 SvtSecurityOptions_Impl::~SvtSecurityOptions_Impl()
 {
-    if( IsModified() )
-        Commit();
+    assert(!IsModified()); // should have been committed
 }
 
-void SvtSecurityOptions_Impl::SetProperty( sal_Int32 nProperty, const Any& rValue, sal_Bool bRO )
+void SvtSecurityOptions_Impl::SetProperty( sal_Int32 nProperty, const Any& rValue, bool bRO )
 {
     switch( nProperty )
     {
@@ -319,7 +287,7 @@ void SvtSecurityOptions_Impl::SetProperty( sal_Int32 nProperty, const Any& rValu
             rValue >>= m_seqSecureURLs;
             SvtPathOptions  aOpt;
             sal_uInt32      nCount = m_seqSecureURLs.getLength();
-            for( sal_uInt32 nItem = 0 ; nItem < nCount ; ++nItem )
+            for( sal_uInt32 nItem = 0; nItem < nCount; ++nItem )
                 m_seqSecureURLs[ nItem ] = aOpt.SubstituteVariable( m_seqSecureURLs[ nItem ] );
             m_bROSecureURLs = bRO;
         }
@@ -402,7 +370,6 @@ void SvtSecurityOptions_Impl::SetProperty( sal_Int32 nProperty, const Any& rValu
         }
         break;
 
-
         // xmlsec05 deprecated
         case PROPERTYHANDLE_STAROFFICEBASIC:
         {
@@ -432,7 +399,6 @@ void SvtSecurityOptions_Impl::SetProperty( sal_Int32 nProperty, const Any& rValu
         break;
         // xmlsec05 deprecated
 
-
         #if OSL_DEBUG_LEVEL > 1
         default:
             DBG_ASSERT( false, "SvtSecurityOptions_Impl::SetProperty()\nUnknown property!\n" );
@@ -440,7 +406,7 @@ void SvtSecurityOptions_Impl::SetProperty( sal_Int32 nProperty, const Any& rValu
     }
 }
 
-void SvtSecurityOptions_Impl::LoadAuthors( void )
+void SvtSecurityOptions_Impl::LoadAuthors()
 {
     m_seqTrustedAuthors.realloc( 0 );       // first clear
     Sequence< OUString >    lAuthors = GetNodeNames( PROPERTYNAME_MACRO_TRUSTEDAUTHORS );
@@ -453,7 +419,7 @@ void SvtSecurityOptions_Impl::LoadAuthors( void )
         sal_Int32               i1;
         sal_Int32               i2;
         OUString                aSep( "/" );
-        for( i1 = 0, i2 = 0 ; i1 < c1 ; ++i1 )
+        for( i1 = 0, i2 = 0; i1 < c1; ++i1 )
         {
             lAllAuthors[ i2 ] = PROPERTYNAME_MACRO_TRUSTEDAUTHORS + aSep + lAuthors[ i1 ] + aSep + PROPERTYNAME_TRUSTEDAUTHOR_SUBJECTNAME;
             ++i2;
@@ -466,9 +432,9 @@ void SvtSecurityOptions_Impl::LoadAuthors( void )
         Sequence< Any >         lValues = GetProperties( lAllAuthors );
         if( lValues.getLength() == c2 )
         {
-            comphelper::SequenceAsVector< SvtSecurityOptions::Certificate > v;
+            std::vector< SvtSecurityOptions::Certificate > v;
             SvtSecurityOptions::Certificate aCert( 3 );
-            for( i1 = 0, i2 = 0 ; i1 < c1 ; ++i1 )
+            for( i1 = 0, i2 = 0; i1 < c1; ++i1 )
             {
                 lValues[ i2 ] >>= aCert[ 0 ];
                 ++i2;
@@ -485,7 +451,7 @@ void SvtSecurityOptions_Impl::LoadAuthors( void )
                     v.push_back( aCert );
                 }
             }
-            m_seqTrustedAuthors = v.getAsConstList();
+            m_seqTrustedAuthors = comphelper::containerToSequence(v);
         }
     }
 }
@@ -536,7 +502,7 @@ sal_Int32 SvtSecurityOptions_Impl::GetHandle( const OUString& rName )
     return nHandle;
 }
 
-bool SvtSecurityOptions_Impl::GetOption( SvtSecurityOptions::EOption eOption, sal_Bool*& rpValue, sal_Bool*& rpRO )
+bool SvtSecurityOptions_Impl::GetOption( SvtSecurityOptions::EOption eOption, bool*& rpValue, bool*& rpRO )
 {
     switch( eOption )
     {
@@ -591,14 +557,14 @@ void SvtSecurityOptions_Impl::Notify( const Sequence< OUString >& seqPropertyNam
     DBG_ASSERT( !(seqPropertyNames.getLength()!=seqValues.getLength()), "SvtSecurityOptions_Impl::Notify()\nI miss some values of configuration keys!\n" );
     // Step over list of property names and get right value from coreesponding value list to set it on internal members!
     sal_Int32               nCount = seqPropertyNames.getLength();
-    for( sal_Int32 nProperty = 0 ; nProperty < nCount ; ++nProperty )
+    for( sal_Int32 nProperty = 0; nProperty < nCount; ++nProperty )
         SetProperty( GetHandle( seqPropertyNames[ nProperty ] ), seqValues[ nProperty ], seqRO[ nProperty ] );
 
     // read set of trusted authors separately
     LoadAuthors();
 }
 
-void SvtSecurityOptions_Impl::Commit()
+void SvtSecurityOptions_Impl::ImplCommit()
 {
     // Get names of supported properties, create a list for values and copy current values to it.
     Sequence< OUString >    lOrgNames = GetPropertyNames();
@@ -611,7 +577,7 @@ void SvtSecurityOptions_Impl::Commit()
 
     ClearNodeSet( PROPERTYNAME_MACRO_TRUSTEDAUTHORS );
 
-    for( sal_Int32 nProperty = 0 ; nProperty < nOrgCount ; ++nProperty )
+    for( sal_Int32 nProperty = 0; nProperty < nOrgCount; ++nProperty )
     {
         switch( nProperty )
         {
@@ -623,7 +589,7 @@ void SvtSecurityOptions_Impl::Commit()
                     Sequence< OUString >    lURLs( m_seqSecureURLs );
                     SvtPathOptions          aOpt;
                     sal_Int32               nURLsCnt = lURLs.getLength();
-                    for( sal_Int32 nItem = 0 ; nItem < nURLsCnt ; ++nItem )
+                    for( sal_Int32 nItem = 0; nItem < nURLsCnt; ++nItem )
                         lURLs[ nItem ] = aOpt.UseVariable( lURLs[ nItem ] );
                     lValues[ nRealCount ] <<= lURLs;
                 }
@@ -710,7 +676,7 @@ void SvtSecurityOptions_Impl::Commit()
                     sal_Int32   nCnt = m_seqTrustedAuthors.getLength();
                     if( nCnt )
                     {
-                        for( sal_Int32 i = 0 ; i < nCnt ; ++i )
+                        for( sal_Int32 i = 0; i < nCnt; ++i )
                         {
                             OUString aPrefix(
                                 PROPERTYNAME_MACRO_TRUSTEDAUTHORS "/a"
@@ -723,7 +689,6 @@ void SvtSecurityOptions_Impl::Commit()
                             lPropertyValues[ 2 ].Name = aPrefix + PROPERTYNAME_TRUSTEDAUTHOR_RAWDATA;
                             lPropertyValues[ 2 ].Value <<= m_seqTrustedAuthors[ i ][2];
 
-
                             SetSetProperties( PROPERTYNAME_MACRO_TRUSTEDAUTHORS, lPropertyValues );
                         }
 
@@ -739,11 +704,10 @@ void SvtSecurityOptions_Impl::Commit()
             {
                 bDone = !m_bRODisableMacros;
                 if( bDone )
-                    lValues[ nRealCount ] <<= (sal_Bool)m_bDisableMacros;
+                    lValues[ nRealCount ] <<= m_bDisableMacros;
             }
             break;
 
-
             // xmlsec05 deprecated
             case PROPERTYHANDLE_STAROFFICEBASIC:
             {
@@ -775,7 +739,6 @@ void SvtSecurityOptions_Impl::Commit()
             break;
             // xmlsec05 deprecated
 
-
             default:
                 bDone = false;
         }
@@ -792,9 +755,9 @@ void SvtSecurityOptions_Impl::Commit()
     PutProperties( lNames, lValues );
 }
 
-sal_Bool SvtSecurityOptions_Impl::IsReadOnly( SvtSecurityOptions::EOption eOption ) const
+bool SvtSecurityOptions_Impl::IsReadOnly( SvtSecurityOptions::EOption eOption ) const
 {
-    sal_Bool    bReadonly;
+    bool    bReadonly;
     switch(eOption)
     {
         case SvtSecurityOptions::E_SECUREURLS :
@@ -849,18 +812,13 @@ sal_Bool SvtSecurityOptions_Impl::IsReadOnly( SvtSecurityOptions::EOption eOptio
             break;
         // xmlsec05 deprecated
 
-
         default:
-            bReadonly = sal_True;
+            bReadonly = true;
     }
 
     return bReadonly;
 }
 
-Sequence< OUString > SvtSecurityOptions_Impl::GetSecureURLs() const
-{
-    return m_seqSecureURLs;
-}
 
 void SvtSecurityOptions_Impl::SetSecureURLs( const Sequence< OUString >& seqURLList )
 {
@@ -877,7 +835,7 @@ inline sal_Int32 SvtSecurityOptions_Impl::GetMacroSecurityLevel() const
     return m_nSecLevel;
 }
 
-inline sal_Bool SvtSecurityOptions_Impl::IsMacroDisabled() const
+inline bool SvtSecurityOptions_Impl::IsMacroDisabled() const
 {
     return m_bDisableMacros;
 }
@@ -897,10 +855,6 @@ void SvtSecurityOptions_Impl::SetMacroSecurityLevel( sal_Int32 _nLevel )
     }
 }
 
-Sequence< SvtSecurityOptions::Certificate > SvtSecurityOptions_Impl::GetTrustedAuthors() const
-{
-    return m_seqTrustedAuthors;
-}
 
 void SvtSecurityOptions_Impl::SetTrustedAuthors( const Sequence< SvtSecurityOptions::Certificate >& rAuthors )
 {
@@ -912,11 +866,11 @@ void SvtSecurityOptions_Impl::SetTrustedAuthors( const Sequence< SvtSecurityOpti
     }
 }
 
-sal_Bool SvtSecurityOptions_Impl::IsOptionSet( SvtSecurityOptions::EOption eOption ) const
+bool SvtSecurityOptions_Impl::IsOptionSet( SvtSecurityOptions::EOption eOption ) const
 {
-    sal_Bool*   pValue;
-    sal_Bool*   pRO;
-    sal_Bool    bRet = sal_False;
+    bool*   pValue;
+    bool*   pRO;
+    bool    bRet = false;
 
     if( ( const_cast< SvtSecurityOptions_Impl* >( this ) )->GetOption( eOption, pValue, pRO ) )
         bRet = *pValue;
@@ -924,17 +878,17 @@ sal_Bool SvtSecurityOptions_Impl::IsOptionSet( SvtSecurityOptions::EOption eOpti
     return bRet;
 }
 
-sal_Bool SvtSecurityOptions_Impl::SetOption( SvtSecurityOptions::EOption eOption, sal_Bool bValue )
+bool SvtSecurityOptions_Impl::SetOption( SvtSecurityOptions::EOption eOption, bool bValue )
 {
-    sal_Bool*   pValue;
-    sal_Bool*   pRO;
-    sal_Bool    bRet = sal_False;
+    bool*   pValue;
+    bool*   pRO;
+    bool    bRet = false;
 
     if( GetOption( eOption, pValue, pRO ) )
     {
         if( !*pRO )
         {
-            bRet = sal_True;
+            bRet = true;
             if( *pValue != bValue )
             {
                 *pValue = bValue;
@@ -946,11 +900,11 @@ sal_Bool SvtSecurityOptions_Impl::SetOption( SvtSecurityOptions::EOption eOption
     return bRet;
 }
 
-sal_Bool SvtSecurityOptions_Impl::IsOptionEnabled( SvtSecurityOptions::EOption eOption ) const
+bool SvtSecurityOptions_Impl::IsOptionEnabled( SvtSecurityOptions::EOption eOption ) const
 {
-    sal_Bool*   pValue;
-    sal_Bool*   pRO;
-    sal_Bool    bRet = sal_False;
+    bool*   pValue;
+    bool*   pRO;
+    bool    bRet = false;
 
     if( ( const_cast< SvtSecurityOptions_Impl* >( this ) )->GetOption( eOption, pValue, pRO ) )
         bRet = !*pRO;
@@ -986,21 +940,20 @@ Sequence< OUString > SvtSecurityOptions_Impl::GetPropertyNames()
     return seqPropertyNames;
 }
 
-//*****************************************************************************************************************
 //  initialize static member
 //  DON'T DO IT IN YOUR HEADER!
 //  see definition for further information
-//*****************************************************************************************************************
-SvtSecurityOptions_Impl*    SvtSecurityOptions::m_pDataContainer    = NULL  ;
-sal_Int32                   SvtSecurityOptions::m_nRefCount         = 0     ;
+
+SvtSecurityOptions_Impl*    SvtSecurityOptions::m_pDataContainer    = NULL;
+sal_Int32                   SvtSecurityOptions::m_nRefCount         = 0;
 
 SvtSecurityOptions::SvtSecurityOptions()
 {
     // Global access, must be guarded (multithreading!).
     MutexGuard aGuard( GetInitMutex() );
-    // Increase ouer refcount ...
+    // Increase our refcount ...
     ++m_nRefCount;
-    // ... and initialize ouer data container only if it not already exist!
+    // ... and initialize our data container only if it not already exist!
     if( m_pDataContainer == NULL )
     {
         m_pDataContainer = new SvtSecurityOptions_Impl;
@@ -1013,10 +966,10 @@ SvtSecurityOptions::~SvtSecurityOptions()
 {
     // Global access, must be guarded (multithreading!)
     MutexGuard aGuard( GetInitMutex() );
-    // Decrease ouer refcount.
+    // Decrease our refcount.
     --m_nRefCount;
     // If last instance was deleted ...
-    // we must destroy ouer static data container!
+    // we must destroy our static data container!
     if( m_nRefCount <= 0 )
     {
         delete m_pDataContainer;
@@ -1024,7 +977,7 @@ SvtSecurityOptions::~SvtSecurityOptions()
     }
 }
 
-sal_Bool SvtSecurityOptions::IsReadOnly( EOption eOption ) const
+bool SvtSecurityOptions::IsReadOnly( EOption eOption ) const
 {
     MutexGuard aGuard( GetInitMutex() );
     return m_pDataContainer->IsReadOnly(eOption);
@@ -1046,14 +999,14 @@ bool SvtSecurityOptions::isSecureMacroUri(
     OUString const & uri, OUString const & referer) const
 {
     switch (INetURLObject(uri).GetProtocol()) {
-    case INET_PROT_MACRO:
+    case INetProtocol::Macro:
         if (uri.startsWithIgnoreAsciiCase("macro:///")) {
             // Denotes an App-BASIC macro (see SfxMacroLoader::loadMacro), which
             // is considered safe:
             return true;
         }
         // fall through
-    case INET_PROT_SLOT:
+    case INetProtocol::Slot:
         return referer.equalsIgnoreAsciiCase("private:user")
             || isTrustedLocationUri(referer);
     default:
@@ -1082,6 +1035,14 @@ bool SvtSecurityOptions::isTrustedLocationUri(OUString const & uri) const {
     return false;
 }
 
+bool SvtSecurityOptions::isTrustedLocationUriForUpdatingLinks(
+    OUString const & uri) const
+{
+    return GetMacroSecurityLevel() == 0 || uri.isEmpty()
+        || uri.startsWithIgnoreAsciiCase("private:")
+        || isTrustedLocationUri(uri);
+}
+
 sal_Int32 SvtSecurityOptions::GetMacroSecurityLevel() const
 {
     MutexGuard aGuard( GetInitMutex() );
@@ -1094,7 +1055,7 @@ void SvtSecurityOptions::SetMacroSecurityLevel( sal_Int32 _nLevel )
     m_pDataContainer->SetMacroSecurityLevel( _nLevel );
 }
 
-sal_Bool SvtSecurityOptions::IsMacroDisabled() const
+bool SvtSecurityOptions::IsMacroDisabled() const
 {
     MutexGuard aGuard( GetInitMutex() );
     return m_pDataContainer->IsMacroDisabled();
@@ -1140,16 +1101,6 @@ Mutex& SvtSecurityOptions::GetInitMutex()
     return theSecurityOptionsMutex::get();
 }
 
-
-
-
-// xmlsec05 deprecated
-
-EBasicSecurityMode SvtSecurityOptions_Impl::GetBasicMode() const
-{
-    return m_eBasicMode;
-}
-
 void SvtSecurityOptions_Impl::SetBasicMode( EBasicSecurityMode eMode )
 {
     DBG_ASSERT(!m_bROBasicMode, "SvtSecurityOptions_Impl::SetBasicMode()\nYou tried to write on a readonly value!\n");
@@ -1160,12 +1111,8 @@ void SvtSecurityOptions_Impl::SetBasicMode( EBasicSecurityMode eMode )
     }
 }
 
-sal_Bool SvtSecurityOptions_Impl::IsExecutePlugins() const
-{
-    return m_bExecutePlugins;
-}
 
-void SvtSecurityOptions_Impl::SetExecutePlugins( sal_Bool bSet )
+void SvtSecurityOptions_Impl::SetExecutePlugins( bool bSet )
 {
     DBG_ASSERT(!m_bROExecutePlugins, "SvtSecurityOptions_Impl::SetExecutePlugins()\nYou tried to write on a readonly value!\n");
     if (!m_bROExecutePlugins && m_bExecutePlugins!=bSet)
@@ -1175,12 +1122,8 @@ void SvtSecurityOptions_Impl::SetExecutePlugins( sal_Bool bSet )
     }
 }
 
-sal_Bool SvtSecurityOptions_Impl::IsWarningEnabled() const
-{
-    return m_bWarning;
-}
 
-void SvtSecurityOptions_Impl::SetWarningEnabled( sal_Bool bSet )
+void SvtSecurityOptions_Impl::SetWarningEnabled( bool bSet )
 {
     DBG_ASSERT(!m_bROWarning, "SvtSecurityOptions_Impl::SetWarningEnabled()\nYou tried to write on a readonly value!\n");
     if (!m_bROWarning && m_bWarning!=bSet)
@@ -1190,12 +1133,8 @@ void SvtSecurityOptions_Impl::SetWarningEnabled( sal_Bool bSet )
     }
 }
 
-sal_Bool SvtSecurityOptions_Impl::IsConfirmationEnabled() const
-{
-    return m_bConfirmation;
-}
 
-void SvtSecurityOptions_Impl::SetConfirmationEnabled( sal_Bool bSet )
+void SvtSecurityOptions_Impl::SetConfirmationEnabled( bool bSet )
 {
     DBG_ASSERT(!m_bROConfirmation, "SvtSecurityOptions_Impl::SetConfirmationEnabled()\nYou tried to write on a readonly value!\n");
     if (!m_bROConfirmation && m_bConfirmation!=bSet)
@@ -1205,38 +1144,37 @@ void SvtSecurityOptions_Impl::SetConfirmationEnabled( sal_Bool bSet )
     }
 }
 
-
-sal_Bool SvtSecurityOptions::IsExecutePlugins() const
+bool SvtSecurityOptions::IsExecutePlugins() const
 {
     MutexGuard aGuard( GetInitMutex() );
     return m_pDataContainer->IsExecutePlugins();
 }
 
-void SvtSecurityOptions::SetExecutePlugins( sal_Bool bSet )
+void SvtSecurityOptions::SetExecutePlugins( bool bSet )
 {
     MutexGuard aGuard( GetInitMutex() );
     m_pDataContainer->SetExecutePlugins( bSet );
 }
 
-sal_Bool SvtSecurityOptions::IsWarningEnabled() const
+bool SvtSecurityOptions::IsWarningEnabled() const
 {
     MutexGuard aGuard( GetInitMutex() );
     return m_pDataContainer->IsWarningEnabled();
 }
 
-void SvtSecurityOptions::SetWarningEnabled( sal_Bool bSet )
+void SvtSecurityOptions::SetWarningEnabled( bool bSet )
 {
     MutexGuard aGuard( GetInitMutex() );
     m_pDataContainer->SetWarningEnabled( bSet );
 }
 
-sal_Bool SvtSecurityOptions::IsConfirmationEnabled() const
+bool SvtSecurityOptions::IsConfirmationEnabled() const
 {
     MutexGuard aGuard( GetInitMutex() );
     return m_pDataContainer->IsConfirmationEnabled();
 }
 
-void SvtSecurityOptions::SetConfirmationEnabled( sal_Bool bSet )
+void SvtSecurityOptions::SetConfirmationEnabled( bool bSet )
 {
     MutexGuard aGuard( GetInitMutex() );
     m_pDataContainer->SetConfirmationEnabled( bSet );
