@@ -17,12 +17,13 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <ucblockbytes.hxx>
 
 #include <sal/macros.h>
-#include <unotools/ucblockbytes.hxx>
 #include <comphelper/processfactory.hxx>
 #include <salhelper/condition.hxx>
 #include <osl/thread.hxx>
+#include <osl/diagnose.h>
 #include <tools/urlobj.hxx>
 #include <ucbhelper/interactionrequest.hxx>
 #include <com/sun/star/task/XInteractionAbort.hpp>
@@ -63,7 +64,6 @@ using namespace ::com::sun::star::task;
 using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::beans;
 
-
 namespace utl
 {
 
@@ -79,20 +79,17 @@ public:
                                 : m_xLockBytes( pLockBytes )
                             {}
 
-    SvLockBytes*            getLockBytes (void)
-                            { return m_xLockBytes; }
-
     // XActiveDataControl.
-    virtual void SAL_CALL   addListener ( const Reference<XStreamListener> &/*rxListener*/) throw(RuntimeException) {}
-    virtual void SAL_CALL   removeListener ( const Reference<XStreamListener> &/*rxListener*/) throw(RuntimeException) {}
-    virtual void SAL_CALL   start (void) throw(RuntimeException) {}
-    virtual void SAL_CALL   terminate (void) throw(RuntimeException)
+    virtual void SAL_CALL   addListener ( const Reference<XStreamListener> &/*rxListener*/) throw(RuntimeException, std::exception) SAL_OVERRIDE {}
+    virtual void SAL_CALL   removeListener ( const Reference<XStreamListener> &/*rxListener*/) throw(RuntimeException, std::exception) SAL_OVERRIDE {}
+    virtual void SAL_CALL   start() throw(RuntimeException, std::exception) SAL_OVERRIDE {}
+    virtual void SAL_CALL   terminate() throw(RuntimeException, std::exception) SAL_OVERRIDE
                             { m_xLockBytes->terminate_Impl(); }
 
     // XActiveDataSink.
-    virtual void SAL_CALL   setInputStream ( const Reference<XInputStream> &rxInputStream) throw(RuntimeException)
+    virtual void SAL_CALL   setInputStream ( const Reference<XInputStream> &rxInputStream) throw(RuntimeException, std::exception) SAL_OVERRIDE
                             { m_xLockBytes->setInputStream_Impl (rxInputStream); }
-    virtual Reference<XInputStream> SAL_CALL getInputStream (void) throw(RuntimeException)
+    virtual Reference<XInputStream> SAL_CALL getInputStream() throw(RuntimeException, std::exception) SAL_OVERRIDE
                             { return m_xLockBytes->getInputStream_Impl(); }
 };
 
@@ -110,16 +107,16 @@ public:
                             {}
 
     // XActiveDataControl.
-    virtual void SAL_CALL   addListener ( const Reference<XStreamListener> &/*rxListener*/) throw(RuntimeException) {}
-    virtual void SAL_CALL   removeListener ( const Reference<XStreamListener> &/*rxListener*/) throw(RuntimeException) {}
-    virtual void SAL_CALL   start (void) throw(RuntimeException) {}
-    virtual void SAL_CALL   terminate (void) throw(RuntimeException)
+    virtual void SAL_CALL   addListener ( const Reference<XStreamListener> &/*rxListener*/) throw(RuntimeException, std::exception) SAL_OVERRIDE {}
+    virtual void SAL_CALL   removeListener ( const Reference<XStreamListener> &/*rxListener*/) throw(RuntimeException, std::exception) SAL_OVERRIDE {}
+    virtual void SAL_CALL   start() throw(RuntimeException, std::exception) SAL_OVERRIDE {}
+    virtual void SAL_CALL   terminate() throw(RuntimeException, std::exception) SAL_OVERRIDE
                             { m_xLockBytes->terminate_Impl(); }
 
     // XActiveDataStreamer
-    virtual void SAL_CALL   setStream( const Reference< XStream >& aStream ) throw(RuntimeException)
+    virtual void SAL_CALL   setStream( const Reference< XStream >& aStream ) throw(RuntimeException, std::exception) SAL_OVERRIDE
                             { m_xStream = aStream; m_xLockBytes->setStream_Impl( aStream ); }
-    virtual Reference< XStream > SAL_CALL getStream() throw(RuntimeException)
+    virtual Reference< XStream > SAL_CALL getStream() throw(RuntimeException, std::exception) SAL_OVERRIDE
                             { return m_xStream; }
 };
 
@@ -128,16 +125,16 @@ public:
  */
 class ProgressHandler_Impl: public ::cppu::WeakImplHelper1< XProgressHandler >
 {
-    Link                    m_aProgress;
+    Link<>                  m_aProgress;
 
 public:
-                            ProgressHandler_Impl( const Link& rLink )
+                            ProgressHandler_Impl( const Link<>& rLink )
                                 : m_aProgress( rLink )
                             {}
     // XProgressHandler
-    virtual void SAL_CALL   push(const Any & /*rStatus*/) throw (RuntimeException) {}
-    virtual void SAL_CALL   pop() throw (RuntimeException) {}
-    virtual void SAL_CALL   update(const Any & /*rStatus*/) throw (RuntimeException)
+    virtual void SAL_CALL   push(const Any & /*rStatus*/) throw (RuntimeException, std::exception) SAL_OVERRIDE {}
+    virtual void SAL_CALL   pop() throw (RuntimeException, std::exception) SAL_OVERRIDE {}
+    virtual void SAL_CALL   update(const Any & /*rStatus*/) throw (RuntimeException, std::exception) SAL_OVERRIDE
                             { if ( m_aProgress.IsSet() ) m_aProgress.Call( 0 ); }
 };
 
@@ -156,14 +153,13 @@ public:
                                 , m_xProgressHandler( rxProgressHandler )
                             {}
 
-    virtual Reference<XInteractionHandler> SAL_CALL getInteractionHandler() throw (RuntimeException)
+    virtual Reference<XInteractionHandler> SAL_CALL getInteractionHandler() throw (RuntimeException, std::exception) SAL_OVERRIDE
     { return m_xInteractionHandler; }
 
-    virtual Reference<XProgressHandler> SAL_CALL    getProgressHandler() throw (RuntimeException)
+    virtual Reference<XProgressHandler> SAL_CALL    getProgressHandler() throw (RuntimeException, std::exception) SAL_OVERRIDE
     { return m_xProgressHandler; }
 };
 
-
 /**
     Helper class for property change notifies when executing UCB commands
 */
@@ -176,11 +172,11 @@ public:
                                 : m_xLockBytes( rRef )
                             {}
 
-    virtual void SAL_CALL   disposing ( const EventObject &/*rEvent*/) throw(RuntimeException) {}
-    virtual void SAL_CALL   propertiesChange ( const Sequence<PropertyChangeEvent> &rEvent) throw(RuntimeException);
+    virtual void SAL_CALL   disposing ( const EventObject &/*rEvent*/) throw(RuntimeException, std::exception) SAL_OVERRIDE {}
+    virtual void SAL_CALL   propertiesChange ( const Sequence<PropertyChangeEvent> &rEvent) throw(RuntimeException, std::exception) SAL_OVERRIDE;
 };
 
-void SAL_CALL UcbPropertiesChangeListener_Impl::propertiesChange ( const Sequence<PropertyChangeEvent> &rEvent) throw(RuntimeException)
+void SAL_CALL UcbPropertiesChangeListener_Impl::propertiesChange ( const Sequence<PropertyChangeEvent> &rEvent) throw(RuntimeException, std::exception)
 {
     sal_Int32 i, n = rEvent.getLength();
     for (i = 0; i < n; i++)
@@ -200,7 +196,7 @@ void SAL_CALL UcbPropertiesChangeListener_Impl::propertiesChange ( const Sequenc
                     if (aName.compareToIgnoreAsciiCaseAscii("Expires") == 0)
                     {
                         DateTime aExpires (0, 0);
-                        if (INetRFC822Message::ParseDateField (aValue, aExpires))
+                        if (INetMIMEMessage::ParseDateField (aValue, aExpires))
                         {
                             aExpires.ConvertToLocalTime();
                             m_xLockBytes->SetExpireDate_Impl( aExpires );
@@ -233,8 +229,6 @@ void SAL_CALL UcbPropertiesChangeListener_Impl::propertiesChange ( const Sequenc
     }
 }
 
-
-
 class Moderator
     : public osl::Thread
 {
@@ -255,8 +249,7 @@ public:
             RuntimeException
         );
 
-    ~Moderator();
-
+    virtual ~Moderator();
 
     enum ResultType {
         NORESULT,
@@ -279,7 +272,6 @@ public:
         GENERAL
     };
 
-
     class ConditionRes
         : public salhelper::Condition
     {
@@ -291,7 +283,7 @@ public:
         }
 
     protected:
-        bool applies() const {
+        bool applies() const SAL_OVERRIDE {
             return m_aModerator.m_aResultType != NORESULT;
         }
 
@@ -299,7 +291,6 @@ public:
         Moderator& m_aModerator;
     };
 
-
     struct Result {
         ResultType        type;
         Any               result;
@@ -326,7 +317,7 @@ public:
         }
 
     protected:
-        bool applies() const {
+        bool applies() const SAL_OVERRIDE {
             return m_aModerator.m_aReplyType != NOREPLY;
         }
 
@@ -344,10 +335,9 @@ public:
     void setStream(const Reference< XStream >& aStream);
     void setInputStream(const Reference<XInputStream> &rxInputStream);
 
-
 protected:
-    virtual void SAL_CALL run();
-    virtual void SAL_CALL onTerminated();
+    virtual void SAL_CALL run() SAL_OVERRIDE;
+    virtual void SAL_CALL onTerminated() SAL_OVERRIDE;
 
 private:
     osl::Mutex        m_aMutex;
@@ -368,7 +358,6 @@ private:
     ::ucbhelper::Content              m_aContent;
 };
 
-
 class ModeratorsActiveDataStreamer
     : public ::cppu::WeakImplHelper1<XActiveDataStreamer>
 {
@@ -376,7 +365,7 @@ public:
 
     ModeratorsActiveDataStreamer(Moderator &theModerator);
 
-    ~ModeratorsActiveDataStreamer();
+    virtual ~ModeratorsActiveDataStreamer();
 
     // XActiveDataStreamer
     virtual void SAL_CALL
@@ -384,21 +373,20 @@ public:
         const Reference< XStream >& aStream
     )
         throw(
-            RuntimeException
-        );
+            RuntimeException, std::exception
+        ) SAL_OVERRIDE;
 
     virtual Reference<XStream> SAL_CALL
     getStream (
         void
     ) throw(
-        RuntimeException
-    )
+        RuntimeException, std::exception
+    ) SAL_OVERRIDE
     {
         osl::MutexGuard aGuard(m_aMutex);
         return m_xStream;
     }
 
-
 private:
     Moderator& m_aModerator;
 
@@ -406,7 +394,6 @@ private:
     Reference<XStream> m_xStream;
 };
 
-
 class ModeratorsActiveDataSink
     : public ::cppu::WeakImplHelper1<XActiveDataSink>
 {
@@ -414,7 +401,7 @@ public:
 
     ModeratorsActiveDataSink(Moderator &theModerator);
 
-    ~ModeratorsActiveDataSink();
+    virtual ~ModeratorsActiveDataSink();
 
     // XActiveDataSink.
     virtual void SAL_CALL
@@ -422,35 +409,31 @@ public:
         const Reference<XInputStream> &rxInputStream
     )
         throw(
-            RuntimeException
-        );
+            RuntimeException, std::exception
+        ) SAL_OVERRIDE;
 
     virtual Reference<XInputStream> SAL_CALL
     getInputStream (
         void
     ) throw(
-        RuntimeException
-    )
+        RuntimeException, std::exception
+    ) SAL_OVERRIDE
     {
         osl::MutexGuard aGuard(m_aMutex);
         return m_xStream;
     }
 
-
 private:
     Moderator& m_aModerator;
     osl::Mutex m_aMutex;
     Reference<XInputStream> m_xStream;
 };
 
-
-
 ModeratorsActiveDataSink::ModeratorsActiveDataSink(Moderator &theModerator)
     : m_aModerator(theModerator)
 {
 }
 
-
 ModeratorsActiveDataSink::~ModeratorsActiveDataSink()
 {
 }
@@ -461,7 +444,7 @@ ModeratorsActiveDataSink::setInputStream (
     const Reference<XInputStream> &rxInputStream
 )
     throw(
-        RuntimeException
+        RuntimeException, std::exception
     )
 {
     m_aModerator.setInputStream(rxInputStream);
@@ -469,7 +452,6 @@ ModeratorsActiveDataSink::setInputStream (
     m_xStream = rxInputStream;
 }
 
-
 ModeratorsActiveDataStreamer::ModeratorsActiveDataStreamer(
     Moderator &theModerator
 )
@@ -477,7 +459,6 @@ ModeratorsActiveDataStreamer::ModeratorsActiveDataStreamer(
 {
 }
 
-
 ModeratorsActiveDataStreamer::~ModeratorsActiveDataStreamer()
 {
 }
@@ -488,7 +469,7 @@ ModeratorsActiveDataStreamer::setStream (
     const Reference<XStream> &rxStream
 )
     throw(
-        RuntimeException
+        RuntimeException, std::exception
     )
 {
     m_aModerator.setStream(rxStream);
@@ -496,8 +477,6 @@ ModeratorsActiveDataStreamer::setStream (
     m_xStream = rxStream;
 }
 
-
-
 class ModeratorsInteractionHandler
     : public ::cppu::WeakImplHelper1<XInteractionHandler>
 {
@@ -505,42 +484,39 @@ public:
 
     ModeratorsInteractionHandler(Moderator &theModerator);
 
-    ~ModeratorsInteractionHandler();
+    virtual ~ModeratorsInteractionHandler();
 
     virtual void SAL_CALL
     handle( const Reference<XInteractionRequest >& Request )
-        throw (RuntimeException);
+        throw (RuntimeException, std::exception) SAL_OVERRIDE;
 
 private:
 
     Moderator& m_aModerator;
 };
 
-
 class ModeratorsProgressHandler
     : public ::cppu::WeakImplHelper1<XProgressHandler>
 {
 public:
     ModeratorsProgressHandler(Moderator &theModerator);
 
-    ~ModeratorsProgressHandler();
+    virtual ~ModeratorsProgressHandler();
 
     virtual void SAL_CALL push( const Any& Status )
         throw (
-            RuntimeException);
+            RuntimeException, std::exception) SAL_OVERRIDE;
 
     virtual void SAL_CALL update( const Any& Status )
-        throw (RuntimeException);
+        throw (RuntimeException, std::exception) SAL_OVERRIDE;
 
     virtual void SAL_CALL pop(  )
-        throw (RuntimeException);
-
+        throw (RuntimeException, std::exception) SAL_OVERRIDE;
 
 private:
     Moderator& m_aModerator;
 };
 
-
 ModeratorsProgressHandler::ModeratorsProgressHandler(Moderator &theModerator)
     : m_aModerator(theModerator)
 {
@@ -550,56 +526,47 @@ ModeratorsProgressHandler::~ModeratorsProgressHandler()
 {
 }
 
-
 void SAL_CALL ModeratorsProgressHandler::push( const Any& Status )
     throw (
-        RuntimeException)
+        RuntimeException, std::exception)
 {
     m_aModerator.push(Status);
 }
 
-
 void SAL_CALL ModeratorsProgressHandler::update( const Any& Status )
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     m_aModerator.update(Status);
 }
 
-
 void SAL_CALL ModeratorsProgressHandler::pop(  )
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     m_aModerator.pop();
 }
 
-
 ModeratorsInteractionHandler::ModeratorsInteractionHandler(
     Moderator &aModerator)
     : m_aModerator(aModerator)
 {
 }
 
-
 ModeratorsInteractionHandler::~ModeratorsInteractionHandler()
 {
 }
 
-
 void SAL_CALL
 ModeratorsInteractionHandler::handle(
     const Reference<XInteractionRequest >& Request
 )
     throw (
-        RuntimeException
+        RuntimeException, std::exception
     )
 {
     // wakes up the mainthread
     m_aModerator.handle(Request);
 }
 
-
-
-
 Moderator::Moderator(
     Reference < XContent >& xContent,
     Reference < XInteractionHandler >& xInteract,
@@ -665,12 +632,10 @@ Moderator::Moderator(
         m_aArg.Argument <<= aOpenArg;
 }
 
-
 Moderator::~Moderator()
 {
 }
 
-
 Moderator::Result Moderator::getResult(const sal_uInt32 milliSec)
 {
     Result ret;
@@ -691,14 +656,12 @@ Moderator::Result Moderator::getResult(const sal_uInt32 milliSec)
     return ret;
 }
 
-
 void Moderator::setReply(ReplyType aReplyType )
 {
     salhelper::ConditionModifier aMod(m_aRep);
     m_aReplyType = aReplyType;
 }
 
-
 void Moderator::handle( const Reference<XInteractionRequest >& Request )
 {
     ReplyType aReplyType;
@@ -735,7 +698,6 @@ void Moderator::handle( const Reference<XInteractionRequest >& Request )
     } while(aReplyType != REQUESTHANDLED);
 }
 
-
 void Moderator::push( const Any& Status )
 {
     {
@@ -753,7 +715,6 @@ void Moderator::push( const Any& Status )
         setReply(EXIT);
 }
 
-
 void Moderator::update( const Any& Status )
 {
     {
@@ -771,7 +732,6 @@ void Moderator::update( const Any& Status )
         setReply(EXIT);
 }
 
-
 void Moderator::pop(  )
 {
     {
@@ -788,7 +748,6 @@ void Moderator::pop(  )
         setReply(EXIT);
 }
 
-
 void Moderator::setStream(const Reference< XStream >& aStream)
 {
     {
@@ -806,7 +765,6 @@ void Moderator::setStream(const Reference< XStream >& aStream)
         setReply(EXIT);
 }
 
-
 void Moderator::setInputStream(const Reference<XInputStream> &rxInputStream)
 {
     {
@@ -824,9 +782,10 @@ void Moderator::setInputStream(const Reference<XInputStream> &rxInputStream)
         setReply(EXIT);
 }
 
-
 void SAL_CALL Moderator::run()
 {
+    osl_setThreadName("utl::Moderator");
+
     ResultType aResultType;
     Any        aResult;
     sal_Int32  nIOErrorCode = 0;
@@ -884,9 +843,7 @@ static bool _UCBOpenContentSync(
     const Command& rArg,
     Reference < XInterface > xSink,
     Reference < XInteractionHandler > xInteract,
-    Reference < XProgressHandler > xProgress,
-    UcbLockBytesHandlerRef xHandler );
-
+    Reference < XProgressHandler > xProgress );
 
 static bool UCBOpenContentSync(
     UcbLockBytesRef xLockBytes,
@@ -894,8 +851,7 @@ static bool UCBOpenContentSync(
     const Command& rArg,
     Reference < XInterface > xSink,
     Reference < XInteractionHandler > xInteract,
-    Reference < XProgressHandler > xProgress,
-    UcbLockBytesHandlerRef xHandler )
+    Reference < XProgressHandler > xProgress )
 {
     // http protocol must be handled in a special way:
     //        during the opening process the input stream may change
@@ -915,10 +871,10 @@ static bool UCBOpenContentSync(
         ! aScheme.equalsIgnoreAsciiCase("vnd.sun.star.webdav") &&
         ! aScheme.equalsIgnoreAsciiCase("ftp"))
         return _UCBOpenContentSync(
-            xLockBytes,xContent,rArg,xSink,xInteract,xProgress,xHandler);
+            xLockBytes,xContent,rArg,xSink,xInteract,xProgress);
 
-    if ( (aScheme.compareToAscii( "http" ) != 0) ||
-         (aScheme.compareToAscii( "https" ) != 0) )
+    if ( !aScheme.equalsIgnoreAsciiCase( "http" ) &&
+         !aScheme.equalsIgnoreAsciiCase( "https" ) )
         xLockBytes->SetStreamValid_Impl();
 
     Reference< XPropertiesChangeListener > xListener;
@@ -1015,8 +971,7 @@ static bool UCBOpenContentSync(
                         OUString() );
                     aExcep.Server = aURL.GetHost();
                     aExcep.Classification = InteractionClassification_ERROR;
-                    aExcep.Message =
-                        OUString( "server not responding after five seconds");
+                    aExcep.Message = "server not responding after five seconds";
                     Any request;
                     request <<= aExcep;
                     ucbhelper::InteractionRequest *ir =
@@ -1110,9 +1065,6 @@ static bool UCBOpenContentSync(
 
     if ( bAborted || bException )
     {
-        if( xHandler.Is() )
-            xHandler->Handle( UcbLockBytesHandler::CANCEL, xLockBytes );
-
         Reference < XActiveDataSink > xActiveSink( xSink, UNO_QUERY );
         if ( xActiveSink.is() )
             xActiveSink->setInputStream( Reference < XInputStream >() );
@@ -1143,8 +1095,7 @@ static bool _UCBOpenContentSync(
     const Command& rArg,
     Reference < XInterface > xSink,
     Reference < XInteractionHandler > xInteract,
-    Reference < XProgressHandler > xProgress,
-    UcbLockBytesHandlerRef xHandler )
+    Reference < XProgressHandler > xProgress )
 {
     ::ucbhelper::Content aContent(
         xContent, new UcbTaskEnvironment( xInteract, xProgress ),
@@ -1154,7 +1105,7 @@ static bool _UCBOpenContentSync(
 
     // http protocol must be handled in a special way: during the opening process the input stream may change
     // only the last inputstream after notifying the document headers is valid
-    if ( aScheme.compareToAscii("http") != 0 )
+    if ( !aScheme.equalsIgnoreAsciiCase("http") )
         xLockBytes->SetStreamValid_Impl();
 
     Reference< XPropertiesChangeListener > xListener = new UcbPropertiesChangeListener_Impl( xLockBytes );
@@ -1205,9 +1156,6 @@ static bool _UCBOpenContentSync(
 
     if ( bAborted || bException )
     {
-        if( xHandler.Is() )
-            xHandler->Handle( UcbLockBytesHandler::CANCEL, xLockBytes );
-
         Reference < XActiveDataSink > xActiveSink( xSink, UNO_QUERY );
         if ( xActiveSink.is() )
             xActiveSink->setInputStream( Reference < XInputStream >() );
@@ -1221,14 +1169,12 @@ static bool _UCBOpenContentSync(
     if ( xControl.is() )
         xControl->terminate();
 
-
     if ( xProps.is() )
         xProps->removePropertiesChangeListener( Sequence< OUString >(), xListener );
 
     return ( bAborted || bException );
 }
 
-//----------------------------------------------------------------------------
 UcbLockBytes::UcbLockBytes( UcbLockBytesHandler* pHandler )
     : m_aExpireDate( DateTime::EMPTY )
     , m_xInputStream (NULL)
@@ -1242,7 +1188,6 @@ UcbLockBytes::UcbLockBytes( UcbLockBytesHandler* pHandler )
     SetSynchronMode( true );
 }
 
-//----------------------------------------------------------------------------
 UcbLockBytes::~UcbLockBytes()
 {
     if ( !m_bDontClose )
@@ -1284,8 +1229,6 @@ Reference < XInputStream > UcbLockBytes::getInputStream()
     return m_xInputStream;
 }
 
-//----------------------------------------------------------------------------
-
 bool UcbLockBytes::setStream_Impl( const Reference<XStream>& aStream )
 {
     osl::MutexGuard aGuard( m_aMutex );
@@ -1350,7 +1293,6 @@ void UcbLockBytes::SetStreamValid_Impl()
         m_aInitialized.set();
 }
 
-//----------------------------------------------------------------------------
 void UcbLockBytes::terminate_Impl()
 {
     m_bTerminated = true;
@@ -1362,19 +1304,15 @@ void UcbLockBytes::terminate_Impl()
         OSL_FAIL("No InputStream, but no error set!" );
         SetError( ERRCODE_IO_NOTEXISTS );
     }
-
-    if ( m_xHandler.Is() )
-        m_xHandler->Handle( UcbLockBytesHandler::DONE, this );
 }
 
-//----------------------------------------------------------------------------
 void UcbLockBytes::SetSynchronMode (bool bSynchron)
 {
     SvLockBytes::SetSynchronMode (bSynchron);
 }
 
-//----------------------------------------------------------------------------
-ErrCode UcbLockBytes::ReadAt ( sal_uLong nPos, void *pBuffer, sal_uLong nCount, sal_uLong *pRead) const
+ErrCode UcbLockBytes::ReadAt(sal_uInt64 const nPos,
+        void *pBuffer, sal_uLong nCount, sal_uLong *pRead) const
 {
     if ( IsSynchronMode() )
     {
@@ -1441,8 +1379,8 @@ ErrCode UcbLockBytes::ReadAt ( sal_uLong nPos, void *pBuffer, sal_uLong nCount,
     return ERRCODE_NONE;
 }
 
-//----------------------------------------------------------------------------
-ErrCode UcbLockBytes::WriteAt ( sal_uLong nPos, const void *pBuffer, sal_uLong nCount, sal_uLong *pWritten)
+ErrCode UcbLockBytes::WriteAt(sal_uInt64 const nPos, const void *pBuffer,
+        sal_uLong nCount, sal_uLong *pWritten)
 {
     if ( pWritten )
         *pWritten = 0;
@@ -1464,7 +1402,7 @@ ErrCode UcbLockBytes::WriteAt ( sal_uLong nPos, const void *pBuffer, sal_uLong n
         return ERRCODE_IO_CANTSEEK;
     }
 
-    sal_Int8* pData = (sal_Int8*) pBuffer;
+    sal_Int8 const * pData = static_cast<sal_Int8 const *>(pBuffer);
     Sequence<sal_Int8> aData( pData, nCount );
     try
     {
@@ -1480,7 +1418,6 @@ ErrCode UcbLockBytes::WriteAt ( sal_uLong nPos, const void *pBuffer, sal_uLong n
     return ERRCODE_NONE;
 }
 
-//----------------------------------------------------------------------------
 ErrCode UcbLockBytes::Flush() const
 {
     Reference <XOutputStream > xOutputStream = getOutputStream_Impl();
@@ -1499,8 +1436,7 @@ ErrCode UcbLockBytes::Flush() const
     return ERRCODE_NONE;
 }
 
-//----------------------------------------------------------------------------
-ErrCode UcbLockBytes::SetSize (sal_uLong nNewSize)
+ErrCode UcbLockBytes::SetSize (sal_uInt64 const nNewSize)
 {
     SvLockBytesStat aStat;
     Stat( &aStat, (SvLockBytesStatFlag) 0 );
@@ -1533,7 +1469,6 @@ ErrCode UcbLockBytes::SetSize (sal_uLong nNewSize)
     return ERRCODE_NONE;
 }
 
-//----------------------------------------------------------------------------
 ErrCode UcbLockBytes::Stat( SvLockBytesStat *pStat, SvLockBytesStatFlag) const
 {
     if ( IsSynchronMode() )
@@ -1570,12 +1505,8 @@ ErrCode UcbLockBytes::Stat( SvLockBytesStat *pStat, SvLockBytesStatFlag) const
     return ERRCODE_NONE;
 }
 
-//----------------------------------------------------------------------------
-IMPL_LINK_NOARG(UcbLockBytes, DataAvailHdl)
+IMPL_STATIC_LINK_NOARG(UcbLockBytes, DataAvailHdl)
 {
-    if ( hasInputStream_Impl() && m_xHandler.Is() )
-        m_xHandler->Handle( UcbLockBytesHandler::DATA_AVAILABLE, this );
-
     return 0;
 }
 
@@ -1584,7 +1515,7 @@ UcbLockBytesRef UcbLockBytes::CreateInputLockBytes( const Reference< XInputStrea
     if( !xInputStream.is() )
         return NULL;
 
-    UcbLockBytesRef xLockBytes = new UcbLockBytes();
+    UcbLockBytesRef xLockBytes = new UcbLockBytes(nullptr);
     xLockBytes->setDontClose_Impl();
     xLockBytes->setInputStream_Impl( xInputStream );
     xLockBytes->terminate_Impl();
@@ -1596,7 +1527,7 @@ UcbLockBytesRef UcbLockBytes::CreateLockBytes( const Reference< XStream >& xStre
     if( !xStream.is() )
         return NULL;
 
-    UcbLockBytesRef xLockBytes = new UcbLockBytes();
+    UcbLockBytesRef xLockBytes = new UcbLockBytes(nullptr);
     xLockBytes->setDontClose_Impl();
     xLockBytes->setStream_Impl( xStream );
     xLockBytes->terminate_Impl();
@@ -1612,7 +1543,7 @@ UcbLockBytesRef UcbLockBytes::CreateLockBytes( const Reference < XContent >& xCo
     UcbLockBytesRef xLockBytes = new UcbLockBytes( pHandler );
     xLockBytes->SetSynchronMode( !pHandler );
     Reference< XActiveDataControl > xSink;
-    if ( eOpenMode & STREAM_WRITE )
+    if ( eOpenMode & StreamMode::WRITE )
         xSink = (XActiveDataControl*) new UcbStreamer_Impl( xLockBytes );
     else
         xSink = (XActiveDataControl*) new UcbDataSink_Impl( xLockBytes );
@@ -1642,8 +1573,7 @@ UcbLockBytesRef UcbLockBytes::CreateLockBytes( const Reference < XContent >& xCo
                                       aCommand,
                                       xSink,
                                       xInteractionHandler,
-                                      xProgressHdl,
-                                      pHandler );
+                                      xProgressHdl );
 
     if ( xLockBytes->GetError() == ERRCODE_NONE && ( bError || !xLockBytes->getInputStream().is() ) )
     {
