@@ -33,7 +33,7 @@
 #include <com/sun/star/document/XEmbeddedScripts.hpp>
 #include <com/sun/star/awt/XWindow2.hpp>
 
-#include <boost/unordered_map.hpp>
+#include <boost/noncopyable.hpp>
 #include <filter/msfilter/msvbahelper.hxx>
 #include <tools/datetime.hxx>
 
@@ -46,6 +46,8 @@
 
 #include "vbacommandbars.hxx"
 
+#include <unordered_map>
+
 using namespace ::com::sun::star;
 using namespace ::ooo::vba;
 
@@ -55,16 +57,12 @@ using namespace ::ooo::vba;
 typedef ::std::pair< OUString, ::std::pair< double, double > > VbaTimerInfo;
 
 // ====VbaTimer==================================
-class VbaTimer
+class VbaTimer: private boost::noncopyable
 {
     Timer m_aTimer;
     VbaTimerInfo m_aTimerInfo;
     ::rtl::Reference< VbaApplicationBase > m_xBase;
 
-    // the following declarations are here to prevent the usage of them
-    VbaTimer( const VbaTimer& );
-    VbaTimer& operator=( const VbaTimer& );
-
 public:
     VbaTimer()
     {}
@@ -77,7 +75,7 @@ public:
     static double GetNow()
     {
         Date aDateNow( Date::SYSTEM );
-        Time aTimeNow( Time::SYSTEM );
+        tools::Time aTimeNow( tools::Time::SYSTEM );
          Date aRefDate( 1,1,1900 );
         long nDiffDays = (long)(aDateNow - aRefDate);
         nDiffDays += 2; // Change VisualBasic: 1.Jan.1900 == 2
@@ -97,10 +95,10 @@ public:
         return (sal_Int32) nResult;
     }
 
-    void Start( const ::rtl::Reference< VbaApplicationBase > xBase, const OUString& aFunction, double nFrom, double nTo )
+    void Start( const ::rtl::Reference< VbaApplicationBase >& xBase, const OUString& aFunction, double nFrom, double nTo )
     {
         if ( !xBase.is() || aFunction.isEmpty() )
-            throw uno::RuntimeException( "Unexpected arguments!" , uno::Reference< uno::XInterface >() );
+            throw uno::RuntimeException( "Unexpected arguments!" );
 
         m_xBase = xBase;
         m_aTimerInfo = VbaTimerInfo( aFunction, ::std::pair< double, double >( nFrom, nTo ) );
@@ -109,10 +107,10 @@ public:
         m_aTimer.Start();
     }
 
-    DECL_LINK( MacroCallHdl, void* );
+    DECL_LINK_TYPED( MacroCallHdl, Timer*, void );
 };
 
-IMPL_LINK_NOARG(VbaTimer, MacroCallHdl)
+IMPL_LINK_NOARG_TYPED(VbaTimer, MacroCallHdl, Timer *, void)
 {
     if ( m_aTimerInfo.second.second == 0 || GetNow() < m_aTimerInfo.second.second )
     {
@@ -131,8 +129,6 @@ IMPL_LINK_NOARG(VbaTimer, MacroCallHdl)
         m_xBase->OnTime( uno::makeAny( m_aTimerInfo.second.first ), m_aTimerInfo.first, uno::makeAny( m_aTimerInfo.second.second ), uno::makeAny( sal_False ) );
     } catch( uno::Exception& )
     {}
-
-    return 0;
 }
 
 // ====VbaTimerInfoHash==================================
@@ -141,21 +137,21 @@ struct VbaTimerInfoHash
     size_t operator()( const VbaTimerInfo& rTimerInfo ) const
     {
         return (size_t)rTimerInfo.first.hashCode()
-             + (size_t)rtl_str_hashCode_WithLength( (char*)&rTimerInfo.second.first, sizeof( double ) )
-             + (size_t)rtl_str_hashCode_WithLength( (char*)&rTimerInfo.second.second, sizeof( double ) );
+             + (size_t)rtl_str_hashCode_WithLength( reinterpret_cast<char const *>(&rTimerInfo.second.first), sizeof( double ) )
+             + (size_t)rtl_str_hashCode_WithLength( reinterpret_cast<char const *>(&rTimerInfo.second.second), sizeof( double ) );
     }
 };
 
 // ====VbaTimerHashMap==================================
-typedef ::boost::unordered_map< VbaTimerInfo, VbaTimer*, VbaTimerInfoHash, ::std::equal_to< VbaTimerInfo > > VbaTimerHashMap;
+typedef std::unordered_map< VbaTimerInfo, VbaTimer*, VbaTimerInfoHash, std::equal_to< VbaTimerInfo > > VbaTimerHashMap;
 
 // ====VbaApplicationBase_Impl==================================
 struct VbaApplicationBase_Impl
 {
     VbaTimerHashMap m_aTimerHash;
-    sal_Bool mbVisible;
+    bool mbVisible;
 
-    inline VbaApplicationBase_Impl() : mbVisible( sal_True ) {}
+    inline VbaApplicationBase_Impl() : mbVisible( true ) {}
 
     virtual ~VbaApplicationBase_Impl()
     {
@@ -183,14 +179,14 @@ VbaApplicationBase::~VbaApplicationBase()
 }
 
 sal_Bool SAL_CALL
-VbaApplicationBase::getScreenUpdating() throw (uno::RuntimeException)
+VbaApplicationBase::getScreenUpdating() throw (uno::RuntimeException, std::exception)
 {
     uno::Reference< frame::XModel > xModel( getCurrentDocument(), uno::UNO_QUERY_THROW );
     return !xModel->hasControllersLocked();
 }
 
 void SAL_CALL
-VbaApplicationBase::setScreenUpdating(sal_Bool bUpdate) throw (uno::RuntimeException)
+VbaApplicationBase::setScreenUpdating(sal_Bool bUpdate) throw (uno::RuntimeException, std::exception)
 {
     uno::Reference< frame::XModel > xModel( getCurrentDocument(), uno::UNO_QUERY_THROW );
     // #163808# use helper from module "basic" to lock all documents of this application
@@ -198,7 +194,7 @@ VbaApplicationBase::setScreenUpdating(sal_Bool bUpdate) throw (uno::RuntimeExcep
 }
 
 sal_Bool SAL_CALL
-VbaApplicationBase::getDisplayStatusBar() throw (uno::RuntimeException)
+VbaApplicationBase::getDisplayStatusBar() throw (uno::RuntimeException, std::exception)
 {
     uno::Reference< frame::XModel > xModel( getCurrentDocument(), uno::UNO_QUERY_THROW );
     uno::Reference< frame::XFrame > xFrame( xModel->getCurrentController()->getFrame(), uno::UNO_QUERY_THROW );
@@ -215,7 +211,7 @@ VbaApplicationBase::getDisplayStatusBar() throw (uno::RuntimeException)
 }
 
 void SAL_CALL
-VbaApplicationBase::setDisplayStatusBar(sal_Bool bDisplayStatusBar) throw (uno::RuntimeException)
+VbaApplicationBase::setDisplayStatusBar(sal_Bool bDisplayStatusBar) throw (uno::RuntimeException, std::exception)
 {
     uno::Reference< frame::XModel > xModel( getCurrentDocument(), uno::UNO_QUERY_THROW );
     uno::Reference< frame::XFrame > xFrame( xModel->getCurrentController()->getFrame(), uno::UNO_QUERY_THROW );
@@ -239,8 +235,8 @@ VbaApplicationBase::setDisplayStatusBar(sal_Bool bDisplayStatusBar) throw (uno::
     return;
 }
 
-::sal_Bool SAL_CALL VbaApplicationBase::getInteractive()
-    throw (uno::RuntimeException)
+sal_Bool SAL_CALL VbaApplicationBase::getInteractive()
+    throw (uno::RuntimeException, std::exception)
 {
     uno::Reference< frame::XModel > xModel( getCurrentDocument(), uno::UNO_QUERY_THROW );
     uno::Reference< frame::XFrame > xFrame( xModel->getCurrentController()->getFrame(), uno::UNO_QUERY_THROW );
@@ -249,27 +245,27 @@ VbaApplicationBase::setDisplayStatusBar(sal_Bool bDisplayStatusBar) throw (uno::
     return xWindow->isEnabled();
 }
 
-void SAL_CALL VbaApplicationBase::setInteractive( ::sal_Bool bInteractive )
-    throw (uno::RuntimeException)
+void SAL_CALL VbaApplicationBase::setInteractive( sal_Bool bInteractive )
+    throw (uno::RuntimeException, std::exception)
 {
     uno::Reference< frame::XModel > xModel( getCurrentDocument(), uno::UNO_QUERY_THROW );
     // #163808# use helper from module "basic" to enable/disable all container windows of all documents of this application
     ::basic::vba::enableContainerWindowsOfAllDocuments( xModel, bInteractive );
 }
 
-sal_Bool SAL_CALL VbaApplicationBase::getVisible() throw (uno::RuntimeException)
+sal_Bool SAL_CALL VbaApplicationBase::getVisible() throw (uno::RuntimeException, std::exception)
 {
     return m_pImpl->mbVisible;    // dummy implementation
 }
 
-void SAL_CALL VbaApplicationBase::setVisible( sal_Bool bVisible ) throw (uno::RuntimeException)
+void SAL_CALL VbaApplicationBase::setVisible( sal_Bool bVisible ) throw (uno::RuntimeException, std::exception)
 {
     m_pImpl->mbVisible = bVisible;  // dummy implementation
 }
 
 
 void SAL_CALL
-VbaApplicationBase::OnKey( const OUString& Key, const uno::Any& Procedure ) throw (uno::RuntimeException)
+VbaApplicationBase::OnKey( const OUString& Key, const uno::Any& Procedure ) throw (uno::RuntimeException, std::exception)
 {
     // parse the Key & modifiers
     awt::KeyEvent aKeyEvent = parseKeyEvent( Key );
@@ -291,21 +287,21 @@ VbaApplicationBase::OnKey( const OUString& Key, const uno::Any& Procedure ) thro
 }
 
 uno::Any SAL_CALL
-VbaApplicationBase::CommandBars( const uno::Any& aIndex ) throw (uno::RuntimeException)
+VbaApplicationBase::CommandBars( const uno::Any& aIndex ) throw (uno::RuntimeException, std::exception)
 {
     uno::Reference< XCommandBars > xCommandBars( new ScVbaCommandBars( this, mxContext, uno::Reference< container::XIndexAccess >(), getCurrentDocument() ) );
     if( aIndex.hasValue() )
-        return uno::makeAny( xCommandBars->Item( aIndex, uno::Any() ) );
+        return xCommandBars->Item( aIndex, uno::Any() );
     return uno::makeAny( xCommandBars );
 }
 
 OUString SAL_CALL
-VbaApplicationBase::getVersion() throw (uno::RuntimeException)
+VbaApplicationBase::getVersion() throw (uno::RuntimeException, std::exception)
 {
     return OUString(OFFICEVERSION);
 }
 
-uno::Any SAL_CALL VbaApplicationBase::Run( const OUString& MacroName, const uno::Any& varg1, const uno::Any& varg2, const uno::Any& varg3, const uno::Any& varg4, const uno::Any& varg5, const uno::Any& varg6, const uno::Any& varg7, const uno::Any& varg8, const uno::Any& varg9, const uno::Any& varg10, const uno::Any& varg11, const uno::Any& varg12, const uno::Any& varg13, const uno::Any& varg14, const uno::Any& varg15, const uno::Any& varg16, const uno::Any& varg17, const uno::Any& varg18, const uno::Any& varg19, const uno::Any& varg20, const uno::Any& varg21, const uno::Any& varg22, const uno::Any& varg23, const uno::Any& varg24, const uno::Any& varg25, const uno::Any& varg26, const uno::Any& varg27, const uno::Any& varg28, const uno::Any& varg29, const uno::Any& varg30 ) throw (uno::RuntimeException)
+uno::Any SAL_CALL VbaApplicationBase::Run( const OUString& MacroName, const uno::Any& varg1, const uno::Any& varg2, const uno::Any& varg3, const uno::Any& varg4, const uno::Any& varg5, const uno::Any& varg6, const uno::Any& varg7, const uno::Any& varg8, const uno::Any& varg9, const uno::Any& varg10, const uno::Any& varg11, const uno::Any& varg12, const uno::Any& varg13, const uno::Any& varg14, const uno::Any& varg15, const uno::Any& varg16, const uno::Any& varg17, const uno::Any& varg18, const uno::Any& varg19, const uno::Any& varg20, const uno::Any& varg21, const uno::Any& varg22, const uno::Any& varg23, const uno::Any& varg24, const uno::Any& varg25, const uno::Any& varg26, const uno::Any& varg27, const uno::Any& varg28, const uno::Any& varg29, const uno::Any& varg30 ) throw (uno::RuntimeException, std::exception)
 {
     OUString aMacroName = MacroName.trim();
     if( aMacroName.startsWith("!") )
@@ -351,23 +347,23 @@ uno::Any SAL_CALL VbaApplicationBase::Run( const OUString& MacroName, const uno:
     }
     else
     {
-        throw uno::RuntimeException( "The macro doesn't exist" , uno::Reference< uno::XInterface >() );
+        throw uno::RuntimeException( "The macro doesn't exist" );
     }
 }
 
 void SAL_CALL VbaApplicationBase::OnTime( const uno::Any& aEarliestTime, const OUString& aFunction, const uno::Any& aLatestTime, const uno::Any& aSchedule )
-    throw ( uno::RuntimeException )
+    throw ( uno::RuntimeException, std::exception )
 {
     if ( aFunction.isEmpty() )
-        throw uno::RuntimeException( "Unexpected function name!" , uno::Reference< uno::XInterface >() );
+        throw uno::RuntimeException( "Unexpected function name!" );
 
     double nEarliestTime = 0;
     double nLatestTime = 0;
     if ( !( aEarliestTime >>= nEarliestTime )
       || ( aLatestTime.hasValue() && !( aLatestTime >>= nLatestTime ) ) )
-        throw uno::RuntimeException( "Only double is supported as time for now!" , uno::Reference< uno::XInterface >() );
+        throw uno::RuntimeException( "Only double is supported as time for now!" );
 
-    sal_Bool bSetTimer = sal_True;
+    bool bSetTimer = true;
     aSchedule >>= bSetTimer;
 
     VbaTimerInfo aTimerIndex( aFunction, ::std::pair< double, double >( nEarliestTime, nLatestTime ) );
@@ -388,14 +384,14 @@ void SAL_CALL VbaApplicationBase::OnTime( const uno::Any& aEarliestTime, const O
     }
 }
 
-float SAL_CALL VbaApplicationBase::CentimetersToPoints( float _Centimeters ) throw (uno::RuntimeException)
+float SAL_CALL VbaApplicationBase::CentimetersToPoints( float _Centimeters ) throw (uno::RuntimeException, std::exception)
 {
     // i cm = 28.35 points
     static const float rate = 28.35f;
     return ( _Centimeters * rate );
 }
 
-uno::Any SAL_CALL VbaApplicationBase::getVBE() throw (uno::RuntimeException)
+uno::Any SAL_CALL VbaApplicationBase::getVBE() throw (uno::RuntimeException, std::exception)
 {
     try // return empty object on error
     {
@@ -432,13 +428,13 @@ VbaApplicationBase::getServiceNames()
 }
 
 void SAL_CALL VbaApplicationBase::Undo()
-    throw (uno::RuntimeException)
+    throw (uno::RuntimeException, std::exception)
 {
     uno::Reference< frame::XModel > xModel( getCurrentDocument(), uno::UNO_QUERY_THROW );
     dispatchRequests( xModel, ".uno:Undo" );
 }
 
-void VbaApplicationBase::Quit() throw (uno::RuntimeException)
+void VbaApplicationBase::Quit() throw (uno::RuntimeException, std::exception)
 {
     // need to stop basic
     SbMethod* pMeth = StarBASIC::GetActiveMethod();
