@@ -14,19 +14,16 @@ class SvpSalData : public SalGenericData
 {
 public:
     SvpSalData( SalInstance *pInstance ) : SalGenericData( SAL_DATA_SVP, pInstance ) {}
-    virtual void ErrorTrapPush() {}
-    virtual bool ErrorTrapPop( bool ) { return false; }
+    virtual void ErrorTrapPush() SAL_OVERRIDE {}
+    virtual bool ErrorTrapPop( bool ) SAL_OVERRIDE { return false; }
 };
 
 // plugin factory function
-extern "C"
+SalInstance* svp_create_SalInstance()
 {
-    SAL_DLLPUBLIC_EXPORT SalInstance* create_SalInstance()
-    {
-        SvpSalInstance* pInstance = new SvpSalInstance( new SalYieldMutex() );
-        new SvpSalData( pInstance );
-        return pInstance;
-    }
+    SvpSalInstance* pInstance = new SvpSalInstance( new SalYieldMutex() );
+    new SvpSalData( pInstance );
+    return pInstance;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
