@@ -17,12 +17,11 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include <cstdio>
 #include <cstring>
 #include <assert.h>
 
-#include <fontsubset.hxx>
+#include "fontsubset.hxx"
 
 #include <vcl/strhelper.hxx>
 
@@ -39,8 +38,6 @@ typedef RealType ValType;
 #include <vector>
 typedef std::vector<ValType> ValVector;
 
-// ====================================================================
-
 static const char* pStringIds[] = {
 /*0*/   ".notdef",      "space",            "exclam",           "quotedbl",
     "numbersign",       "dollar",           "percent",          "ampersand",
@@ -142,10 +139,6 @@ static const char* pStringIds[] = {
     "Regular",          "Roman",            "Semibold"
 };
 
-// --------------------------------------------------------------------
-
-// --------------------------------------------------------------------
-
 // TOP DICT keywords (also covers PRIV DICT keywords)
 static const char* pDictOps[] = {
     "sVersion",         "sNotice",              "sFullName",        "sFamilyName",
@@ -158,8 +151,6 @@ static const char* pDictOps[] = {
     "shortint",         "longint",              "BCD",              NULL
 };
 
-// --------------------------------------------------------------------
-
 // TOP DICT escapes (also covers PRIV DICT escapes)
 static const char* pDictEscs[] = {
     "sCopyright",           "bIsFixedPitch",    "nItalicAngle",     "nUnderlinePosition",
@@ -174,8 +165,6 @@ static const char* pDictEscs[] = {
     "nFDArray",             "nFDSelect",        "sFontName"
 };
 
-// --------------------------------------------------------------------
-
 static const char* pType1Ops[] = {
     NULL,               "2hstem",           NULL,               "2vstem",
     "1vmoveto",         "Arlineto",         "1hlineto",         "1vlineto",
@@ -187,8 +176,6 @@ static const char* pType1Ops[] = {
     NULL,               NULL,               "4vhcurveto",       "4hvcurveto"
 };
 
-// --------------------------------------------------------------------
-
 static const char* pT1EscOps[] = {
     "0dotsection",      "6vstem3",          "6hstem3",          NULL,
     NULL,               NULL,               "5seac",            "4sbw",
@@ -201,8 +188,6 @@ static const char* pT1EscOps[] = {
     NULL,               "2setcurrentpoint"
 };
 
-// --------------------------------------------------------------------
-
 struct TYPE1OP
 {
     enum OPS
@@ -222,8 +207,6 @@ struct TYPE1OP
     };
 };
 
-// --------------------------------------------------------------------
-
 static const char* pType2Ops[] = {
     NULL,           "hhstem",       NULL,           "vvstem",
     "mvmoveto",     "Arlineto",     "Ehlineto",     "Evlineto",
@@ -235,8 +218,6 @@ static const char* pType2Ops[] = {
     ".shortint",    "Gcallgsubr",   ".vhcurveto",   ".hvcurveto"
 };
 
-// --------------------------------------------------------------------
-
 static const char* pT2EscOps[] = {
     NULL,       NULL,       NULL,       "2and",
     "2or",      "1not",     NULL,       NULL,
@@ -250,8 +231,6 @@ static const char* pT2EscOps[] = {
     "9hflex1",  "fflex1"
 };
 
-// --------------------------------------------------------------------
-
 struct TYPE2OP
 {
     enum OPS
@@ -276,8 +255,6 @@ struct TYPE2OP
     };
 };
 
-// ====================================================================
-
 struct CffGlobal
 {
     explicit CffGlobal();
@@ -306,8 +283,6 @@ struct CffGlobal
     int     mnFamilyNameSID;
 };
 
-// ====================================================================
-
 struct CffLocal
 {
     explicit CffLocal();
@@ -339,27 +314,8 @@ struct CffLocal
     bool        mbForceBold;
 };
 
-// ====================================================================
-
-class SubsetterContext
-{
-public:
-    virtual ~SubsetterContext( void);
-    virtual bool emitAsType1( class Type1Emitter&,
-                const long* pGlyphIDs, const U8* pEncoding,
-                GlyphWidth* pGlyphWidths, int nGlyphCount, FontSubsetInfo& ) = 0;
-};
-
-// --------------------------------------------------------------------
-
-SubsetterContext::~SubsetterContext( void)
-{}
-
-// ====================================================================
-
 class CffSubsetterContext
-:   public SubsetterContext
-,   private CffGlobal
+:   private CffGlobal
 {
 public:
     static const int NMAXSTACK = 48;    // see CFF.appendixB
@@ -367,23 +323,22 @@ public:
     static const int NMAXTRANS = 32;    // see CFF.appendixB
 public:
     explicit CffSubsetterContext( const U8* pBasePtr, int nBaseLen);
-    virtual ~CffSubsetterContext( void);
+    ~CffSubsetterContext();
 
     bool    initialCffRead();
     bool    emitAsType1( class Type1Emitter&,
-                const long* pGlyphIDs, const U8* pEncoding,
+                const sal_GlyphId* pGlyphIds, const U8* pEncoding,
                 GlyphWidth* pGlyphWidths, int nGlyphCount, FontSubsetInfo& );
 
     // used by charstring converter
     void    setCharStringType( int);
-    void    fakeLocalSubrCount( int nLocalSubrs ) { maCffLocal[0].mnLocalSubrCount=nLocalSubrs;}
 protected:
     int     convert2Type1Ops( CffLocal*, const U8* pType2Ops, int nType2Len, U8* pType1Ops);
 private:
-    void    convertOneTypeOp( void);
-    void    convertOneTypeEsc( void);
+    void    convertOneTypeOp();
+    void    convertOneTypeEsc();
     void    callType2Subr( bool bGlobal, int nSubrNumber);
-    long    getReadOfs( void) const { return (long)(mpReadPtr - mpBasePtr);}
+    sal_Int32 getReadOfs() const { return (sal_Int32)(mpReadPtr - mpBasePtr);}
 
     const U8* mpBasePtr;
     const U8* mpBaseEnd;
@@ -395,7 +350,7 @@ private:
     bool    mbSawError;
     bool    mbNeedClose;
     bool    mbIgnoreHints;
-    long    mnCntrMask;
+    sal_Int32 mnCntrMask;
 
 private:
     int     seekIndexData( int nIndexBase, int nDataIndex);
@@ -408,15 +363,14 @@ private:
     CffLocal    maCffLocal[256];
     CffLocal*   mpCffLocal;
 
-    void        readDictOp( void);
-    RealType    readRealVal( void);
+    void        readDictOp();
+    RealType    readRealVal();
     const char* getString( int nStringID);
     int         getFDSelect( int nGlyphIndex) const;
     int         getGlyphSID( int nGlyphIndex) const;
     const char* getGlyphName( int nGlyphIndex);
 
-    void    read2push( void);
-    void    pop2write( void);
+    void    read2push();
     void    writeType1Val( ValType);
     void    writeTypeOp( int nTypeOp);
     void    writeTypeEsc( int nTypeOp);
@@ -428,24 +382,18 @@ public: // TODO: is public really needed?
     // accessing the value stack
     // TODO: add more checks
     void    push( ValType nVal) { mnValStack[ mnStackIdx++] = nVal;}
-    ValType popVal( void) { return ((mnStackIdx>0) ? mnValStack[ --mnStackIdx] : 0);}
-    ValType peekVal( void) const { return ((mnStackIdx>0) ? mnValStack[ mnStackIdx-1] : 0);}
+    ValType popVal() { return ((mnStackIdx>0) ? mnValStack[ --mnStackIdx] : 0);}
     ValType getVal( int nIndex) const { return mnValStack[ nIndex];}
-    int     popInt( void);
-    int     peekInt( void) const;
-    int     getInt( int nIndex) const;
-    int     size( void) const { return mnStackIdx;}
-    bool    empty( void) const { return !mnStackIdx;}
-    void    clear( void) { mnStackIdx = 0;}
+    int     popInt();
+    int     size() const { return mnStackIdx;}
+    void    clear() { mnStackIdx = 0;}
 
     // accessing the charstring hints
     void    addHints( bool bVerticalHints);
-    int     getHorzHintCount( void) const { return (mnHorzHintSize/2);}
-    int     getVertHintCount( void) const { return (mnHintSize-mnHorzHintSize)/2;}
 
     // accessing other charstring specifics
-    bool    hasCharWidth( void) const { return (maCharWidth > 0);}
-    ValType getCharWidth( void) const { return maCharWidth;}
+    bool    hasCharWidth() const { return (maCharWidth > 0);}
+    ValType getCharWidth() const { return maCharWidth;}
     void    setNominalWidth( ValType aWidth) { mpCffLocal->maNominalWidth = aWidth;}
     void    setDefaultWidth( ValType aWidth) { mpCffLocal->maDefaultWidth = aWidth;}
     void    updateWidth( bool bUseFirstVal);
@@ -463,31 +411,34 @@ private:
     ValType maCharWidth;
 };
 
-// --------------------------------------------------------------------
-
 CffSubsetterContext::CffSubsetterContext( const U8* pBasePtr, int nBaseLen)
-:   mpBasePtr( pBasePtr)
-,   mpBaseEnd( pBasePtr+nBaseLen)
-,   mnStackIdx(0)
-,   mnHintSize(0)
-,   mnHorzHintSize(0)
-,   maCharWidth(-1)
+    : mpBasePtr( pBasePtr)
+    , mpBaseEnd( pBasePtr+nBaseLen)
+    , mpReadPtr(NULL)
+    , mpReadEnd(NULL)
+    , mpWritePtr(NULL)
+    , mbSawError(false)
+    , mbNeedClose(false)
+    , mbIgnoreHints(false)
+    , mnCntrMask(0)
+    , mpCharStringOps(NULL)
+    , mpCharStringEscs(NULL)
+    , mnStackIdx(0)
+    , mnHintSize(0)
+    , mnHorzHintSize(0)
+    , maCharWidth(-1)
 {
 //  setCharStringType( 1);
     // TODO: new CffLocal[ mnFDAryCount];
     mpCffLocal = &maCffLocal[0];
 }
 
-// --------------------------------------------------------------------
-
-CffSubsetterContext::~CffSubsetterContext( void)
+CffSubsetterContext::~CffSubsetterContext()
 {
     // TODO: delete[] maCffLocal;
 }
 
-// --------------------------------------------------------------------
-
-inline int CffSubsetterContext::popInt( void)
+inline int CffSubsetterContext::popInt()
 {
     const ValType aVal = popVal();
     const int nInt = static_cast<int>(aVal);
@@ -495,28 +446,6 @@ inline int CffSubsetterContext::popInt( void)
     return nInt;
 }
 
-// --------------------------------------------------------------------
-
-inline int CffSubsetterContext::peekInt( void) const
-{
-    const ValType aVal = peekVal();
-    const int nInt = static_cast<int>(aVal);
-    assert( nInt == aVal);
-    return nInt;
-}
-
-// --------------------------------------------------------------------
-
-inline int CffSubsetterContext::getInt( int nIndex) const
-{
-    const ValType aVal = getVal( nIndex);
-    const int nInt = static_cast<int>(aVal);
-    assert( nInt == aVal);
-    return nInt;
-}
-
-// --------------------------------------------------------------------
-
 inline void CffSubsetterContext::updateWidth( bool bUseFirstVal)
 {
 #if 1 // TODO: is this still needed?
@@ -535,8 +464,6 @@ inline void CffSubsetterContext::updateWidth( bool bUseFirstVal)
     }
 }
 
-// --------------------------------------------------------------------
-
 void CffSubsetterContext::addHints( bool bVerticalHints)
 {
     // the first charstring value may a charwidth instead of a charwidth
@@ -568,8 +495,6 @@ void CffSubsetterContext::addHints( bool bVerticalHints)
     mnStackIdx = 0;
 }
 
-// --------------------------------------------------------------------
-
 void CffSubsetterContext::setCharStringType( int nVal)
 {
     switch( nVal) {
@@ -579,9 +504,7 @@ void CffSubsetterContext::setCharStringType( int nVal)
     }
 }
 
-// --------------------------------------------------------------------
-
-void CffSubsetterContext::readDictOp( void)
+void CffSubsetterContext::readDictOp()
 {
     ValType nVal = 0;
     const U8 c = *mpReadPtr;
@@ -718,8 +641,6 @@ void CffSubsetterContext::readDictOp( void)
     }
 }
 
-// --------------------------------------------------------------------
-
 void CffSubsetterContext::read2push()
 {
     ValType aVal = 0;
@@ -752,23 +673,12 @@ void CffSubsetterContext::read2push()
     push( aVal);
 }
 
-// --------------------------------------------------------------------
-
 void CffSubsetterContext::writeType1Val( ValType aVal)
 {
     U8* pOut = mpWritePtr;
 
     int nInt = static_cast<int>(aVal);
-    static const int nOutCharstrType = 1;
-    if( (nInt != aVal) && (nOutCharstrType == 2)) {
-        // numtype==255 means int32 for Type1, but 16.16 for Type2 charstrings!!!
-        *(pOut++) = 255;                            // Fixed 16.16
-        *(pOut++) = static_cast<U8>(nInt >> 8);
-        *(pOut++) = static_cast<U8>(nInt);
-        nInt = static_cast<int>(aVal * 0x10000) & 0xFFFF;
-        *(pOut++) = static_cast<U8>(nInt >> 8);
-        *(pOut++) = static_cast<U8>(nInt);
-    } else if( (nInt >= -107) && (nInt <= +107)) {
+    if( (nInt >= -107) && (nInt <= +107)) {
         *(pOut++) = static_cast<U8>(nInt + 139);    // -107..+107
     } else if( (nInt >= -1131) && (nInt <= +1131)) {
         if( nInt >= 0)
@@ -777,7 +687,7 @@ void CffSubsetterContext::writeType1Val( ValType aVal)
             nInt = 64148 - nInt;                    // -108..-1131
         *(pOut++) = static_cast<U8>(nInt >> 8);
         *(pOut++) = static_cast<U8>(nInt);
-    } else if( nOutCharstrType == 1) {
+    } else {
         // numtype==255 means int32 for Type1, but 16.16 for Type2 charstrings!!!
         *(pOut++) = 255;
         *(pOut++) = static_cast<U8>(nInt >> 24);
@@ -789,31 +699,17 @@ void CffSubsetterContext::writeType1Val( ValType aVal)
     mpWritePtr = pOut;
 }
 
-// --------------------------------------------------------------------
-
-inline void CffSubsetterContext::pop2write( void)
-{
-    const ValType aVal = popVal();
-    writeType1Val( aVal);
-}
-
-// --------------------------------------------------------------------
-
 inline void CffSubsetterContext::writeTypeOp( int nTypeOp)
 {
     *(mpWritePtr++) = static_cast<U8>(nTypeOp);
 }
 
-// --------------------------------------------------------------------
-
 inline void CffSubsetterContext::writeTypeEsc( int nTypeEsc)
 {
     *(mpWritePtr++) = TYPE1OP::T1ESC;
     *(mpWritePtr++) = static_cast<U8>(nTypeEsc);
 }
 
-// --------------------------------------------------------------------
-
 void CffSubsetterContext::pop2MultiWrite( int nArgsPerTypo, int nTypeOp, int nTypeXor)
 {
     for( int i = 0; i < mnStackIdx;) {
@@ -828,8 +724,6 @@ void CffSubsetterContext::pop2MultiWrite( int nArgsPerTypo, int nTypeOp, int nTy
     clear();
 }
 
-// --------------------------------------------------------------------
-
 void CffSubsetterContext::popAll2Write( int nTypeOp)
 {
     // pop in reverse order, then write
@@ -841,8 +735,6 @@ void CffSubsetterContext::popAll2Write( int nTypeOp)
     writeTypeOp( nTypeOp);
 }
 
-// --------------------------------------------------------------------
-
 void CffSubsetterContext::writeCurveTo( int nStackPos,
     int nIX1, int nIY1, int nIX2, int nIY2, int nIX3, int nIY3)
 {
@@ -866,9 +758,7 @@ void CffSubsetterContext::writeCurveTo( int nStackPos,
     writeTypeOp( TYPE1OP::RCURVETO );
 }
 
-// --------------------------------------------------------------------
-
-void CffSubsetterContext::convertOneTypeOp( void)
+void CffSubsetterContext::convertOneTypeOp()
 {
     const int nType2Op = *(mpReadPtr++);
 
@@ -925,7 +815,7 @@ void CffSubsetterContext::convertOneTypeOp( void)
         mpReadPtr += (mnHintSize + 15) / 16;
 #else
         {
-        long nHintMask = 0;
+        sal_Int32 nHintMask = 0;
         int nCntrBits[2] = {0,0};
         U8 nMaskBit = 0;
         U8 nMaskByte = 0;
@@ -1087,15 +977,13 @@ void CffSubsetterContext::convertOneTypeOp( void)
             read2push();
         } else {
             popAll2Write( nType2Op);
-            assert( false); // TODO?
+            assert(false && "TODO?");
         }
         break;
     }
 }
 
-// --------------------------------------------------------------------
-
-void CffSubsetterContext::convertOneTypeEsc( void)
+void CffSubsetterContext::convertOneTypeEsc()
 {
     const int nType2Esc = *(mpReadPtr++);
     ValType* pTop = &mnValStack[ mnStackIdx-1];
@@ -1113,7 +1001,7 @@ void CffSubsetterContext::convertOneTypeEsc( void)
         break;
     case TYPE2OP::NOT:
         assert( mnStackIdx >= 1 );
-        pTop[0] = (pTop[0] == 0);
+        pTop[0] = ValType(pTop[0] == 0);
         break;
     case TYPE2OP::ABS:
         assert( mnStackIdx >= 1 );
@@ -1148,7 +1036,7 @@ void CffSubsetterContext::convertOneTypeEsc( void)
         break;
     case TYPE2OP::EQ:
         assert( mnStackIdx >= 2 );
-        pTop[0] = (pTop[0] == pTop[-1]);
+        pTop[0] = ValType(pTop[0] == pTop[-1]);
         --mnStackIdx;
         break;
     case TYPE2OP::DROP:
@@ -1276,8 +1164,6 @@ void CffSubsetterContext::convertOneTypeEsc( void)
     }
 }
 
-// --------------------------------------------------------------------
-
 void CffSubsetterContext::callType2Subr( bool bGlobal, int nSubrNumber)
 {
     const U8* const pOldReadPtr = mpReadPtr;
@@ -1298,8 +1184,6 @@ void CffSubsetterContext::callType2Subr( bool bGlobal, int nSubrNumber)
     mpReadEnd = pOldReadEnd;
 }
 
-// --------------------------------------------------------------------
-
 static const int MAX_T1OPS_SIZE = 81920; // TODO: use dynamic value
 
 int CffSubsetterContext::convert2Type1Ops( CffLocal* pCffLocal, const U8* const pT2Ops, int nT2Len, U8* const pT1Ops)
@@ -1369,14 +1253,12 @@ if( mbSawError) {
     int nRDCryptR = 4330; // TODO: mnRDCryptSeed;
     for( U8* p = pT1Ops; p < mpWritePtr; ++p) {
         *p ^= (nRDCryptR >> 8);
-        nRDCryptR = (*(U8*)p + nRDCryptR) * 52845 + 22719;
+        nRDCryptR = (*p + nRDCryptR) * 52845 + 22719;
     }
 
     return nType1Len;
 }
 
-// --------------------------------------------------------------------
-
 RealType CffSubsetterContext::readRealVal()
 {
     // TODO: more thorough number validity test
@@ -1447,8 +1329,6 @@ RealType CffSubsetterContext::readRealVal()
     return fReal;
 }
 
-// --------------------------------------------------------------------
-
 // prepare to access an element inside a CFF/CID index table
 int CffSubsetterContext::seekIndexData( int nIndexBase, int nDataIndex)
 {
@@ -1488,8 +1368,6 @@ int CffSubsetterContext::seekIndexData( int nIndexBase, int nDataIndex)
     return (nOfs2 - nOfs1);
 }
 
-// --------------------------------------------------------------------
-
 // skip over a CFF/CID index table
 void CffSubsetterContext::seekIndexEnd( int nIndexBase)
 {
@@ -1514,10 +1392,8 @@ void CffSubsetterContext::seekIndexEnd( int nIndexBase)
     assert( mpReadEnd <= mpBaseEnd);
 }
 
-// ====================================================================
-
 // initialize FONTDICT specific values
-CffLocal::CffLocal( void)
+CffLocal::CffLocal()
 :   mnPrivDictBase( 0)
 ,   mnPrivDictSize( 0)
 ,   mnLocalSubrOffs( 0)
@@ -1543,9 +1419,7 @@ CffLocal::CffLocal( void)
     maFamilyOtherBlues.clear();
 }
 
-// --------------------------------------------------------------------
-
-CffGlobal::CffGlobal( void)
+CffGlobal::CffGlobal()
 :   mnNameIdxBase( 0)
 ,   mnNameIdxCount( 0)
 ,   mnStringIdxBase( 0)
@@ -1588,7 +1462,7 @@ bool CffSubsetterContext::initialCffRead()
     seekIndexEnd( mnNameIdxBase);
 
     // get the TopDict index
-    const long nTopDictBase = getReadOfs();
+    const sal_Int32 nTopDictBase = getReadOfs();
     const int nTopDictCount = (mpReadPtr[0]<<8) + mpReadPtr[1];
     if( nTopDictCount) {
         for( int i = 0; i < nTopDictCount; ++i) {
@@ -1676,8 +1550,6 @@ bool CffSubsetterContext::initialCffRead()
     return true;
 }
 
-// --------------------------------------------------------------------
-
 // get a cstring from a StringID
 const char* CffSubsetterContext::getString( int nStringID)
 {
@@ -1710,8 +1582,6 @@ const char* CffSubsetterContext::getString( int nStringID)
     return aNameBuf;
 }
 
-// --------------------------------------------------------------------
-
 // access a CID's FDSelect table
 int CffSubsetterContext::getFDSelect( int nGlyphIndex) const
 {
@@ -1756,8 +1626,6 @@ int CffSubsetterContext::getFDSelect( int nGlyphIndex) const
     return -1;
 }
 
-// --------------------------------------------------------------------
-
 int CffSubsetterContext::getGlyphSID( int nGlyphIndex) const
 {
     if( nGlyphIndex == 0)
@@ -1805,8 +1673,6 @@ int CffSubsetterContext::getGlyphSID( int nGlyphIndex) const
     return nSID;
 }
 
-// --------------------------------------------------------------------
-
 // NOTE: the result becomes invalid with the next call to this method
 const char* CffSubsetterContext::getGlyphName( int nGlyphIndex)
 {
@@ -1843,20 +1709,18 @@ const char* CffSubsetterContext::getGlyphName( int nGlyphIndex)
      return pGlyphName;
 }
 
-// --------------------------------------------------------------------
-
 class Type1Emitter
 {
 public:
     explicit    Type1Emitter( FILE* pOutFile, bool bPfbSubset = true);
-    /*virtual*/ ~Type1Emitter( void);
+    ~Type1Emitter();
     void        setSubsetName( const char* );
 
     size_t      emitRawData( const char* pData, size_t nLength) const;
-    void        emitAllRaw( void);
-    void        emitAllHex( void);
-    void        emitAllCrypted( void);
-    int         tellPos( void) const;
+    void        emitAllRaw();
+    void        emitAllHex();
+    void        emitAllCrypted();
+    int         tellPos() const;
     size_t      updateLen( int nTellPos, size_t nLength);
     void        emitValVector( const char* pLineHead, const char* pLineTail, const ValVector&);
 private:
@@ -1872,8 +1736,6 @@ public:
     int         mnHexLineCol;
 };
 
-// --------------------------------------------------------------------
-
 Type1Emitter::Type1Emitter( FILE* pOutFile, bool bPfbSubset)
 :   mpFileOut( pOutFile)
 ,   mbCloseOutfile( false)
@@ -1885,9 +1747,7 @@ Type1Emitter::Type1Emitter( FILE* pOutFile, bool bPfbSubset)
     maSubsetName[0] = '\0';
 }
 
-// --------------------------------------------------------------------
-
-Type1Emitter::~Type1Emitter( void)
+Type1Emitter::~Type1Emitter()
 {
     if( !mpFileOut)
         return;
@@ -1896,8 +1756,6 @@ Type1Emitter::~Type1Emitter( void)
     mpFileOut = NULL;
 }
 
-// --------------------------------------------------------------------
-
 void Type1Emitter::setSubsetName( const char* pSubsetName)
 {
     maSubsetName[0] = '\0';
@@ -1906,16 +1764,12 @@ void Type1Emitter::setSubsetName( const char* pSubsetName)
     maSubsetName[sizeof(maSubsetName)-1] = '\0';
 }
 
-// --------------------------------------------------------------------
-
-int Type1Emitter::tellPos( void) const
+int Type1Emitter::tellPos() const
 {
     int nTellPos = ftell( mpFileOut);
     return nTellPos;
 }
 
-// --------------------------------------------------------------------
-
 size_t Type1Emitter::updateLen( int nTellPos, size_t nLength)
 {
     // update PFB segment header length
@@ -1924,24 +1778,23 @@ size_t Type1Emitter::updateLen( int nTellPos, size_t nLength)
     cData[1] = static_cast<U8>(nLength >>  8);
     cData[2] = static_cast<U8>(nLength >> 16);
     cData[3] = static_cast<U8>(nLength >> 24);
-    const long nCurrPos = ftell( mpFileOut);
-    fseek( mpFileOut, nTellPos, SEEK_SET);
-    size_t nWrote = fwrite( cData, 1, sizeof(cData), mpFileOut);
+    const long nCurrPos = ftell(mpFileOut);
+    if (nCurrPos < 0)
+        return 0;
+    if (fseek( mpFileOut, nTellPos, SEEK_SET) != 0)
+        return 0;
+    size_t nWrote = fwrite(cData, 1, sizeof(cData), mpFileOut);
     if( nCurrPos >= 0)
-        fseek( mpFileOut, nCurrPos, SEEK_SET);
+        (void)fseek(mpFileOut, nCurrPos, SEEK_SET);
     return nWrote;
 }
 
-// --------------------------------------------------------------------
-
 inline size_t Type1Emitter::emitRawData(const char* pData, size_t nLength) const
 {
     return fwrite( pData, 1, nLength, mpFileOut);
 }
 
-// --------------------------------------------------------------------
-
-inline void Type1Emitter::emitAllRaw( void)
+inline void Type1Emitter::emitAllRaw()
 {
     // writeout raw data
     assert( (mpPtr - maBuffer) < (int)sizeof(maBuffer));
@@ -1950,9 +1803,7 @@ inline void Type1Emitter::emitAllRaw( void)
     mpPtr = maBuffer;
 }
 
-// --------------------------------------------------------------------
-
-inline void Type1Emitter::emitAllHex( void)
+inline void Type1Emitter::emitAllHex()
 {
     assert( (mpPtr - maBuffer) < (int)sizeof(maBuffer));
     for( const char* p = maBuffer; p < mpPtr;) {
@@ -1978,14 +1829,12 @@ inline void Type1Emitter::emitAllHex( void)
     mpPtr = maBuffer;
 }
 
-// --------------------------------------------------------------------
-
-void Type1Emitter::emitAllCrypted( void)
+void Type1Emitter::emitAllCrypted()
 {
     // apply t1crypt
     for( char* p = maBuffer; p < mpPtr; ++p) {
         *p ^= (mnEECryptR >> 8);
-        mnEECryptR = (*(U8*)p + mnEECryptR) * 52845 + 22719;
+        mnEECryptR = (*reinterpret_cast<U8*>(p) + mnEECryptR) * 52845 + 22719;
     }
 
     // emit the t1crypt result
@@ -1995,8 +1844,6 @@ void Type1Emitter::emitAllCrypted( void)
         emitAllHex();
 }
 
-// --------------------------------------------------------------------
-
 // #i110387# quick-and-dirty double->ascii conversion
 // needed because sprintf/ecvt/etc. alone are too localized (LC_NUMERIC)
 // also strip off trailing zeros in fraction while we are at it
@@ -2006,8 +1853,6 @@ inline int dbl2str( char* pOut, double fVal, int nPrecision=6)
     return nLen;
 }
 
-// --------------------------------------------------------------------
-
 void Type1Emitter::emitValVector( const char* pLineHead, const char* pLineTail,
     const ValVector& rVector)
 {
@@ -2032,10 +1877,8 @@ void Type1Emitter::emitValVector( const char* pLineHead, const char* pLineTail,
     mpPtr += sprintf( mpPtr, "%s", pLineTail);
 }
 
-// --------------------------------------------------------------------
-
 bool CffSubsetterContext::emitAsType1( Type1Emitter& rEmitter,
-    const long* pReqGlyphIDs, const U8* pReqEncoding,
+    const sal_GlyphId* pReqGlyphIds, const U8* pReqEncoding,
     GlyphWidth* pGlyphWidths, int nGlyphCount, FontSubsetInfo& rFSInfo)
 {
     // prepare some fontdirectory details
@@ -2108,7 +1951,7 @@ bool CffSubsetterContext::emitAsType1( Type1Emitter& rEmitter,
         "/Encoding 256 array\n"
         "0 1 255 {1 index exch /.notdef put} for\n");
     for( int i = 1; (i < nGlyphCount) && (i < 256); ++i) {
-        const char* pGlyphName = getGlyphName( pReqGlyphIDs[i]);
+        const char* pGlyphName = getGlyphName( pReqGlyphIds[i]);
         pOut += sprintf( pOut, "dup %d /%s put\n", pReqEncoding[i], pGlyphName);
     }
     pOut += sprintf( pOut, "readonly def\n");
@@ -2134,22 +1977,22 @@ bool CffSubsetterContext::emitAsType1( Type1Emitter& rEmitter,
     int nPrivEntryCount = 9;
 #if !defined(IGNORE_HINTS)
     // emit blue hints only if non-default values
-    nPrivEntryCount += !mpCffLocal->maOtherBlues.empty();
-    nPrivEntryCount += !mpCffLocal->maFamilyBlues.empty();
-    nPrivEntryCount += !mpCffLocal->maFamilyOtherBlues.empty();
-    nPrivEntryCount += (mpCffLocal->mfBlueScale != 0.0);
-    nPrivEntryCount += (mpCffLocal->mfBlueShift != 0.0);
-    nPrivEntryCount += (mpCffLocal->mfBlueFuzz != 0.0);
+    nPrivEntryCount += int(!mpCffLocal->maOtherBlues.empty());
+    nPrivEntryCount += int(!mpCffLocal->maFamilyBlues.empty());
+    nPrivEntryCount += int(!mpCffLocal->maFamilyOtherBlues.empty());
+    nPrivEntryCount += int(mpCffLocal->mfBlueScale != 0.0);
+    nPrivEntryCount += int(mpCffLocal->mfBlueShift != 0.0);
+    nPrivEntryCount += int(mpCffLocal->mfBlueFuzz != 0.0);
     // emit stem hints only if non-default values
-    nPrivEntryCount += (mpCffLocal->maStemStdHW != 0);
-    nPrivEntryCount += (mpCffLocal->maStemStdVW != 0);
-    nPrivEntryCount += !mpCffLocal->maStemSnapH.empty();
-    nPrivEntryCount += !mpCffLocal->maStemSnapV.empty();
+    nPrivEntryCount += int(mpCffLocal->maStemStdHW != 0);
+    nPrivEntryCount += int(mpCffLocal->maStemStdVW != 0);
+    nPrivEntryCount += int(!mpCffLocal->maStemSnapH.empty());
+    nPrivEntryCount += int(!mpCffLocal->maStemSnapV.empty());
     // emit other hints only if non-default values
-    nPrivEntryCount += (mpCffLocal->mfExpFactor != 0.0);
-    nPrivEntryCount += (mpCffLocal->mnLangGroup != 0);
-    nPrivEntryCount += (mpCffLocal->mnLangGroup == 1);
-    nPrivEntryCount += (mpCffLocal->mbForceBold != false);
+    nPrivEntryCount += int(mpCffLocal->mfExpFactor != 0.0);
+    nPrivEntryCount += int(mpCffLocal->mnLangGroup != 0);
+    nPrivEntryCount += int(mpCffLocal->mnLangGroup == 1);
+    nPrivEntryCount += int(mpCffLocal->mbForceBold);
 #endif // IGNORE_HINTS
     // emit the privdict header
     pOut += sprintf( pOut,
@@ -2258,20 +2101,20 @@ bool CffSubsetterContext::emitAsType1( Type1Emitter& rEmitter,
         "2 index /CharStrings %d dict dup begin\n", nGlyphCount);
     rEmitter.emitAllCrypted();
     for( int i = 0; i < nGlyphCount; ++i) {
-        const int nGlyphId = pReqGlyphIDs[i];
-        assert( (nGlyphId >= 0) && (nGlyphId < mnCharStrCount));
+        const int nCffGlyphId = pReqGlyphIds[i];
+        assert( (nCffGlyphId >= 0) && (nCffGlyphId < mnCharStrCount));
         // get privdict context matching to the glyph
-        const int nFDSelect = getFDSelect( nGlyphId);
+        const int nFDSelect = getFDSelect( nCffGlyphId);
         if( nFDSelect < 0)
             continue;
         mpCffLocal = &maCffLocal[ nFDSelect];
         // convert the Type2op charstring to its Type1op counterpart
-        const int nT2Len = seekIndexData( mnCharStrBase, nGlyphId);
+        const int nT2Len = seekIndexData( mnCharStrBase, nCffGlyphId);
         assert( nT2Len > 0);
         U8 aType1Ops[ MAX_T1OPS_SIZE]; // TODO: dynamic allocation
         const int nT1Len = convert2Type1Ops( mpCffLocal, mpReadPtr, nT2Len, aType1Ops);
         // get the glyph name
-        const char* pGlyphName = getGlyphName( nGlyphId);
+        const char* pGlyphName = getGlyphName( nCffGlyphId);
         // emit the encrypted Type1op charstring
         pOut += sprintf( pOut, "/%s %d RD ", pGlyphName, nT1Len);
         memcpy( pOut, aType1Ops, nT1Len);
@@ -2323,10 +2166,10 @@ bool CffSubsetterContext::emitAsType1( Type1Emitter& rEmitter,
         fXFactor = 1000.0F * maFontMatrix[0];
         fYFactor = 1000.0F * maFontMatrix[3];
     }
-    rFSInfo.m_aFontBBox = Rectangle( Point( static_cast<long>(maFontBBox[0] * fXFactor),
-                                        static_cast<long>(maFontBBox[1] * fYFactor) ),
-                                    Point( static_cast<long>(maFontBBox[2] * fXFactor),
-                                        static_cast<long>(maFontBBox[3] * fYFactor) ) );
+    rFSInfo.m_aFontBBox = Rectangle( Point( static_cast<sal_Int32>(maFontBBox[0] * fXFactor),
+                                        static_cast<sal_Int32>(maFontBBox[1] * fYFactor) ),
+                                    Point( static_cast<sal_Int32>(maFontBBox[2] * fXFactor),
+                                        static_cast<sal_Int32>(maFontBBox[3] * fYFactor) ) );
     // PDF-Spec says the values below mean the ink bounds!
     // TODO: use better approximations for these ink bounds
     rFSInfo.m_nAscent  = +rFSInfo.m_aFontBBox.Bottom(); // for capital letters
@@ -2339,8 +2182,6 @@ bool CffSubsetterContext::emitAsType1( Type1Emitter& rEmitter,
     return true;
 }
 
-// ====================================================================
-
 bool FontSubsetInfo::CreateFontSubsetFromCff( GlyphWidth* pOutGlyphWidths )
 {
     CffSubsetterContext aCff( mpInFontBytes, mnInByteLength);
@@ -2359,6 +2200,4 @@ bool FontSubsetInfo::CreateFontSubsetFromCff( GlyphWidth* pOutGlyphWidths )
     return bRC;
 }
 
-// ====================================================================
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
