@@ -17,10 +17,8 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <boost/scoped_ptr.hpp>
 #include <boost/scoped_array.hpp>
 
-
 #include <osl/file.hxx>
 #include <tools/debug.hxx>
 #include <tools/stream.hxx>
@@ -41,21 +39,16 @@
 #include <rtl/strbuf.hxx>
 #endif
 
-DBG_NAME( Image )
-DBG_NAME( ImageList )
-
 using namespace ::com::sun::star;
 
 Image::Image() :
     mpImplData( NULL )
 {
-    DBG_CTOR( Image, NULL );
 }
 
 Image::Image( const ResId& rResId ) :
     mpImplData( NULL )
 {
-    DBG_CTOR( Image, NULL );
 
     rResId.SetRT( RSC_IMAGE );
 
@@ -69,30 +62,30 @@ Image::Image( const ResId& rResId ) :
 
         if( nObjMask & RSC_IMAGE_IMAGEBITMAP )
         {
-            aBmpEx = BitmapEx( ResId( (RSHEADER_TYPE*)pResMgr->GetClass(), *pResMgr ) );
-            pResMgr->Increment( pResMgr->GetObjSize( (RSHEADER_TYPE*)pResMgr->GetClass() ) );
+            aBmpEx = BitmapEx( ResId( static_cast<RSHEADER_TYPE*>(pResMgr->GetClass()), *pResMgr ) );
+            pResMgr->Increment( ResMgr::GetObjSize( static_cast<RSHEADER_TYPE*>(pResMgr->GetClass()) ) );
         }
 
         if( nObjMask & RSC_IMAGE_MASKBITMAP )
         {
             if( !aBmpEx.IsEmpty() && aBmpEx.GetTransparentType() == TRANSPARENT_NONE )
             {
-                const Bitmap aMaskBitmap( ResId( (RSHEADER_TYPE*)pResMgr->GetClass(), *pResMgr ) );
+                const Bitmap aMaskBitmap( ResId( static_cast<RSHEADER_TYPE*>(pResMgr->GetClass()), *pResMgr ) );
                 aBmpEx = BitmapEx( aBmpEx.GetBitmap(), aMaskBitmap );
             }
 
-            pResMgr->Increment( pResMgr->GetObjSize( (RSHEADER_TYPE*)pResMgr->GetClass() ) );
+            pResMgr->Increment( ResMgr::GetObjSize( static_cast<RSHEADER_TYPE*>(pResMgr->GetClass()) ) );
         }
 
         if( nObjMask & RSC_IMAGE_MASKCOLOR )
         {
             if( !aBmpEx.IsEmpty() && aBmpEx.GetTransparentType() == TRANSPARENT_NONE )
             {
-                const Color aMaskColor( ResId( (RSHEADER_TYPE*)pResMgr->GetClass(), *pResMgr ) );
+                const Color aMaskColor( ResId( static_cast<RSHEADER_TYPE*>(pResMgr->GetClass()), *pResMgr ) );
                 aBmpEx = BitmapEx( aBmpEx.GetBitmap(), aMaskColor );
             }
 
-            pResMgr->Increment( pResMgr->GetObjSize( (RSHEADER_TYPE*)pResMgr->GetClass() ) );
+            pResMgr->Increment( ResMgr::GetObjSize( static_cast<RSHEADER_TYPE*>(pResMgr->GetClass()) ) );
         }
         if( ! aBmpEx.IsEmpty() )
             ImplInit( aBmpEx );
@@ -102,7 +95,6 @@ Image::Image( const ResId& rResId ) :
 Image::Image( const Image& rImage ) :
     mpImplData( rImage.mpImplData )
 {
-    DBG_CTOR( Image, NULL );
 
     if( mpImplData )
         ++mpImplData->mnRefCount;
@@ -111,7 +103,6 @@ Image::Image( const Image& rImage ) :
 Image::Image( const BitmapEx& rBitmapEx ) :
     mpImplData( NULL )
 {
-    DBG_CTOR( Image, NULL );
 
     ImplInit( rBitmapEx );
 }
@@ -119,7 +110,6 @@ Image::Image( const BitmapEx& rBitmapEx ) :
 Image::Image( const Bitmap& rBitmap ) :
     mpImplData( NULL )
 {
-    DBG_CTOR( Image, NULL );
 
     ImplInit( rBitmap );
 }
@@ -127,7 +117,6 @@ Image::Image( const Bitmap& rBitmap ) :
 Image::Image( const Bitmap& rBitmap, const Bitmap& rMaskBitmap ) :
     mpImplData( NULL )
 {
-    DBG_CTOR( Image, NULL );
 
     const BitmapEx aBmpEx( rBitmap, rMaskBitmap );
 
@@ -137,7 +126,6 @@ Image::Image( const Bitmap& rBitmap, const Bitmap& rMaskBitmap ) :
 Image::Image( const Bitmap& rBitmap, const Color& rColor ) :
     mpImplData( NULL )
 {
-    DBG_CTOR( Image, NULL );
 
     const BitmapEx aBmpEx( rBitmap, rColor );
 
@@ -147,7 +135,6 @@ Image::Image( const Bitmap& rBitmap, const Color& rColor ) :
 Image::Image( const uno::Reference< graphic::XGraphic >& rxGraphic ) :
     mpImplData( NULL )
 {
-    DBG_CTOR( Image, NULL );
 
     const Graphic aGraphic( rxGraphic );
     ImplInit( aGraphic.GetBitmapEx() );
@@ -156,7 +143,6 @@ Image::Image( const uno::Reference< graphic::XGraphic >& rxGraphic ) :
 Image::Image( const OUString &rFileUrl ) :
     mpImplData( NULL )
 {
-    DBG_CTOR( Image, NULL );
     OUString aTmp;
     osl::FileBase::getSystemPathFromFileURL( rFileUrl, aTmp );
     Graphic aGraphic;
@@ -169,7 +155,6 @@ Image::Image( const OUString &rFileUrl ) :
 
 Image::~Image()
 {
-    DBG_DTOR( Image, NULL );
 
     if( mpImplData && ( 0 == --mpImplData->mnRefCount ) )
         delete mpImplData;
@@ -180,7 +165,6 @@ void Image::ImplInit( const BitmapEx& rBmpEx )
     if( !rBmpEx.IsEmpty() )
     {
         mpImplData = new ImplImage;
-        mpImplData->mnRefCount = 1;
 
         if( rBmpEx.GetTransparentType() == TRANSPARENT_NONE )
         {
@@ -197,7 +181,6 @@ void Image::ImplInit( const BitmapEx& rBmpEx )
 
 Size Image::GetSizePixel() const
 {
-    DBG_CHKTHIS( Image, NULL );
 
     Size aRet;
 
@@ -220,7 +203,6 @@ Size Image::GetSizePixel() const
 
 BitmapEx Image::GetBitmapEx() const
 {
-    DBG_CHKTHIS( Image, NULL );
 
     BitmapEx aRet;
 
@@ -250,8 +232,6 @@ uno::Reference< graphic::XGraphic > Image::GetXGraphic() const
 
 Image& Image::operator=( const Image& rImage )
 {
-    DBG_CHKTHIS( Image, NULL );
-    DBG_CHKOBJ( &rImage, Image, NULL );
 
     if( rImage.mpImplData )
         ++rImage.mpImplData->mnRefCount;
@@ -264,10 +244,8 @@ Image& Image::operator=( const Image& rImage )
     return *this;
 }
 
-sal_Bool Image::operator==( const Image& rImage ) const
+bool Image::operator==( const Image& rImage ) const
 {
-    DBG_CHKTHIS( Image, NULL );
-    DBG_CHKOBJ( &rImage, Image, NULL );
 
     bool bRet = false;
 
@@ -303,7 +281,6 @@ ImageList::ImageList( sal_uInt16 nInit, sal_uInt16 nGrow ) :
     mnInitSize( nInit ),
     mnGrowSize( nGrow )
 {
-    DBG_CTOR( ImageList, NULL );
 }
 
 ImageList::ImageList( const ResId& rResId ) :
@@ -313,8 +290,6 @@ ImageList::ImageList( const ResId& rResId ) :
 {
     SAL_INFO( "vcl.gdi", "vcl: ImageList::ImageList( const ResId& rResId )" );
 
-    DBG_CTOR( ImageList, NULL );
-
     rResId.SetRT( RSC_IMAGELIST );
 
     ResMgr* pResMgr = rResId.GetResMgr();
@@ -325,12 +300,12 @@ ImageList::ImageList( const ResId& rResId ) :
 
         sal_uLong                               nObjMask = pResMgr->ReadLong();
         pResMgr->ReadString(); //skip string
-        ::boost::scoped_ptr< Color >        spMaskColor;
+        std::unique_ptr< Color >        xMaskColor;
 
         if( nObjMask & RSC_IMAGE_MASKCOLOR )
-            spMaskColor.reset( new Color( ResId( (RSHEADER_TYPE*)pResMgr->GetClass(), *pResMgr ) ) );
+            xMaskColor.reset( new Color( ResId( static_cast<RSHEADER_TYPE*>(pResMgr->GetClass()), *pResMgr ) ) );
 
-        pResMgr->Increment( pResMgr->GetObjSize( (RSHEADER_TYPE*)pResMgr->GetClass() ) );
+        pResMgr->Increment( ResMgr::GetObjSize( static_cast<RSHEADER_TYPE*>(pResMgr->GetClass()) ) );
 
         if( nObjMask & RSC_IMAGELIST_IDLIST )
         {
@@ -363,8 +338,6 @@ ImageList::ImageList( const ::std::vector< OUString >& rNameVector,
 {
     SAL_INFO( "vcl.gdi", "vcl: ImageList::ImageList(const vector< OUString >& ..." );
 
-    DBG_CTOR( ImageList, NULL );
-
     ImplInit( sal::static_int_cast< sal_uInt16 >( rNameVector.size() ), Size() );
 
     mpImplData->maPrefix = rPrefix;
@@ -379,7 +352,6 @@ ImageList::ImageList( const ImageList& rImageList ) :
     mnInitSize( rImageList.mnInitSize ),
     mnGrowSize( rImageList.mnGrowSize )
 {
-    DBG_CTOR( ImageList, NULL );
 
     if( mpImplData )
         ++mpImplData->mnRefCount;
@@ -387,8 +359,6 @@ ImageList::ImageList( const ImageList& rImageList ) :
 
 ImageList::~ImageList()
 {
-    DBG_DTOR( ImageList, NULL );
-
     if( mpImplData && ( 0 == --mpImplData->mnRefCount ) )
         delete mpImplData;
 }
@@ -396,7 +366,6 @@ ImageList::~ImageList()
 void ImageList::ImplInit( sal_uInt16 nItems, const Size &rSize )
 {
     mpImplData = new ImplImageList;
-    mpImplData->mnRefCount = 1;
     mpImplData->maImages.reserve( nItems );
     mpImplData->maImageSize = rSize;
 }
@@ -405,7 +374,7 @@ void ImageAryData::Load(const OUString &rPrefix)
 {
     static ImplImageTreeSingletonRef aImageTree;
 
-    OUString aSymbolsStyle = Application::GetSettings().GetStyleSettings().GetCurrentSymbolsStyleName();
+    OUString aIconTheme = Application::GetSettings().GetStyleSettings().DetermineIconTheme();
 
     BitmapEx aBmpEx;
 
@@ -414,7 +383,7 @@ void ImageAryData::Load(const OUString &rPrefix)
 #if OSL_DEBUG_LEVEL > 0
     bool bSuccess =
 #endif
-        aImageTree->loadImage( aFileName, aSymbolsStyle, maBitmapEx, true );
+        aImageTree->loadImage( aFileName, aIconTheme, maBitmapEx, true );
 #if OSL_DEBUG_LEVEL > 0
     if ( !bSuccess )
     {
@@ -511,7 +480,6 @@ void ImageList::InsertFromHorizontalBitmap( const ResId& rResId,
 
 sal_uInt16 ImageList::ImplGetImageId( const OUString& rImageName ) const
 {
-    DBG_CHKTHIS( ImageList, NULL );
 
     ImageAryData *pImg = mpImplData->maNameHash[ rImageName ];
     if( pImg )
@@ -546,7 +514,6 @@ void ImageList::ReplaceImage( const OUString& rImageName, const Image& rImage )
 
 void ImageList::RemoveImage( sal_uInt16 nId )
 {
-    DBG_CHKTHIS( ImageList, NULL );
 
     for( sal_uInt32 i = 0; i < mpImplData->maImages.size(); ++i )
     {
@@ -560,7 +527,6 @@ void ImageList::RemoveImage( sal_uInt16 nId )
 
 Image ImageList::GetImage( sal_uInt16 nId ) const
 {
-    DBG_CHKTHIS( ImageList, NULL );
 
     Image aRet;
 
@@ -583,7 +549,7 @@ Image ImageList::GetImage( sal_uInt16 nId ) const
     if (!aRet)
     {
         BitmapEx rBitmap;
-        bool res = ::vcl::ImageRepository::loadDefaultImage(rBitmap);
+        bool res = vcl::ImageRepository::loadDefaultImage(rBitmap);
         if (res)
             aRet =  Image(rBitmap);
     }
@@ -610,14 +576,12 @@ Image ImageList::GetImage( const OUString& rImageName ) const
 
 sal_uInt16 ImageList::GetImageCount() const
 {
-    DBG_CHKTHIS( ImageList, NULL );
 
     return mpImplData ? static_cast< sal_uInt16 >( mpImplData->maImages.size() ) : 0;
 }
 
 sal_uInt16 ImageList::GetImagePos( sal_uInt16 nId ) const
 {
-    DBG_CHKTHIS( ImageList, NULL );
 
     if( mpImplData && nId )
     {
@@ -638,7 +602,6 @@ bool ImageList::HasImageAtPos( sal_uInt16 nId ) const
 
 sal_uInt16 ImageList::GetImagePos( const OUString& rImageName ) const
 {
-    DBG_CHKTHIS( ImageList, NULL );
 
     if( mpImplData && !rImageName.isEmpty() )
     {
@@ -654,7 +617,6 @@ sal_uInt16 ImageList::GetImagePos( const OUString& rImageName ) const
 
 sal_uInt16 ImageList::GetImageId( sal_uInt16 nPos ) const
 {
-    DBG_CHKTHIS( ImageList, NULL );
 
     if( mpImplData && (nPos < GetImageCount()) )
         return mpImplData->maImages[ nPos ]->mnId;
@@ -664,7 +626,6 @@ sal_uInt16 ImageList::GetImageId( sal_uInt16 nPos ) const
 
 OUString ImageList::GetImageName( sal_uInt16 nPos ) const
 {
-    DBG_CHKTHIS( ImageList, NULL );
 
     if( mpImplData && (nPos < GetImageCount()) )
         return mpImplData->maImages[ nPos ]->maName;
@@ -676,8 +637,6 @@ void ImageList::GetImageNames( ::std::vector< OUString >& rNames ) const
 {
     SAL_INFO( "vcl.gdi", "vcl: ImageList::GetImageNames" );
 
-    DBG_CHKTHIS( ImageList, NULL );
-
     rNames = ::std::vector< OUString >();
 
     if( mpImplData )
@@ -693,7 +652,6 @@ void ImageList::GetImageNames( ::std::vector< OUString >& rNames ) const
 
 Size ImageList::GetImageSize() const
 {
-    DBG_CHKTHIS( ImageList, NULL );
 
     Size aRet;
 
@@ -714,8 +672,6 @@ Size ImageList::GetImageSize() const
 
 ImageList& ImageList::operator=( const ImageList& rImageList )
 {
-    DBG_CHKTHIS( ImageList, NULL );
-    DBG_CHKOBJ( &rImageList, ImageList, NULL );
 
     if( rImageList.mpImplData )
         ++rImageList.mpImplData->mnRefCount;
@@ -728,10 +684,8 @@ ImageList& ImageList::operator=( const ImageList& rImageList )
     return *this;
 }
 
-sal_Bool ImageList::operator==( const ImageList& rImageList ) const
+bool ImageList::operator==( const ImageList& rImageList ) const
 {
-    DBG_CHKTHIS( ImageList, NULL );
-    DBG_CHKOBJ( &rImageList, ImageList, NULL );
 
     bool bRet = false;
 
