@@ -27,6 +27,7 @@
 #include <vcl/taskpanelist.hxx>
 #include <vcl/gradient.hxx>
 #include <vcl/lineinfo.hxx>
+#include <vcl/settings.hxx>
 
 #include <rtl/instance.hxx>
 
@@ -48,23 +49,19 @@ namespace
     };
 }
 
-// =======================================================================
-
 void Splitter::ImplInitSplitterData()
 {
-    ImplGetWindowImpl()->mbSplitter        = sal_True;
+    ImplGetWindowImpl()->mbSplitter        = true;
     mpRefWin          = NULL;
     mnSplitPos        = 0;
     mnLastSplitPos    = 0;
     mnStartSplitPos   = 0;
-    mbDragFull        = sal_False;
-    mbKbdSplitting    = sal_False;
+    mbDragFull        = false;
+    mbKbdSplitting    = false;
     mbInKeyEvent      = 0;
     mnKeyboardStepSize = SPLITTER_DEFAULTSTEPSIZE;
 }
 
-// -----------------------------------------------------------------------
-
 // Should only be called from a ImplInit method for initialization or
 // after checking bNew is different from the current mbHorzSplit value.
 // The public method that does that check is Splitter::SetHorizontal().
@@ -77,21 +74,19 @@ void Splitter::ImplInitHorVer(bool bNew)
 
     if ( mbHorzSplit )
     {
-        ePointerStyle = POINTER_HSPLIT;
+        ePointerStyle = PointerStyle::HSplit;
         SetSizePixel( Size( rSettings.GetSplitSize(), rSettings.GetScrollBarSize() ) );
     }
     else
     {
-        ePointerStyle = POINTER_VSPLIT;
+        ePointerStyle = PointerStyle::VSplit;
         SetSizePixel( Size( rSettings.GetScrollBarSize(), rSettings.GetSplitSize() ) );
     }
 
     SetPointer( Pointer( ePointerStyle ) );
 }
 
-// -----------------------------------------------------------------------
-
-void Splitter::ImplInit( Window* pParent, WinBits nWinStyle )
+void Splitter::ImplInit( vcl::Window* pParent, WinBits nWinStyle )
 {
     Window::ImplInit( pParent, nWinStyle, NULL );
 
@@ -108,8 +103,6 @@ void Splitter::ImplInit( Window* pParent, WinBits nWinStyle )
     pTList->AddWindow( this );
 }
 
-// -----------------------------------------------------------------------
-
 void Splitter::ImplSplitMousePos( Point& rPos )
 {
     if ( mbHorzSplit )
@@ -128,8 +121,6 @@ void Splitter::ImplSplitMousePos( Point& rPos )
     }
 }
 
-// -----------------------------------------------------------------------
-
 void Splitter::ImplDrawSplitter()
 {
     Rectangle aInvRect( maDragRect );
@@ -148,9 +139,7 @@ void Splitter::ImplDrawSplitter()
     mpRefWin->InvertTracking( mpRefWin->PixelToLogic(aInvRect), SHOWTRACK_SPLIT );
 }
 
-// -----------------------------------------------------------------------
-
-Splitter::Splitter( Window* pParent, WinBits nStyle ) :
+Splitter::Splitter( vcl::Window* pParent, WinBits nStyle ) :
     Window( WINDOW_SPLITTER )
 {
     ImplInitSplitterData();
@@ -160,33 +149,22 @@ Splitter::Splitter( Window* pParent, WinBits nStyle ) :
     SetFillColor();
 }
 
-// -----------------------------------------------------------------------
-
-Splitter::Splitter( Window* pParent, const ResId& rResId ) :
-    Window( WINDOW_SPLITTER )
-{
-    ImplInitSplitterData();
-    rResId.SetRT( RSC_SPLITTER );
-    WinBits nStyle = ImplInitRes( rResId );
-    ImplInit( pParent, nStyle );
-    ImplLoadRes( rResId );
-
-    SetLineColor();
-    SetFillColor();
-
-    if ( !(nStyle & WB_HIDE) )
-        Show();
-}
-
-// -----------------------------------------------------------------------
-
 Splitter::~Splitter()
 {
-    TaskPaneList *pTList = GetSystemWindow()->GetTaskPaneList();
-    pTList->RemoveWindow( this );
+    disposeOnce();
 }
 
-// -----------------------------------------------------------------------
+void Splitter::dispose()
+{
+    SystemWindow *pSysWin = GetSystemWindow();
+    if(pSysWin)
+    {
+        TaskPaneList *pTList = pSysWin->GetTaskPaneList();
+        pTList->RemoveWindow(this);
+    }
+    mpRefWin.clear();
+    Window::dispose();
+}
 
 void Splitter::SetHorizontal(bool bNew)
 {
@@ -196,40 +174,34 @@ void Splitter::SetHorizontal(bool bNew)
     }
 }
 
-// -----------------------------------------------------------------------
-
 void Splitter::SetKeyboardStepSize( long nStepSize )
 {
     mnKeyboardStepSize = nStepSize;
 }
 
-// -----------------------------------------------------------------------
-
 Splitter* Splitter::ImplFindSibling()
 {
     // look for another splitter with the same parent but different orientation
-    Window *pWin = GetParent()->GetWindow( WINDOW_FIRSTCHILD );
+    vcl::Window *pWin = GetParent()->GetWindow( GetWindowType::FirstChild );
     Splitter *pSplitter = NULL;
     while( pWin )
     {
         if( pWin->ImplIsSplitter() )
         {
-            pSplitter = (Splitter*) pWin;
+            pSplitter = static_cast<Splitter*>(pWin);
             if( pSplitter != this && IsHorizontal() != pSplitter->IsHorizontal() )
                 return pSplitter;
         }
-        pWin = pWin->GetWindow( WINDOW_NEXT );
+        pWin = pWin->GetWindow( GetWindowType::Next );
     }
     return NULL;
 }
 
-// -----------------------------------------------------------------------
-
-sal_Bool Splitter::ImplSplitterActive()
+bool Splitter::ImplSplitterActive()
 {
     // is splitter in document or at scrollbar handle ?
 
-    sal_Bool bActive = sal_True;
+    bool bActive = true;
     const StyleSettings& rSettings = GetSettings().GetStyleSettings();
     long nA = rSettings.GetScrollBarSize();
     long nB = rSettings.GetSplitSize();
@@ -238,18 +210,16 @@ sal_Bool Splitter::ImplSplitterActive()
     if ( mbHorzSplit )
     {
         if( aSize.Width() == nB && aSize.Height() == nA )
-            bActive = sal_False;
+            bActive = false;
     }
     else
     {
         if( aSize.Width() == nA && aSize.Height() == nB )
-            bActive = sal_False;
+            bActive = false;
     }
     return bActive;
 }
 
-// -----------------------------------------------------------------------
-
 void Splitter::MouseButtonDown( const MouseEvent& rMEvt )
 {
     if ( rMEvt.GetClicks() == 2 )
@@ -279,8 +249,6 @@ void Splitter::MouseButtonDown( const MouseEvent& rMEvt )
         StartDrag();
 }
 
-// -----------------------------------------------------------------------
-
 void Splitter::Tracking( const TrackingEvent& rTEvt )
 {
     if ( rTEvt.IsTrackingEnded() )
@@ -355,9 +323,7 @@ void Splitter::Tracking( const TrackingEvent& rTEvt )
     }
 }
 
-// -----------------------------------------------------------------------
-
-void Splitter::ImplKbdTracking( KeyCode aKeyCode )
+void Splitter::ImplKbdTracking( vcl::KeyCode aKeyCode )
 {
     sal_uInt16 nCode = aKeyCode.GetCode();
     if ( nCode == KEY_ESCAPE || nCode == KEY_RETURN )
@@ -365,7 +331,7 @@ void Splitter::ImplKbdTracking( KeyCode aKeyCode )
         if( !mbKbdSplitting )
             return;
         else
-            mbKbdSplitting = sal_False;
+            mbKbdSplitting = false;
 
         if ( nCode != KEY_ESCAPE )
         {
@@ -394,10 +360,10 @@ void Splitter::ImplKbdTracking( KeyCode aKeyCode )
         Point aNewPos;
         Size aSize = mpRefWin->GetOutputSize();
         Point aPos = GetPosPixel();
-        // depending on the position calc allows continous moves or snaps to row/columns
-        // continous mode is active when position is at the origin or end of the splitter
+        // depending on the position calc allows continuous moves or snaps to row/columns
+        // continuous mode is active when position is at the origin or end of the splitter
         // otherwise snap mode is active
-        // default here is snap, holding shift sets continous mode
+        // default here is snap, holding shift sets continuous mode
         if( mbHorzSplit )
             aNewPos = Point( ImplSplitterActive() ? aPos.X() : mnSplitPos, aKeyCode.IsShift() ? 0 : aSize.Height()/2);
         else
@@ -472,37 +438,27 @@ void Splitter::ImplKbdTracking( KeyCode aKeyCode )
     }
 }
 
-// -----------------------------------------------------------------------
-
 void Splitter::StartSplit()
 {
     maStartSplitHdl.Call( this );
 }
 
-// -----------------------------------------------------------------------
-
 void Splitter::Split()
 {
     maSplitHdl.Call( this );
 }
 
-// -----------------------------------------------------------------------
-
 void Splitter::EndSplit()
 {
     if ( maEndSplitHdl.IsSet() )
         maEndSplitHdl.Call( this );
 }
 
-// -----------------------------------------------------------------------
-
 void Splitter::Splitting( Point& /* rSplitPos */ )
 {
 }
 
-// -----------------------------------------------------------------------
-
-void Splitter::SetDragRectPixel( const Rectangle& rDragRect, Window* _pRefWin )
+void Splitter::SetDragRectPixel( const Rectangle& rDragRect, vcl::Window* _pRefWin )
 {
     maDragRect = rDragRect;
     if ( !_pRefWin )
@@ -511,15 +467,11 @@ void Splitter::SetDragRectPixel( const Rectangle& rDragRect, Window* _pRefWin )
         mpRefWin = _pRefWin;
 }
 
-// -----------------------------------------------------------------------
-
 void Splitter::SetSplitPosPixel( long nNewPos )
 {
     mnSplitPos = nNewPos;
 }
 
-// -----------------------------------------------------------------------
-
 void Splitter::StartDrag()
 {
     if ( IsTracking() )
@@ -530,7 +482,7 @@ void Splitter::StartDrag()
     // Tracking starten
     StartTracking();
 
-    // Start-Positon ermitteln
+    // Start-Position ermitteln
     maDragPos = mpRefWin->GetPointerPosPixel();
     ImplSplitMousePos( maDragPos );
     Splitting( maDragPos );
@@ -540,20 +492,17 @@ void Splitter::StartDrag()
     else
         mnStartSplitPos = maDragPos.Y();
 
-    mbDragFull = (Application::GetSettings().GetStyleSettings().GetDragFullOptions() & DRAGFULL_OPTION_SPLIT) != 0;
+    mbDragFull = bool(Application::GetSettings().GetStyleSettings().GetDragFullOptions() & DragFullOptions::Split);
     if ( !mbDragFull )
         ImplDrawSplitter();
 }
 
-
-// -----------------------------------------------------------------------
-
 void Splitter::ImplStartKbdSplitting()
 {
     if( mbKbdSplitting )
         return;
 
-    mbKbdSplitting = sal_True;
+    mbKbdSplitting = true;
 
     StartSplit();
 
@@ -576,8 +525,6 @@ void Splitter::ImplStartKbdSplitting()
         mnStartSplitPos = maDragPos.Y();
 }
 
-// -----------------------------------------------------------------------
-
 void Splitter::ImplRestoreSplitter()
 {
     // set splitter in the center of the ref window
@@ -606,9 +553,6 @@ void Splitter::ImplRestoreSplitter()
     EndSplit();
 }
 
-
-// -----------------------------------------------------------------------
-
 void Splitter::GetFocus()
 {
     if( !ImplSplitterActive() )
@@ -617,21 +561,17 @@ void Splitter::GetFocus()
     Invalidate();
 }
 
-// -----------------------------------------------------------------------
-
 void Splitter::LoseFocus()
 {
     if( mbKbdSplitting )
     {
-        KeyCode aReturnKey( KEY_RETURN );
+        vcl::KeyCode aReturnKey( KEY_RETURN );
         ImplKbdTracking( aReturnKey );
-        mbKbdSplitting = sal_False;
+        mbKbdSplitting = false;
     }
     Invalidate();
 }
 
-// -----------------------------------------------------------------------
-
 void Splitter::KeyInput( const KeyEvent& rKEvt )
 {
     if( mbInKeyEvent )
@@ -640,7 +580,7 @@ void Splitter::KeyInput( const KeyEvent& rKEvt )
     mbInKeyEvent = 1;
 
     Splitter *pSibling = ImplFindSibling();
-    KeyCode aKeyCode = rKEvt.GetKeyCode();
+    vcl::KeyCode aKeyCode = rKEvt.GetKeyCode();
     sal_uInt16 nCode = aKeyCode.GetCode();
     switch ( nCode )
     {
@@ -682,7 +622,7 @@ void Splitter::KeyInput( const KeyEvent& rKEvt )
             {
                 if( mbKbdSplitting )
                 {
-                    KeyCode aKey( KEY_ESCAPE );
+                    vcl::KeyCode aKey( KEY_ESCAPE );
                     ImplKbdTracking( aKey );
                 }
 
@@ -731,19 +671,15 @@ void Splitter::KeyInput( const KeyEvent& rKEvt )
     mbInKeyEvent = 0;
 }
 
-// -----------------------------------------------------------------------
-
-long Splitter::Notify( NotifyEvent& rNEvt )
+bool Splitter::Notify( NotifyEvent& rNEvt )
 {
     return Window::Notify( rNEvt );
 }
 
-// -----------------------------------------------------------------------
-
 void Splitter::DataChanged( const DataChangedEvent& rDCEvt )
 {
     Window::DataChanged( rDCEvt );
-    if( rDCEvt.GetType() == DATACHANGED_SETTINGS )
+    if( rDCEvt.GetType() == DataChangedEventType::SETTINGS )
     {
         const AllSettings* pOldSettings = rDCEvt.GetOldSettings();
         if(!pOldSettings)
@@ -761,17 +697,15 @@ void Splitter::DataChanged( const DataChangedEvent& rDCEvt )
     }
 }
 
-// -----------------------------------------------------------------------
-
-void Splitter::Paint( const Rectangle& rPaintRect )
+void Splitter::Paint(vcl::RenderContext& rRenderContext, const Rectangle& rPaintRect)
 {
-    DrawRect( rPaintRect );
+    rRenderContext.DrawRect(rPaintRect);
 
-    Polygon aPoly( rPaintRect );
-    PolyPolygon aPolyPoly( aPoly );
-    DrawTransparent( aPolyPoly, 85 );
+    Polygon aPoly(rPaintRect);
+    tools::PolyPolygon aPolyPoly(aPoly);
+    rRenderContext.DrawTransparent(aPolyPoly, 85);
 
-    if( mbKbdSplitting )
+    if (mbKbdSplitting)
     {
         LineInfo aInfo( LINE_DASH );
         //aInfo.SetDashLen( 2 );
@@ -780,11 +714,11 @@ void Splitter::Paint( const Rectangle& rPaintRect )
         aInfo.SetDotLen( 2 );
         aInfo.SetDotCount( 3 );
 
-        DrawPolyLine( aPoly, aInfo );
+        rRenderContext.DrawPolyLine( aPoly, aInfo );
     }
     else
     {
-        DrawRect( rPaintRect );
+        rRenderContext.DrawRect(rPaintRect);
     }
 }
 
