@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #ifdef AIX
 #define _LINUX_SOURCE_COMPAT
 #include <sys/timer.h>
@@ -40,7 +39,6 @@
 
 using namespace com::sun::star;
 
-
 AtkListener::AtkListener( AtkObjectWrapper* pWrapper ) : mpWrapper( pWrapper )
 {
     if( mpWrapper )
@@ -89,7 +87,7 @@ extern "C" {
 }
 
 // XEventListener implementation
-void AtkListener::disposing( const lang::EventObject& ) throw (uno::RuntimeException)
+void AtkListener::disposing( const lang::EventObject& ) throw (uno::RuntimeException, std::exception)
 {
     if( mpWrapper )
     {
@@ -99,7 +97,7 @@ void AtkListener::disposing( const lang::EventObject& ) throw (uno::RuntimeExcep
         // global mutex
         atk_object_wrapper_dispose( mpWrapper );
 
-        g_idle_add( (GSourceFunc) idle_defunc_state_change,
+        g_idle_add( reinterpret_cast<GSourceFunc>(idle_defunc_state_change),
                     g_object_ref( G_OBJECT( atk_obj ) ) );
 
         // Release the wrapper object so that it can vanish ..
@@ -139,7 +137,10 @@ void AtkListener::updateChildList(accessibility::XAccessibleContext* pContext)
              }
              catch (lang::IndexOutOfBoundsException const&)
              {
-                 assert(false); // not consistent with getAccessibleChildCount
+                 sal_Int32 nChildren2 = pContext->getAccessibleChildCount();
+                 assert(nChildren2 <= n && "consistency?");
+                 m_aChildList.resize(std::min(nChildren2, n));
+                 break;
              }
              OSL_ASSERT(m_aChildList[n].is());
          }
@@ -268,7 +269,7 @@ getAccessibleContextFromSource( const uno::Reference< uno::XInterface >& rxSourc
 /*****************************************************************************/
 
 // XAccessibleEventListener
-void AtkListener::notifyEvent( const accessibility::AccessibleEventObject& aEvent ) throw( uno::RuntimeException )
+void AtkListener::notifyEvent( const accessibility::AccessibleEventObject& aEvent ) throw( uno::RuntimeException, std::exception )
 {
     if( !mpWrapper )
         return;
@@ -549,6 +550,14 @@ void AtkListener::notifyEvent( const accessibility::AccessibleEventObject& aEven
             g_signal_emit_by_name( G_OBJECT( atk_obj ), "property_change::accessible-hypertext-offset");
             break;
 
+        case accessibility::AccessibleEventId::ROLE_CHANGED:
+        {
+            uno::Reference< accessibility::XAccessibleContext > xContext;
+            xContext = getAccessibleContextFromSource( aEvent.Source );
+            atk_object_wrapper_set_role( mpWrapper, xContext->getAccessibleRole() );
+            break;
+        }
+
     default:
             g_warning( "Unknown event notification %d", aEvent.EventId );
             break;
