@@ -11,6 +11,8 @@
 
 #ifdef ENABLE_GMENU_INTEGRATION
 
+#include <generic/gendata.hxx>
+#include <unx/saldisp.hxx>
 #include <unx/gtk/glomenu.h>
 #include <unx/gtk/gloactiongroup.h>
 #include <vcl/menu.hxx>
@@ -28,7 +30,7 @@
 const sal_uInt16 START_ITEMID_WINDOWLIST    = 4600;
 const sal_uInt16 END_ITEMID_WINDOWLIST      = 4699;
 
-static sal_Bool bMenuVisibility = sal_False;
+static bool bMenuVisibility = false;
 
 /*
  * This function generates the proper command name for all actions, including
@@ -70,94 +72,13 @@ static gchar* GetCommandForItem( GtkSalMenuItem* pSalMenuItem, gchar* aCurrentCo
     return aCommand;
 }
 
-static void KeyCodeToGdkKey ( const KeyCode& rKeyCode, guint* pGdkKeyCode, GdkModifierType *pGdkModifiers )
-{
-    if ( pGdkKeyCode == NULL || pGdkModifiers == NULL )
-        return;
-
-    // Get GDK key modifiers
-    GdkModifierType nModifiers = (GdkModifierType) 0;
-
-    if ( rKeyCode.IsShift() )
-        nModifiers = (GdkModifierType) ( nModifiers | GDK_SHIFT_MASK );
-
-    if ( rKeyCode.IsMod1() )
-        nModifiers = (GdkModifierType) ( nModifiers | GDK_CONTROL_MASK );
-
-    if ( rKeyCode.IsMod2() )
-        nModifiers = (GdkModifierType) ( nModifiers | GDK_MOD1_MASK );
-
-    *pGdkModifiers = nModifiers;
-
-    // Get GDK keycode.
-    guint nKeyCode = 0;
-
-    guint nCode = rKeyCode.GetCode();
-
-    if ( nCode >= KEY_0 && nCode <= KEY_9 )
-        nKeyCode = ( nCode - KEY_0 ) + GDK_0;
-    else if ( nCode >= KEY_A && nCode <= KEY_Z )
-        nKeyCode = ( nCode - KEY_A ) + GDK_A;
-    else if ( nCode >= KEY_F1 && nCode <= KEY_F26 )
-        nKeyCode = ( nCode - KEY_F1 ) + GDK_F1;
-    else
-    {
-        switch( nCode )
-        {
-        case KEY_DOWN:          nKeyCode = GDK_Down;            break;
-        case KEY_UP:            nKeyCode = GDK_Up;              break;
-        case KEY_LEFT:          nKeyCode = GDK_Left;            break;
-        case KEY_RIGHT:         nKeyCode = GDK_Right;           break;
-        case KEY_HOME:          nKeyCode = GDK_Home;            break;
-        case KEY_END:           nKeyCode = GDK_End;             break;
-        case KEY_PAGEUP:        nKeyCode = GDK_Page_Up;         break;
-        case KEY_PAGEDOWN:      nKeyCode = GDK_Page_Down;       break;
-        case KEY_RETURN:        nKeyCode = GDK_Return;          break;
-        case KEY_ESCAPE:        nKeyCode = GDK_Escape;          break;
-        case KEY_TAB:           nKeyCode = GDK_Tab;             break;
-        case KEY_BACKSPACE:     nKeyCode = GDK_BackSpace;       break;
-        case KEY_SPACE:         nKeyCode = GDK_space;           break;
-        case KEY_INSERT:        nKeyCode = GDK_Insert;          break;
-        case KEY_DELETE:        nKeyCode = GDK_Delete;          break;
-        case KEY_ADD:           nKeyCode = GDK_plus;            break;
-        case KEY_SUBTRACT:      nKeyCode = GDK_minus;           break;
-        case KEY_MULTIPLY:      nKeyCode = GDK_asterisk;        break;
-        case KEY_DIVIDE:        nKeyCode = GDK_slash;           break;
-        case KEY_POINT:         nKeyCode = GDK_period;          break;
-        case KEY_COMMA:         nKeyCode = GDK_comma;           break;
-        case KEY_LESS:          nKeyCode = GDK_less;            break;
-        case KEY_GREATER:       nKeyCode = GDK_greater;         break;
-        case KEY_EQUAL:         nKeyCode = GDK_equal;           break;
-        case KEY_FIND:          nKeyCode = GDK_Find;            break;
-        case KEY_CONTEXTMENU:   nKeyCode = GDK_Menu;            break;
-        case KEY_HELP:          nKeyCode = GDK_Help;            break;
-        case KEY_UNDO:          nKeyCode = GDK_Undo;            break;
-        case KEY_REPEAT:        nKeyCode = GDK_Redo;            break;
-        case KEY_DECIMAL:       nKeyCode = GDK_KP_Decimal;      break;
-        case KEY_TILDE:         nKeyCode = GDK_asciitilde;      break;
-        case KEY_QUOTELEFT:     nKeyCode = GDK_quoteleft;       break;
-        case KEY_BRACKETLEFT:   nKeyCode = GDK_bracketleft;     break;
-        case KEY_BRACKETRIGHT:  nKeyCode = GDK_bracketright;    break;
-        case KEY_SEMICOLON:     nKeyCode = GDK_semicolon;       break;
-
-        // Special cases
-        case KEY_COPY:          nKeyCode = GDK_Copy;            break;
-        case KEY_CUT:           nKeyCode = GDK_Cut;             break;
-        case KEY_PASTE:         nKeyCode = GDK_Paste;           break;
-        case KEY_OPEN:          nKeyCode = GDK_Open;            break;
-        }
-    }
-
-    *pGdkKeyCode = nKeyCode;
-}
-
 bool GtkSalMenu::PrepUpdate()
 {
     const GtkSalFrame* pFrame = GetFrame();
     if (pFrame)
     {
-        GtkSalFrame* pNonConstFrame = ( GtkSalFrame* ) pFrame;
-        GtkSalMenu* pSalMenu = ((GtkSalMenu*) this);
+        GtkSalFrame* pNonConstFrame = const_cast<GtkSalFrame*>(pFrame);
+        GtkSalMenu* pSalMenu = this;
 
         if ( !pNonConstFrame->GetMenu() )
             pNonConstFrame->SetMenu( pSalMenu );
@@ -206,13 +127,17 @@ void RemoveSpareSectionsFromNativeMenu( GLOMenu* pMenu, GList** pOldCommandList,
 
 gint CompareStr( gpointer str1, gpointer str2 )
 {
-    return g_strcmp0( (const gchar*) str1, (const gchar*) str2 );
+    return g_strcmp0( static_cast<const gchar*>(str1), static_cast<const gchar*>(str2) );
 }
 
 void RemoveUnusedCommands( GLOActionGroup* pActionGroup, GList* pOldCommandList, GList* pNewCommandList )
 {
     if ( pActionGroup == NULL || pOldCommandList == NULL )
+    {
+        g_list_free_full( pOldCommandList, g_free );
+        g_list_free_full( pNewCommandList, g_free );
         return;
+    }
 
     while ( pNewCommandList != NULL )
     {
@@ -221,7 +146,7 @@ void RemoveUnusedCommands( GLOActionGroup* pActionGroup, GList* pOldCommandList,
 
         gpointer aCommand = g_list_nth_data( pNewCommand, 0 );
 
-        GList* pOldCommand = g_list_find_custom( pOldCommandList, aCommand, (GCompareFunc) CompareStr );
+        GList* pOldCommand = g_list_find_custom( pOldCommandList, aCommand, reinterpret_cast<GCompareFunc>(CompareStr) );
 
         if ( pOldCommand != NULL )
         {
@@ -237,7 +162,7 @@ void RemoveUnusedCommands( GLOActionGroup* pActionGroup, GList* pOldCommandList,
         GList* pCommand = g_list_first( pOldCommandList );
         pOldCommandList = g_list_remove_link( pOldCommandList, pCommand );
 
-        gchar* aCommand = (gchar*) g_list_nth_data( pCommand, 0 );
+        gchar* aCommand = static_cast<gchar*>(g_list_nth_data( pCommand, 0 ));
 
         g_lo_action_group_remove( pActionGroup, aCommand );
 
@@ -271,13 +196,13 @@ void GtkSalMenu::ImplUpdate( gboolean bRecurse )
     sal_Int32 nItem;
 
     for ( nItem = 0; nItem < ( sal_Int32 ) GetItemCount(); nItem++ ) {
-        if ( IsItemVisible( nItem ) == sal_False )
+        if ( !IsItemVisible( nItem ) )
             continue;
 
         GtkSalMenuItem *pSalMenuItem = GetItemAtPos( nItem );
         sal_uInt16 nId = pSalMenuItem->mnId;
 
-        if ( pSalMenuItem->mnType == MENUITEM_SEPARATOR )
+        if ( pSalMenuItem->mnType == MenuItemType::SEPARATOR )
         {
             // Delete extra items from current section.
             RemoveSpareItemsFromNativeMenu( pLOMenu, &pOldCommandList, nSection, validItems );
@@ -300,15 +225,11 @@ void GtkSalMenu::ImplUpdate( gboolean bRecurse )
 
         // Get internal menu item values.
         OUString aText = pVCLMenu->GetItemText( nId );
-        sal_Bool itemEnabled = pVCLMenu->IsItemEnabled( nId );
-        KeyCode nAccelKey = pVCLMenu->GetAccelKey( nId );
-        sal_Bool itemChecked = pVCLMenu->IsItemChecked( nId );
+        bool bEnabled = pVCLMenu->IsItemEnabled( nId );
+        vcl::KeyCode nAccelKey = pVCLMenu->GetAccelKey( nId );
+        bool bChecked = pVCLMenu->IsItemChecked( nId );
         MenuItemBits itemBits = pVCLMenu->GetItemBits( nId );
 
-        // Convert internal values to native values.
-        gboolean bChecked = ( itemChecked == sal_True ) ? TRUE : FALSE;
-        gboolean bEnabled = ( itemEnabled == sal_True ) ? TRUE : FALSE;
-
         // Store current item command in command list.
         gchar *aCurrentCommand = g_lo_menu_get_command_from_item_in_section( pLOMenu, nSection, nItemPos );
 
@@ -383,15 +304,13 @@ void GtkSalMenu::UpdateFull()
     ImplUpdate( TRUE );
 }
 
-
 /*
  * GtkSalMenu
  */
 
-GtkSalMenu::GtkSalMenu( sal_Bool bMenuBar ) :
+GtkSalMenu::GtkSalMenu( bool bMenuBar ) :
     mbMenuBar( bMenuBar ),
     mpVCLMenu( NULL ),
-    mpOldSalMenu( NULL ),
     mpParentSalMenu( NULL ),
     mpFrame( NULL ),
     mpMenuModel( NULL ),
@@ -403,7 +322,7 @@ GtkSalMenu::~GtkSalMenu()
 {
     SolarMutexGuard aGuard;
 
-    if ( mbMenuBar == sal_True )
+    if ( mbMenuBar )
     {
         if ( mpMenuModel )
         {
@@ -415,7 +334,7 @@ GtkSalMenu::~GtkSalMenu()
     maItems.clear();
 }
 
-sal_Bool GtkSalMenu::VisibleMenuBar()
+bool GtkSalMenu::VisibleMenuBar()
 {
     return bMenuVisibility;
 }
@@ -452,9 +371,51 @@ void GtkSalMenu::SetSubMenu( SalMenuItem* pSalMenuItem, SalMenu* pSubMenu, unsig
     pItem->mpSubMenu = pGtkSubMenu;
 }
 
+static bool bInvalidMenus = false;
+static gboolean RefreshMenusUnity(gpointer)
+{
+    SolarMutexGuard g;
+
+    SalDisplay* pSalDisplay = vcl_sal::getSalDisplay(GetGenericData());
+    std::list< SalFrame* >::const_iterator pSalFrame = pSalDisplay->getFrames().begin();
+    std::list< SalFrame* >::const_iterator pEndSalFrame = pSalDisplay->getFrames().end();
+    for(; pSalFrame != pEndSalFrame; ++pSalFrame) {
+        const GtkSalFrame* pGtkSalFrame = static_cast< const GtkSalFrame* >( *pSalFrame );
+        GtkSalFrame* pFrameNonConst = const_cast<GtkSalFrame*>(pGtkSalFrame);
+        GtkSalMenu* pSalMenu = static_cast<GtkSalMenu*>(pFrameNonConst->GetMenu());
+        if(pSalMenu) {
+            pSalMenu->Activate();
+            pSalMenu->UpdateFull();
+        }
+    }
+    bInvalidMenus = false;
+    return FALSE;
+}
+
+static long RefreshMenusUnity(void*, void*)
+{
+    if(!bInvalidMenus) {
+        g_timeout_add(10, &RefreshMenusUnity, NULL);
+        bInvalidMenus = true;
+    }
+    return 0;
+}
+
+static Link<>* getRefreshLinkInstance()
+{
+    static Link<>* pLink = NULL;
+    if(!pLink) {
+        pLink = new Link<>(NULL, &RefreshMenusUnity);
+    }
+    return pLink;
+}
+
 void GtkSalMenu::SetFrame( const SalFrame* pFrame )
 {
     SolarMutexGuard aGuard;
+    {
+        vcl::MenuInvalidator::GetMenuInvalidateListeners()->addListener(*getRefreshLinkInstance());
+    }
 
     assert(mbMenuBar);
     SAL_INFO("vcl.unity", "GtkSalMenu set to frame");
@@ -464,7 +425,6 @@ void GtkSalMenu::SetFrame( const SalFrame* pFrame )
     // if we had a menu on the GtkSalMenu we have to free it as we generate a
     // full menu anyway and we might need to reuse an existing model and
     // actiongroup
-    mpOldSalMenu = static_cast< GtkSalMenu* >( pFrameNonConst->GetMenu() );
     pFrameNonConst->SetMenu( this );
     pFrameNonConst->EnsureAppMenuWatch();
 
@@ -520,7 +480,7 @@ void GtkSalMenu::NativeCheckItem( unsigned nSection, unsigned nItemPos, MenuItem
         GVariant *pCheckValue = NULL;
         GVariant *pCurrentState = g_action_group_get_action_state( mpActionGroup, aCommand );
 
-        if ( bits & MIB_RADIOCHECK )
+        if ( bits & MenuItemBits::RADIOCHECK )
             pCheckValue = bCheck ? g_variant_new_string( aCommand ) : g_variant_new_string( "" );
         else
         {
@@ -529,8 +489,17 @@ void GtkSalMenu::NativeCheckItem( unsigned nSection, unsigned nItemPos, MenuItem
                 pCheckValue = g_variant_new_boolean( bCheck );
         }
 
-        if ( pCheckValue != NULL && ( pCurrentState == NULL || g_variant_equal( pCurrentState, pCheckValue ) == FALSE ) )
-            g_action_group_change_action_state( mpActionGroup, aCommand, pCheckValue );
+        if ( pCheckValue != NULL )
+        {
+            if ( pCurrentState == NULL || g_variant_equal( pCurrentState, pCheckValue ) == FALSE )
+            {
+                g_action_group_change_action_state( mpActionGroup, aCommand, pCheckValue );
+            }
+            else
+            {
+                g_variant_unref (pCheckValue);
+            }
+        }
 
         if ( pCurrentState != NULL )
             g_variant_unref( pCurrentState );
@@ -568,7 +537,7 @@ void GtkSalMenu::NativeSetItemText( unsigned nSection, unsigned nItemPos, const
         g_free( aLabel );
 }
 
-void GtkSalMenu::NativeSetAccelerator( unsigned nSection, unsigned nItemPos, const KeyCode& rKeyCode, const OUString& rKeyName )
+void GtkSalMenu::NativeSetAccelerator( unsigned nSection, unsigned nItemPos, const vcl::KeyCode& rKeyCode, const OUString& rKeyName )
 {
     SolarMutexGuard aGuard;
 
@@ -577,8 +546,7 @@ void GtkSalMenu::NativeSetAccelerator( unsigned nSection, unsigned nItemPos, con
 
     guint nKeyCode;
     GdkModifierType nModifiers;
-
-    KeyCodeToGdkKey( rKeyCode, &nKeyCode, &nModifiers );
+    GtkSalFrame::KeyCodeToGdkKey(rKeyCode, &nKeyCode, &nModifiers);
 
     gchar* aAccelerator = gtk_accelerator_name( nKeyCode, nModifiers );
 
@@ -588,6 +556,7 @@ void GtkSalMenu::NativeSetAccelerator( unsigned nSection, unsigned nItemPos, con
         g_lo_menu_set_accelerator_to_item_in_section ( G_LO_MENU( mpMenuModel ), nSection, nItemPos, aAccelerator );
 
     g_free( aAccelerator );
+    g_free( aCurrentAccel );
 }
 
 void GtkSalMenu::NativeSetItemCommand( unsigned nSection,
@@ -604,19 +573,19 @@ void GtkSalMenu::NativeSetItemCommand( unsigned nSection,
     GVariant *pTarget = NULL;
 
     if ( g_action_group_has_action( mpActionGroup, aCommand ) == FALSE ) {
-        if ( ( nBits & MIB_CHECKABLE ) || bIsSubmenu )
+        if ( ( nBits & MenuItemBits::CHECKABLE ) || bIsSubmenu )
         {
             // Item is a checkmark button.
-            GVariantType* pStateType = g_variant_type_new( (gchar*) G_VARIANT_TYPE_BOOLEAN );
+            GVariantType* pStateType = g_variant_type_new( reinterpret_cast<gchar const *>(G_VARIANT_TYPE_BOOLEAN) );
             GVariant* pState = g_variant_new_boolean( bChecked );
 
             g_lo_action_group_insert_stateful( pActionGroup, aCommand, nId, bIsSubmenu, NULL, pStateType, NULL, pState );
         }
-        else if ( nBits & MIB_RADIOCHECK )
+        else if ( nBits & MenuItemBits::RADIOCHECK )
         {
             // Item is a radio button.
-            GVariantType* pParameterType = g_variant_type_new( (gchar*) G_VARIANT_TYPE_STRING );
-            GVariantType* pStateType = g_variant_type_new( (gchar*) G_VARIANT_TYPE_STRING );
+            GVariantType* pParameterType = g_variant_type_new( reinterpret_cast<gchar const *>(G_VARIANT_TYPE_STRING) );
+            GVariantType* pStateType = g_variant_type_new( reinterpret_cast<gchar const *>(G_VARIANT_TYPE_STRING) );
             GVariant* pState = g_variant_new_string( "" );
             pTarget = g_variant_new_string( aCommand );
 
@@ -661,7 +630,11 @@ GtkSalMenu* GtkSalMenu::GetMenuForItemCommand( gchar* aCommand, gboolean bGetSub
         GtkSalMenuItem *pSalItem = maItems[ nPos ];
 
         OUString aItemCommand = mpVCLMenu->GetItemCommand( pSalItem->mnId );
-        gchar* aItemCommandStr = (gchar*) OUStringToOString( aItemCommand, RTL_TEXTENCODING_UTF8 ).getStr();
+        // Do not join the following two lines, or the OString will be destroyed
+        // immediately, and the gchar* pointed to by aItemCommandStr will be
+        // freed before it can be used - fdo#69090
+        OString aItemCommandOStr = OUStringToOString( aItemCommand, RTL_TEXTENCODING_UTF8 );
+        gchar* aItemCommandStr = const_cast<gchar*>(aItemCommandOStr.getStr());
 
         if ( g_strcmp0( aItemCommandStr, aCommand ) == 0 )
         {
@@ -685,10 +658,10 @@ void GtkSalMenu::DispatchCommand( gint itemId, const gchar *aCommand )
 {
     SolarMutexGuard aGuard;
     // Only the menubar is allowed to dispatch commands.
-    if ( mbMenuBar != TRUE )
+    if ( !mbMenuBar )
         return;
 
-    GtkSalMenu* pSalSubMenu = GetMenuForItemCommand( (gchar*) aCommand, FALSE );
+    GtkSalMenu* pSalSubMenu = GetMenuForItemCommand( const_cast<gchar*>(aCommand), FALSE );
     Menu* pSubMenu = ( pSalSubMenu != NULL ) ? pSalSubMenu->GetMenu() : NULL;
 
     MenuBar* pMenuBar = static_cast< MenuBar* >( mpVCLMenu );
@@ -711,18 +684,17 @@ void GtkSalMenu::ActivateAllSubmenus(MenuBar* pMenuBar)
 
 void GtkSalMenu::Activate()
 {
-    if ( mbMenuBar != TRUE )
+    if ( !mbMenuBar )
         return;
     ActivateAllSubmenus(static_cast<MenuBar*>(mpVCLMenu));
 }
 
-
 void GtkSalMenu::Deactivate( const gchar* aMenuCommand )
 {
-    if ( mbMenuBar == sal_False )
+    if ( !mbMenuBar )
         return;
 
-    GtkSalMenu* pSalSubMenu = GetMenuForItemCommand( (gchar*) aMenuCommand, TRUE );
+    GtkSalMenu* pSalSubMenu = GetMenuForItemCommand( const_cast<gchar*>(aMenuCommand), TRUE );
 
     if ( pSalSubMenu != NULL ) {
         MenuBar* pMenuBar = static_cast< MenuBar* >( mpVCLMenu );
@@ -730,23 +702,23 @@ void GtkSalMenu::Deactivate( const gchar* aMenuCommand )
     }
 }
 
-void GtkSalMenu::Display( sal_Bool bVisible )
+void GtkSalMenu::Display( bool bVisible )
 {
-    if ( mbMenuBar == sal_False || mpVCLMenu == NULL )
+    if ( !mbMenuBar || mpVCLMenu == NULL )
         return;
 
     bMenuVisibility = bVisible;
 
-    sal_Bool bVCLMenuVisible = ( bVisible == sal_True ) ? sal_False : sal_True;
+    bool bVCLMenuVisible = !bVisible;
 
     MenuBar* pMenuBar = static_cast< MenuBar* >( mpVCLMenu );
     pMenuBar->SetDisplayable( bVCLMenuVisible );
 }
 
-sal_Bool GtkSalMenu::IsItemVisible( unsigned nPos )
+bool GtkSalMenu::IsItemVisible( unsigned nPos )
 {
     SolarMutexGuard aGuard;
-    sal_Bool bVisible = sal_False;
+    bool bVisible = false;
 
     if ( nPos < maItems.size() )
         bVisible = ( ( GtkSalMenuItem* ) maItems[ nPos ])->mbVisible;
@@ -754,22 +726,21 @@ sal_Bool GtkSalMenu::IsItemVisible( unsigned nPos )
     return bVisible;
 }
 
-void GtkSalMenu::CheckItem( unsigned, sal_Bool )
+void GtkSalMenu::CheckItem( unsigned, bool )
 {
 }
 
-void GtkSalMenu::EnableItem( unsigned, sal_Bool )
+void GtkSalMenu::EnableItem( unsigned, bool )
 {
 }
 
-void GtkSalMenu::ShowItem( unsigned nPos, sal_Bool bShow )
+void GtkSalMenu::ShowItem( unsigned nPos, bool bShow )
 {
     SolarMutexGuard aGuard;
     if ( nPos < maItems.size() )
         ( ( GtkSalMenuItem* ) maItems[ nPos ] )->mbVisible = bShow;
 }
 
-
 void GtkSalMenu::SetItemText( unsigned, SalMenuItem*, const OUString& )
 {
 }
@@ -778,7 +749,7 @@ void GtkSalMenu::SetItemImage( unsigned, SalMenuItem*, const Image& )
 {
 }
 
-void GtkSalMenu::SetAccelerator( unsigned, SalMenuItem*, const KeyCode&, const OUString& )
+void GtkSalMenu::SetAccelerator( unsigned, SalMenuItem*, const vcl::KeyCode&, const OUString& )
 {
 }
 
@@ -786,8 +757,6 @@ void GtkSalMenu::GetSystemMenuData( SystemMenuData* )
 {
 }
 
-// =======================================================================
-
 /*
  * GtkSalMenuItem
  */
@@ -795,7 +764,7 @@ void GtkSalMenu::GetSystemMenuData( SystemMenuData* )
 GtkSalMenuItem::GtkSalMenuItem( const SalItemParams* pItemData ) :
     mnId( pItemData->nId ),
     mnType( pItemData->eType ),
-    mbVisible( sal_True ),
+    mbVisible( true ),
     mpVCLMenu( pItemData->pMenu ),
     mpParentMenu( NULL ),
     mpSubMenu( NULL )
