@@ -88,7 +88,6 @@ XMLSectionExport::XMLSectionExport(
 ,   sCreateFromStarCalc("CreateFromStarCalc")
 ,   sCreateFromStarChart("CreateFromStarChart")
 ,   sCreateFromStarDraw("CreateFromStarDraw")
-,   sCreateFromStarImage("CreateFromStarImage")
 ,   sCreateFromStarMath("CreateFromStarMath")
 ,   sCreateFromTables("CreateFromTables")
 ,   sCreateFromTextFrames("CreateFromTextFrames")
@@ -107,7 +106,6 @@ XMLSectionExport::XMLSectionExport(
 ,   sLinkRegion("LinkRegion")
 ,   sMainEntryCharacterStyleName("MainEntryCharacterStyleName")
 ,   sParaStyleHeading("ParaStyleHeading")
-,   sParaStyleLevel("ParaStyleLevel")
 ,   sTitle("Title")
 ,   sName("Name")
 ,   sUseAlphabeticalSeparators("UseAlphabeticalSeparators")
@@ -137,14 +135,14 @@ XMLSectionExport::XMLSectionExport(
 
 ,   rExport(rExp)
 ,   rParaExport(rParaExp)
-,   bHeadingDummiesExported( sal_False )
+,   bHeadingDummiesExported( false )
 {
 }
 
 
 void XMLSectionExport::ExportSectionStart(
     const Reference<XTextSection> & rSection,
-    sal_Bool bAutoStyles)
+    bool bAutoStyles)
 {
     Reference<XPropertySet> xPropertySet(rSection, UNO_QUERY);
 
@@ -188,12 +186,12 @@ void XMLSectionExport::ExportSectionStart(
     }
 }
 
-sal_Bool XMLSectionExport::GetIndex(
+bool XMLSectionExport::GetIndex(
     const Reference<XTextSection> & rSection,
     Reference<XDocumentIndex> & rIndex) const
 {
     // first, reset result
-    sal_Bool bRet = sal_False;
+    bool bRet = false;
     rIndex = NULL;
 
     // get section Properties
@@ -220,7 +218,7 @@ sal_Bool XMLSectionExport::GetIndex(
             if (rSection == xEnclosingSection)
             {
                 rIndex = xDocumentIndex;
-                bRet = sal_True;
+                bRet = true;
             }
             // else: index header or regular section
 
@@ -232,7 +230,7 @@ sal_Bool XMLSectionExport::GetIndex(
             // if the enclosing section is "our" section, then we are an index!
             if (rSection == xEnclosingSection)
             {
-                bRet = sal_True;
+                bRet = true;
             }
             // else: regular section
         }
@@ -246,7 +244,7 @@ sal_Bool XMLSectionExport::GetIndex(
 
 void XMLSectionExport::ExportSectionEnd(
     const Reference<XTextSection> & rSection,
-    sal_Bool bAutoStyles)
+    bool bAutoStyles)
 {
     // no end section for styles
     if (!bAutoStyles)
@@ -261,7 +259,7 @@ void XMLSectionExport::ExportSectionEnd(
             {
                 // index end: close index body element
                 GetExport().EndElement( XML_NAMESPACE_TEXT, XML_INDEX_BODY,
-                                        sal_True );
+                                        true );
                 GetExport().IgnorableWhitespace();
 
                 switch (MapSectionType(xIndex->getServiceName()))
@@ -316,7 +314,7 @@ void XMLSectionExport::ExportSectionEnd(
             GetExport().CheckAttrList();
 
             // element surrounded by whitespace
-            GetExport().EndElement( XML_NAMESPACE_TEXT, eElement, sal_True);
+            GetExport().EndElement( XML_NAMESPACE_TEXT, eElement, true);
             GetExport().IgnorableWhitespace();
         }
         else
@@ -378,7 +376,7 @@ void XMLSectionExport::ExportIndexHeaderStart(
     GetExport().AddAttribute(XML_NAMESPACE_TEXT, XML_NAME, xName->getName());
 
     // format already handled -> export only start element
-    GetExport().StartElement( XML_NAMESPACE_TEXT, XML_INDEX_TITLE, sal_True );
+    GetExport().StartElement( XML_NAMESPACE_TEXT, XML_INDEX_TITLE, true );
     GetExport().IgnorableWhitespace();
 }
 
@@ -432,13 +430,13 @@ void XMLSectionExport::ExportRegularSectionStart(
     {
         OUString sQValue =
             GetExport().GetNamespaceMap().GetQNameByKey( XML_NAMESPACE_OOOW,
-                                                         sCond, sal_False );
+                                                         sCond, false );
         GetExport().AddAttribute(XML_NAMESPACE_TEXT, XML_CONDITION, sQValue);
         eDisplay = XML_CONDITION;
 
         // #97450# store hidden-status (of conditional sections only)
         aAny = xPropSet->getPropertyValue(sIsCurrentlyVisible);
-        if (! *(sal_Bool*)aAny.getValue())
+        if (! *static_cast<sal_Bool const *>(aAny.getValue()))
         {
             GetExport().AddAttribute(XML_NAMESPACE_TEXT, XML_IS_HIDDEN,
                                      XML_TRUE);
@@ -449,14 +447,14 @@ void XMLSectionExport::ExportRegularSectionStart(
         eDisplay = XML_NONE;
     }
     aAny = xPropSet->getPropertyValue(sIsVisible);
-    if (! *(sal_Bool*)aAny.getValue())
+    if (! *static_cast<sal_Bool const *>(aAny.getValue()))
     {
         GetExport().AddAttribute(XML_NAMESPACE_TEXT, XML_DISPLAY, eDisplay);
     }
 
     // protect + protection key
     aAny = xPropSet->getPropertyValue(sIsProtected);
-    if (*(sal_Bool*)aAny.getValue())
+    if (*static_cast<sal_Bool const *>(aAny.getValue()))
     {
         GetExport().AddAttribute(XML_NAMESPACE_TEXT, XML_PROTECTED, XML_TRUE);
     }
@@ -472,7 +470,7 @@ void XMLSectionExport::ExportRegularSectionStart(
 
     // export element
     GetExport().IgnorableWhitespace();
-    GetExport().StartElement( XML_NAMESPACE_TEXT, XML_SECTION, sal_True );
+    GetExport().StartElement( XML_NAMESPACE_TEXT, XML_SECTION, true );
 
     // data source
     // unfortunately, we have to test all relevant strings for non-zero length
@@ -508,7 +506,7 @@ void XMLSectionExport::ExportRegularSectionStart(
 
         SvXMLElementExport aElem(GetExport(),
                                  XML_NAMESPACE_TEXT, XML_SECTION_SOURCE,
-                                 sal_True, sal_True);
+                                 true, true);
     }
     else
     {
@@ -540,7 +538,7 @@ void XMLSectionExport::ExportRegularSectionStart(
                                          sItem);
 
                 aAny = xPropSet->getPropertyValue(sIsAutomaticUpdate);
-                if (*(sal_Bool*)aAny.getValue())
+                if (*static_cast<sal_Bool const *>(aAny.getValue()))
                 {
                     GetExport().AddAttribute(XML_NAMESPACE_OFFICE,
                                              XML_AUTOMATIC_UPDATE, XML_TRUE);
@@ -548,7 +546,7 @@ void XMLSectionExport::ExportRegularSectionStart(
 
                 SvXMLElementExport aElem(GetExport(),
                                          XML_NAMESPACE_OFFICE,
-                                         XML_DDE_SOURCE, sal_True, sal_True);
+                                         XML_DDE_SOURCE, true, true);
             }
             // else: no DDE data source
         }
@@ -579,15 +577,15 @@ void XMLSectionExport::ExportTableOfContentStart(
 
         // use outline level
         ExportBoolean(rPropertySet, sCreateFromOutline,
-                          XML_USE_OUTLINE_LEVEL, sal_True);
+                          XML_USE_OUTLINE_LEVEL, true);
 
         // use index marks
         ExportBoolean(rPropertySet, sCreateFromMarks,
-                      XML_USE_INDEX_MARKS, sal_True);
+                      XML_USE_INDEX_MARKS, true);
 
         // use level styles
         ExportBoolean(rPropertySet, sCreateFromLevelParagraphStyles,
-                      XML_USE_INDEX_SOURCE_STYLES, sal_False);
+                      XML_USE_INDEX_SOURCE_STYLES, false);
 
         ExportBaseIndexSource(TEXT_SECTION_TYPE_TOC, rPropertySet);
     }
@@ -604,15 +602,15 @@ void XMLSectionExport::ExportObjectIndexStart(
     // scope for index source element
     {
         ExportBoolean(rPropertySet, sCreateFromOtherEmbeddedObjects,
-                      XML_USE_OTHER_OBJECTS, sal_False);
+                      XML_USE_OTHER_OBJECTS, false);
         ExportBoolean(rPropertySet, sCreateFromStarCalc,
-                      XML_USE_SPREADSHEET_OBJECTS, sal_False);
+                      XML_USE_SPREADSHEET_OBJECTS, false);
         ExportBoolean(rPropertySet, sCreateFromStarChart,
-                      XML_USE_CHART_OBJECTS, sal_False);
+                      XML_USE_CHART_OBJECTS, false);
         ExportBoolean(rPropertySet, sCreateFromStarDraw,
-                      XML_USE_DRAW_OBJECTS, sal_False);
+                      XML_USE_DRAW_OBJECTS, false);
         ExportBoolean(rPropertySet, sCreateFromStarMath,
-                      XML_USE_MATH_OBJECTS, sal_False);
+                      XML_USE_MATH_OBJECTS, false);
 
         ExportBaseIndexSource(TEXT_SECTION_TYPE_OBJECT, rPropertySet);
     }
@@ -677,21 +675,21 @@ void XMLSectionExport::ExportAlphabeticalIndexStart(
 
         // other (boolean) attributes
         ExportBoolean(rPropertySet, sIsCaseSensitive, XML_IGNORE_CASE,
-                      sal_False, sal_True);
+                      false, true);
         ExportBoolean(rPropertySet, sUseAlphabeticalSeparators,
-                      XML_ALPHABETICAL_SEPARATORS, sal_False);
+                      XML_ALPHABETICAL_SEPARATORS, false);
         ExportBoolean(rPropertySet, sUseCombinedEntries, XML_COMBINE_ENTRIES,
-                      sal_True);
+                      true);
         ExportBoolean(rPropertySet, sUseDash, XML_COMBINE_ENTRIES_WITH_DASH,
-                      sal_False);
+                      false);
         ExportBoolean(rPropertySet, sUseKeyAsEntry, XML_USE_KEYS_AS_ENTRIES,
-                      sal_False);
+                      false);
         ExportBoolean(rPropertySet, sUsePP, XML_COMBINE_ENTRIES_WITH_PP,
-                      sal_True);
+                      true);
         ExportBoolean(rPropertySet, sUseUpperCase, XML_CAPITALIZE_ENTRIES,
-                      sal_False);
+                      false);
         ExportBoolean(rPropertySet, sIsCommaSeparated, XML_COMMA_SEPARATED,
-                      sal_False);
+                      false);
 
         // sort algorithm
         aAny = rPropertySet->getPropertyValue(sSortAlgorithm);
@@ -725,19 +723,19 @@ void XMLSectionExport::ExportUserIndexStart(
     {
         // bool attributes
         ExportBoolean(rPropertySet, sCreateFromEmbeddedObjects,
-                      XML_USE_OBJECTS, sal_False);
+                      XML_USE_OBJECTS, false);
         ExportBoolean(rPropertySet, sCreateFromGraphicObjects,
-                      XML_USE_GRAPHICS, sal_False);
+                      XML_USE_GRAPHICS, false);
         ExportBoolean(rPropertySet, sCreateFromMarks,
-                      XML_USE_INDEX_MARKS, sal_False);
+                      XML_USE_INDEX_MARKS, false);
         ExportBoolean(rPropertySet, sCreateFromTables,
-                      XML_USE_TABLES, sal_False);
+                      XML_USE_TABLES, false);
         ExportBoolean(rPropertySet, sCreateFromTextFrames,
-                      XML_USE_FLOATING_FRAMES, sal_False);
+                      XML_USE_FLOATING_FRAMES, false);
         ExportBoolean(rPropertySet, sUseLevelFromSource,
-                      XML_COPY_OUTLINE_LEVELS, sal_False);
+                      XML_COPY_OUTLINE_LEVELS, false);
         ExportBoolean(rPropertySet, sCreateFromLevelParagraphStyles,
-                      XML_USE_INDEX_SOURCE_STYLES, sal_False);
+                      XML_USE_INDEX_SOURCE_STYLES, false);
 
         Any aAny = rPropertySet->getPropertyValue( sUserIndexName );
         OUString sIndexName;
@@ -774,7 +772,7 @@ void XMLSectionExport::ExportBaseIndexStart(
 {
     // protect + protection key
     Any aAny = rPropertySet->getPropertyValue(sIsProtected);
-    if (*(sal_Bool*)aAny.getValue())
+    if (*static_cast<sal_Bool const *>(aAny.getValue()))
     {
         GetExport().AddAttribute(XML_NAMESPACE_TEXT, XML_PROTECTED, XML_TRUE);
     }
@@ -789,7 +787,7 @@ void XMLSectionExport::ExportBaseIndexStart(
 
     // index  Element start
     GetExport().IgnorableWhitespace();
-    GetExport().StartElement( XML_NAMESPACE_TEXT, eElement, sal_False );
+    GetExport().StartElement( XML_NAMESPACE_TEXT, eElement, false );
 }
 
 static const XMLTokenEnum aTypeSourceElementNameMap[] =
@@ -818,7 +816,7 @@ void XMLSectionExport::ExportBaseIndexSource(
     {
         // document or chapter index?
         aAny = rPropertySet->getPropertyValue(sCreateFromChapter);
-        if (*(sal_Bool*)aAny.getValue())
+        if (*static_cast<sal_Bool const *>(aAny.getValue()))
         {
             GetExport().AddAttribute(XML_NAMESPACE_TEXT,
                                      XML_INDEX_SCOPE, XML_CHAPTER);
@@ -826,7 +824,7 @@ void XMLSectionExport::ExportBaseIndexSource(
 
         // tab-stops relative to margin?
         aAny = rPropertySet->getPropertyValue(sIsRelativeTabstops);
-        if (! *(sal_Bool*)aAny.getValue())
+        if (! *static_cast<sal_Bool const *>(aAny.getValue()))
         {
             GetExport().AddAttribute(XML_NAMESPACE_TEXT,
                                      XML_RELATIVE_TAB_STOP_POSITION,
@@ -840,7 +838,7 @@ void XMLSectionExport::ExportBaseIndexSource(
                              GetXMLToken(
                                  aTypeSourceElementNameMap[
                                     eType - TEXT_SECTION_TYPE_TOC]),
-                             sal_True, sal_True);
+                             true, true);
 
     // scope for title template (all indices)
     {
@@ -856,7 +854,7 @@ void XMLSectionExport::ExportBaseIndexSource(
         SvXMLElementExport aHeaderTemplate(GetExport(),
                                            XML_NAMESPACE_TEXT,
                                            XML_INDEX_TITLE_TEMPLATE,
-                                           sal_True, sal_False);
+                                           true, false);
 
         // title as element content
         aAny = rPropertySet->getPropertyValue(sTitle);
@@ -881,7 +879,7 @@ void XMLSectionExport::ExportBaseIndexSource(
         aAny >>= aTemplateSequence;
 
         // export the sequence (abort export if an error occurred; #91214#)
-        sal_Bool bResult =
+        bool bResult =
             ExportIndexTemplate(eType, i, rPropertySet, aTemplateSequence);
         if ( !bResult )
             break;
@@ -919,7 +917,7 @@ void XMLSectionExport::ExportBaseIndexBody(
 
     // start surrounded by whitespace
     GetExport().IgnorableWhitespace();
-    GetExport().StartElement( XML_NAMESPACE_TEXT, XML_INDEX_BODY, sal_True );
+    GetExport().StartElement( XML_NAMESPACE_TEXT, XML_INDEX_BODY, true );
 }
 
 void XMLSectionExport::ExportTableAndIllustrationIndexSourceAttributes(
@@ -927,7 +925,7 @@ void XMLSectionExport::ExportTableAndIllustrationIndexSourceAttributes(
 {
     // use caption
     Any aAny = rPropertySet->getPropertyValue(sCreateFromLabels);
-    if (! *(sal_Bool*)aAny.getValue())
+    if (! *static_cast<sal_Bool const *>(aAny.getValue()))
     {
         GetExport().AddAttribute(XML_NAMESPACE_TEXT,
                                  XML_USE_CAPTION, XML_FALSE);
@@ -1036,7 +1034,7 @@ static const XMLTokenEnum aTypeElementNameMap[] =
 };
 
 
-sal_Bool XMLSectionExport::ExportIndexTemplate(
+bool XMLSectionExport::ExportIndexTemplate(
     SectionTypeEnum eType,
     sal_Int32 nOutlineLevel,
     const Reference<XPropertySet> & rPropertySet,
@@ -1065,7 +1063,7 @@ sal_Bool XMLSectionExport::ExportIndexTemplate(
         if ( XML_TOKEN_INVALID == eLevelName )
         {
             // output level not found? Then end of templates! #91214#
-            return sal_False;
+            return false;
         }
 
         // output level name
@@ -1097,7 +1095,7 @@ sal_Bool XMLSectionExport::ExportIndexTemplate(
         SvXMLElementExport aLevelTemplate(GetExport(),
                                           XML_NAMESPACE_TEXT,
                                           GetXMLToken(eElementName),
-                                          sal_True, sal_True);
+                                          true, true);
 
         // export sequence
         sal_Int32 nTemplateCount = rValues.getLength();
@@ -1111,7 +1109,7 @@ sal_Bool XMLSectionExport::ExportIndexTemplate(
         }
     }
 
-    return sal_True;
+    return true;
 }
 
 
@@ -1217,38 +1215,38 @@ void XMLSectionExport::ExportIndexTemplateElement(
 
     // char style
     OUString sCharStyle;
-    sal_Bool bCharStyleOK = sal_False;
+    bool bCharStyleOK = false;
 
     // text
     OUString sText;
-    sal_Bool bTextOK = sal_False;
+    bool bTextOK = false;
 
     // tab position
-    sal_Bool bRightAligned = sal_False;
+    bool bRightAligned = false;
 
     // tab position
     sal_Int32 nTabPosition = 0;
-    sal_Bool bTabPositionOK = sal_False;
+    bool bTabPositionOK = false;
 
     // fill character
     OUString sFillChar;
-    sal_Bool bFillCharOK = sal_False;
+    bool bFillCharOK = false;
 
     // chapter format
     sal_Int16 nChapterFormat = 0;
-    sal_Bool bChapterFormatOK = sal_False;
+    bool bChapterFormatOK = false;
 
     // outline max level
     sal_Int16 nLevel = 0;
-    sal_Bool bLevelOK = sal_False;
+    bool bLevelOK = false;
 
     // Bibliography Data
     sal_Int16 nBibliographyData = 0;
-    sal_Bool bBibliographyDataOK = sal_False;
+    bool bBibliographyDataOK = false;
 
     // With Tab Stop #i21237#
-    sal_Bool bWithTabStop = sal_False;
-    sal_Bool bWithTabStopOK = sal_False;
+    bool bWithTabStop = false;
+    bool bWithTabStopOK = false;
 
     //i90246, the ODF version being written to is:
     const SvtSaveOptions::ODFDefaultVersion aODFVersion = rExport.getDefaultVersion();
@@ -1292,42 +1290,42 @@ void XMLSectionExport::ExportIndexTemplateElement(
 
                 case TOK_TPARAM_TEXT:
                     rValues[i].Value >>= sText;
-                    bTextOK = sal_True;
+                    bTextOK = true;
                     break;
 
                 case TOK_TPARAM_TAB_RIGHT_ALIGNED:
                     bRightAligned =
-                        *(sal_Bool *)rValues[i].Value.getValue();
+                        *static_cast<sal_Bool const *>(rValues[i].Value.getValue());
                     break;
 
                 case TOK_TPARAM_TAB_POSITION:
                     rValues[i].Value >>= nTabPosition;
-                    bTabPositionOK = sal_True;
+                    bTabPositionOK = true;
                     break;
 
                 // #i21237#
                 case TOK_TPARAM_TAB_WITH_TAB:
-                    bWithTabStop = *(sal_Bool *)rValues[i].Value.getValue();
-                    bWithTabStopOK = sal_True;
+                    bWithTabStop = *static_cast<sal_Bool const *>(rValues[i].Value.getValue());
+                    bWithTabStopOK = true;
                     break;
 
                 case TOK_TPARAM_TAB_FILL_CHAR:
                     rValues[i].Value >>= sFillChar;
-                    bFillCharOK = sal_True;
+                    bFillCharOK = true;
                     break;
 
                 case TOK_TPARAM_CHAPTER_FORMAT:
                     rValues[i].Value >>= nChapterFormat;
-                    bChapterFormatOK = sal_True;
+                    bChapterFormatOK = true;
                     break;
 //---> i53420
                 case TOK_TPARAM_CHAPTER_LEVEL:
                     rValues[i].Value >>= nLevel;
-                    bLevelOK = sal_True;
+                    bLevelOK = true;
                     break;
                 case TOK_TPARAM_BIBLIOGRAPHY_DATA:
                     rValues[i].Value >>= nBibliographyData;
-                    bBibliographyDataOK = sal_True;
+                    bBibliographyDataOK = true;
                     break;
             }
         }
@@ -1385,7 +1383,7 @@ void XMLSectionExport::ExportIndexTemplateElement(
     if( aODFVersion == SvtSaveOptions::ODFVER_011
         || aODFVersion == SvtSaveOptions::ODFVER_010)
     {
-        bLevelOK = sal_False;
+        bLevelOK = false;
         if (TOK_TTYPE_CHAPTER_INFO == nTokenType)
         {
             //if we are emitting for ODF 1.1 or 1.0, this information can be used for alphabetical index only
@@ -1398,18 +1396,18 @@ void XMLSectionExport::ExportIndexTemplateElement(
             {
                 // a few word here: OOo up to 2.4 uses the field chapter info in Alphabetical index
                 // in a way different from the ODF 1.1/1.0 specification:
-                //
+
                 // ODF1.1/1.0         OOo display in chapter info                       ODF1.2
                 //                    (used in alphabetical index only
-                //
+
                 // number             chapter number without pre/postfix                plain-number
                 // number-and-name    chapter number without pre/postfix plus title     plain-number-and-name
-                //
+
                 // with issue i89791 the reading of ODF 1.1 and 1.0 was corrected
                 // this one corrects the writing back from ODF 1.2 to ODF 1.1/1.0
                 // unfortunately if there is another application which interprets correctly ODF1.1/1.0,
                 // the resulting alphabetical index will be rendered wrong by OOo 2.4 version
-                //
+
                 switch( nChapterFormat )
                 {
                 case ChapterFormat::DIGIT:
@@ -1429,7 +1427,7 @@ void XMLSectionExport::ExportIndexTemplateElement(
             // ' ChapterFormat::DIGIT', forced to 'none, since the
             // 'value allowed in ODF 1.1 and 1.0 is 'number' the default
             // this can be obtained by simply disabling the chapter format
-            bChapterFormatOK = sal_False;
+            bChapterFormatOK = false;
         }
     }
 
@@ -1536,7 +1534,7 @@ void XMLSectionExport::ExportIndexTemplateElement(
         // export template
         SvXMLElementExport aTemplateElement(GetExport(), XML_NAMESPACE_TEXT,
                                             GetXMLToken(eElement),
-                                            sal_True, sal_False)
+                                            true, false)
             ;
 
         // entry text or span element: write text
@@ -1574,7 +1572,7 @@ void XMLSectionExport::ExportLevelParagraphStyles(
             SvXMLElementExport aParaStyles(GetExport(),
                                            XML_NAMESPACE_TEXT,
                                            XML_INDEX_SOURCE_STYLES,
-                                           sal_True, sal_True);
+                                           true, true);
 
             // iterate over styles in this level
             for(sal_Int32 nName = 0; nName < nNamesCount; nName++)
@@ -1588,7 +1586,7 @@ void XMLSectionExport::ExportLevelParagraphStyles(
                 SvXMLElementExport aParaStyle(GetExport(),
                                               XML_NAMESPACE_TEXT,
                                               XML_INDEX_SOURCE_STYLE,
-                                              sal_True, sal_False);
+                                              true, false);
             }
         }
     }
@@ -1598,18 +1596,17 @@ void XMLSectionExport::ExportBoolean(
     const Reference<XPropertySet> & rPropSet,
     const OUString& sPropertyName,
     enum XMLTokenEnum eAttributeName,
-    sal_Bool bDefault,
-    sal_Bool bInvert)
+    bool bDefault,
+    bool bInvert)
 {
     OSL_ENSURE(eAttributeName != XML_TOKEN_INVALID, "Need attribute name");
 
     Any aAny = rPropSet->getPropertyValue(sPropertyName);
-    sal_Bool bTmp = *(sal_Bool*)aAny.getValue();
+    bool bTmp = *static_cast<sal_Bool const *>(aAny.getValue());
 
     // value = value ^ bInvert
     // omit if value == default
-    // negate forces sal_Bool to 0/1, making them comparable
-    if ((!(bTmp ^ bInvert)) != (!bDefault))
+    if ( (bTmp != bInvert) != bDefault )
     {
         // export non-default value (since default is omitted)
         GetExport().AddAttribute(XML_NAMESPACE_TEXT,
@@ -1620,8 +1617,6 @@ void XMLSectionExport::ExportBoolean(
 
 const sal_Char sAPI_FieldMaster_Bibliography[] =
                                 "com.sun.star.text.FieldMaster.Bibliography";
-const sal_Char sAPI_SortKey[] = "SortKey";
-const sal_Char sAPI_IsSortAscending[] = "IsSortAscending";
 
 void XMLSectionExport::ExportBibliographyConfiguration(SvXMLExport& rExport)
 {
@@ -1663,14 +1658,14 @@ void XMLSectionExport::ExportBibliographyConfiguration(SvXMLExport& rExport)
             rExport.AddAttribute(XML_NAMESPACE_TEXT, XML_SUFFIX, sTmp);
 
             aAny = xPropSet->getPropertyValue(sIsNumberEntries);
-            if (*(sal_Bool*)aAny.getValue())
+            if (*static_cast<sal_Bool const *>(aAny.getValue()))
             {
                 rExport.AddAttribute(XML_NAMESPACE_TEXT,
                                      XML_NUMBERED_ENTRIES, XML_TRUE);
             }
 
             aAny = xPropSet->getPropertyValue(sIsSortByPosition);
-            if (! *(sal_Bool*)aAny.getValue())
+            if (! *static_cast<sal_Bool const *>(aAny.getValue()))
             {
                 rExport.AddAttribute(XML_NAMESPACE_TEXT,
                                      XML_SORT_BY_POSITION, XML_FALSE);
@@ -1695,7 +1690,7 @@ void XMLSectionExport::ExportBibliographyConfiguration(SvXMLExport& rExport)
             // configuration element
             SvXMLElementExport aElement(rExport, XML_NAMESPACE_TEXT,
                                         XML_BIBLIOGRAPHY_CONFIGURATION,
-                                        sal_True, sal_True);
+                                        true, true);
 
             // sort keys
             aAny = xPropSet->getPropertyValue(sSortKeys);
@@ -1711,8 +1706,7 @@ void XMLSectionExport::ExportBibliographyConfiguration(SvXMLExport& rExport)
                 {
                     PropertyValue& rValue = rKey[nPropertyKey];
 
-                    if (rValue.Name.equalsAsciiL(sAPI_SortKey,
-                                                 sizeof(sAPI_SortKey)-1))
+                    if (rValue.Name == "SortKey")
                     {
                         sal_Int16 nKey = 0;
                         rValue.Value >>= nKey;
@@ -1724,10 +1718,9 @@ void XMLSectionExport::ExportBibliographyConfiguration(SvXMLExport& rExport)
                                                  sBuf.makeStringAndClear());
                         }
                     }
-                    else if (rValue.Name.equalsAsciiL(sAPI_IsSortAscending,
-                                            sizeof(sAPI_IsSortAscending)-1))
+                    else if (rValue.Name == "IsSortAscending")
                     {
-                        sal_Bool bTmp = *(sal_Bool*)rValue.Value.getValue();
+                        bool bTmp = *static_cast<sal_Bool const *>(rValue.Value.getValue());
                         rExport.AddAttribute(XML_NAMESPACE_TEXT,
                                              XML_SORT_ASCENDING,
                                              bTmp ? XML_TRUE : XML_FALSE);
@@ -1736,17 +1729,17 @@ void XMLSectionExport::ExportBibliographyConfiguration(SvXMLExport& rExport)
 
                 SvXMLElementExport aKeyElem(rExport,
                                             XML_NAMESPACE_TEXT, XML_SORT_KEY,
-                                            sal_True, sal_True);
+                                            true, true);
             }
         }
     }
 }
 
 
-sal_Bool XMLSectionExport::IsMuteSection(
+bool XMLSectionExport::IsMuteSection(
     const Reference<XTextSection> & rSection) const
 {
-    sal_Bool bRet = sal_False;
+    bool bRet = false;
 
     // a section is mute if
     // 1) it exists
@@ -1767,12 +1760,12 @@ sal_Bool XMLSectionExport::IsMuteSection(
             {
                 Any aAny = xPropSet->getPropertyValue(sIsGlobalDocumentSection);
 
-                if ( *(sal_Bool*)aAny.getValue() )
+                if ( *static_cast<sal_Bool const *>(aAny.getValue()) )
                 {
                     Reference<XDocumentIndex> xIndex;
                     if (! GetIndex(rSection, xIndex))
                     {
-                        bRet = sal_True;
+                        bRet = true;
 
                         // early out if result is known
                         break;
@@ -1787,12 +1780,12 @@ sal_Bool XMLSectionExport::IsMuteSection(
     return bRet;
 }
 
-sal_Bool XMLSectionExport::IsMuteSection(
+bool XMLSectionExport::IsMuteSection(
     const Reference<XTextContent> & rSection,
-    sal_Bool bDefault) const
+    bool bDefault) const
 {
     // default: like default argument
-    sal_Bool bRet = bDefault;
+    bool bRet = bDefault;
 
     Reference<XPropertySet> xPropSet(rSection->getAnchor(), UNO_QUERY);
     if (xPropSet.is())
@@ -1812,13 +1805,13 @@ sal_Bool XMLSectionExport::IsMuteSection(
     return bRet;
 }
 
-sal_Bool XMLSectionExport::IsInSection(
+bool XMLSectionExport::IsInSection(
     const Reference<XTextSection> & rEnclosingSection,
     const Reference<XTextContent> & rContent,
-    sal_Bool bDefault)
+    bool bDefault)
 {
     // default: like default argument
-    sal_Bool bRet = bDefault;
+    bool bRet = bDefault;
     OSL_ENSURE(rEnclosingSection.is(), "enclosing section expected");
 
     Reference<XPropertySet> xPropSet(rContent, UNO_QUERY);
@@ -1841,7 +1834,7 @@ sal_Bool XMLSectionExport::IsInSection(
                 while (!bRet && xSection.is());
             }
             else
-                bRet = sal_False;   // no section -> can't be inside
+                bRet = false;   // no section -> can't be inside
         }
         // else: no TextSection property -> return default
     }
@@ -1890,11 +1883,11 @@ void XMLSectionExport::ExportMasterDocHeadingDummies()
             GetExport().AddAttribute( XML_NAMESPACE_TEXT, XML_LEVEL,
                                         sTmp.makeStringAndClear() );
             SvXMLElementExport aElem( GetExport(), XML_NAMESPACE_TEXT, XML_H,
-                                        sal_True, sal_False );
+                                        true, false );
         }
     }
 
-    bHeadingDummiesExported  = sal_True;
+    bHeadingDummiesExported  = true;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
